Description: Schema.org is a set of extensible schemas that enables webmasters to embed structured data on their web pages for use by search engines and other applications.

Full Release Summary - Schema.org
Schema.org

- Documentation
- Schemas
- About

Note: you are viewing the development version of Schema.org. See How we work for more details.

# Schema.org Version 12.0

Version:
  12.0
Archive URL:
  https://github.com/schemaorg/schemaorg/tree/main/data/releases/12.0/
Published:
  2021-03-08
Alternate formats:
  This release, full core and extension definition files in N-Triples, Quads, JSON-LD, and Turtle formats, are also available for download.

Overview: This is a full release summary for schema.org. It describes in one document the terms (types, properties and enumerations) included in this version of schema.org. The live site offers various other page-by-page views that include more information and examples. Note that schema.org release numbers are not generally included when you use schema.org. In contexts (e.g. related standards work) when a particular release needs to be cited, this document provides the appropriate URL.

See the releases page for information about other schema.org releases.

Status: this document represents a stable release of schema.org, and is automatically generated from the underlying canonical RDFS-based schema data. Although the formal schema dataset associated with this release will not change, we may update the formatting (tracked as issue #484), layout and other details of this document to improve the presentation of this information. Similarly, the encoding and publication details (RDFa/RDFS etc.) for the machine-readable schema file may evolve; however the data encoded should be considered canonical and frozen for each release. We solicit advice on data formats that are useful for publishers and consumers of schema.org data.

The structure of this document is simple: it provides an alphabetic list of types, and then properties, as they are defined in this version of schema.org.

#### Type hierarchy

- Thing
  - Action
    - AchieveAction
      - LoseAction
      - TieAction
      - WinAction
    - AssessAction
      - ChooseAction
        - VoteAction
      - IgnoreAction
      - ReactAction
        - AgreeAction
        - DisagreeAction
        - DislikeAction
        - EndorseAction
        - LikeAction
        - WantAction
      - ReviewAction
    - ConsumeAction
      - DrinkAction
      - EatAction
      - InstallAction
      - ListenAction
      - ReadAction
      - UseAction
        - WearAction
      - ViewAction
      - WatchAction
    - ControlAction
      - ActivateAction
      - DeactivateAction
      - ResumeAction
      - SuspendAction
    - CreateAction
      - CookAction
      - DrawAction
      - FilmAction
      - PaintAction
      - PhotographAction
      - WriteAction
    - FindAction
      - CheckAction
      - DiscoverAction
      - TrackAction
    - InteractAction
      - BefriendAction
      - CommunicateAction
        - AskAction
        - CheckInAction
        - CheckOutAction
        - CommentAction
        - InformAction
          - ConfirmAction
          - RsvpAction
        - InviteAction
        - ReplyAction
        - ShareAction
      - FollowAction
      - JoinAction
      - LeaveAction
      - MarryAction
      - RegisterAction
      - SubscribeAction
      - UnRegisterAction
    - MoveAction
      - ArriveAction
      - DepartAction
      - TravelAction
    - OrganizeAction
      - AllocateAction
        - AcceptAction
        - AssignAction
        - AuthorizeAction
        - RejectAction
      - ApplyAction
      - BookmarkAction
      - PlanAction
        - CancelAction
        - ReserveAction
        - ScheduleAction
    - PlayAction
      - ExerciseAction
      - PerformAction
    - SearchAction
    - SeekToAction
    - SolveMathAction
    - TradeAction
      - BuyAction
      - DonateAction
      - OrderAction
      - PayAction
      - PreOrderAction
      - QuoteAction
      - RentAction
      - SellAction
      - TipAction
    - TransferAction
      - BorrowAction
      - DownloadAction
      - GiveAction
      - LendAction
      - MoneyTransfer
      - ReceiveAction
      - ReturnAction
      - SendAction
      - TakeAction
    - UpdateAction
      - AddAction
        - InsertAction
          - AppendAction
          - PrependAction
      - DeleteAction
      - ReplaceAction
  - CreativeWork
    - AmpStory
    - ArchiveComponent
    - Article
      - AdvertiserContentArticle
      - NewsArticle
        - AnalysisNewsArticle
        - AskPublicNewsArticle
        - BackgroundNewsArticle
        - OpinionNewsArticle
        - ReportageNewsArticle
        - ReviewNewsArticle
      - Report
      - SatiricalArticle
      - ScholarlyArticle
        - MedicalScholarlyArticle
      - SocialMediaPosting
        - BlogPosting
          - LiveBlogPosting
        - DiscussionForumPosting
      - TechArticle
        - APIReference
    - Atlas
    - Blog
    - Book
      - Audiobook
    - Chapter
    - Claim
    - Clip
      - MovieClip
      - RadioClip
      - TVClip
      - VideoGameClip
    - Code
    - Collection
      - ProductCollection
    - ComicStory
      - ComicCoverArt
    - Comment
      - Answer
      - CorrectionComment
      - Question
    - Conversation
    - Course
    - CreativeWorkSeason
      - PodcastSeason
      - RadioSeason
      - TVSeason
    - CreativeWorkSeries
      - BookSeries
      - MovieSeries
      - Periodical
        - ComicSeries
        - Newspaper
      - PodcastSeries
      - RadioSeries
      - TVSeries
      - VideoGameSeries
    - DataCatalog
    - Dataset
      - DataFeed
        - CompleteDataFeed
    - DefinedTermSet
      - CategoryCodeSet
    - Diet
    - DigitalDocument
      - NoteDigitalDocument
      - PresentationDigitalDocument
      - SpreadsheetDigitalDocument
      - TextDigitalDocument
    - Drawing
    - EducationalOccupationalCredential
    - Episode
      - PodcastEpisode
      - RadioEpisode
      - TVEpisode
    - ExercisePlan
    - Game
      - VideoGame
    - Guide
    - HowTo
      - Recipe
    - HowToDirection
    - HowToSection
    - HowToStep
    - HowToTip
    - HyperToc
    - HyperTocEntry
    - LearningResource
      - Course +
      - Quiz
    - Legislation
      - LegislationObject
    - Manuscript
    - Map
    - MathSolver
    - MediaObject
      - 3DModel
      - AudioObject
        - Audiobook +
      - DataDownload
      - ImageObject
        - Barcode
      - LegislationObject +
      - MusicVideoObject
      - VideoObject
    - Menu
    - MenuSection
    - Message
      - EmailMessage
    - Movie
    - MusicComposition
    - MusicPlaylist
      - MusicAlbum
      - MusicRelease
    - MusicRecording
    - Painting
    - Photograph
    - Play
    - Poster
    - PublicationIssue
      - ComicIssue
    - PublicationVolume
    - Quotation
    - Review
      - ClaimReview
      - CriticReview
        - ReviewNewsArticle +
      - EmployerReview
      - MediaReview
      - Recommendation
      - UserReview
    - Sculpture
    - Season
    - SheetMusic
    - ShortStory
    - SoftwareApplication
      - MobileApplication
      - VideoGame +
      - WebApplication
    - SoftwareSourceCode
    - SpecialAnnouncement
    - TVSeason +
    - TVSeries +
    - Thesis
    - VisualArtwork
      - CoverArt
        - ComicCoverArt +
    - WebContent
      - HealthTopicContent
    - WebPage
      - AboutPage
      - CheckoutPage
      - CollectionPage
        - MediaGallery
          - ImageGallery
          - VideoGallery
      - ContactPage
      - FAQPage
      - ItemPage
      - MedicalWebPage
      - ProfilePage
      - QAPage
      - RealEstateListing
      - SearchResultsPage
    - WebPageElement
      - SiteNavigationElement
      - Table
      - WPAdBlock
      - WPFooter
      - WPHeader
      - WPSideBar
    - WebSite
  - Event
    - BusinessEvent
    - ChildrensEvent
    - ComedyEvent
    - CourseInstance
    - DanceEvent
    - DeliveryEvent
    - EducationEvent
    - EventSeries
    - ExhibitionEvent
    - Festival
    - FoodEvent
    - Hackathon
    - LiteraryEvent
    - MusicEvent
    - PublicationEvent
      - BroadcastEvent
      - OnDemandEvent
    - SaleEvent
    - ScreeningEvent
    - SocialEvent
    - SportsEvent
    - TheaterEvent
    - UserInteraction
      - UserBlocks
      - UserCheckins
      - UserComments
      - UserDownloads
      - UserLikes
      - UserPageVisits
      - UserPlays
      - UserPlusOnes
      - UserTweets
    - VisualArtsEvent
  - Intangible
    - ActionAccessSpecification
    - AlignmentObject
    - Audience
      - BusinessAudience
      - EducationalAudience
      - MedicalAudience
        - Patient
      - PeopleAudience
        - MedicalAudience +
        - ParentAudience
      - Researcher
    - BedDetails
    - Brand
    - BroadcastChannel
      - RadioChannel
        - AMRadioChannel
        - FMRadioChannel
      - TelevisionChannel
    - BroadcastFrequencySpecification
    - Class
    - ComputerLanguage
    - DataFeedItem
    - DefinedTerm
      - CategoryCode
        - MedicalCode
    - Demand
    - DigitalDocumentPermission
    - EducationalOccupationalProgram
      - WorkBasedProgram
    - EnergyConsumptionDetails
    - EntryPoint
    - Enumeration
      - BoardingPolicyType
        - GroupBoardingPolicy
        - ZoneBoardingPolicy
      - BookFormatType
        - AudiobookFormat
        - EBook
        - GraphicNovel
        - Hardcover
        - Paperback
      - BusinessEntityType
      - BusinessFunction
      - CarUsageType
        - DrivingSchoolVehicleUsage
        - RentalVehicleUsage
        - TaxiVehicleUsage
      - ContactPointOption
        - HearingImpairedSupported
        - TollFree
      - DayOfWeek
        - Friday
        - Monday
        - PublicHolidays
        - Saturday
        - Sunday
        - Thursday
        - Tuesday
        - Wednesday
      - DeliveryMethod
        - LockerDelivery
        - OnSitePickup
        - ParcelService
      - DigitalDocumentPermissionType
        - CommentPermission
        - ReadPermission
        - WritePermission
      - EnergyEfficiencyEnumeration
        - EUEnergyEfficiencyEnumeration
          - EUEnergyEfficiencyCategoryA
          - EUEnergyEfficiencyCategoryA1Plus
          - EUEnergyEfficiencyCategoryA2Plus
          - EUEnergyEfficiencyCategoryA3Plus
          - EUEnergyEfficiencyCategoryB
          - EUEnergyEfficiencyCategoryC
          - EUEnergyEfficiencyCategoryD
          - EUEnergyEfficiencyCategoryE
          - EUEnergyEfficiencyCategoryF
          - EUEnergyEfficiencyCategoryG
        - EnergyStarEnergyEfficiencyEnumeration
          - EnergyStarCertified
      - EventAttendanceModeEnumeration
        - MixedEventAttendanceMode
        - OfflineEventAttendanceMode
        - OnlineEventAttendanceMode
      - GamePlayMode
        - CoOp
        - MultiPlayer
        - SinglePlayer
      - GenderType
        - Female
        - Male
      - GovernmentBenefitsType
        - BasicIncome
        - BusinessSupport
        - DisabilitySupport
        - HealthCare
        - OneTimePayments
        - PaidLeave
        - ParentalSupport
        - UnemploymentSupport
      - HealthAspectEnumeration
        - AllergiesHealthAspect
        - BenefitsHealthAspect
        - CausesHealthAspect
        - ContagiousnessHealthAspect
        - EffectivenessHealthAspect
        - GettingAccessHealthAspect
        - HowItWorksHealthAspect
        - HowOrWhereHealthAspect
        - IngredientsHealthAspect
        - LivingWithHealthAspect
        - MayTreatHealthAspect
        - MisconceptionsHealthAspect
        - OverviewHealthAspect
        - PatientExperienceHealthAspect
        - PregnancyHealthAspect
        - PreventionHealthAspect
        - PrognosisHealthAspect
        - RelatedTopicsHealthAspect
        - RisksOrComplicationsHealthAspect
        - SafetyHealthAspect
        - ScreeningHealthAspect
        - SeeDoctorHealthAspect
        - SelfCareHealthAspect
        - SideEffectsHealthAspect
        - StagesHealthAspect
        - SymptomsHealthAspect
        - TreatmentsHealthAspect
        - TypesHealthAspect
        - UsageOrScheduleHealthAspect
      - ItemAvailability
        - BackOrder
        - Discontinued
        - InStock
        - InStoreOnly
        - LimitedAvailability
        - OnlineOnly
        - OutOfStock
        - PreOrder
        - PreSale
        - SoldOut
      - ItemListOrderType
        - ItemListOrderAscending
        - ItemListOrderDescending
        - ItemListUnordered
      - LegalValueLevel
        - AuthoritativeLegalValue
        - DefinitiveLegalValue
        - OfficialLegalValue
        - UnofficialLegalValue
      - MapCategoryType
        - ParkingMap
        - SeatingMap
        - TransitMap
        - VenueMap
      - MeasurementTypeEnumeration
        - BodyMeasurementTypeEnumeration
          - BodyMeasurementArm
          - BodyMeasurementBust
          - BodyMeasurementChest
          - BodyMeasurementFoot
          - BodyMeasurementHand
          - BodyMeasurementHead
          - BodyMeasurementHeight
          - BodyMeasurementHips
          - BodyMeasurementInsideLeg
          - BodyMeasurementNeck
          - BodyMeasurementUnderbust
          - BodyMeasurementWaist
          - BodyMeasurementWeight
        - WearableMeasurementTypeEnumeration
          - WearableMeasurementBack
          - WearableMeasurementChestOrBust
          - WearableMeasurementCollar
          - WearableMeasurementCup
          - WearableMeasurementHeight
          - WearableMeasurementHips
          - WearableMeasurementInseam
          - WearableMeasurementLength
          - WearableMeasurementOutsideLeg
          - WearableMeasurementSleeve
          - WearableMeasurementWaist
          - WearableMeasurementWidth
      - MediaManipulationRatingEnumeration
        - DecontextualizedContent
        - EditedOrCroppedContent
        - OriginalMediaContent
        - SatireOrParodyContent
        - StagedContent
        - TransformedContent
      - MedicalEnumeration
        - DrugCostCategory
          - ReimbursementCap
          - Retail
          - Wholesale
        - DrugPregnancyCategory
          - FDAcategoryA
          - FDAcategoryB
          - FDAcategoryC
          - FDAcategoryD
          - FDAcategoryX
          - FDAnotEvaluated
        - DrugPrescriptionStatus
          - OTC
          - PrescriptionOnly
        - InfectiousAgentClass
          - Bacteria
          - Fungus
          - MulticellularParasite
          - Prion
          - Protozoa
          - Virus
        - MedicalAudienceType
          - Clinician
          - MedicalResearcher
        - MedicalDevicePurpose
          - Diagnostic
          - Therapeutic
        - MedicalEvidenceLevel
          - EvidenceLevelA
          - EvidenceLevelB
          - EvidenceLevelC
        - MedicalImagingTechnique
          - CT
          - MRI
          - PET
          - Radiography
          - Ultrasound
          - XRay
        - MedicalObservationalStudyDesign
          - CaseSeries
          - CohortStudy
          - CrossSectional
          - Longitudinal
          - Observational
          - Registry
        - MedicalProcedureType
          - NoninvasiveProcedure
          - PercutaneousProcedure
        - MedicalSpecialty
          - Anesthesia
          - Cardiovascular
          - CommunityHealth
          - Dentistry
          - Dermatologic
          - Dermatology
          - DietNutrition
          - Emergency
          - Endocrine
          - Gastroenterologic
          - Genetic
          - Geriatric
          - Gynecologic
          - Hematologic
          - Infectious
          - LaboratoryScience
          - Midwifery
          - Musculoskeletal
          - Neurologic
          - Nursing
          - Obstetric
          - Oncologic
          - Optometric
          - Otolaryngologic
          - Pathology
          - Pediatric
          - PharmacySpecialty
          - Physiotherapy
          - PlasticSurgery
          - Podiatric
          - PrimaryCare
          - Psychiatric
          - PublicHealth
          - Pulmonary
          - Radiography +
          - Renal
          - RespiratoryTherapy
          - Rheumatologic
          - SpeechPathology
          - Surgical
          - Toxicologic
          - Urologic
        - MedicalStudyStatus
          - ActiveNotRecruiting
          - Completed
          - EnrollingByInvitation
          - NotYetRecruiting
          - Recruiting
          - ResultsAvailable
          - ResultsNotAvailable
          - Suspended
          - Terminated
          - Withdrawn
        - MedicalTrialDesign
          - DoubleBlindedTrial
          - InternationalTrial
          - MultiCenterTrial
          - OpenTrial
          - PlaceboControlledTrial
          - RandomizedTrial
          - SingleBlindedTrial
          - SingleCenterTrial
          - TripleBlindedTrial
        - MedicineSystem
          - Ayurvedic
          - Chiropractic
          - Homeopathic
          - Osteopathic
          - TraditionalChinese
          - WesternConventional
        - PhysicalExam
          - Abdomen
          - Appearance
          - CardiovascularExam
          - Ear
          - Eye
          - Genitourinary
          - Head
          - Lung
          - MusculoskeletalExam
          - Neck
          - Neuro
          - Nose
          - Skin
          - Throat
      - MerchantReturnEnumeration
        - MerchantReturnFiniteReturnWindow
        - MerchantReturnNotPermitted
        - MerchantReturnUnlimitedWindow
        - MerchantReturnUnspecified
      - MusicAlbumProductionType
        - CompilationAlbum
        - DJMixAlbum
        - DemoAlbum
        - LiveAlbum
        - MixtapeAlbum
        - RemixAlbum
        - SoundtrackAlbum
        - SpokenWordAlbum
        - StudioAlbum
      - MusicAlbumReleaseType
        - AlbumRelease
        - BroadcastRelease
        - EPRelease
        - SingleRelease
      - MusicReleaseFormatType
        - CDFormat
        - CassetteFormat
        - DVDFormat
        - DigitalAudioTapeFormat
        - DigitalFormat
        - LaserDiscFormat
        - VinylFormat
      - NonprofitType
        - NLNonprofitType
          - NonprofitANBI
          - NonprofitSBBI
        - UKNonprofitType
          - CharitableIncorporatedOrganization
          - LimitedByGuaranteeCharity
          - UKTrust
          - UnincorporatedAssociationCharity
        - USNonprofitType
          - Nonprofit501a
          - Nonprofit501c1
          - Nonprofit501c10
          - Nonprofit501c11
          - Nonprofit501c12
          - Nonprofit501c13
          - Nonprofit501c14
          - Nonprofit501c15
          - Nonprofit501c16
          - Nonprofit501c17
          - Nonprofit501c18
          - Nonprofit501c19
          - Nonprofit501c2
          - Nonprofit501c20
          - Nonprofit501c21
          - Nonprofit501c22
          - Nonprofit501c23
          - Nonprofit501c24
          - Nonprofit501c25
          - Nonprofit501c26
          - Nonprofit501c27
          - Nonprofit501c28
          - Nonprofit501c3
          - Nonprofit501c4
          - Nonprofit501c5
          - Nonprofit501c6
          - Nonprofit501c7
          - Nonprofit501c8
          - Nonprofit501c9
          - Nonprofit501d
          - Nonprofit501e
          - Nonprofit501f
          - Nonprofit501k
          - Nonprofit501n
          - Nonprofit501q
          - Nonprofit527
      - OfferItemCondition
        - DamagedCondition
        - NewCondition
        - RefurbishedCondition
        - UsedCondition
      - PaymentMethod
        - PaymentCard
          - CreditCard
      - PhysicalActivityCategory
        - AerobicActivity
        - AnaerobicActivity
        - Balance
        - Flexibility
        - LeisureTimeActivity
        - OccupationalActivity
        - StrengthTraining
      - PriceComponentTypeEnumeration
        - ActivationFee
        - CleaningFee
        - DistanceFee
        - Downpayment
        - Installment
        - Subscription
      - PriceTypeEnumeration
        - InvoicePrice
        - ListPrice
        - MSRP
        - MinimumAdvertisedPrice
        - SRP
        - SalePrice
      - QualitativeValue
        - BedType
        - DriveWheelConfigurationValue
          - AllWheelDriveConfiguration
          - FourWheelDriveConfiguration
          - FrontWheelDriveConfiguration
          - RearWheelDriveConfiguration
        - SizeSpecification
        - SteeringPositionValue
          - LeftHandDriving
          - RightHandDriving
      - RefundTypeEnumeration
        - ExchangeRefund
        - FullRefund
        - StoreCreditRefund
      - RestrictedDiet
        - DiabeticDiet
        - GlutenFreeDiet
        - HalalDiet
        - HinduDiet
        - KosherDiet
        - LowCalorieDiet
        - LowFatDiet
        - LowLactoseDiet
        - LowSaltDiet
        - VeganDiet
        - VegetarianDiet
      - ReturnFeesEnumeration
        - OriginalShippingFees
        - RestockingFees
        - ReturnShippingFees
      - RsvpResponseType
        - RsvpResponseMaybe
        - RsvpResponseNo
        - RsvpResponseYes
      - SizeGroupEnumeration
        - WearableSizeGroupEnumeration
          - WearableSizeGroupBig
          - WearableSizeGroupBoys
          - WearableSizeGroupExtraShort
          - WearableSizeGroupExtraTall
          - WearableSizeGroupGirls
          - WearableSizeGroupHusky
          - WearableSizeGroupInfants
          - WearableSizeGroupJuniors
          - WearableSizeGroupMaternity
          - WearableSizeGroupMens
          - WearableSizeGroupMisses
          - WearableSizeGroupPetite
          - WearableSizeGroupPlus
          - WearableSizeGroupRegular
          - WearableSizeGroupShort
          - WearableSizeGroupTall
          - WearableSizeGroupWomens
      - SizeSystemEnumeration
        - SizeSystemImperial
        - SizeSystemMetric
        - WearableSizeSystemEnumeration
          - WearableSizeSystemAU
          - WearableSizeSystemBR
          - WearableSizeSystemCN
          - WearableSizeSystemContinental
          - WearableSizeSystemDE
          - WearableSizeSystemEN13402
          - WearableSizeSystemEurope
          - WearableSizeSystemFR
          - WearableSizeSystemGS1
          - WearableSizeSystemIT
          - WearableSizeSystemJP
          - WearableSizeSystemMX
          - WearableSizeSystemUK
          - WearableSizeSystemUS
      - Specialty
        - MedicalSpecialty +
      - StatusEnumeration
        - ActionStatusType
          - ActiveActionStatus
          - CompletedActionStatus
          - FailedActionStatus
          - PotentialActionStatus
        - EventStatusType
          - EventCancelled
          - EventMovedOnline
          - EventPostponed
          - EventRescheduled
          - EventScheduled
        - GameServerStatus
          - OfflinePermanently
          - OfflineTemporarily
          - Online
          - OnlineFull
        - LegalForceStatus
          - InForce
          - NotInForce
          - PartiallyInForce
        - OrderStatus
          - OrderCancelled
          - OrderDelivered
          - OrderInTransit
          - OrderPaymentDue
          - OrderPickupAvailable
          - OrderProblem
          - OrderProcessing
          - OrderReturned
        - PaymentStatusType
          - PaymentAutomaticallyApplied
          - PaymentComplete
          - PaymentDeclined
          - PaymentDue
          - PaymentPastDue
        - ReservationStatusType
          - ReservationCancelled
          - ReservationConfirmed
          - ReservationHold
          - ReservationPending
      - WarrantyScope
    - FloorPlan
    - GameServer
    - GeospatialGeometry
    - Grant
      - MonetaryGrant
    - HealthInsurancePlan
    - HealthPlanCostSharingSpecification
    - HealthPlanFormulary
    - HealthPlanNetwork
    - Invoice
    - ItemList
      - BreadcrumbList
      - HowToSection +
      - HowToStep +
      - OfferCatalog
    - JobPosting
    - Language
    - ListItem
      - HowToDirection +
      - HowToItem
        - HowToSupply
        - HowToTool
      - HowToSection +
      - HowToStep +
      - HowToTip +
    - MediaSubscription
    - MenuItem
    - MerchantReturnPolicy
    - Observation
    - Occupation
    - OccupationalExperienceRequirements
    - Offer
      - AggregateOffer
      - OfferForLease
      - OfferForPurchase
    - Order
    - OrderItem
    - ParcelDelivery
    - Permit
      - GovernmentPermit
    - ProgramMembership
    - Property
    - PropertyValueSpecification
    - Quantity
      - Distance
      - Duration
      - Energy
      - Mass
    - Rating
      - AggregateRating
        - EmployerAggregateRating
      - EndorsementRating
    - Reservation
      - BoatReservation
      - BusReservation
      - EventReservation
      - FlightReservation
      - FoodEstablishmentReservation
      - LodgingReservation
      - RentalCarReservation
      - ReservationPackage
      - TaxiReservation
      - TrainReservation
    - Role
      - LinkRole
      - OrganizationRole
        - EmployeeRole
      - PerformanceRole
    - Schedule
    - Seat
    - Series
      - CreativeWorkSeries +
      - EventSeries +
    - Service
      - BroadcastService
        - RadioBroadcastService
      - CableOrSatelliteService
      - FinancialProduct
        - BankAccount
          - DepositAccount
        - CurrencyConversionService
        - InvestmentOrDeposit
          - BrokerageAccount
          - DepositAccount +
          - InvestmentFund
        - LoanOrCredit
          - CreditCard +
          - MortgageLoan
        - PaymentCard +
        - PaymentService
      - FoodService
      - GovernmentService
      - Taxi
      - TaxiService
      - WebAPI
    - ServiceChannel
    - SpeakableSpecification
    - StatisticalPopulation
    - StructuredValue
      - CDCPMDRecord
      - ContactPoint
        - PostalAddress
      - DatedMoneySpecification
      - DefinedRegion
      - DeliveryTimeSettings
      - EngineSpecification
      - ExchangeRateSpecification
      - GeoCoordinates
      - GeoShape
        - GeoCircle
      - InteractionCounter
      - MonetaryAmount
      - NutritionInformation
      - OfferShippingDetails
      - OpeningHoursSpecification
      - OwnershipInfo
      - PostalCodeRangeSpecification
      - PriceSpecification
        - CompoundPriceSpecification
        - DeliveryChargeSpecification
        - PaymentChargeSpecification
        - UnitPriceSpecification
      - PropertyValue
        - LocationFeatureSpecification
      - QuantitativeValue
      - QuantitativeValueDistribution
        - MonetaryAmountDistribution
      - RepaymentSpecification
      - ShippingDeliveryTime
      - ShippingRateSettings
      - TypeAndQuantityNode
      - WarrantyPromise
    - Ticket
    - Trip
      - BoatTrip
      - BusTrip
      - Flight
      - TouristTrip
      - TrainTrip
    - VirtualLocation
  - MedicalEntity
    - AnatomicalStructure
      - Bone
      - BrainStructure
      - Joint
      - Ligament
      - Muscle
      - Nerve
      - Vessel
        - Artery
        - LymphaticVessel
        - Vein
    - AnatomicalSystem
    - DrugClass
    - DrugCost
    - LifestyleModification
      - Diet +
      - PhysicalActivity
        - ExercisePlan +
    - MedicalCause
    - MedicalCondition
      - InfectiousDisease
      - MedicalSignOrSymptom
        - MedicalSign
          - VitalSign
        - MedicalSymptom
    - MedicalContraindication
    - MedicalDevice
    - MedicalGuideline
      - MedicalGuidelineContraindication
      - MedicalGuidelineRecommendation
    - MedicalIndication
      - ApprovedIndication
      - PreventionIndication
      - TreatmentIndication
    - MedicalIntangible
      - DDxElement
      - DoseSchedule
        - MaximumDoseSchedule
        - RecommendedDoseSchedule
        - ReportedDoseSchedule
      - DrugLegalStatus
      - DrugStrength
      - MedicalCode +
      - MedicalConditionStage
    - MedicalProcedure
      - DiagnosticProcedure
      - PalliativeProcedure
      - PhysicalExam +
      - SurgicalProcedure
      - TherapeuticProcedure
        - MedicalTherapy
          - OccupationalTherapy
          - PalliativeProcedure +
          - PhysicalTherapy
          - RadiationTherapy
          - RespiratoryTherapy +
        - PsychologicalTreatment
    - MedicalRiskEstimator
      - MedicalRiskCalculator
      - MedicalRiskScore
    - MedicalRiskFactor
    - MedicalStudy
      - MedicalObservationalStudy
      - MedicalTrial
    - MedicalTest
      - BloodTest
      - ImagingTest
      - MedicalTestPanel
      - PathologyTest
    - Substance
      - DietarySupplement
      - Drug
    - SuperficialAnatomy
  - Organization
    - Airline
    - Consortium
    - Corporation
    - EducationalOrganization
      - CollegeOrUniversity
      - ElementarySchool
      - HighSchool
      - MiddleSchool
      - Preschool
      - School
    - FundingScheme
    - GovernmentOrganization
    - LibrarySystem
    - LocalBusiness
      - AnimalShelter
      - ArchiveOrganization
      - AutomotiveBusiness
        - AutoBodyShop
        - AutoDealer
        - AutoPartsStore
        - AutoRental
        - AutoRepair
        - AutoWash
        - GasStation
        - MotorcycleDealer
        - MotorcycleRepair
      - ChildCare
      - Dentist
      - DryCleaningOrLaundry
      - EmergencyService
        - FireStation
        - Hospital
        - PoliceStation
      - EmploymentAgency
      - EntertainmentBusiness
        - AdultEntertainment
        - AmusementPark
        - ArtGallery
        - Casino
        - ComedyClub
        - MovieTheater
        - NightClub
      - FinancialService
        - AccountingService
        - AutomatedTeller
        - BankOrCreditUnion
        - InsuranceAgency
      - FoodEstablishment
        - Bakery
        - BarOrPub
        - Brewery
        - CafeOrCoffeeShop
        - Distillery
        - FastFoodRestaurant
        - IceCreamShop
        - Restaurant
        - Winery
      - GovernmentOffice
        - PostOffice
      - HealthAndBeautyBusiness
        - BeautySalon
        - DaySpa
        - HairSalon
        - HealthClub
        - NailSalon
        - TattooParlor
      - HomeAndConstructionBusiness
        - Electrician
        - GeneralContractor
        - HVACBusiness
        - HousePainter
        - Locksmith
        - MovingCompany
        - Plumber
        - RoofingContractor
      - InternetCafe
      - LegalService
        - Attorney
        - Notary
      - Library
      - LodgingBusiness
        - BedAndBreakfast
        - Campground
        - Hostel
        - Hotel
        - Motel
        - Resort
          - SkiResort
      - MedicalBusiness
        - CommunityHealth +
        - Dentist +
        - Dermatology +
        - DietNutrition +
        - Emergency +
        - Geriatric +
        - Gynecologic +
        - MedicalClinic
          - CovidTestingFacility
        - Midwifery +
        - Nursing +
        - Obstetric +
        - Oncologic +
        - Optician
        - Optometric +
        - Otolaryngologic +
        - Pediatric +
        - Pharmacy
        - Physician
        - Physiotherapy +
        - PlasticSurgery +
        - Podiatric +
        - PrimaryCare +
        - Psychiatric +
        - PublicHealth +
      - ProfessionalService
      - RadioStation
      - RealEstateAgent
      - RecyclingCenter
      - SelfStorage
      - ShoppingCenter
      - SportsActivityLocation
        - BowlingAlley
        - ExerciseGym
        - GolfCourse
        - HealthClub +
        - PublicSwimmingPool
        - SkiResort +
        - SportsClub
        - StadiumOrArena
        - TennisComplex
      - Store
        - AutoPartsStore +
        - BikeStore
        - BookStore
        - ClothingStore
        - ComputerStore
        - ConvenienceStore
        - DepartmentStore
        - ElectronicsStore
        - Florist
        - FurnitureStore
        - GardenStore
        - GroceryStore
        - HardwareStore
        - HobbyShop
        - HomeGoodsStore
        - JewelryStore
        - LiquorStore
        - MensClothingStore
        - MobilePhoneStore
        - MovieRentalStore
        - MusicStore
        - OfficeEquipmentStore
        - OutletStore
        - PawnShop
        - PetStore
        - ShoeStore
        - SportingGoodsStore
        - TireShop
        - ToyStore
        - WholesaleStore
      - TelevisionStation
      - TouristInformationCenter
      - TravelAgency
    - MedicalOrganization
      - Dentist +
      - DiagnosticLab
      - Hospital +
      - MedicalClinic +
      - Pharmacy +
      - Physician +
      - VeterinaryCare
    - NGO
    - NewsMediaOrganization
    - PerformingGroup
      - DanceGroup
      - MusicGroup
      - TheaterGroup
    - Project
      - FundingAgency
      - ResearchProject
    - SportsOrganization
      - SportsTeam
    - WorkersUnion
  - Person
    - Patient +
  - Place
    - Accommodation
      - Apartment
      - CampingPitch
      - House
        - SingleFamilyResidence
      - Room
        - HotelRoom
        - MeetingRoom
      - Suite
    - AdministrativeArea
      - City
      - Country
      - SchoolDistrict
      - State
    - CivicStructure
      - Airport
      - Aquarium
      - Beach
      - BoatTerminal
      - Bridge
      - BusStation
      - BusStop
      - Campground +
      - Cemetery
      - Crematorium
      - EducationalOrganization +
      - EventVenue
      - FireStation +
      - GovernmentBuilding
        - CityHall
        - Courthouse
        - DefenceEstablishment
        - Embassy
        - LegislativeBuilding
      - Hospital +
      - MovieTheater +
      - Museum
      - MusicVenue
      - Park
      - ParkingFacility
      - PerformingArtsTheater
      - PlaceOfWorship
        - BuddhistTemple
        - Church
          - CatholicChurch
        - HinduTemple
        - Mosque
        - Synagogue
      - Playground
      - PoliceStation +
      - PublicToilet
      - RVPark
      - StadiumOrArena +
      - SubwayStation
      - TaxiStand
      - TrainStation
      - Zoo
    - Landform
      - BodyOfWater
        - Canal
        - LakeBodyOfWater
        - OceanBodyOfWater
        - Pond
        - Reservoir
        - RiverBodyOfWater
        - SeaBodyOfWater
        - Waterfall
      - Continent
      - Mountain
      - Volcano
    - LandmarksOrHistoricalBuildings
    - LocalBusiness +
    - Residence
      - ApartmentComplex
      - GatedResidenceCommunity
    - TouristAttraction
    - TouristDestination
  - Product
    - IndividualProduct
    - ProductCollection +
    - ProductGroup
    - ProductModel
    - SomeProducts
    - Vehicle
      - BusOrCoach
      - Car
      - Motorcycle
      - MotorizedBicycle

## Types A-Z

#### 3DModel

A 3D model represents some kind of 3D content, which may have encodings in one or more MediaObjects. Many 3D formats are available (e.g. see Wikipedia); specific encoding formats can be represented using the encodingFormat property applied to the relevant MediaObject. For the case of a single file published after Zip compression, the convention of appending '+zip' to the encodingFormat can be used. Geospatial, AR/VR, artistic/animation, gaming, engineering and scientific content can all be represented using 3DModel.

Properties used on this type:

- isResizable

Properties whose values are of this type:

[^top]

#### AMRadioChannel

A radio channel that uses AM.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### APIReference

Reference documentation for application programming interfaces (APIs).

Properties used on this type:

- assembly
- assemblyVersion
- executableLibraryName
- programmingModel
- targetPlatform

Properties whose values are of this type:

[^top]

#### Abdomen

An Enumeration member

Abdomen clinical examination.

Member of Enumeration: PhysicalExam
[^top]

#### AboutPage

Web page type: About page.

Properties used on this type:

Properties whose values are of this type:

- ownershipFundingInfo

[^top]

#### AcceptAction

The act of committing to/adopting an object.
Related actions:

- RejectAction: The antonym of AcceptAction.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Accommodation

An accommodation is a place that can accommodate human beings, e.g. a hotel room, a camping pitch, or a meeting room. Many accommodations are for overnight stays, but this is not a mandatory requirement. For more specific types of accommodations not defined in schema.org, one can use additionalType with external vocabularies.
See also the dedicated document on the use of schema.org for marking up hotels and other forms of accommodations.

Properties used on this type:

- accommodationCategory
- accommodationFloorPlan
- amenityFeature
- floorLevel
- floorSize
- leaseLength
- numberOfBathroomsTotal
- numberOfBedrooms
- numberOfFullBathrooms
- numberOfPartialBathrooms
- numberOfRooms
- permittedUsage
- petsAllowed
- tourBookingPage
- yearBuilt

Properties whose values are of this type:

- isPlanForApartment

[^top]

#### AccountingService

Accountancy business.
As a LocalBusiness it can be described as a provider of one or more Service(s).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AchieveAction

The act of accomplishing something via previous efforts. It is an instantaneous action rather than an ongoing process.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Action

An action performed by a direct agent and indirect participants upon a direct object. Optionally happens at a location with the help of an inanimate instrument. The execution of the action may produce a result. Specific action sub-type documentation specifies the exact expectation of each argument/role.
See also blog post and Actions overview document.

Properties used on this type:

- actionStatus
- agent
- endTime
- error
- instrument
- location
- object
- participant
- result
- startTime
- target

Properties whose values are of this type:

- interactionType
- potentialAction

[^top]

#### ActionAccessSpecification

A set of requirements that a must be fulfilled in order to perform an Action.

Properties used on this type:

- availabilityEnds
- availabilityStarts
- category
- eligibleRegion
- expectsAcceptanceOf
- ineligibleRegion
- requiresSubscription

Properties whose values are of this type:

- actionAccessibilityRequirement

[^top]

#### ActionStatusType

An Enumeration

The status of an Action.

Properties used on this type:

Enumeration members of this type:

- ActiveActionStatus
- CompletedActionStatus
- FailedActionStatus
- PotentialActionStatus

Properties whose values are of this type:

- actionStatus

[^top]

#### ActivateAction

The act of starting or activating a device or application (e.g. starting a timer or turning on a flashlight).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ActivationFee

An Enumeration member

Represents the activation fee part of the total price for an offered product, for example a cellphone contract.

Member of Enumeration: PriceComponentTypeEnumeration
[^top]

#### ActiveActionStatus

An Enumeration member

An in-progress action (e.g, while watching the movie, or driving to a location).

Member of Enumeration: ActionStatusType
[^top]

#### ActiveNotRecruiting

An Enumeration member

Active, but not recruiting new participants.

Member of Enumeration: MedicalStudyStatus
[^top]

#### AddAction

The act of editing by adding an object to a collection.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AdministrativeArea

A geographical region, typically under the jurisdiction of a particular government.

Properties used on this type:

Properties whose values are of this type:

- applicableLocation
- applicantLocationRequirements
- areaServed
- availableIn
- geographicArea
- jurisdiction
- legislationJurisdiction
- occupationLocation
- serviceArea
- studyLocation
- validIn

[^top]

#### AdultEntertainment

An adult entertainment establishment.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AdvertiserContentArticle

An Article that an external entity has paid to place or to produce to its specifications. Includes advertorials, sponsored content, native advertising and other paid content.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AerobicActivity

An Enumeration member

Physical activity of relatively low intensity that depends primarily on the aerobic energy-generating process; during activity, the aerobic metabolism uses oxygen to adequately meet energy demands during exercise.

Member of Enumeration: PhysicalActivityCategory
[^top]

#### AggregateOffer

When a single product is associated with multiple offers (for example, the same pair of shoes is offered by different merchants), then AggregateOffer can be used.
Note: AggregateOffers are normally expected to associate multiple offers that all share the same defined businessFunction value, or default to http://purl.org/goodrelations/v1#Sell if businessFunction is not explicitly defined.

Properties used on this type:

- highPrice
- lowPrice
- offerCount
- offers

Properties whose values are of this type:

- itemOffered

[^top]

#### AggregateRating

The average rating based on multiple ratings or reviews.

Properties used on this type:

- itemReviewed
- ratingCount
- reviewCount

Properties whose values are of this type:

- aggregateRating

[^top]

#### AgreeAction

The act of expressing a consistency of opinion with the object. An agent agrees to/about an object (a proposition, topic or theme) with participants.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Airline

An organization that provides flights for passengers.

Properties used on this type:

- boardingPolicy
- iataCode

Properties whose values are of this type:

[^top]

#### Airport

An airport.

Properties used on this type:

- iataCode
- icaoCode

Properties whose values are of this type:

- arrivalAirport
- departureAirport

[^top]

#### AlbumRelease

An Enumeration member

AlbumRelease.

Member of Enumeration: MusicAlbumReleaseType
[^top]

#### AlignmentObject

An intangible item that describes an alignment between a learning resource and a node in an educational framework.
Should not be used where the nature of the alignment can be described using a simple property, for example to express that a resource teaches or assesses a competency.

Properties used on this type:

- alignmentType
- educationalFramework
- targetDescription
- targetName
- targetUrl

Properties whose values are of this type:

- coursePrerequisites
- educationalAlignment
- programPrerequisites

[^top]

#### AllWheelDriveConfiguration

An Enumeration member

All-wheel Drive is a transmission layout where the engine drives all four wheels.

Member of Enumeration: DriveWheelConfigurationValue
[^top]

#### AllergiesHealthAspect

An Enumeration member

Content about the allergy-related aspects of a health topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### AllocateAction

The act of organizing tasks/objects/events by associating resources to it.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AmpStory

A creative work with a visual storytelling format intended to be viewed online, particularly on mobile devices.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AmusementPark

An amusement park.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AnaerobicActivity

An Enumeration member

Physical activity that is of high-intensity which utilizes the anaerobic metabolism of the body.

Member of Enumeration: PhysicalActivityCategory
[^top]

#### AnalysisNewsArticle

An AnalysisNewsArticle is a NewsArticle that, while based on factual reporting, incorporates the expertise of the author/producer, offering interpretations and conclusions.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AnatomicalStructure

Any part of the human body, typically a component of an anatomical system. Organs, tissues, and cells are all anatomical structures.

Properties used on this type:

- associatedPathophysiology
- bodyLocation
- connectedTo
- diagram
- partOfSystem
- relatedCondition
- relatedTherapy
- subStructure

Properties whose values are of this type:

- arterialBranch
- associatedAnatomy
- branch
- comprisedOf
- connectedTo
- insertion
- regionDrained
- relatedAnatomy
- relatedStructure
- sensoryUnit
- subStructure
- supplyTo
- tributary

[^top]

#### AnatomicalSystem

An anatomical system is a group of anatomical structures that work together to perform a certain task. Anatomical systems, such as organ systems, are one organizing principle of anatomy, and can includes circulatory, digestive, endocrine, integumentary, immune, lymphatic, muscular, nervous, reproductive, respiratory, skeletal, urinary, vestibular, and other systems.

Properties used on this type:

- associatedPathophysiology
- comprisedOf
- relatedCondition
- relatedStructure
- relatedTherapy

Properties whose values are of this type:

- associatedAnatomy
- comprisedOf
- partOfSystem
- regionDrained
- relatedAnatomy

[^top]

#### Anesthesia

An Enumeration member

A specific branch of medical science that pertains to study of anesthetics and their application.

Member of Enumeration: MedicalSpecialty
[^top]

#### AnimalShelter

Animal shelter.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Answer

An answer offered to a question; perhaps correct, perhaps opinionated or wrong.

Properties used on this type:

- answerExplanation

Properties whose values are of this type:

- acceptedAnswer
- suggestedAnswer

[^top]

#### Apartment

An apartment (in American English) or flat (in British English) is a self-contained housing unit (a type of residential real estate) that occupies only part of a building (Source: Wikipedia, the free encyclopedia, see http://en.wikipedia.org/wiki/Apartment).

Properties used on this type:

- numberOfRooms
- occupancy

Properties whose values are of this type:

[^top]

#### ApartmentComplex

Residence type: Apartment complex.

Properties used on this type:

- numberOfAccommodationUnits
- numberOfAvailableAccommodationUnits
- numberOfBedrooms
- petsAllowed
- tourBookingPage

Properties whose values are of this type:

[^top]

#### Appearance

An Enumeration member

Appearance assessment with clinical examination.

Member of Enumeration: PhysicalExam
[^top]

#### AppendAction

The act of inserting at the end if an ordered collection.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ApplyAction

The act of registering to an organization/service without the guarantee to receive it.
Related actions:

- RegisterAction: Unlike RegisterAction, ApplyAction has no guarantees that the application will be accepted.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ApprovedIndication

An indication for a medical therapy that has been formally specified or approved by a regulatory body that regulates use of the therapy; for example, the US FDA approves indications for most drugs in the US.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Aquarium

Aquarium.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ArchiveComponent

An intangible type to be applied to any archive content, carrying with it a set of properties required to describe archival items and collections.

Properties used on this type:

- holdingArchive
- itemLocation

Properties whose values are of this type:

- archiveHeld

[^top]

#### ArchiveOrganization

An organization with archival holdings. An organization which keeps and preserves archival material and typically makes it accessible to the public.

Properties used on this type:

- archiveHeld

Properties whose values are of this type:

- holdingArchive

[^top]

#### ArriveAction

The act of arriving at a place. An agent arrives at a destination from a fromLocation, optionally with participants.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ArtGallery

An art gallery.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Artery

A type of blood vessel that specifically carries blood away from the heart.

Properties used on this type:

- arterialBranch
- supplyTo

Properties whose values are of this type:

[^top]

#### Article

An article, such as a news article or piece of investigative report. Newspapers and magazines have articles of many different types and this is intended to cover them all.
See also blog post.

Properties used on this type:

- articleBody
- articleSection
- backstory
- pageEnd
- pageStart
- pagination
- speakable
- wordCount

Properties whose values are of this type:

- diversityStaffingReport

[^top]

#### AskAction

The act of posing a question / favor to someone.
Related actions:

- ReplyAction: Appears generally as a response to AskAction.

Properties used on this type:

- question

Properties whose values are of this type:

[^top]

#### AskPublicNewsArticle

A NewsArticle expressing an open call by a NewsMediaOrganization asking the public for input, insights, clarifications, anecdotes, documentation, etc., on an issue, for reporting purposes.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AssessAction

The act of forming one's opinion, reaction or sentiment.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AssignAction

The act of allocating an action/event/task to some destination (someone or something).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Atlas

A collection or bound volume of maps, charts, plates or tables, physical or in media form illustrating any subject.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Attorney

Professional service: Attorney.
This type is deprecated - LegalService is more inclusive and less ambiguous.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Audience

Intended audience for an item, i.e. the group for whom the item was created.

Properties used on this type:

- audienceType
- geographicArea

Properties whose values are of this type:

- audience
- grantee
- permitAudience
- recipient
- sender
- serviceAudience
- toRecipient
- touristType

[^top]

#### AudioObject

An audio file.

Properties used on this type:

- caption
- transcript

Properties whose values are of this type:

- audio

[^top]

#### Audiobook

An audiobook.

Properties used on this type:

- duration
- readBy

Properties whose values are of this type:

[^top]

#### AudiobookFormat

An Enumeration member

Book format: Audiobook. This is an enumerated value for use with the bookFormat property. There is also a type 'Audiobook' in the bib extension which includes Audiobook specific properties.

Member of Enumeration: BookFormatType
[^top]

#### AuthoritativeLegalValue

An Enumeration member

Indicates that the publisher gives some special status to the publication of the document. ("The Queens Printer" version of a UK Act of Parliament, or the PDF version of a Directive published by the EU Office of Publications). Something "Authoritative" is considered to be also OfficialLegalValue".

Member of Enumeration: LegalValueLevel
[^top]

#### AuthorizeAction

The act of granting permission to an object.

Properties used on this type:

- recipient

Properties whose values are of this type:

[^top]

#### AutoBodyShop

Auto body shop.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AutoDealer

An car dealership.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AutoPartsStore

An auto parts store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AutoRental

A car rental business.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AutoRepair

Car repair business.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AutoWash

A car wash business.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AutomatedTeller

ATM/cash machine.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### AutomotiveBusiness

Car repair, sales, or parts.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Ayurvedic

An Enumeration member

A system of medicine that originated in India over thousands of years and that focuses on integrating and balancing the body, mind, and spirit.

Member of Enumeration: MedicineSystem
[^top]

#### BackOrder

An Enumeration member

Indicates that the item is available on back order.

Member of Enumeration: ItemAvailability
[^top]

#### BackgroundNewsArticle

A NewsArticle providing historical context, definition and detail on a specific topic (aka "explainer" or "backgrounder"). For example, an in-depth article or frequently-asked-questions (FAQ) document on topics such as Climate Change or the European Union. Other kinds of background material from a non-news setting are often described using Book or Article, in particular ScholarlyArticle. See also NewsArticle for related vocabulary from a learning/education perspective.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Bacteria

An Enumeration member

Pathogenic bacteria that cause bacterial infection.

Member of Enumeration: InfectiousAgentClass
[^top]

#### Bakery

A bakery.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Balance

An Enumeration member

Physical activity that is engaged to help maintain posture and balance.

Member of Enumeration: PhysicalActivityCategory
[^top]

#### BankAccount

A product or service offered by a bank whereby one may deposit, withdraw or transfer money and in some cases be paid interest.

Properties used on this type:

- accountMinimumInflow
- accountOverdraftLimit
- bankAccountType

Properties whose values are of this type:

[^top]

#### BankOrCreditUnion

Bank or credit union.

Properties used on this type:

Properties whose values are of this type:

- beneficiaryBank

[^top]

#### BarOrPub

A bar or pub.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Barcode

An image of a visual machine-readable code such as a barcode or QR code.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### BasicIncome

An Enumeration member

BasicIncome: this is a benefit for basic income.

Member of Enumeration: GovernmentBenefitsType
[^top]

#### Beach

Beach.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### BeautySalon

Beauty salon.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### BedAndBreakfast

Bed and breakfast.
See also the dedicated document on the use of schema.org for marking up hotels and other forms of accommodations.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### BedDetails

An entity holding detailed information about the available bed types, e.g. the quantity of twin beds for a hotel room. For the single case of just one bed of a certain type, you can use bed directly with a text. See also BedType (under development).

Properties used on this type:

- numberOfBeds
- typeOfBed

Properties whose values are of this type:

- bed

[^top]

#### BedType

An Enumeration

A type of bed. This is used for indicating the bed or beds available in an accommodation.

Properties used on this type:

Enumeration members of this type:

Properties whose values are of this type:

- bed
- typeOfBed

[^top]

#### BefriendAction

The act of forming a personal connection with someone (object) mutually/bidirectionally/symmetrically.
Related actions:

- FollowAction: Unlike FollowAction, BefriendAction implies that the connection is reciprocal.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### BenefitsHealthAspect

An Enumeration member

Content about the benefits and advantages of usage or utilization of topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### BikeStore

A bike store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Blog

A blog.

Properties used on this type:

- blogPost
- blogPosts
- issn

Properties whose values are of this type:

[^top]

#### BlogPosting

A blog post.

Properties used on this type:

Properties whose values are of this type:

- blogPost
- blogPosts
- liveBlogUpdate

[^top]

#### BloodTest

A medical test performed on a sample of a patient's blood.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### BoardingPolicyType

An Enumeration

A type of boarding policy used by an airline.

Properties used on this type:

Enumeration members of this type:

- GroupBoardingPolicy
- ZoneBoardingPolicy

Properties whose values are of this type:

- boardingPolicy

[^top]

#### BoatReservation

A reservation for boat travel.
Note: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations. For offers of tickets, use Offer.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### BoatTerminal

A terminal for boats, ships, and other water vessels.

Properties used on this type:

Properties whose values are of this type:

- arrivalBoatTerminal
- departureBoatTerminal

[^top]

#### BoatTrip

A trip on a commercial ferry line.

Properties used on this type:

- arrivalBoatTerminal
- departureBoatTerminal

Properties whose values are of this type:

[^top]

#### BodyMeasurementArm

An Enumeration member

Arm length (measured between arms/shoulder line intersection and the prominent wrist bone). Used, for example, to fit shirts.

Member of Enumeration: BodyMeasurementTypeEnumeration
[^top]

#### BodyMeasurementBust

An Enumeration member

Maximum girth of bust. Used, for example, to fit women's suits.

Member of Enumeration: BodyMeasurementTypeEnumeration
[^top]

#### BodyMeasurementChest

An Enumeration member

Maximum girth of chest. Used, for example, to fit men's suits.

Member of Enumeration: BodyMeasurementTypeEnumeration
[^top]

#### BodyMeasurementFoot

An Enumeration member

Foot length (measured between end of the most prominent toe and the most prominent part of the heel). Used, for example, to measure socks.

Member of Enumeration: BodyMeasurementTypeEnumeration
[^top]

#### BodyMeasurementHand

An Enumeration member

Maximum hand girth (measured over the knuckles of the open right hand excluding thumb, fingers together). Used, for example, to fit gloves.

Member of Enumeration: BodyMeasurementTypeEnumeration
[^top]

#### BodyMeasurementHead

An Enumeration member

Maximum girth of head above the ears. Used, for example, to fit hats.

Member of Enumeration: BodyMeasurementTypeEnumeration
[^top]

#### BodyMeasurementHeight

An Enumeration member

Body height (measured between crown of head and soles of feet). Used, for example, to fit jackets.

Member of Enumeration: BodyMeasurementTypeEnumeration
[^top]

#### BodyMeasurementHips

An Enumeration member

Girth of hips (measured around the buttocks). Used, for example, to fit skirts.

Member of Enumeration: BodyMeasurementTypeEnumeration
[^top]

#### BodyMeasurementInsideLeg

An Enumeration member

Inside leg (measured between crotch and soles of feet). Used, for example, to fit pants.

Member of Enumeration: BodyMeasurementTypeEnumeration
[^top]

#### BodyMeasurementNeck

An Enumeration member

Girth of neck. Used, for example, to fit shirts.

Member of Enumeration: BodyMeasurementTypeEnumeration
[^top]

#### BodyMeasurementTypeEnumeration

An Enumeration

Enumerates types (or dimensions) of a person's body measurements, for example for fitting of clothes.

Properties used on this type:

Enumeration members of this type:

- BodyMeasurementArm
- BodyMeasurementBust
- BodyMeasurementChest
- BodyMeasurementFoot
- BodyMeasurementHand
- BodyMeasurementHead
- BodyMeasurementHeight
- BodyMeasurementHips
- BodyMeasurementInsideLeg
- BodyMeasurementNeck
- BodyMeasurementUnderbust
- BodyMeasurementWaist
- BodyMeasurementWeight

Properties whose values are of this type:

[^top]

#### BodyMeasurementUnderbust

An Enumeration member

Girth of body just below the bust. Used, for example, to fit women's swimwear.

Member of Enumeration: BodyMeasurementTypeEnumeration
[^top]

#### BodyMeasurementWaist

An Enumeration member

Girth of natural waistline (between hip bones and lower ribs). Used, for example, to fit pants.

Member of Enumeration: BodyMeasurementTypeEnumeration
[^top]

#### BodyMeasurementWeight

An Enumeration member

Body weight. Used, for example, to measure pantyhose.

Member of Enumeration: BodyMeasurementTypeEnumeration
[^top]

#### BodyOfWater

A body of water, such as a sea, ocean, or lake.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Bone

Rigid connective tissue that comprises up the skeletal structure of the human body.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Book

A book.

Properties used on this type:

- abridged
- bookEdition
- bookFormat
- illustrator
- isbn
- numberOfPages

Properties whose values are of this type:

[^top]

#### BookFormatType

An Enumeration

The publication format of the book.

Properties used on this type:

Enumeration members of this type:

- AudiobookFormat
- EBook
- GraphicNovel
- Hardcover
- Paperback

Properties whose values are of this type:

- bookFormat

[^top]

#### BookSeries

A series of books. Included books can be indicated with the hasPart property.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### BookStore

A bookstore.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### BookmarkAction

An agent bookmarks/flags/labels/tags/marks an object.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Boolean

A Datatype

Boolean: True or False.

Properties used on this type:

Properties whose values are of this type:

- abridged
- acceptsReservations
- cashBack
- contactlessPayment
- doesNotShip
- domiciledMortgage
- experienceInPlaceOfEducation
- free
- hasDriveThroughService
- healthPlanCostSharing
- inStoreReturnsOffered
- isAcceptingNewPatients
- isAccessibleForFree
- isAvailableGenerically
- isFamilyFriendly
- isGift
- isLiveBroadcast
- isProprietary
- isResizable
- isUnlabelledFallback
- jobImmediateStart
- multipleValues
- offersPrescriptionByMail
- petsAllowed
- publicAccess
- readonlyValue
- recourseLoan
- renegotiableLoan
- representativeOfPage
- requiresSubscription
- smokingAllowed
- value
- valueAddedTaxIncluded
- valueRequired

[^top]

#### BorrowAction

The act of obtaining an object under an agreement to return it at a later date. Reciprocal of LendAction.
Related actions:

- LendAction: Reciprocal of BorrowAction.

Properties used on this type:

- lender

Properties whose values are of this type:

[^top]

#### BowlingAlley

A bowling alley.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### BrainStructure

Any anatomical structure which pertains to the soft nervous tissue functioning as the coordinating center of sensation and intellectual and nervous activity.

Properties used on this type:

Properties whose values are of this type:

- sourcedFrom

[^top]

#### Brand

A brand is a name used by an organization or business person for labeling a product, product group, or similar.

Properties used on this type:

- aggregateRating
- logo
- review
- slogan

Properties whose values are of this type:

- brand

[^top]

#### BreadcrumbList

A BreadcrumbList is an ItemList consisting of a chain of linked Web pages, typically described using at least their URL and their name, and typically ending with the current page.
The position property is used to reconstruct the order of the items in a BreadcrumbList The convention is that a breadcrumb list has an itemListOrder of ItemListOrderAscending (lower values listed first), and that the first items in this list correspond to the "top" or beginning of the breadcrumb trail, e.g. with a site or section homepage. The specific values of 'position' are not assigned meaning for a BreadcrumbList, but they should be integers, e.g. beginning with '1' for the first item in the list.

Properties used on this type:

Properties whose values are of this type:

- breadcrumb

[^top]

#### Brewery

Brewery.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Bridge

A bridge.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### BroadcastChannel

A unique instance of a BroadcastService on a CableOrSatelliteService lineup.

Properties used on this type:

- broadcastChannelId
- broadcastFrequency
- broadcastServiceTier
- genre
- inBroadcastLineup
- providesBroadcastService

Properties whose values are of this type:

- hasBroadcastChannel

[^top]

#### BroadcastEvent

An over the air or online broadcast event.

Properties used on this type:

- broadcastOfEvent
- isLiveBroadcast
- subtitleLanguage
- videoFormat

Properties whose values are of this type:

[^top]

#### BroadcastFrequencySpecification

The frequency in MHz and the modulation used for a particular BroadcastService.

Properties used on this type:

- broadcastFrequencyValue
- broadcastSignalModulation
- broadcastSubChannel

Properties whose values are of this type:

- broadcastFrequency

[^top]

#### BroadcastRelease

An Enumeration member

BroadcastRelease.

Member of Enumeration: MusicAlbumReleaseType
[^top]

#### BroadcastService

A delivery service through which content is provided via broadcast over the air or online.

Properties used on this type:

- area
- broadcastAffiliateOf
- broadcastDisplayName
- broadcastFrequency
- broadcastTimezone
- broadcaster
- callSign
- hasBroadcastChannel
- inLanguage
- parentService
- videoFormat

Properties whose values are of this type:

- parentService
- providesBroadcastService
- publishedOn

[^top]

#### BrokerageAccount

An account that allows an investor to deposit funds and place investment orders with a licensed broker or brokerage firm.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### BuddhistTemple

A Buddhist temple.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### BusOrCoach

A bus (also omnibus or autobus) is a road vehicle designed to carry passengers. Coaches are luxury busses, usually in service for long distance travel.

Properties used on this type:

- acrissCode
- roofLoad

Properties whose values are of this type:

[^top]

#### BusReservation

A reservation for bus travel.
Note: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations. For offers of tickets, use Offer.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### BusStation

A bus station.

Properties used on this type:

Properties whose values are of this type:

- arrivalBusStop
- departureBusStop

[^top]

#### BusStop

A bus stop.

Properties used on this type:

Properties whose values are of this type:

- arrivalBusStop
- departureBusStop

[^top]

#### BusTrip

A trip on a commercial bus line.

Properties used on this type:

- arrivalBusStop
- busName
- busNumber
- departureBusStop

Properties whose values are of this type:

[^top]

#### BusinessAudience

A set of characteristics belonging to businesses, e.g. who compose an item's target audience.

Properties used on this type:

- numberOfEmployees
- yearlyRevenue
- yearsInOperation

Properties whose values are of this type:

[^top]

#### BusinessEntityType

An Enumeration

A business entity type is a conceptual entity representing the legal form, the size, the main line of business, the position in the value chain, or any combination thereof, of an organization or business person.
Commonly used values:

- http://purl.org/goodrelations/v1#Business
- http://purl.org/goodrelations/v1#Enduser
- http://purl.org/goodrelations/v1#PublicInstitution
- http://purl.org/goodrelations/v1#Reseller

Properties used on this type:

Enumeration members of this type:

Properties whose values are of this type:

- eligibleCustomerType

[^top]

#### BusinessEvent

Event type: Business event.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### BusinessFunction

An Enumeration

The business function specifies the type of activity or access (i.e., the bundle of rights) offered by the organization or business person through the offer. Typical are sell, rental or lease, maintenance or repair, manufacture / produce, recycle / dispose, engineering / construction, or installation. Proprietary specifications of access rights are also instances of this class.
Commonly used values:

- http://purl.org/goodrelations/v1#ConstructionInstallation
- http://purl.org/goodrelations/v1#Dispose
- http://purl.org/goodrelations/v1#LeaseOut
- http://purl.org/goodrelations/v1#Maintain
- http://purl.org/goodrelations/v1#ProvideService
- http://purl.org/goodrelations/v1#Repair
- http://purl.org/goodrelations/v1#Sell
- http://purl.org/goodrelations/v1#Buy

Properties used on this type:

Enumeration members of this type:

Properties whose values are of this type:

- businessFunction

[^top]

#### BusinessSupport

An Enumeration member

BusinessSupport: this is a benefit for supporting businesses.

Member of Enumeration: GovernmentBenefitsType
[^top]

#### BuyAction

The act of giving money to a seller in exchange for goods or services rendered. An agent buys an object, product, or service from a seller for a price. Reciprocal of SellAction.

Properties used on this type:

- seller
- vendor
- warrantyPromise

Properties whose values are of this type:

[^top]

#### CDCPMDRecord

A CDCPMDRecord is a data structure representing a record in a CDC tabular data format used for hospital data reporting. See documentation for details, and the linked CDC materials for authoritative definitions used as the source here.

Properties used on this type:

- cvdCollectionDate
- cvdFacilityCounty
- cvdFacilityId
- cvdNumBeds
- cvdNumBedsOcc
- cvdNumC19Died
- cvdNumC19HOPats
- cvdNumC19HospPats
- cvdNumC19MechVentPats
- cvdNumC19OFMechVentPats
- cvdNumC19OverflowPats
- cvdNumICUBeds
- cvdNumICUBedsOcc
- cvdNumTotBeds
- cvdNumVent
- cvdNumVentUse
- datePosted

Properties whose values are of this type:

- healthcareReportingData

[^top]

#### CDFormat

An Enumeration member

CDFormat.

Member of Enumeration: MusicReleaseFormatType
[^top]

#### CT

An Enumeration member

X-ray computed tomography imaging.

Member of Enumeration: MedicalImagingTechnique
[^top]

#### CableOrSatelliteService

A service which provides access to media programming like TV or radio. Access may be via cable or satellite.

Properties used on this type:

Properties whose values are of this type:

- inBroadcastLineup

[^top]

#### CafeOrCoffeeShop

A cafe or coffee shop.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Campground

A camping site, campsite, or Campground is a place used for overnight stay in the outdoors, typically containing individual CampingPitch locations.
In British English a campsite is an area, usually divided into a number of pitches, where people can camp overnight using tents or camper vans or caravans; this British English use of the word is synonymous with the American English expression campground. In American English the term campsite generally means an area where an individual, family, group, or military unit can pitch a tent or park a camper; a campground may contain many campsites (Source: Wikipedia see https://en.wikipedia.org/wiki/Campsite).
See also the dedicated document on the use of schema.org for marking up hotels and other forms of accommodations.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CampingPitch

A CampingPitch is an individual place for overnight stay in the outdoors, typically being part of a larger camping site, or Campground.
In British English a campsite, or campground, is an area, usually divided into a number of pitches, where people can camp overnight using tents or camper vans or caravans; this British English use of the word is synonymous with the American English expression campground. In American English the term campsite generally means an area where an individual, family, group, or military unit can pitch a tent or park a camper; a campground may contain many campsites. (Source: Wikipedia see https://en.wikipedia.org/wiki/Campsite).
See also the dedicated document on the use of schema.org for marking up hotels and other forms of accommodations.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Canal

A canal, like the Panama Canal.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CancelAction

The act of asserting that a future event/action is no longer going to happen.
Related actions:

- ConfirmAction: The antonym of CancelAction.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Car

A car is a wheeled, self-powered motor vehicle used for transportation.

Properties used on this type:

- acrissCode
- roofLoad

Properties whose values are of this type:

[^top]

#### CarUsageType

An Enumeration

A value indicating a special usage of a car, e.g. commercial rental, driving school, or as a taxi.

Properties used on this type:

Enumeration members of this type:

- DrivingSchoolVehicleUsage
- RentalVehicleUsage
- TaxiVehicleUsage

Properties whose values are of this type:

- vehicleSpecialUsage

[^top]

#### Cardiovascular

An Enumeration member

A specific branch of medical science that pertains to diagnosis and treatment of disorders of heart and vasculature.

Member of Enumeration: MedicalSpecialty
[^top]

#### CardiovascularExam

An Enumeration member

Cardiovascular system assessment withclinical examination.

Member of Enumeration: PhysicalExam
[^top]

#### CaseSeries

An Enumeration member

A case series (also known as a clinical series) is a medical research study that tracks patients with a known exposure given similar treatment or examines their medical records for exposure and outcome. A case series can be retrospective or prospective and usually involves a smaller number of patients than the more powerful case-control studies or randomized controlled trials. Case series may be consecutive or non-consecutive, depending on whether all cases presenting to the reporting authors over a period of time were included, or only a selection.

Member of Enumeration: MedicalObservationalStudyDesign
[^top]

#### Casino

A casino.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CassetteFormat

An Enumeration member

CassetteFormat.

Member of Enumeration: MusicReleaseFormatType
[^top]

#### CategoryCode

A Category Code.

Properties used on this type:

- codeValue
- inCodeSet

Properties whose values are of this type:

- hasCategoryCode
- legislationType
- occupationalCategory

[^top]

#### CategoryCodeSet

A set of Category Code values.

Properties used on this type:

- hasCategoryCode

Properties whose values are of this type:

- inCodeSet

[^top]

#### CatholicChurch

A Catholic church.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CausesHealthAspect

An Enumeration member

Information about the causes and main actions that gave rise to the topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### Cemetery

A graveyard.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Chapter

One of the sections into which a book is divided. A chapter usually has a section number or a name.

Properties used on this type:

- pageEnd
- pageStart
- pagination

Properties whose values are of this type:

[^top]

#### CharitableIncorporatedOrganization

An Enumeration member

CharitableIncorporatedOrganization: Non-profit type referring to a Charitable Incorporated Organization (UK).

Member of Enumeration: UKNonprofitType
[^top]

#### CheckAction

An agent inspects, determines, investigates, inquires, or examines an object's accuracy, quality, condition, or state.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CheckInAction

The act of an agent communicating (service provider, social media, etc) their arrival by registering/confirming for a previously reserved service (e.g. flight check in) or at a place (e.g. hotel), possibly resulting in a result (boarding pass, etc).
Related actions:

- CheckOutAction: The antonym of CheckInAction.
- ArriveAction: Unlike ArriveAction, CheckInAction implies that the agent is informing/confirming the start of a previously reserved service.
- ConfirmAction: Unlike ConfirmAction, CheckInAction implies that the agent is informing/confirming the start of a previously reserved service rather than its validity/existence.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CheckOutAction

The act of an agent communicating (service provider, social media, etc) their departure of a previously reserved service (e.g. flight check in) or place (e.g. hotel).
Related actions:

- CheckInAction: The antonym of CheckOutAction.
- DepartAction: Unlike DepartAction, CheckOutAction implies that the agent is informing/confirming the end of a previously reserved service.
- CancelAction: Unlike CancelAction, CheckOutAction implies that the agent is informing/confirming the end of a previously reserved service.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CheckoutPage

Web page type: Checkout page.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ChildCare

A Childcare center.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ChildrensEvent

Event type: Children's event.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Chiropractic

An Enumeration member

A system of medicine focused on the relationship between the body's structure, mainly the spine, and its functioning.

Member of Enumeration: MedicineSystem
[^top]

#### ChooseAction

The act of expressing a preference from a set of options or a large or unbounded set of choices/options.

Properties used on this type:

- actionOption
- option

Properties whose values are of this type:

[^top]

#### Church

A church.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### City

A city or town.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CityHall

A city hall.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CivicStructure

A public structure, such as a town hall or concert hall.

Properties used on this type:

- openingHours

Properties whose values are of this type:

- announcementLocation

[^top]

#### Claim

A Claim in Schema.org represents a specific, factually-oriented claim that could be the itemReviewed in a ClaimReview. The content of a claim can be summarized with the text property. Variations on well known claims can have their common identity indicated via sameAs links, and summarized with a name. Ideally, a Claim description includes enough contextual information to minimize the risk of ambiguity or inclarity. In practice, many claims are better understood in the context in which they appear or the interpretations provided by claim reviews.
Beyond ClaimReview, the Claim type can be associated with related creative works - for example a ScholarlyArticle or Question might be about some Claim.
At this time, Schema.org does not define any types of relationship between claims. This is a natural area for future exploration.

Properties used on this type:

- appearance
- firstAppearance

Properties whose values are of this type:

[^top]

#### ClaimReview

A fact-checking review of claims made (or reported) in some creative work (referenced via itemReviewed).

Properties used on this type:

- claimReviewed

Properties whose values are of this type:

[^top]

#### Class

A class, also often called a 'Type'; equivalent to rdfs:Class.

Properties used on this type:

- supersededBy

Properties whose values are of this type:

- domainIncludes
- populationType
- rangeIncludes
- supersededBy

[^top]

#### CleaningFee

An Enumeration member

Represents the cleaning fee part of the total price for an offered product, for example a vacation rental.

Member of Enumeration: PriceComponentTypeEnumeration
[^top]

#### Clinician

An Enumeration member

Medical clinicians, including practicing physicians and other medical professionals involved in clinical practice.

Member of Enumeration: MedicalAudienceType
[^top]

#### Clip

A short TV or radio program or a segment/part of a program.

Properties used on this type:

- actor
- actors
- clipNumber
- director
- directors
- endOffset
- musicBy
- partOfEpisode
- partOfSeason
- partOfSeries
- startOffset

Properties whose values are of this type:

- audio
- video

[^top]

#### ClothingStore

A clothing store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CoOp

An Enumeration member

Play mode: CoOp. Co-operative games, where you play on the same team with friends.

Member of Enumeration: GamePlayMode
[^top]

#### Code

Computer programming source code. Example: Full (compile ready) solutions, code snippet samples, scripts, templates.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CohortStudy

An Enumeration member

Also known as a panel study. A cohort study is a form of longitudinal study used in medicine and social science. It is one type of study design and should be compared with a cross-sectional study. A cohort is a group of people who share a common characteristic or experience within a defined period (e.g., are born, leave school, lose their job, are exposed to a drug or a vaccine, etc.). The comparison group may be the general population from which the cohort is drawn, or it may be another cohort of persons thought to have had little or no exposure to the substance under investigation, but otherwise similar. Alternatively, subgroups within the cohort may be compared with each other.

Member of Enumeration: MedicalObservationalStudyDesign
[^top]

#### Collection

A collection of items e.g. creative works or products.

Properties used on this type:

- collectionSize

Properties whose values are of this type:

[^top]

#### CollectionPage

Web page type: Collection page.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CollegeOrUniversity

A college, university, or other third-level educational institution.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ComedyClub

A comedy club.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ComedyEvent

Event type: Comedy event.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ComicCoverArt

The artwork on the cover of a comic.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ComicIssue

Individual comic issues are serially published as part of a larger series. For the sake of consistency, even one-shot issues belong to a series comprised of a single issue. All comic issues can be uniquely identified by: the combination of the name and volume number of the series to which the issue belongs; the issue number; and the variant description of the issue (if any).

Properties used on this type:

- artist
- colorist
- inker
- letterer
- penciler
- variantCover

Properties whose values are of this type:

[^top]

#### ComicSeries

A sequential publication of comic stories under a unifying title, for example "The Amazing Spider-Man" or "Groo the Wanderer".

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ComicStory

The term "story" is any indivisible, re-printable unit of a comic, including the interior stories, covers, and backmatter. Most comics have at least two stories: a cover (ComicCoverArt) and an interior story.

Properties used on this type:

- artist
- colorist
- inker
- letterer
- penciler

Properties whose values are of this type:

[^top]

#### Comment

A comment on an item - for example, a comment on a blog post. The comment's content is expressed via the text property, and its topic via about, properties shared with all CreativeWorks.

Properties used on this type:

- downvoteCount
- parentItem
- upvoteCount

Properties whose values are of this type:

- answerExplanation
- comment
- parentItem
- resultComment

[^top]

#### CommentAction

The act of generating a comment about a subject.

Properties used on this type:

- resultComment

Properties whose values are of this type:

[^top]

#### CommentPermission

An Enumeration member

Permission to add comments to the document.

Member of Enumeration: DigitalDocumentPermissionType
[^top]

#### CommunicateAction

The act of conveying information to another person via a communication medium (instrument) such as speech, email, or telephone conversation.

Properties used on this type:

- about
- inLanguage
- language
- recipient

Properties whose values are of this type:

[^top]

#### CommunityHealth

An Enumeration member

A field of public health focusing on improving health characteristics of a defined population in relation with their geographical or environment areas.

Member of Enumeration: MedicalSpecialty
[^top]

#### CompilationAlbum

An Enumeration member

CompilationAlbum.

Member of Enumeration: MusicAlbumProductionType
[^top]

#### CompleteDataFeed

A CompleteDataFeed is a DataFeed whose standard representation includes content for every item currently in the feed.
This is the equivalent of Atom's element as defined in Feed Paging and Archiving RFC 5005, For example (and as defined for Atom), when using data from a feed that represents a collection of items that varies over time (e.g. "Top Twenty Records") there is no need to have newer entries mixed in alongside older, obsolete entries. By marking this feed as a CompleteDataFeed, old entries can be safely discarded when the feed is refreshed, since we can assume the feed has provided descriptions for all current items.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Completed

An Enumeration member

Completed.

Member of Enumeration: MedicalStudyStatus
[^top]

#### CompletedActionStatus

An Enumeration member

An action that has already taken place.

Member of Enumeration: ActionStatusType
[^top]

#### CompoundPriceSpecification

A compound price specification is one that bundles multiple prices that all apply in combination for different dimensions of consumption. Use the name property of the attached unit price specification for indicating the dimension of a price component (e.g. "electricity" or "final cleaning").

Properties used on this type:

- priceComponent
- priceType

Properties whose values are of this type:

[^top]

#### ComputerLanguage

This type covers computer programming languages such as Scheme and Lisp, as well as other language-like computer representations. Natural languages are best represented with the Language type.

Properties used on this type:

Properties whose values are of this type:

- programmingLanguage

[^top]

#### ComputerStore

A computer store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ConfirmAction

The act of notifying someone that a future event/action is going to happen as expected.
Related actions:

- CancelAction: The antonym of ConfirmAction.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Consortium

A Consortium is a membership Organization whose members are typically Organizations.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ConsumeAction

The act of ingesting information/resources/food.

Properties used on this type:

- actionAccessibilityRequirement
- expectsAcceptanceOf

Properties whose values are of this type:

[^top]

#### ContactPage

Web page type: Contact page.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ContactPoint

A contact point—for example, a Customer Complaints department.

Properties used on this type:

- areaServed
- availableLanguage
- contactOption
- contactType
- email
- faxNumber
- hoursAvailable
- productSupported
- serviceArea
- telephone

Properties whose values are of this type:

- applicationContact
- bccRecipient
- ccRecipient
- contactPoint
- contactPoints
- grantee
- homeLocation
- recipient
- servicePhone
- serviceSmsNumber
- toRecipient
- workLocation

[^top]

#### ContactPointOption

An Enumeration

Enumerated options related to a ContactPoint.

Properties used on this type:

Enumeration members of this type:

- HearingImpairedSupported
- TollFree

Properties whose values are of this type:

- contactOption

[^top]

#### ContagiousnessHealthAspect

An Enumeration member

Content about contagion mechanisms and contagiousness information over the topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### Continent

One of the continents (for example, Europe or Africa).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ControlAction

An agent controls a device or application.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ConvenienceStore

A convenience store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Conversation

One or more messages between organizations or people on a particular topic. Individual messages can be linked to the conversation with isPartOf or hasPart properties.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CookAction

The act of producing/preparing food.

Properties used on this type:

- foodEstablishment
- foodEvent
- recipe

Properties whose values are of this type:

[^top]

#### Corporation

Organization: A business corporation.

Properties used on this type:

- tickerSymbol

Properties whose values are of this type:

[^top]

#### CorrectionComment

A comment that corrects CreativeWork.

Properties used on this type:

Properties whose values are of this type:

- correction

[^top]

#### Country

A country.

Properties used on this type:

Properties whose values are of this type:

- addressCountry
- countryOfOrigin
- nationality

[^top]

#### Course

A description of an educational course which may be offered as distinct instances at which take place at different times or take place at different locations, or be offered through different media or modes of study. An educational course is a sequence of one or more educational events and/or creative works which aims to build knowledge, competence or ability of learners.

Properties used on this type:

- courseCode
- coursePrerequisites
- educationalCredentialAwarded
- hasCourseInstance
- numberOfCredits
- occupationalCredentialAwarded

Properties whose values are of this type:

- coursePrerequisites
- hasCourse
- programPrerequisites

[^top]

#### CourseInstance

An instance of a Course which is distinct from other instances because it is offered at a different time or location or through different media or modes of study or to a specific section of students.

Properties used on this type:

- courseMode
- courseWorkload
- instructor

Properties whose values are of this type:

- hasCourseInstance

[^top]

#### Courthouse

A courthouse.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CoverArt

The artwork on the outer surface of a CreativeWork.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CovidTestingFacility

A CovidTestingFacility is a MedicalClinic where testing for the COVID-19 Coronavirus disease is available. If the facility is being made available from an established Pharmacy, Hotel, or other non-medical organization, multiple types can be listed. This makes it easier to re-use existing schema.org information about that place e.g. contact info, address, opening hours. Note that in an emergency, such information may not always be reliable.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CreateAction

The act of deliberately creating/producing/generating/building a result out of the agent.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CreativeWork

The most generic kind of creative work, including books, movies, photographs, software programs, etc.

Properties used on this type:

- about
- abstract
- accessMode
- accessModeSufficient
- accessibilityAPI
- accessibilityControl
- accessibilityFeature
- accessibilityHazard
- accessibilitySummary
- accountablePerson
- acquireLicensePage
- aggregateRating
- alternativeHeadline
- assesses
- associatedMedia
- audience
- audio
- author
- award
- awards
- character
- citation
- comment
- commentCount
- conditionsOfAccess
- contentLocation
- contentRating
- contentReferenceTime
- contributor
- copyrightHolder
- copyrightNotice
- copyrightYear
- correction
- creativeWorkStatus
- creator
- creditText
- dateCreated
- dateModified
- datePublished
- discussionUrl
- editEIDR
- editor
- educationalAlignment
- educationalLevel
- educationalUse
- encoding
- encodingFormat
- encodings
- exampleOfWork
- expires
- fileFormat
- funder
- genre
- hasPart
- headline
- inLanguage
- interactionStatistic
- interactivityType
- isAccessibleForFree
- isBasedOn
- isBasedOnUrl
- isFamilyFriendly
- isPartOf
- keywords
- learningResourceType
- license
- locationCreated
- mainEntity
- maintainer
- material
- materialExtent
- mentions
- offers
- pattern
- position
- producer
- provider
- publication
- publisher
- publisherImprint
- publishingPrinciples
- recordedAt
- releasedEvent
- review
- reviews
- schemaVersion
- sdDatePublished
- sdLicense
- sdPublisher
- size
- sourceOrganization
- spatial
- spatialCoverage
- sponsor
- teaches
- temporal
- temporalCoverage
- text
- thumbnailUrl
- timeRequired
- translationOfWork
- translator
- typicalAgeRange
- usageInfo
- version
- video
- workExample
- workTranslation

Properties whose values are of this type:

- acquireLicensePage
- actionableFeedbackPolicy
- appearance
- backstory
- cheatCode
- citation
- correctionsPolicy
- discusses
- diversityPolicy
- documentation
- encodesCreativeWork
- ethicsPolicy
- exampleOfWork
- firstAppearance
- gameTip
- hasPart
- isBasedOn
- isBasedOnUrl
- isPartOf
- itemOffered
- license
- lyrics
- mainEntityOfPage
- masthead
- messageAttachment
- missionCoveragePrioritiesPolicy
- noBylinesPolicy
- ownershipFundingInfo
- publishingPrinciples
- recipeInstructions
- recordedIn
- sdLicense
- sharedContent
- softwareHelp
- step
- steps
- subjectOf
- translationOfWork
- unnamedSourcesPolicy
- usageInfo
- verificationFactCheckingPolicy
- workExample
- workFeatured
- workPerformed
- workTranslation

[^top]

#### CreativeWorkSeason

A media season e.g. tv, radio, video game etc.

Properties used on this type:

- actor
- director
- endDate
- episode
- episodes
- numberOfEpisodes
- partOfSeries
- productionCompany
- seasonNumber
- startDate
- trailer

Properties whose values are of this type:

- containsSeason
- partOfSeason
- season
- seasons

[^top]

#### CreativeWorkSeries

A CreativeWorkSeries in schema.org is a group of related items, typically but not necessarily of the same kind. CreativeWorkSeries are usually organized into some order, often chronological. Unlike ItemList which is a general purpose data structure for lists of things, the emphasis with CreativeWorkSeries is on published materials (written e.g. books and periodicals, or media such as tv, radio and games).
Specific subtypes are available for describing TVSeries, RadioSeries, MovieSeries, BookSeries, Periodical and VideoGameSeries. In each case, the hasPart / isPartOf properties can be used to relate the CreativeWorkSeries to its parts. The general CreativeWorkSeries type serves largely just to organize these more specific and practical subtypes.
It is common for properties applicable to an item from the series to be usefully applied to the containing group. Schema.org attempts to anticipate some of these cases, but publishers should be free to apply properties of the series parts to the series as a whole wherever they seem appropriate.

Properties used on this type:

- endDate
- issn
- startDate

Properties whose values are of this type:

- partOfSeries

[^top]

#### CreditCard

An Enumeration

A card payment method of a particular brand or name. Used to mark up a particular payment method and/or the financial product/service that supplies the card account.
Commonly used values:

- http://purl.org/goodrelations/v1#AmericanExpress
- http://purl.org/goodrelations/v1#DinersClub
- http://purl.org/goodrelations/v1#Discover
- http://purl.org/goodrelations/v1#JCB
- http://purl.org/goodrelations/v1#MasterCard
- http://purl.org/goodrelations/v1#VISA

Properties used on this type:

Enumeration members of this type:

Properties whose values are of this type:

[^top]

#### Crematorium

A crematorium.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CriticReview

A CriticReview is a more specialized form of Review written or published by a source that is recognized for its reviewing activities. These can include online columns, travel and food guides, TV and radio shows, blogs and other independent Web sites. CriticReviews are typically more in-depth and professionally written. For simpler, casually written user/visitor/viewer/customer reviews, it is more appropriate to use the UserReview type. Review aggregator sites such as Metacritic already separate out the site's user reviews from selected critic reviews that originate from third-party sources.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### CrossSectional

An Enumeration member

Studies carried out on pre-existing data (usually from 'snapshot' surveys), such as that collected by the Census Bureau. Sometimes called Prevalence Studies.

Member of Enumeration: MedicalObservationalStudyDesign
[^top]

#### CssSelectorType

Text representing a CSS selector.

Properties used on this type:

Properties whose values are of this type:

- cssSelector

[^top]

#### CurrencyConversionService

A service to convert funds from one currency to another currency.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### DDxElement

An alternative, closely-related condition typically considered later in the differential diagnosis process along with the signs that are used to distinguish it.

Properties used on this type:

- diagnosis
- distinguishingSign

Properties whose values are of this type:

- differentialDiagnosis

[^top]

#### DJMixAlbum

An Enumeration member

DJMixAlbum.

Member of Enumeration: MusicAlbumProductionType
[^top]

#### DVDFormat

An Enumeration member

DVDFormat.

Member of Enumeration: MusicReleaseFormatType
[^top]

#### DamagedCondition

An Enumeration member

Indicates that the item is damaged.

Member of Enumeration: OfferItemCondition
[^top]

#### DanceEvent

Event type: A social dance.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### DanceGroup

A dance group—for example, the Alvin Ailey Dance Theater or Riverdance.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### DataCatalog

A collection of datasets.

Properties used on this type:

- dataset
- measurementTechnique

Properties whose values are of this type:

- catalog
- includedDataCatalog
- includedInDataCatalog

[^top]

#### DataDownload

A dataset in downloadable form.

Properties used on this type:

- measurementTechnique

Properties whose values are of this type:

- distribution

[^top]

#### DataFeed

A single feed providing structured information about one or more entities or topics.

Properties used on this type:

- dataFeedElement

Properties whose values are of this type:

- supportingData
- webFeed

[^top]

#### DataFeedItem

A single item within a larger data feed.

Properties used on this type:

- dateCreated
- dateDeleted
- dateModified
- item

Properties whose values are of this type:

- dataFeedElement

[^top]

#### DataType

A Datatype

The basic data types such as Integers, Strings, etc.

Properties used on this type:

Properties whose values are of this type:

- measuredValue

[^top]

#### Dataset

A body of structured information describing some topic(s) of interest.

Properties used on this type:

- catalog
- datasetTimeInterval
- distribution
- includedDataCatalog
- includedInDataCatalog
- issn
- measurementTechnique
- variableMeasured
- variablesMeasured

Properties whose values are of this type:

- dataset
- diseaseSpreadStatistics
- healthcareReportingData

[^top]

#### Date

A Datatype

A date value in ISO 8601 date format.

Properties used on this type:

Properties whose values are of this type:

- applicationDeadline
- applicationStartDate
- availabilityEnds
- availabilityStarts
- birthDate
- commentTime
- dateCreated
- dateDeleted
- dateIssued
- dateModified
- datePosted
- datePublished
- dateRead
- dateVehicleFirstRegistered
- deathDate
- dissolutionDate
- endDate
- exceptDate
- expectedArrivalFrom
- expectedArrivalUntil
- expires
- foundingDate
- guidelineDate
- jobStartDate
- lastReviewed
- legislationDate
- legislationDateVersion
- modelDate
- orderDate
- paymentDueDate
- previousStartDate
- priceValidUntil
- productionDate
- purchaseDate
- releaseDate
- scheduledPaymentDate
- sdDatePublished
- startDate
- uploadDate
- validFrom
- validThrough
- validUntil
- vehicleModelDate

[^top]

#### DateTime

A Datatype

A combination of date and time of day in the form [-]CCYY-MM-DDThh:mm:ss[Z|(+|-)hh:mm] (see Chapter 5.4 of ISO 8601).

Properties used on this type:

Properties whose values are of this type:

- arrivalTime
- availabilityEnds
- availabilityStarts
- availableFrom
- availableThrough
- bookingTime
- checkinTime
- checkoutTime
- commentTime
- contentReferenceTime
- coverageEndTime
- coverageStartTime
- cvdCollectionDate
- datasetTimeInterval
- dateCreated
- dateDeleted
- dateIssued
- dateModified
- datePosted
- datePublished
- dateRead
- dateReceived
- dateSent
- departureTime
- doorTime
- dropoffTime
- endDate
- endTime
- exceptDate
- expectedArrivalFrom
- expectedArrivalUntil
- modifiedTime
- observationDate
- orderDate
- ownedFrom
- ownedThrough
- paymentDue
- paymentDueDate
- pickupTime
- scheduledTime
- startDate
- startTime
- temporal
- temporalCoverage
- validFrom
- validThrough
- webCheckinTime

[^top]

#### DatedMoneySpecification

A DatedMoneySpecification represents monetary values with optional start and end dates. For example, this could represent an employee's salary over a specific period of time. Note: This type has been superseded by MonetaryAmount use of that type is recommended

Properties used on this type:

- amount
- currency
- endDate
- startDate

Properties whose values are of this type:

[^top]

#### DayOfWeek

An Enumeration

The day of the week, e.g. used to specify to which day the opening hours of an OpeningHoursSpecification refer.
Originally, URLs from GoodRelations were used (for Monday, Tuesday, Wednesday, Thursday, Friday, Saturday, Sunday plus a special entry for PublicHolidays); these have now been integrated directly into schema.org.

Properties used on this type:

Enumeration members of this type:

- Friday
- Monday
- PublicHolidays
- Saturday
- Sunday
- Thursday
- Tuesday
- Wednesday

Properties whose values are of this type:

- byDay
- dayOfWeek

[^top]

#### DaySpa

A day spa.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### DeactivateAction

The act of stopping or deactivating a device or application (e.g. stopping a timer or turning off a flashlight).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### DecontextualizedContent

An Enumeration member

Content coded 'missing context' in a MediaReview, considered in the context of how it was published or shared.
For a VideoObject to be 'missing context': Presenting unaltered video in an inaccurate manner that misrepresents the footage. For example, using incorrect dates or locations, altering the transcript or sharing brief clips from a longer video to mislead viewers. (A video rated 'original' can also be missing context.)
For an ImageObject to be 'missing context': Presenting unaltered images in an inaccurate manner to misrepresent the image and mislead the viewer. For example, a common tactic is using an unaltered image but saying it came from a different time or place. (An image rated 'original' can also be missing context.)
For an ImageObject with embedded text to be 'missing context': An unaltered image presented in an inaccurate manner to misrepresent the image and mislead the viewer. For example, a common tactic is using an unaltered image but saying it came from a different time or place. (An 'original' image with inaccurate text would generally fall in this category.)
For an AudioObject to be 'missing context': Unaltered audio presented in an inaccurate manner that misrepresents it. For example, using incorrect dates or locations, or sharing brief clips from a longer recording to mislead viewers. (Audio rated “original” can also be missing context.)

Member of Enumeration: MediaManipulationRatingEnumeration
[^top]

#### DefenceEstablishment

A defence establishment, such as an army or navy base.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### DefinedRegion

A DefinedRegion is a geographic area defined by potentially arbitrary (rather than political, administrative or natural geographical) criteria. Properties are provided for defining a region by reference to sets of postal codes.
Examples: a delivery destination when shopping. Region where regional pricing is configured.
Requirement 1: Country: US States: "NY", "CA"
Requirement 2: Country: US PostalCode Set: { [94000-94585], [97000, 97999], [13000, 13599]} { [12345, 12345], [78945, 78945], } Region = state, canton, prefecture, autonomous community...

Properties used on this type:

- addressCountry
- addressRegion
- postalCode
- postalCodePrefix
- postalCodeRange

Properties whose values are of this type:

- shippingDestination

[^top]

#### DefinedTerm

A word, name, acronym, phrase, etc. with a formal definition. Often used in the context of category or subject classification, glossaries or dictionaries, product or creative work types, etc. Use the name property for the term being defined, use termCode if the term has an alpha-numeric code allocated, use description to provide the definition of the term.

Properties used on this type:

- inDefinedTermSet
- termCode

Properties whose values are of this type:

- assesses
- competencyRequired
- creativeWorkStatus
- credentialCategory
- educationalLevel
- educationalUse
- financialAidEligible
- hasDefinedTerm
- industry
- jobTitle
- keywords
- learningResourceType
- pattern
- physicalRequirement
- programType
- sensoryRequirement
- size
- skills
- teaches
- valueReference
- variesBy

[^top]

#### DefinedTermSet

A set of defined terms for example a set of categories or a classification scheme, a glossary, dictionary or enumeration.

Properties used on this type:

- hasDefinedTerm

Properties whose values are of this type:

- inDefinedTermSet

[^top]

#### DefinitiveLegalValue

An Enumeration member

Indicates a document for which the text is conclusively what the law says and is legally binding. (e.g. The digitally signed version of an Official Journal.) Something "Definitive" is considered to be also AuthoritativeLegalValue.

Member of Enumeration: LegalValueLevel
[^top]

#### DeleteAction

The act of editing a recipient by removing one of its objects.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### DeliveryChargeSpecification

The price for the delivery of an offer using a particular delivery method.

Properties used on this type:

- appliesToDeliveryMethod
- areaServed
- eligibleRegion
- ineligibleRegion

Properties whose values are of this type:

- freeShippingThreshold

[^top]

#### DeliveryEvent

An event involving the delivery of an item.

Properties used on this type:

- accessCode
- availableFrom
- availableThrough
- hasDeliveryMethod

Properties whose values are of this type:

- deliveryStatus

[^top]

#### DeliveryMethod

An Enumeration

A delivery method is a standardized procedure for transferring the product or service to the destination of fulfillment chosen by the customer. Delivery methods are characterized by the means of transportation used, and by the organization or group that is the contracting party for the sending organization or person.
Commonly used values:

- http://purl.org/goodrelations/v1#DeliveryModeDirectDownload
- http://purl.org/goodrelations/v1#DeliveryModeFreight
- http://purl.org/goodrelations/v1#DeliveryModeMail
- http://purl.org/goodrelations/v1#DeliveryModeOwnFleet
- http://purl.org/goodrelations/v1#DeliveryModePickUp
- http://purl.org/goodrelations/v1#DHL
- http://purl.org/goodrelations/v1#FederalExpress
- http://purl.org/goodrelations/v1#UPS

Properties used on this type:

Enumeration members of this type:

- LockerDelivery
- OnSitePickup
- ParcelService

Properties whose values are of this type:

- appliesToDeliveryMethod
- availableDeliveryMethod
- deliveryMethod
- hasDeliveryMethod

[^top]

#### DeliveryTimeSettings

A DeliveryTimeSettings represents re-usable pieces of shipping information, relating to timing. It is designed for publication on an URL that may be referenced via the shippingSettingsLink property of a OfferShippingDetails. Several occurrences can be published, distinguished (and identified/referenced) by their different values for transitTimeLabel.

Properties used on this type:

- deliveryTime
- isUnlabelledFallback
- shippingDestination
- transitTimeLabel

Properties whose values are of this type:

[^top]

#### Demand

A demand entity represents the public, not necessarily binding, not necessarily exclusive, announcement by an organization or person to seek a certain type of goods or services. For describing demand using this type, the very same properties used for Offer apply.

Properties used on this type:

- acceptedPaymentMethod
- advanceBookingRequirement
- areaServed
- availability
- availabilityEnds
- availabilityStarts
- availableAtOrFrom
- availableDeliveryMethod
- businessFunction
- deliveryLeadTime
- eligibleCustomerType
- eligibleDuration
- eligibleQuantity
- eligibleRegion
- eligibleTransactionVolume
- gtin
- gtin12
- gtin13
- gtin14
- gtin8
- includesObject
- ineligibleRegion
- inventoryLevel
- itemCondition
- itemOffered
- mpn
- priceSpecification
- seller
- serialNumber
- sku
- validFrom
- validThrough
- warranty

Properties whose values are of this type:

- offers
- seeks

[^top]

#### DemoAlbum

An Enumeration member

DemoAlbum.

Member of Enumeration: MusicAlbumProductionType
[^top]

#### Dentist

A dentist.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Dentistry

An Enumeration member

A branch of medicine that is involved in the dental care.

Member of Enumeration: MedicalSpecialty
[^top]

#### DepartAction

The act of departing from a place. An agent departs from an fromLocation for a destination, optionally with participants.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### DepartmentStore

A department store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### DepositAccount

A type of Bank Account with a main purpose of depositing funds to gain interest or other benefits.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Dermatologic

An Enumeration member

Something relating to or practicing dermatology.

Member of Enumeration: MedicalSpecialty
[^top]

#### Dermatology

An Enumeration member

A specific branch of medical science that pertains to diagnosis and treatment of disorders of skin.

Member of Enumeration: MedicalSpecialty
[^top]

#### DiabeticDiet

An Enumeration member

A diet appropriate for people with diabetes.

Member of Enumeration: RestrictedDiet
[^top]

#### Diagnostic

An Enumeration member

A medical device used for diagnostic purposes.

Member of Enumeration: MedicalDevicePurpose
[^top]

#### DiagnosticLab

A medical laboratory that offers on-site or off-site diagnostic services.

Properties used on this type:

- availableTest

Properties whose values are of this type:

[^top]

#### DiagnosticProcedure

A medical procedure intended primarily for diagnostic, as opposed to therapeutic, purposes.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Diet

A strategy of regulating the intake of food to achieve or maintain a specific health-related goal.

Properties used on this type:

- dietFeatures
- endorsers
- expertConsiderations
- physiologicalBenefits
- risks

Properties whose values are of this type:

- diet
- exerciseRelatedDiet

[^top]

#### DietNutrition

An Enumeration member

Dietetic and nutrition as a medical specialty.

Member of Enumeration: MedicalSpecialty
[^top]

#### DietarySupplement

A product taken by mouth that contains a dietary ingredient intended to supplement the diet. Dietary ingredients may include vitamins, minerals, herbs or other botanicals, amino acids, and substances such as enzymes, organ tissues, glandulars and metabolites.

Properties used on this type:

- activeIngredient
- isProprietary
- legalStatus
- manufacturer
- maximumIntake
- mechanismOfAction
- nonProprietaryName
- proprietaryName
- recommendedIntake
- safetyConsideration
- targetPopulation

Properties whose values are of this type:

[^top]

#### DigitalAudioTapeFormat

An Enumeration member

DigitalAudioTapeFormat.

Member of Enumeration: MusicReleaseFormatType
[^top]

#### DigitalDocument

An electronic file or document.

Properties used on this type:

- hasDigitalDocumentPermission

Properties whose values are of this type:

[^top]

#### DigitalDocumentPermission

A permission for a particular person or group to access a particular file.

Properties used on this type:

- grantee
- permissionType

Properties whose values are of this type:

- hasDigitalDocumentPermission

[^top]

#### DigitalDocumentPermissionType

An Enumeration

A type of permission which can be granted for accessing a digital document.

Properties used on this type:

Enumeration members of this type:

- CommentPermission
- ReadPermission
- WritePermission

Properties whose values are of this type:

- permissionType

[^top]

#### DigitalFormat

An Enumeration member

DigitalFormat.

Member of Enumeration: MusicReleaseFormatType
[^top]

#### DisabilitySupport

An Enumeration member

DisabilitySupport: this is a benefit for disability support.

Member of Enumeration: GovernmentBenefitsType
[^top]

#### DisagreeAction

The act of expressing a difference of opinion with the object. An agent disagrees to/about an object (a proposition, topic or theme) with participants.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Discontinued

An Enumeration member

Indicates that the item has been discontinued.

Member of Enumeration: ItemAvailability
[^top]

#### DiscoverAction

The act of discovering/finding an object.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### DiscussionForumPosting

A posting to a discussion forum.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### DislikeAction

The act of expressing a negative sentiment about the object. An agent dislikes an object (a proposition, topic or theme) with participants.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Distance

Properties that take Distances as values are of the form '<Number> <Length unit of measure>'. E.g., '7 ft'.

Properties used on this type:

Properties whose values are of this type:

- depth
- distance
- flightDistance
- geoRadius
- height
- width

[^top]

#### DistanceFee

An Enumeration member

Represents the distance fee (e.g., price per km or mile) part of the total price for an offered product, for example a car rental.

Member of Enumeration: PriceComponentTypeEnumeration
[^top]

#### Distillery

A distillery.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### DonateAction

The act of providing goods, services, or money without compensation, often for philanthropic reasons.

Properties used on this type:

- recipient

Properties whose values are of this type:

[^top]

#### DoseSchedule

A specific dosing schedule for a drug or supplement.

Properties used on this type:

- doseUnit
- doseValue
- frequency
- targetPopulation

Properties whose values are of this type:

- doseSchedule

[^top]

#### DoubleBlindedTrial

An Enumeration member

A trial design in which neither the researcher nor the patient knows the details of the treatment the patient was randomly assigned to.

Member of Enumeration: MedicalTrialDesign
[^top]

#### DownloadAction

The act of downloading an object.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Downpayment

An Enumeration member

Represents the downpayment (up-front payment) price component of the total price for an offered product that has additional installment payments.

Member of Enumeration: PriceComponentTypeEnumeration
[^top]

#### DrawAction

The act of producing a visual/graphical representation of an object, typically with a pen/pencil and paper as instruments.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Drawing

A picture or diagram made with a pencil, pen, or crayon rather than paint.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### DrinkAction

The act of swallowing liquids.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### DriveWheelConfigurationValue

An Enumeration

A value indicating which roadwheels will receive torque.

Properties used on this type:

Enumeration members of this type:

- AllWheelDriveConfiguration
- FourWheelDriveConfiguration
- FrontWheelDriveConfiguration
- RearWheelDriveConfiguration

Properties whose values are of this type:

- driveWheelConfiguration

[^top]

#### DrivingSchoolVehicleUsage

An Enumeration member

Indicates the usage of the vehicle for driving school.

Member of Enumeration: CarUsageType
[^top]

#### Drug

A chemical or biologic substance, used as a medical therapy, that has a physiological effect on an organism. Here the term drug is used interchangeably with the term medicine although clinical knowledge make a clear difference between them.

Properties used on this type:

- activeIngredient
- administrationRoute
- alcoholWarning
- availableStrength
- breastfeedingWarning
- clincalPharmacology
- clinicalPharmacology
- dosageForm
- doseSchedule
- drugClass
- drugUnit
- foodWarning
- includedInHealthInsurancePlan
- interactingDrug
- isAvailableGenerically
- isProprietary
- labelDetails
- legalStatus
- manufacturer
- maximumIntake
- mechanismOfAction
- nonProprietaryName
- overdosage
- pregnancyCategory
- pregnancyWarning
- prescribingInfo
- prescriptionStatus
- proprietaryName
- relatedDrug
- rxcui
- warning

Properties whose values are of this type:

- affectedBy
- drug
- interactingDrug
- relatedDrug

[^top]

#### DrugClass

A class of medical drugs, e.g., statins. Classes can represent general pharmacological class, common mechanisms of action, common physiological effects, etc.

Properties used on this type:

- drug

Properties whose values are of this type:

- drugClass

[^top]

#### DrugCost

The cost per unit of a medical drug. Note that this type is not meant to represent the price in an offer of a drug for sale; see the Offer type for that. This type will typically be used to tag wholesale or average retail cost of a drug, or maximum reimbursable cost. Costs of medical drugs vary widely depending on how and where they are paid for, so while this type captures some of the variables, costs should be used with caution by consumers of this schema's markup.

Properties used on this type:

- applicableLocation
- costCategory
- costCurrency
- costOrigin
- costPerUnit
- drugUnit

Properties whose values are of this type:

[^top]

#### DrugCostCategory

An Enumeration

Enumerated categories of medical drug costs.

Properties used on this type:

Enumeration members of this type:

- ReimbursementCap
- Retail
- Wholesale

Properties whose values are of this type:

- costCategory

[^top]

#### DrugLegalStatus

The legal availability status of a medical drug.

Properties used on this type:

- applicableLocation

Properties whose values are of this type:

- legalStatus

[^top]

#### DrugPregnancyCategory

An Enumeration

Categories that represent an assessment of the risk of fetal injury due to a drug or pharmaceutical used as directed by the mother during pregnancy.

Properties used on this type:

Enumeration members of this type:

- FDAcategoryA
- FDAcategoryB
- FDAcategoryC
- FDAcategoryD
- FDAcategoryX
- FDAnotEvaluated

Properties whose values are of this type:

- pregnancyCategory

[^top]

#### DrugPrescriptionStatus

An Enumeration

Indicates whether this drug is available by prescription or over-the-counter.

Properties used on this type:

Enumeration members of this type:

- OTC
- PrescriptionOnly

Properties whose values are of this type:

- prescriptionStatus

[^top]

#### DrugStrength

A specific strength in which a medical drug is available in a specific country.

Properties used on this type:

- activeIngredient
- availableIn
- maximumIntake
- strengthUnit
- strengthValue

Properties whose values are of this type:

- availableStrength

[^top]

#### DryCleaningOrLaundry

A dry-cleaning business.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Duration

Quantity: Duration (use ISO 8601 duration format).

Properties used on this type:

Properties whose values are of this type:

- activityDuration
- billingDuration
- billingPeriod
- cookTime
- duration
- estimatedFlightDuration
- gracePeriod
- leaseLength
- performTime
- prepTime
- processingTime
- repeatFrequency
- termDuration
- timeRequired
- timeToComplete
- totalTime
- validFor

[^top]

#### EBook

An Enumeration member

Book format: Ebook.

Member of Enumeration: BookFormatType
[^top]

#### EPRelease

An Enumeration member

EPRelease.

Member of Enumeration: MusicAlbumReleaseType
[^top]

#### EUEnergyEfficiencyCategoryA

An Enumeration member

Represents EU Energy Efficiency Class A as defined in EU energy labeling regulations.

Member of Enumeration: EUEnergyEfficiencyEnumeration
[^top]

#### EUEnergyEfficiencyCategoryA1Plus

An Enumeration member

Represents EU Energy Efficiency Class A+ as defined in EU energy labeling regulations.

Member of Enumeration: EUEnergyEfficiencyEnumeration
[^top]

#### EUEnergyEfficiencyCategoryA2Plus

An Enumeration member

Represents EU Energy Efficiency Class A++ as defined in EU energy labeling regulations.

Member of Enumeration: EUEnergyEfficiencyEnumeration
[^top]

#### EUEnergyEfficiencyCategoryA3Plus

An Enumeration member

Represents EU Energy Efficiency Class A+++ as defined in EU energy labeling regulations.

Member of Enumeration: EUEnergyEfficiencyEnumeration
[^top]

#### EUEnergyEfficiencyCategoryB

An Enumeration member

Represents EU Energy Efficiency Class B as defined in EU energy labeling regulations.

Member of Enumeration: EUEnergyEfficiencyEnumeration
[^top]

#### EUEnergyEfficiencyCategoryC

An Enumeration member

Represents EU Energy Efficiency Class C as defined in EU energy labeling regulations.

Member of Enumeration: EUEnergyEfficiencyEnumeration
[^top]

#### EUEnergyEfficiencyCategoryD

An Enumeration member

Represents EU Energy Efficiency Class D as defined in EU energy labeling regulations.

Member of Enumeration: EUEnergyEfficiencyEnumeration
[^top]

#### EUEnergyEfficiencyCategoryE

An Enumeration member

Represents EU Energy Efficiency Class E as defined in EU energy labeling regulations.

Member of Enumeration: EUEnergyEfficiencyEnumeration
[^top]

#### EUEnergyEfficiencyCategoryF

An Enumeration member

Represents EU Energy Efficiency Class F as defined in EU energy labeling regulations.

Member of Enumeration: EUEnergyEfficiencyEnumeration
[^top]

#### EUEnergyEfficiencyCategoryG

An Enumeration member

Represents EU Energy Efficiency Class G as defined in EU energy labeling regulations.

Member of Enumeration: EUEnergyEfficiencyEnumeration
[^top]

#### EUEnergyEfficiencyEnumeration

An Enumeration

Enumerates the EU energy efficiency classes A-G as well as A+, A++, and A+++ as defined in EU directive 2017/1369.

Properties used on this type:

Enumeration members of this type:

- EUEnergyEfficiencyCategoryA
- EUEnergyEfficiencyCategoryA1Plus
- EUEnergyEfficiencyCategoryA2Plus
- EUEnergyEfficiencyCategoryA3Plus
- EUEnergyEfficiencyCategoryB
- EUEnergyEfficiencyCategoryC
- EUEnergyEfficiencyCategoryD
- EUEnergyEfficiencyCategoryE
- EUEnergyEfficiencyCategoryF
- EUEnergyEfficiencyCategoryG

Properties whose values are of this type:

- energyEfficiencyScaleMax
- energyEfficiencyScaleMin

[^top]

#### Ear

An Enumeration member

Ear function assessment with clinical examination.

Member of Enumeration: PhysicalExam
[^top]

#### EatAction

The act of swallowing solid objects.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### EditedOrCroppedContent

An Enumeration member

Content coded 'edited or cropped content' in a MediaReview, considered in the context of how it was published or shared.
For a VideoObject to be 'edited or cropped content': The video has been edited or rearranged. This category applies to time edits, including editing multiple videos together to alter the story being told or editing out large portions from a video.
For an ImageObject to be 'edited or cropped content': Presenting a part of an image from a larger whole to mislead the viewer.
For an ImageObject with embedded text to be 'edited or cropped content': Presenting a part of an image from a larger whole to mislead the viewer.
For an AudioObject to be 'edited or cropped content': The audio has been edited or rearranged. This category applies to time edits, including editing multiple audio clips together to alter the story being told or editing out large portions from the recording.

Member of Enumeration: MediaManipulationRatingEnumeration
[^top]

#### EducationEvent

Event type: Education event.

Properties used on this type:

- assesses
- educationalLevel
- teaches

Properties whose values are of this type:

[^top]

#### EducationalAudience

An EducationalAudience.

Properties used on this type:

- educationalRole

Properties whose values are of this type:

[^top]

#### EducationalOccupationalCredential

An educational or occupational credential. A diploma, academic degree, certification, qualification, badge, etc., that may be awarded to a person or other entity that meets the requirements defined by the credentialer.

Properties used on this type:

- competencyRequired
- credentialCategory
- educationalLevel
- recognizedBy
- validFor
- validIn

Properties whose values are of this type:

- educationRequirements
- educationalCredentialAwarded
- hasCredential
- occupationalCredentialAwarded
- programPrerequisites
- qualifications

[^top]

#### EducationalOccupationalProgram

A program offered by an institution which determines the learning progress to achieve an outcome, usually a credential like a degree or certificate. This would define a discrete set of opportunities (e.g., job, courses) that together constitute a program with a clear start, end, set of requirements, and transition to a new occupational opportunity (e.g., a job), or sometimes a higher educational opportunity (e.g., an advanced degree).

Properties used on this type:

- applicationDeadline
- applicationStartDate
- dayOfWeek
- educationalCredentialAwarded
- educationalProgramMode
- endDate
- financialAidEligible
- hasCourse
- maximumEnrollment
- numberOfCredits
- occupationalCategory
- occupationalCredentialAwarded
- offers
- programPrerequisites
- programType
- provider
- salaryUponCompletion
- startDate
- termDuration
- termsPerYear
- timeOfDay
- timeToComplete
- trainingSalary
- typicalCreditsPerTerm

Properties whose values are of this type:

[^top]

#### EducationalOrganization

An educational organization.

Properties used on this type:

- alumni

Properties whose values are of this type:

- alumniOf

[^top]

#### EffectivenessHealthAspect

An Enumeration member

Content about the effectiveness-related aspects of a health topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### Electrician

An electrician.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ElectronicsStore

An electronics store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ElementarySchool

An elementary school.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### EmailMessage

An email message.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Embassy

An embassy.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Emergency

An Enumeration member

A specific branch of medical science that deals with the evaluation and initial treatment of medical conditions caused by trauma or sudden illness.

Member of Enumeration: MedicalSpecialty
[^top]

#### EmergencyService

An emergency service, such as a fire station or ER.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### EmployeeRole

A subclass of OrganizationRole used to describe employee relationships.

Properties used on this type:

- baseSalary
- salaryCurrency

Properties whose values are of this type:

[^top]

#### EmployerAggregateRating

An aggregate rating of an Organization related to its role as an employer.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### EmployerReview

An EmployerReview is a review of an Organization regarding its role as an employer, written by a current or former employee of that organization.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### EmploymentAgency

An employment agency.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Endocrine

An Enumeration member

A specific branch of medical science that pertains to diagnosis and treatment of disorders of endocrine glands and their secretions.

Member of Enumeration: MedicalSpecialty
[^top]

#### EndorseAction

An agent approves/certifies/likes/supports/sanction an object.

Properties used on this type:

- endorsee

Properties whose values are of this type:

[^top]

#### EndorsementRating

An EndorsementRating is a rating that expresses some level of endorsement, for example inclusion in a "critic's pick" blog, a "Like" or "+1" on a social network. It can be considered the result of an EndorseAction in which the object of the action is rated positively by some agent. As is common elsewhere in schema.org, it is sometimes more useful to describe the results of such an action without explicitly describing the Action.
An EndorsementRating may be part of a numeric scale or organized system, but this is not required: having an explicit type for indicating a positive, endorsement rating is particularly useful in the absence of numeric scales as it helps consumers understand that the rating is broadly positive.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Energy

Properties that take Energy as values are of the form '<Number> <Energy unit of measure>'.

Properties used on this type:

Properties whose values are of this type:

- calories
- workload

[^top]

#### EnergyConsumptionDetails

EnergyConsumptionDetails represents information related to the energy efficiency of a product that consumes energy. The information that can be provided is based on international regulations such as for example EU directive 2017/1369 for energy labeling and the Energy labeling rule under the Energy Policy and Conservation Act (EPCA) in the US.

Properties used on this type:

- energyEfficiencyScaleMax
- energyEfficiencyScaleMin
- hasEnergyEfficiencyCategory

Properties whose values are of this type:

- hasEnergyConsumptionDetails

[^top]

#### EnergyEfficiencyEnumeration

An Enumeration

Enumerates energy efficiency levels (also known as "classes" or "ratings") and certifications that are part of several international energy efficiency standards.

Properties used on this type:

Enumeration members of this type:

Properties whose values are of this type:

- hasEnergyEfficiencyCategory

[^top]

#### EnergyStarCertified

An Enumeration member

Represents EnergyStar certification.

Member of Enumeration: EnergyStarEnergyEfficiencyEnumeration
[^top]

#### EnergyStarEnergyEfficiencyEnumeration

An Enumeration

Used to indicate whether a product is EnergyStar certified.

Properties used on this type:

Enumeration members of this type:

- EnergyStarCertified

Properties whose values are of this type:

[^top]

#### EngineSpecification

Information about the engine of the vehicle. A vehicle can have multiple engines represented by multiple engine specification entities.

Properties used on this type:

- engineDisplacement
- enginePower
- engineType
- fuelType
- torque

Properties whose values are of this type:

- vehicleEngine

[^top]

#### EnrollingByInvitation

An Enumeration member

Enrolling participants by invitation only.

Member of Enumeration: MedicalStudyStatus
[^top]

#### EntertainmentBusiness

A business providing entertainment.

Properties used on this type:

Properties whose values are of this type:

- entertainmentBusiness

[^top]

#### EntryPoint

An entry point, within some Web-based protocol.

Properties used on this type:

- actionApplication
- actionPlatform
- application
- contentType
- encodingType
- httpMethod
- urlTemplate

Properties whose values are of this type:

- target

[^top]

#### Enumeration

An Enumeration

Lists or enumerations—for example, a list of cuisines or music genres, etc.

Properties used on this type:

- supersededBy

Enumeration members of this type:

Properties whose values are of this type:

- supersededBy
- valueReference

[^top]

#### Episode

A media episode (e.g. TV, radio, video game) which can be part of a series or season.

Properties used on this type:

- actor
- actors
- director
- directors
- duration
- episodeNumber
- musicBy
- partOfSeason
- partOfSeries
- productionCompany
- trailer

Properties whose values are of this type:

- episode
- episodes
- partOfEpisode

[^top]

#### Event

An event happening at a certain time and location, such as a concert, lecture, or festival. Ticketing information may be added via the offers property. Repeated events may be structured as separate Event objects.

Properties used on this type:

- about
- actor
- aggregateRating
- attendee
- attendees
- audience
- composer
- contributor
- director
- doorTime
- duration
- endDate
- eventAttendanceMode
- eventSchedule
- eventStatus
- funder
- inLanguage
- isAccessibleForFree
- location
- maximumAttendeeCapacity
- maximumPhysicalAttendeeCapacity
- maximumVirtualAttendeeCapacity
- offers
- organizer
- performer
- performers
- previousStartDate
- recordedIn
- remainingAttendeeCapacity
- review
- sponsor
- startDate
- subEvent
- subEvents
- superEvent
- translator
- typicalAgeRange
- workFeatured
- workPerformed

Properties whose values are of this type:

- broadcastOfEvent
- event
- events
- firstPerformance
- itemOffered
- performerIn
- recordedAt
- subEvent
- subEvents
- subjectOf
- superEvent

[^top]

#### EventAttendanceModeEnumeration

An Enumeration

An EventAttendanceModeEnumeration value is one of potentially several modes of organising an event, relating to whether it is online or offline.

Properties used on this type:

Enumeration members of this type:

- MixedEventAttendanceMode
- OfflineEventAttendanceMode
- OnlineEventAttendanceMode

Properties whose values are of this type:

- eventAttendanceMode

[^top]

#### EventCancelled

An Enumeration member

The event has been cancelled. If the event has multiple startDate values, all are assumed to be cancelled. Either startDate or previousStartDate may be used to specify the event's cancelled date(s).

Member of Enumeration: EventStatusType
[^top]

#### EventMovedOnline

An Enumeration member

Indicates that the event was changed to allow online participation. See eventAttendanceMode for specifics of whether it is now fully or partially online.

Member of Enumeration: EventStatusType
[^top]

#### EventPostponed

An Enumeration member

The event has been postponed and no new date has been set. The event's previousStartDate should be set.

Member of Enumeration: EventStatusType
[^top]

#### EventRescheduled

An Enumeration member

The event has been rescheduled. The event's previousStartDate should be set to the old date and the startDate should be set to the event's new date. (If the event has been rescheduled multiple times, the previousStartDate property may be repeated).

Member of Enumeration: EventStatusType
[^top]

#### EventReservation

A reservation for an event like a concert, sporting event, or lecture.
Note: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations. For offers of tickets, use Offer.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### EventScheduled

An Enumeration member

The event is taking place or has taken place on the startDate as scheduled. Use of this value is optional, as it is assumed by default.

Member of Enumeration: EventStatusType
[^top]

#### EventSeries

A series of Events. Included events can relate with the series using the superEvent property.
An EventSeries is a collection of events that share some unifying characteristic. For example, "The Olympic Games" is a series, which is repeated regularly. The "2012 London Olympics" can be presented both as an Event in the series "Olympic Games", and as an EventSeries that included a number of sporting competitions as Events.
The nature of the association between the events in an EventSeries can vary, but typical examples could include a thematic event series (e.g. topical meetups or classes), or a series of regular events that share a location, attendee group and/or organizers.
EventSeries has been defined as a kind of Event to make it easy for publishers to use it in an Event context without worrying about which kinds of series are really event-like enough to call an Event. In general an EventSeries may seem more Event-like when the period of time is compact and when aspects such as location are fixed, but it may also sometimes prove useful to describe a longer-term series as an Event.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### EventStatusType

An Enumeration

EventStatusType is an enumeration type whose instances represent several states that an Event may be in.

Properties used on this type:

Enumeration members of this type:

- EventCancelled
- EventMovedOnline
- EventPostponed
- EventRescheduled
- EventScheduled

Properties whose values are of this type:

- eventStatus
- status

[^top]

#### EventVenue

An event venue.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### EvidenceLevelA

An Enumeration member

Data derived from multiple randomized clinical trials or meta-analyses.

Member of Enumeration: MedicalEvidenceLevel
[^top]

#### EvidenceLevelB

An Enumeration member

Data derived from a single randomized trial, or nonrandomized studies.

Member of Enumeration: MedicalEvidenceLevel
[^top]

#### EvidenceLevelC

An Enumeration member

Only consensus opinion of experts, case studies, or standard-of-care.

Member of Enumeration: MedicalEvidenceLevel
[^top]

#### ExchangeRateSpecification

A structured value representing exchange rate.

Properties used on this type:

- currency
- currentExchangeRate
- exchangeRateSpread

Properties whose values are of this type:

[^top]

#### ExchangeRefund

An Enumeration member

A ExchangeRefund ...

Member of Enumeration: RefundTypeEnumeration
[^top]

#### ExerciseAction

The act of participating in exertive activity for the purposes of improving health and fitness.

Properties used on this type:

- course
- diet
- distance
- exerciseCourse
- exercisePlan
- exerciseRelatedDiet
- exerciseType
- fromLocation
- opponent
- sportsActivityLocation
- sportsEvent
- sportsTeam
- toLocation

Properties whose values are of this type:

[^top]

#### ExerciseGym

A gym.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ExercisePlan

Fitness-related activity designed for a specific health-related purpose, including defined exercise routines as well as activity prescribed by a clinician.

Properties used on this type:

- activityDuration
- activityFrequency
- additionalVariable
- exerciseType
- intensity
- repetitions
- restPeriods
- workload

Properties whose values are of this type:

- exercisePlan

[^top]

#### ExhibitionEvent

Event type: Exhibition event, e.g. at a museum, library, archive, tradeshow, ...

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Eye

An Enumeration member

Eye or ophtalmological function assessment with clinical examination.

Member of Enumeration: PhysicalExam
[^top]

#### FAQPage

A FAQPage is a WebPage presenting one or more "Frequently asked questions" (see also QAPage).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### FDAcategoryA

An Enumeration member

A designation by the US FDA signifying that adequate and well-controlled studies have failed to demonstrate a risk to the fetus in the first trimester of pregnancy (and there is no evidence of risk in later trimesters).

Member of Enumeration: DrugPregnancyCategory
[^top]

#### FDAcategoryB

An Enumeration member

A designation by the US FDA signifying that animal reproduction studies have failed to demonstrate a risk to the fetus and there are no adequate and well-controlled studies in pregnant women.

Member of Enumeration: DrugPregnancyCategory
[^top]

#### FDAcategoryC

An Enumeration member

A designation by the US FDA signifying that animal reproduction studies have shown an adverse effect on the fetus and there are no adequate and well-controlled studies in humans, but potential benefits may warrant use of the drug in pregnant women despite potential risks.

Member of Enumeration: DrugPregnancyCategory
[^top]

#### FDAcategoryD

An Enumeration member

A designation by the US FDA signifying that there is positive evidence of human fetal risk based on adverse reaction data from investigational or marketing experience or studies in humans, but potential benefits may warrant use of the drug in pregnant women despite potential risks.

Member of Enumeration: DrugPregnancyCategory
[^top]

#### FDAcategoryX

An Enumeration member

A designation by the US FDA signifying that studies in animals or humans have demonstrated fetal abnormalities and/or there is positive evidence of human fetal risk based on adverse reaction data from investigational or marketing experience, and the risks involved in use of the drug in pregnant women clearly outweigh potential benefits.

Member of Enumeration: DrugPregnancyCategory
[^top]

#### FDAnotEvaluated

An Enumeration member

A designation that the drug in question has not been assigned a pregnancy category designation by the US FDA.

Member of Enumeration: DrugPregnancyCategory
[^top]

#### FMRadioChannel

A radio channel that uses FM.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### FailedActionStatus

An Enumeration member

An action that failed to complete. The action's error property and the HTTP return code contain more information about the failure.

Member of Enumeration: ActionStatusType
[^top]

#### FastFoodRestaurant

A fast-food restaurant.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Female

An Enumeration member

The female gender.

Member of Enumeration: GenderType
[^top]

#### Festival

Event type: Festival.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### FilmAction

The act of capturing sound and moving images on film, video, or digitally.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### FinancialProduct

A product provided to consumers and businesses by financial institutions such as banks, insurance companies, brokerage firms, consumer finance companies, and investment companies which comprise the financial services industry.

Properties used on this type:

- annualPercentageRate
- feesAndCommissionsSpecification
- interestRate

Properties whose values are of this type:

[^top]

#### FinancialService

Financial services business.

Properties used on this type:

- feesAndCommissionsSpecification

Properties whose values are of this type:

[^top]

#### FindAction

The act of finding an object.
Related actions:

- SearchAction: FindAction is generally lead by a SearchAction, but not necessarily.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### FireStation

A fire station. With firemen.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Flexibility

An Enumeration member

Physical activity that is engaged in to improve joint and muscle flexibility.

Member of Enumeration: PhysicalActivityCategory
[^top]

#### Flight

An airline flight.

Properties used on this type:

- aircraft
- arrivalAirport
- arrivalGate
- arrivalTerminal
- boardingPolicy
- carrier
- departureAirport
- departureGate
- departureTerminal
- estimatedFlightDuration
- flightDistance
- flightNumber
- mealService
- seller
- webCheckinTime

Properties whose values are of this type:

[^top]

#### FlightReservation

A reservation for air travel.
Note: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations. For offers of tickets, use Offer.

Properties used on this type:

- boardingGroup
- passengerPriorityStatus
- passengerSequenceNumber
- securityScreening

Properties whose values are of this type:

[^top]

#### Float

Data type: Floating number.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### FloorPlan

A FloorPlan is an explicit representation of a collection of similar accommodations, allowing the provision of common information (room counts, sizes, layout diagrams) and offers for rental or sale. In typical use, some ApartmentComplex has an accommodationFloorPlan which is a FloorPlan. A FloorPlan is always in the context of a particular place, either a larger ApartmentComplex or a single Apartment. The visual/spatial aspects of a floor plan (i.e. room layout, see wikipedia) can be indicated using image.

Properties used on this type:

- amenityFeature
- floorSize
- isPlanForApartment
- layoutImage
- numberOfAccommodationUnits
- numberOfAvailableAccommodationUnits
- numberOfBathroomsTotal
- numberOfBedrooms
- numberOfFullBathrooms
- numberOfPartialBathrooms
- numberOfRooms
- petsAllowed

Properties whose values are of this type:

- accommodationFloorPlan

[^top]

#### Florist

A florist.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### FollowAction

The act of forming a personal connection with someone/something (object) unidirectionally/asymmetrically to get updates polled from.
Related actions:

- BefriendAction: Unlike BefriendAction, FollowAction implies that the connection is not necessarily reciprocal.
- SubscribeAction: Unlike SubscribeAction, FollowAction implies that the follower acts as an active agent constantly/actively polling for updates.
- RegisterAction: Unlike RegisterAction, FollowAction implies that the agent is interested in continuing receiving updates from the object.
- JoinAction: Unlike JoinAction, FollowAction implies that the agent is interested in getting updates from the object.
- TrackAction: Unlike TrackAction, FollowAction refers to the polling of updates of all aspects of animate objects rather than the location of inanimate objects (e.g. you track a package, but you don't follow it).

Properties used on this type:

- followee

Properties whose values are of this type:

[^top]

#### FoodEstablishment

A food-related business.

Properties used on this type:

- acceptsReservations
- hasMenu
- menu
- servesCuisine
- starRating

Properties whose values are of this type:

- foodEstablishment

[^top]

#### FoodEstablishmentReservation

A reservation to dine at a food-related business.
Note: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations.

Properties used on this type:

- endTime
- partySize
- startTime

Properties whose values are of this type:

[^top]

#### FoodEvent

Event type: Food event.

Properties used on this type:

Properties whose values are of this type:

- foodEvent

[^top]

#### FoodService

A food service, like breakfast, lunch, or dinner.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### FourWheelDriveConfiguration

An Enumeration member

Four-wheel drive is a transmission layout where the engine primarily drives two wheels with a part-time four-wheel drive capability.

Member of Enumeration: DriveWheelConfigurationValue
[^top]

#### Friday

An Enumeration member

The day of the week between Thursday and Saturday.

Member of Enumeration: DayOfWeek
[^top]

#### FrontWheelDriveConfiguration

An Enumeration member

Front-wheel drive is a transmission layout where the engine drives the front wheels.

Member of Enumeration: DriveWheelConfigurationValue
[^top]

#### FullRefund

An Enumeration member

A FullRefund ...

Member of Enumeration: RefundTypeEnumeration
[^top]

#### FundingAgency

A FundingAgency is an organization that implements one or more FundingSchemes and manages the granting process (via Grants, typically MonetaryGrants). A funding agency is not always required for grant funding, e.g. philanthropic giving, corporate sponsorship etc.
Examples of funding agencies include ERC, REA, NIH, Bill and Melinda Gates Foundation...

Properties used on this type:

Properties whose values are of this type:

[^top]

#### FundingScheme

A FundingScheme combines organizational, project and policy aspects of grant-based funding that sets guidelines, principles and mechanisms to support other kinds of projects and activities. Funding is typically organized via Grant funding. Examples of funding schemes: Swiss Priority Programmes (SPPs); EU Framework 7 (FP7); Horizon 2020; the NIH-R01 Grant Program; Wellcome institutional strategic support fund. For large scale public sector funding, the management and administration of grant awards is often handled by other, dedicated, organizations - FundingAgencys such as ERC, REA, ...

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Fungus

An Enumeration member

Pathogenic fungus.

Member of Enumeration: InfectiousAgentClass
[^top]

#### FurnitureStore

A furniture store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Game

The Game type represents things which are games. These are typically rule-governed recreational activities, e.g. role-playing games in which players assume the role of characters in a fictional setting.

Properties used on this type:

- characterAttribute
- gameItem
- gameLocation
- numberOfPlayers
- quest

Properties whose values are of this type:

[^top]

#### GamePlayMode

An Enumeration

Indicates whether this game is multi-player, co-op or single-player.

Properties used on this type:

Enumeration members of this type:

- CoOp
- MultiPlayer
- SinglePlayer

Properties whose values are of this type:

- playMode

[^top]

#### GameServer

Server that provides game interaction in a multiplayer game.

Properties used on this type:

- game
- playersOnline
- serverStatus

Properties whose values are of this type:

- gameServer

[^top]

#### GameServerStatus

An Enumeration

Status of a game server.

Properties used on this type:

Enumeration members of this type:

- OfflinePermanently
- OfflineTemporarily
- Online
- OnlineFull

Properties whose values are of this type:

- serverStatus

[^top]

#### GardenStore

A garden store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### GasStation

A gas station.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Gastroenterologic

An Enumeration member

A specific branch of medical science that pertains to diagnosis and treatment of disorders of digestive system.

Member of Enumeration: MedicalSpecialty
[^top]

#### GatedResidenceCommunity

Residence type: Gated community.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### GenderType

An Enumeration

An enumeration of genders.

Properties used on this type:

Enumeration members of this type:

- Female
- Male

Properties whose values are of this type:

- gender
- suggestedGender

[^top]

#### GeneralContractor

A general contractor.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Genetic

An Enumeration member

A specific branch of medical science that pertains to hereditary transmission and the variation of inherited characteristics and disorders.

Member of Enumeration: MedicalSpecialty
[^top]

#### Genitourinary

An Enumeration member

Genitourinary system function assessment with clinical examination.

Member of Enumeration: PhysicalExam
[^top]

#### GeoCircle

A GeoCircle is a GeoShape representing a circular geographic area. As it is a GeoShape it provides the simple textual property 'circle', but also allows the combination of postalCode alongside geoRadius. The center of the circle can be indicated via the 'geoMidpoint' property, or more approximately using 'address', 'postalCode'.

Properties used on this type:

- geoMidpoint
- geoRadius

Properties whose values are of this type:

[^top]

#### GeoCoordinates

The geographic coordinates of a place or event.

Properties used on this type:

- address
- addressCountry
- elevation
- latitude
- longitude
- postalCode

Properties whose values are of this type:

- geo
- geoMidpoint

[^top]

#### GeoShape

The geographic shape of a place. A GeoShape can be described using several properties whose values are based on latitude/longitude pairs. Either whitespace or commas can be used to separate latitude and longitude; whitespace should be used when writing a list of several such points.

Properties used on this type:

- address
- addressCountry
- box
- circle
- elevation
- line
- polygon
- postalCode

Properties whose values are of this type:

- areaServed
- eligibleRegion
- geo
- ineligibleRegion
- serviceArea

[^top]

#### GeospatialGeometry

(Eventually to be defined as) a supertype of GeoShape designed to accommodate definitions from Geo-Spatial best practices.

Properties used on this type:

- geoContains
- geoCoveredBy
- geoCovers
- geoCrosses
- geoDisjoint
- geoEquals
- geoIntersects
- geoOverlaps
- geoTouches
- geoWithin

Properties whose values are of this type:

- geoContains
- geoCoveredBy
- geoCovers
- geoCrosses
- geoDisjoint
- geoEquals
- geoIntersects
- geoOverlaps
- geoTouches
- geoWithin

[^top]

#### Geriatric

An Enumeration member

A specific branch of medical science that is concerned with the diagnosis and treatment of diseases, debilities and provision of care to the aged.

Member of Enumeration: MedicalSpecialty
[^top]

#### GettingAccessHealthAspect

An Enumeration member

Content that discusses practical and policy aspects for getting access to specific kinds of healthcare (e.g. distribution mechanisms for vaccines).

Member of Enumeration: HealthAspectEnumeration
[^top]

#### GiveAction

The act of transferring ownership of an object to a destination. Reciprocal of TakeAction.
Related actions:

- TakeAction: Reciprocal of GiveAction.
- SendAction: Unlike SendAction, GiveAction implies that ownership is being transferred (e.g. I may send my laptop to you, but that doesn't mean I'm giving it to you).

Properties used on this type:

- recipient

Properties whose values are of this type:

[^top]

#### GlutenFreeDiet

An Enumeration member

A diet exclusive of gluten.

Member of Enumeration: RestrictedDiet
[^top]

#### GolfCourse

A golf course.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### GovernmentBenefitsType

An Enumeration

GovernmentBenefitsType enumerates several kinds of government benefits to support the COVID-19 situation. Note that this structure may not capture all benefits offered.

Properties used on this type:

Enumeration members of this type:

- BasicIncome
- BusinessSupport
- DisabilitySupport
- HealthCare
- OneTimePayments
- PaidLeave
- ParentalSupport
- UnemploymentSupport

Properties whose values are of this type:

- serviceType

[^top]

#### GovernmentBuilding

A government building.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### GovernmentOffice

A government office—for example, an IRS or DMV office.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### GovernmentOrganization

A governmental organization or agency.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### GovernmentPermit

A permit issued by a government agency.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### GovernmentService

A service provided by a government organization, e.g. food stamps, veterans benefits, etc.

Properties used on this type:

- jurisdiction
- serviceOperator

Properties whose values are of this type:

- governmentBenefitsInfo

[^top]

#### Grant

A grant, typically financial or otherwise quantifiable, of resources. Typically a funder sponsors some MonetaryAmount to an Organization or Person, sometimes not necessarily via a dedicated or long-lived Project, resulting in one or more outputs, or fundedItems. For financial sponsorship, indicate the funder of a MonetaryGrant. For non-financial support, indicate sponsor of Grants of resources (e.g. office space).
Grants support activities directed towards some agreed collective goals, often but not always organized as Projects. Long-lived projects are sometimes sponsored by a variety of grants over time, but it is also common for a project to be associated with a single grant.
The amount of a Grant is represented using amount as a MonetaryAmount.

Properties used on this type:

- fundedItem
- sponsor

Properties whose values are of this type:

[^top]

#### GraphicNovel

An Enumeration member

Book format: GraphicNovel. May represent a bound collection of ComicIssue instances.

Member of Enumeration: BookFormatType
[^top]

#### GroceryStore

A grocery store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### GroupBoardingPolicy

An Enumeration member

The airline boards by groups based on check-in time, priority, etc.

Member of Enumeration: BoardingPolicyType
[^top]

#### Guide

Guide is a page or article that recommend specific products or services, or aspects of a thing for a user to consider. A Guide may represent a Buying Guide and detail aspects of products or services for a user to consider. A Guide may represent a Product Guide and recommend specific products or services. A Guide may represent a Ranked List and recommend specific products or services with ranking.

Properties used on this type:

- reviewAspect

Properties whose values are of this type:

[^top]

#### Gynecologic

An Enumeration member

A specific branch of medical science that pertains to the health care of women, particularly in the diagnosis and treatment of disorders affecting the female reproductive system.

Member of Enumeration: MedicalSpecialty
[^top]

#### HVACBusiness

A business that provide Heating, Ventilation and Air Conditioning services.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Hackathon

A hackathon event.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### HairSalon

A hair salon.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### HalalDiet

An Enumeration member

A diet conforming to Islamic dietary practices.

Member of Enumeration: RestrictedDiet
[^top]

#### Hardcover

An Enumeration member

Book format: Hardcover.

Member of Enumeration: BookFormatType
[^top]

#### HardwareStore

A hardware store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Head

An Enumeration member

Head assessment with clinical examination.

Member of Enumeration: PhysicalExam
[^top]

#### HealthAndBeautyBusiness

Health and beauty.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### HealthAspectEnumeration

An Enumeration

HealthAspectEnumeration enumerates several aspects of health content online, each of which might be described using hasHealthAspect and HealthTopicContent.

Properties used on this type:

Enumeration members of this type:

- AllergiesHealthAspect
- BenefitsHealthAspect
- CausesHealthAspect
- ContagiousnessHealthAspect
- EffectivenessHealthAspect
- GettingAccessHealthAspect
- HowItWorksHealthAspect
- HowOrWhereHealthAspect
- IngredientsHealthAspect
- LivingWithHealthAspect
- MayTreatHealthAspect
- MisconceptionsHealthAspect
- OverviewHealthAspect
- PatientExperienceHealthAspect
- PregnancyHealthAspect
- PreventionHealthAspect
- PrognosisHealthAspect
- RelatedTopicsHealthAspect
- RisksOrComplicationsHealthAspect
- SafetyHealthAspect
- ScreeningHealthAspect
- SeeDoctorHealthAspect
- SelfCareHealthAspect
- SideEffectsHealthAspect
- StagesHealthAspect
- SymptomsHealthAspect
- TreatmentsHealthAspect
- TypesHealthAspect
- UsageOrScheduleHealthAspect

Properties whose values are of this type:

- hasHealthAspect

[^top]

#### HealthCare

An Enumeration member

HealthCare: this is a benefit for health care.

Member of Enumeration: GovernmentBenefitsType
[^top]

#### HealthClub

A health club.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### HealthInsurancePlan

A US-style health insurance plan, including PPOs, EPOs, and HMOs.

Properties used on this type:

- benefitsSummaryUrl
- contactPoint
- healthPlanDrugOption
- healthPlanDrugTier
- healthPlanId
- healthPlanMarketingUrl
- includesHealthPlanFormulary
- includesHealthPlanNetwork
- usesHealthPlanIdStandard

Properties whose values are of this type:

- includedInHealthInsurancePlan

[^top]

#### HealthPlanCostSharingSpecification

A description of costs to the patient under a given network or formulary.

Properties used on this type:

- healthPlanCoinsuranceOption
- healthPlanCoinsuranceRate
- healthPlanCopay
- healthPlanCopayOption
- healthPlanPharmacyCategory

Properties whose values are of this type:

[^top]

#### HealthPlanFormulary

For a given health insurance plan, the specification for costs and coverage of prescription drugs.

Properties used on this type:

- healthPlanCostSharing
- healthPlanDrugTier
- offersPrescriptionByMail

Properties whose values are of this type:

- includesHealthPlanFormulary

[^top]

#### HealthPlanNetwork

A US-style health insurance plan network.

Properties used on this type:

- healthPlanCostSharing
- healthPlanNetworkId
- healthPlanNetworkTier

Properties whose values are of this type:

- includesHealthPlanNetwork

[^top]

#### HealthTopicContent

HealthTopicContent is WebContent that is about some aspect of a health topic, e.g. a condition, its symptoms or treatments. Such content may be comprised of several parts or sections and use different types of media. Multiple instances of WebContent (and hence HealthTopicContent) can be related using hasPart / isPartOf where there is some kind of content hierarchy, and their content described with about and mentions e.g. building upon the existing MedicalCondition vocabulary.

Properties used on this type:

- hasHealthAspect

Properties whose values are of this type:

[^top]

#### HearingImpairedSupported

An Enumeration member

Uses devices to support users with hearing impairments.

Member of Enumeration: ContactPointOption
[^top]

#### Hematologic

An Enumeration member

A specific branch of medical science that pertains to diagnosis and treatment of disorders of blood and blood producing organs.

Member of Enumeration: MedicalSpecialty
[^top]

#### HighSchool

A high school.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### HinduDiet

An Enumeration member

A diet conforming to Hindu dietary practices, in particular, beef-free.

Member of Enumeration: RestrictedDiet
[^top]

#### HinduTemple

A Hindu temple.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### HobbyShop

A store that sells materials useful or necessary for various hobbies.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### HomeAndConstructionBusiness

A construction business.
A HomeAndConstructionBusiness is a LocalBusiness that provides services around homes and buildings.
As a LocalBusiness it can be described as a provider of one or more Service(s).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### HomeGoodsStore

A home goods store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Homeopathic

An Enumeration member

A system of medicine based on the principle that a disease can be cured by a substance that produces similar symptoms in healthy people.

Member of Enumeration: MedicineSystem
[^top]

#### Hospital

A hospital.

Properties used on this type:

- availableService
- healthcareReportingData
- medicalSpecialty

Properties whose values are of this type:

- hospitalAffiliation

[^top]

#### Hostel

A hostel - cheap accommodation, often in shared dormitories.
See also the dedicated document on the use of schema.org for marking up hotels and other forms of accommodations.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Hotel

A hotel is an establishment that provides lodging paid on a short-term basis (Source: Wikipedia, the free encyclopedia, see http://en.wikipedia.org/wiki/Hotel).
See also the dedicated document on the use of schema.org for marking up hotels and other forms of accommodations.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### HotelRoom

A hotel room is a single room in a hotel.
See also the dedicated document on the use of schema.org for marking up hotels and other forms of accommodations.

Properties used on this type:

- bed
- occupancy

Properties whose values are of this type:

[^top]

#### House

A house is a building or structure that has the ability to be occupied for habitation by humans or other creatures (Source: Wikipedia, the free encyclopedia, see http://en.wikipedia.org/wiki/House).

Properties used on this type:

- numberOfRooms

Properties whose values are of this type:

[^top]

#### HousePainter

A house painting service.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### HowItWorksHealthAspect

An Enumeration member

Content that discusses and explains how a particular health-related topic works, e.g. in terms of mechanisms and underlying science.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### HowOrWhereHealthAspect

An Enumeration member

Information about how or where to find a topic. Also may contain location data that can be used for where to look for help if the topic is observed.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### HowTo

Instructions that explain how to achieve a result by performing a sequence of steps.

Properties used on this type:

- estimatedCost
- performTime
- prepTime
- step
- steps
- supply
- tool
- totalTime
- yield

Properties whose values are of this type:

[^top]

#### HowToDirection

A direction indicating a single action to do in the instructions for how to achieve a result.

Properties used on this type:

- afterMedia
- beforeMedia
- duringMedia
- performTime
- prepTime
- supply
- tool
- totalTime

Properties whose values are of this type:

[^top]

#### HowToItem

An item used as either a tool or supply when performing the instructions for how to to achieve a result.

Properties used on this type:

- requiredQuantity

Properties whose values are of this type:

[^top]

#### HowToSection

A sub-grouping of steps in the instructions for how to achieve a result (e.g. steps for making a pie crust within a pie recipe).

Properties used on this type:

- steps

Properties whose values are of this type:

- step

[^top]

#### HowToStep

A step in the instructions for how to achieve a result. It is an ordered list with HowToDirection and/or HowToTip items.

Properties used on this type:

Properties whose values are of this type:

- step

[^top]

#### HowToSupply

A supply consumed when performing the instructions for how to achieve a result.

Properties used on this type:

- estimatedCost

Properties whose values are of this type:

- supply

[^top]

#### HowToTip

An explanation in the instructions for how to achieve a result. It provides supplementary information about a technique, supply, author's preference, etc. It can explain what could be done, or what should not be done, but doesn't specify what should be done (see HowToDirection).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### HowToTool

A tool used (but not consumed) when performing instructions for how to achieve a result.

Properties used on this type:

Properties whose values are of this type:

- tool

[^top]

#### HyperToc

A HyperToc represents a hypertext table of contents for complex media objects, such as VideoObject, AudioObject. Items in the table of contents are indicated using the tocEntry property, and typed HyperTocEntry. For cases where the same larger work is split into multiple files, associatedMedia can be used on individual HyperTocEntry items.

Properties used on this type:

- associatedMedia
- tocEntry

Properties whose values are of this type:

[^top]

#### HyperTocEntry

A HyperToEntry is an item within a HyperToc, which represents a hypertext table of contents for complex media objects, such as VideoObject, AudioObject. The media object itself is indicated using associatedMedia. Each section of interest within that content can be described with a HyperTocEntry, with associated startOffset and endOffset. When several entries are all from the same file, associatedMedia is used on the overarching HyperTocEntry; if the content has been split into multiple files, they can be referenced using associatedMedia on each HyperTocEntry.

Properties used on this type:

- associatedMedia
- tocContinuation
- utterances

Properties whose values are of this type:

- endOffset
- startOffset
- tocContinuation
- tocEntry

[^top]

#### IceCreamShop

An ice cream shop.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### IgnoreAction

The act of intentionally disregarding the object. An agent ignores an object.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ImageGallery

Web page type: Image gallery page.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ImageObject

An image file.

Properties used on this type:

- caption
- exifData
- representativeOfPage
- thumbnail

Properties whose values are of this type:

- diagram
- image
- layoutImage
- logo
- photo
- photos
- primaryImageOfPage
- screenshot
- thumbnail

[^top]

#### ImagingTest

Any medical imaging modality typically used for diagnostic purposes.

Properties used on this type:

- imagingTechnique

Properties whose values are of this type:

[^top]

#### InForce

An Enumeration member

Indicates that a legislation is in force.

Member of Enumeration: LegalForceStatus
[^top]

#### InStock

An Enumeration member

Indicates that the item is in stock.

Member of Enumeration: ItemAvailability
[^top]

#### InStoreOnly

An Enumeration member

Indicates that the item is available only at physical locations.

Member of Enumeration: ItemAvailability
[^top]

#### IndividualProduct

A single, identifiable product instance (e.g. a laptop with a particular serial number).

Properties used on this type:

- serialNumber

Properties whose values are of this type:

[^top]

#### Infectious

An Enumeration member

Something in medical science that pertains to infectious diseases i.e caused by bacterial, viral, fungal or parasitic infections.

Member of Enumeration: MedicalSpecialty
[^top]

#### InfectiousAgentClass

An Enumeration

Classes of agents or pathogens that transmit infectious diseases. Enumerated type.

Properties used on this type:

Enumeration members of this type:

- Bacteria
- Fungus
- MulticellularParasite
- Prion
- Protozoa
- Virus

Properties whose values are of this type:

- infectiousAgentClass

[^top]

#### InfectiousDisease

An infectious disease is a clinically evident human disease resulting from the presence of pathogenic microbial agents, like pathogenic viruses, pathogenic bacteria, fungi, protozoa, multicellular parasites, and prions. To be considered an infectious disease, such pathogens are known to be able to cause this disease.

Properties used on this type:

- infectiousAgent
- infectiousAgentClass
- transmissionMethod

Properties whose values are of this type:

[^top]

#### InformAction

The act of notifying someone of information pertinent to them, with no expectation of a response.

Properties used on this type:

- event

Properties whose values are of this type:

[^top]

#### IngredientsHealthAspect

An Enumeration member

Content discussing ingredients-related aspects of a health topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### InsertAction

The act of adding at a specific location in an ordered collection.

Properties used on this type:

- toLocation

Properties whose values are of this type:

[^top]

#### InstallAction

The act of installing an application.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Installment

An Enumeration member

Represents the installment pricing component of the total price for an offered product.

Member of Enumeration: PriceComponentTypeEnumeration
[^top]

#### InsuranceAgency

An Insurance agency.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Intangible

A utility class that serves as the umbrella for a number of 'intangible' things such as quantities, structured values, etc.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Integer

Data type: Integer.

Properties used on this type:

Properties whose values are of this type:

- answerCount
- artEdition
- byMonth
- byMonthDay
- byMonthWeek
- clipNumber
- collectionSize
- commentCount
- constrainingProperty
- downvoteCount
- episodeNumber
- issueNumber
- maximumAttendeeCapacity
- maximumEnrollment
- maximumPhysicalAttendeeCapacity
- maximumVirtualAttendeeCapacity
- merchantReturnDays
- numAdults
- numChildren
- numConstraints
- numTracks
- numberOfBathroomsTotal
- numberOfCredits
- numberOfEpisodes
- numberOfItems
- numberOfPages
- numberOfSeasons
- offerCount
- pageEnd
- pageStart
- partySize
- playersOnline
- position
- productReturnDays
- ratingCount
- remainingAttendeeCapacity
- repeatCount
- requiredMaxAge
- requiredMinAge
- reviewCount
- seasonNumber
- totalJobOpenings
- typicalCreditsPerTerm
- upvoteCount
- userInteractionCount
- volumeNumber
- wordCount

[^top]

#### InteractAction

The act of interacting with another person or organization.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### InteractionCounter

A summary of how users have interacted with this CreativeWork. In most cases, authors will use a subtype to specify the specific type of interaction.

Properties used on this type:

- interactionService
- interactionType
- userInteractionCount

Properties whose values are of this type:

- interactionStatistic

[^top]

#### InternationalTrial

An Enumeration member

An international trial.

Member of Enumeration: MedicalTrialDesign
[^top]

#### InternetCafe

An internet cafe.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### InvestmentFund

A company or fund that gathers capital from a number of investors to create a pool of money that is then re-invested into stocks, bonds and other assets.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### InvestmentOrDeposit

A type of financial product that typically requires the client to transfer funds to a financial service in return for potential beneficial financial return.

Properties used on this type:

- amount

Properties whose values are of this type:

[^top]

#### InviteAction

The act of asking someone to attend an event. Reciprocal of RsvpAction.

Properties used on this type:

- event

Properties whose values are of this type:

[^top]

#### Invoice

A statement of the money due for goods or services; a bill.

Properties used on this type:

- accountId
- billingPeriod
- broker
- category
- confirmationNumber
- customer
- minimumPaymentDue
- paymentDue
- paymentDueDate
- paymentMethod
- paymentMethodId
- paymentStatus
- provider
- referencesOrder
- scheduledPaymentDate
- totalPaymentDue

Properties whose values are of this type:

- partOfInvoice

[^top]

#### InvoicePrice

An Enumeration member

Represents the invoice price of an offered product.

Member of Enumeration: PriceTypeEnumeration
[^top]

#### ItemAvailability

An Enumeration

A list of possible product availability options.

Properties used on this type:

Enumeration members of this type:

- BackOrder
- Discontinued
- InStock
- InStoreOnly
- LimitedAvailability
- OnlineOnly
- OutOfStock
- PreOrder
- PreSale
- SoldOut

Properties whose values are of this type:

- availability

[^top]

#### ItemList

A list of items of any sort—for example, Top 10 Movies About Weathermen, or Top 100 Party Songs. Not to be confused with HTML lists, which are often used only for formatting.

Properties used on this type:

- itemListElement
- itemListOrder
- numberOfItems

Properties whose values are of this type:

- acceptedAnswer
- accessModeSufficient
- itinerary
- recipeInstructions
- steps
- suggestedAnswer
- track

[^top]

#### ItemListOrderAscending

An Enumeration member

An ItemList ordered with lower values listed first.

Member of Enumeration: ItemListOrderType
[^top]

#### ItemListOrderDescending

An Enumeration member

An ItemList ordered with higher values listed first.

Member of Enumeration: ItemListOrderType
[^top]

#### ItemListOrderType

An Enumeration

Enumerated for values for itemListOrder for indicating how an ordered ItemList is organized.

Properties used on this type:

Enumeration members of this type:

- ItemListOrderAscending
- ItemListOrderDescending
- ItemListUnordered

Properties whose values are of this type:

- itemListOrder

[^top]

#### ItemListUnordered

An Enumeration member

An ItemList ordered with no explicit order.

Member of Enumeration: ItemListOrderType
[^top]

#### ItemPage

A page devoted to a single item, such as a particular product or hotel.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### JewelryStore

A jewelry store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### JobPosting

A listing that describes a job opening in a certain organization.

Properties used on this type:

- applicantLocationRequirements
- applicationContact
- baseSalary
- benefits
- datePosted
- educationRequirements
- eligibilityToWorkRequirement
- employerOverview
- employmentType
- employmentUnit
- estimatedSalary
- experienceInPlaceOfEducation
- experienceRequirements
- hiringOrganization
- incentiveCompensation
- incentives
- industry
- jobBenefits
- jobImmediateStart
- jobLocation
- jobLocationType
- jobStartDate
- occupationalCategory
- physicalRequirement
- qualifications
- relevantOccupation
- responsibilities
- salaryCurrency
- securityClearanceRequirement
- sensoryRequirement
- skills
- specialCommitments
- title
- totalJobOpenings
- validThrough
- workHours

Properties whose values are of this type:

[^top]

#### JoinAction

An agent joins an event/group with participants/friends at a location.
Related actions:

- RegisterAction: Unlike RegisterAction, JoinAction refers to joining a group/team of people.
- SubscribeAction: Unlike SubscribeAction, JoinAction does not imply that you'll be receiving updates.
- FollowAction: Unlike FollowAction, JoinAction does not imply that you'll be polling for updates.

Properties used on this type:

- event

Properties whose values are of this type:

[^top]

#### Joint

The anatomical location at which two or more bones make contact.

Properties used on this type:

- biomechnicalClass
- functionalClass
- structuralClass

Properties whose values are of this type:

[^top]

#### KosherDiet

An Enumeration member

A diet conforming to Jewish dietary practices.

Member of Enumeration: RestrictedDiet
[^top]

#### LaboratoryScience

An Enumeration member

A medical science pertaining to chemical, hematological, immunologic, microscopic, or bacteriological diagnostic analyses or research.

Member of Enumeration: MedicalSpecialty
[^top]

#### LakeBodyOfWater

A lake (for example, Lake Pontrachain).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Landform

A landform or physical feature. Landform elements include mountains, plains, lakes, rivers, seascape and oceanic waterbody interface features such as bays, peninsulas, seas and so forth, including sub-aqueous terrain features such as submersed mountain ranges, volcanoes, and the great ocean basins.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### LandmarksOrHistoricalBuildings

An historical landmark or building.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Language

Natural languages such as Spanish, Tamil, Hindi, English, etc. Formal language code tags expressed in BCP 47 can be used via the alternateName property. The Language type previously also covered programming languages such as Scheme and Lisp, which are now best represented using ComputerLanguage.

Properties used on this type:

Properties whose values are of this type:

- availableLanguage
- inLanguage
- knowsLanguage
- language
- subtitleLanguage

[^top]

#### LaserDiscFormat

An Enumeration member

LaserDiscFormat.

Member of Enumeration: MusicReleaseFormatType
[^top]

#### LearningResource

The LearningResource type can be used to indicate CreativeWorks (whether physical or digital) that have a particular and explicit orientation towards learning, education, skill acquisition, and other educational purposes.
LearningResource is expected to be used as an addition to a primary type such as Book, VideoObject, Product etc.
EducationEvent serves a similar purpose for event-like things (e.g. a Trip). A LearningResource may be created as a result of an EducationEvent, for example by recording one.

Properties used on this type:

- assesses
- competencyRequired
- educationalAlignment
- educationalLevel
- educationalUse
- learningResourceType
- teaches

Properties whose values are of this type:

[^top]

#### LeaveAction

An agent leaves an event / group with participants/friends at a location.
Related actions:

- JoinAction: The antonym of LeaveAction.
- UnRegisterAction: Unlike UnRegisterAction, LeaveAction implies leaving a group/team of people rather than a service.

Properties used on this type:

- event

Properties whose values are of this type:

[^top]

#### LeftHandDriving

An Enumeration member

The steering position is on the left side of the vehicle (viewed from the main direction of driving).

Member of Enumeration: SteeringPositionValue
[^top]

#### LegalForceStatus

An Enumeration

A list of possible statuses for the legal force of a legislation.

Properties used on this type:

Enumeration members of this type:

- InForce
- NotInForce
- PartiallyInForce

Properties whose values are of this type:

- legislationLegalForce

[^top]

#### LegalService

A LegalService is a business that provides legally-oriented services, advice and representation, e.g. law firms.
As a LocalBusiness it can be described as a provider of one or more Service(s).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### LegalValueLevel

An Enumeration

A list of possible levels for the legal validity of a legislation.

Properties used on this type:

Enumeration members of this type:

- AuthoritativeLegalValue
- DefinitiveLegalValue
- OfficialLegalValue
- UnofficialLegalValue

Properties whose values are of this type:

- legislationLegalValue

[^top]

#### Legislation

A legal document such as an act, decree, bill, etc. (enforceable or not) or a component of a legal act (like an article).

Properties used on this type:

- jurisdiction
- legislationApplies
- legislationChanges
- legislationConsolidates
- legislationDate
- legislationDateVersion
- legislationIdentifier
- legislationJurisdiction
- legislationLegalForce
- legislationPassedBy
- legislationResponsible
- legislationTransposes
- legislationType

Properties whose values are of this type:

- legislationApplies
- legislationChanges
- legislationConsolidates
- legislationTransposes

[^top]

#### LegislationObject

A specific object or file containing a Legislation. Note that the same Legislation can be published in multiple files. For example, a digitally signed PDF, a plain PDF and an HTML version.

Properties used on this type:

- legislationLegalValue

Properties whose values are of this type:

[^top]

#### LegislativeBuilding

A legislative building—for example, the state capitol.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### LeisureTimeActivity

An Enumeration member

Any physical activity engaged in for recreational purposes. Examples may include ballroom dancing, roller skating, canoeing, fishing, etc.

Member of Enumeration: PhysicalActivityCategory
[^top]

#### LendAction

The act of providing an object under an agreement that it will be returned at a later date. Reciprocal of BorrowAction.
Related actions:

- BorrowAction: Reciprocal of LendAction.

Properties used on this type:

- borrower

Properties whose values are of this type:

[^top]

#### Library

A library.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### LibrarySystem

A LibrarySystem is a collaborative system amongst several libraries.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### LifestyleModification

A process of care involving exercise, changes to diet, fitness routines, and other lifestyle changes aimed at improving a health condition.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Ligament

A short band of tough, flexible, fibrous connective tissue that functions to connect multiple bones, cartilages, and structurally support joints.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### LikeAction

The act of expressing a positive sentiment about the object. An agent likes an object (a proposition, topic or theme) with participants.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### LimitedAvailability

An Enumeration member

Indicates that the item has limited availability.

Member of Enumeration: ItemAvailability
[^top]

#### LimitedByGuaranteeCharity

An Enumeration member

LimitedByGuaranteeCharity: Non-profit type referring to a charitable company that is limited by guarantee (UK).

Member of Enumeration: UKNonprofitType
[^top]

#### LinkRole

A Role that represents a Web link e.g. as expressed via the 'url' property. Its linkRelationship property can indicate URL-based and plain textual link types e.g. those in IANA link registry or others such as 'amphtml'. This structure provides a placeholder where details from HTML's link element can be represented outside of HTML, e.g. in JSON-LD feeds.

Properties used on this type:

- inLanguage
- linkRelationship

Properties whose values are of this type:

[^top]

#### LiquorStore

A shop that sells alcoholic drinks such as wine, beer, whisky and other spirits.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ListItem

An list item, e.g. a step in a checklist or how-to description.

Properties used on this type:

- item
- nextItem
- position
- previousItem

Properties whose values are of this type:

- itemListElement
- nextItem
- previousItem

[^top]

#### ListPrice

An Enumeration member

Represents the list price (the price a product is actually advertised for) of an offered product.

Member of Enumeration: PriceTypeEnumeration
[^top]

#### ListenAction

The act of consuming audio content.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### LiteraryEvent

Event type: Literary event.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### LiveAlbum

An Enumeration member

LiveAlbum.

Member of Enumeration: MusicAlbumProductionType
[^top]

#### LiveBlogPosting

A blog post intended to provide a rolling textual coverage of an ongoing event through continuous updates.

Properties used on this type:

- coverageEndTime
- coverageStartTime
- liveBlogUpdate

Properties whose values are of this type:

[^top]

#### LivingWithHealthAspect

An Enumeration member

Information about coping or life related to the topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### LoanOrCredit

A financial product for the loaning of an amount of money, or line of credit, under agreed terms and charges.

Properties used on this type:

- amount
- currency
- gracePeriod
- loanRepaymentForm
- loanTerm
- loanType
- recourseLoan
- renegotiableLoan
- requiredCollateral

Properties whose values are of this type:

- acceptedPaymentMethod

[^top]

#### LocalBusiness

A particular physical business or branch of an organization. Examples of LocalBusiness include a restaurant, a particular branch of a restaurant chain, a branch of a bank, a medical practice, a club, a bowling alley, etc.

Properties used on this type:

- branchOf
- currenciesAccepted
- openingHours
- paymentAccepted
- priceRange

Properties whose values are of this type:

- announcementLocation

[^top]

#### LocationFeatureSpecification

Specifies a location feature by providing a structured value representing a feature of an accommodation as a property-value pair of varying degrees of formality.

Properties used on this type:

- hoursAvailable
- validFrom
- validThrough

Properties whose values are of this type:

- amenityFeature

[^top]

#### LockerDelivery

An Enumeration member

A DeliveryMethod in which an item is made available via locker.

Member of Enumeration: DeliveryMethod
[^top]

#### Locksmith

A locksmith.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### LodgingBusiness

A lodging business, such as a motel, hotel, or inn.

Properties used on this type:

- amenityFeature
- audience
- availableLanguage
- checkinTime
- checkoutTime
- numberOfRooms
- petsAllowed
- starRating

Properties whose values are of this type:

[^top]

#### LodgingReservation

A reservation for lodging at a hotel, motel, inn, etc.
Note: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations.

Properties used on this type:

- checkinTime
- checkoutTime
- lodgingUnitDescription
- lodgingUnitType
- numAdults
- numChildren

Properties whose values are of this type:

[^top]

#### Longitudinal

An Enumeration member

Unlike cross-sectional studies, longitudinal studies track the same people, and therefore the differences observed in those people are less likely to be the result of cultural differences across generations. Longitudinal studies are also used in medicine to uncover predictors of certain diseases.

Member of Enumeration: MedicalObservationalStudyDesign
[^top]

#### LoseAction

The act of being defeated in a competitive activity.

Properties used on this type:

- winner

Properties whose values are of this type:

[^top]

#### LowCalorieDiet

An Enumeration member

A diet focused on reduced calorie intake.

Member of Enumeration: RestrictedDiet
[^top]

#### LowFatDiet

An Enumeration member

A diet focused on reduced fat and cholesterol intake.

Member of Enumeration: RestrictedDiet
[^top]

#### LowLactoseDiet

An Enumeration member

A diet appropriate for people with lactose intolerance.

Member of Enumeration: RestrictedDiet
[^top]

#### LowSaltDiet

An Enumeration member

A diet focused on reduced sodium intake.

Member of Enumeration: RestrictedDiet
[^top]

#### Lung

An Enumeration member

Lung and respiratory system clinical examination.

Member of Enumeration: PhysicalExam
[^top]

#### LymphaticVessel

A type of blood vessel that specifically carries lymph fluid unidirectionally toward the heart.

Properties used on this type:

- originatesFrom
- regionDrained
- runsTo

Properties whose values are of this type:

[^top]

#### MRI

An Enumeration member

Magnetic resonance imaging.

Member of Enumeration: MedicalImagingTechnique
[^top]

#### MSRP

An Enumeration member

Represents the manufacturer suggested retail price ("MSRP") of an offered product.

Member of Enumeration: PriceTypeEnumeration
[^top]

#### Male

An Enumeration member

The male gender.

Member of Enumeration: GenderType
[^top]

#### Manuscript

A book, document, or piece of music written by hand rather than typed or printed.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Map

A map.

Properties used on this type:

- mapType

Properties whose values are of this type:

- hasMap

[^top]

#### MapCategoryType

An Enumeration

An enumeration of several kinds of Map.

Properties used on this type:

Enumeration members of this type:

- ParkingMap
- SeatingMap
- TransitMap
- VenueMap

Properties whose values are of this type:

- mapType

[^top]

#### MarryAction

The act of marrying a person.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Mass

Properties that take Mass as values are of the form '<Number> <Mass unit of measure>'. E.g., '7 kg'.

Properties used on this type:

Properties whose values are of this type:

- carbohydrateContent
- cholesterolContent
- fatContent
- fiberContent
- proteinContent
- saturatedFatContent
- sodiumContent
- sugarContent
- transFatContent
- unsaturatedFatContent

[^top]

#### MathSolver

A math solver which is capable of solving a subset of mathematical problems.

Properties used on this type:

- mathExpression

Properties whose values are of this type:

[^top]

#### MaximumDoseSchedule

The maximum dosing schedule considered safe for a drug or supplement as recommended by an authority or by the drug/supplement's manufacturer. Capture the recommending authority in the recognizingAuthority property of MedicalEntity.

Properties used on this type:

Properties whose values are of this type:

- maximumIntake

[^top]

#### MayTreatHealthAspect

An Enumeration member

Related topics may be treated by a Topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### MeasurementTypeEnumeration

An Enumeration

Enumeration of common measurement types (or dimensions), for example "chest" for a person, "inseam" for pants, "gauge" for screws, or "wheel" for bicycles.

Properties used on this type:

Enumeration members of this type:

Properties whose values are of this type:

- valueReference

[^top]

#### MediaGallery

Web page type: Media gallery page. A mixed-media page that can contains media such as images, videos, and other multimedia.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MediaManipulationRatingEnumeration

An Enumeration

Codes for use with the mediaAuthenticityCategory property, indicating the authenticity of a media object (in the context of how it was published or shared). In general these codes are not mutually exclusive, although some combinations (such as 'original' versus 'transformed', 'edited' and 'staged') would be contradictory if applied in the same MediaReview. Note that the application of these codes is with regard to a piece of media shared or published in a particular context.

Properties used on this type:

Enumeration members of this type:

- DecontextualizedContent
- EditedOrCroppedContent
- OriginalMediaContent
- SatireOrParodyContent
- StagedContent
- TransformedContent

Properties whose values are of this type:

- mediaAuthenticityCategory

[^top]

#### MediaObject

A media object, such as an image, video, or audio object embedded in a web page or a downloadable dataset i.e. DataDownload. Note that a creative work may have many media objects associated with it on the same web page. For example, a page about a single song (MusicRecording) may have a music video (VideoObject), and a high and low bandwidth audio stream (2 AudioObject's).

Properties used on this type:

- associatedArticle
- bitrate
- contentSize
- contentUrl
- duration
- embedUrl
- encodesCreativeWork
- encodingFormat
- endTime
- height
- ineligibleRegion
- playerType
- productionCompany
- regionsAllowed
- requiresSubscription
- startTime
- uploadDate
- width

Properties whose values are of this type:

- afterMedia
- associatedMedia
- beforeMedia
- caption
- duringMedia
- encoding
- encodings

[^top]

#### MediaReview

A MediaReview is a more specialized form of Review dedicated to the evaluation of media content online, typically in the context of fact-checking and misinformation. For more general reviews of media in the broader sense, use UserReview, CriticReview or other Review types. This definition is a work in progress. While the MediaManipulationRatingEnumeration list reflects significant community review amongst fact-checkers and others working to combat misinformation, the specific structures for representing media objects, their versions and publication context, is still evolving. Similarly, best practices for the relationship between MediaReview and ClaimReview markup has not yet been finalized.

Properties used on this type:

- mediaAuthenticityCategory

Properties whose values are of this type:

[^top]

#### MediaSubscription

A subscription which allows a user to access media including audio, video, books, etc.

Properties used on this type:

- authenticator
- expectsAcceptanceOf

Properties whose values are of this type:

- requiresSubscription

[^top]

#### MedicalAudience

Target audiences for medical web pages.

Properties used on this type:

Properties whose values are of this type:

- medicalAudience

[^top]

#### MedicalAudienceType

An Enumeration

Target audiences types for medical web pages. Enumerated type.

Properties used on this type:

Enumeration members of this type:

- Clinician
- MedicalResearcher

Properties whose values are of this type:

- medicalAudience

[^top]

#### MedicalBusiness

A particular physical or virtual business of an organization for medical purposes. Examples of MedicalBusiness include differents business run by health professionals.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MedicalCause

The causative agent(s) that are responsible for the pathophysiologic process that eventually results in a medical condition, symptom or sign. In this schema, unless otherwise specified this is meant to be the proximate cause of the medical condition, symptom or sign. The proximate cause is defined as the causative agent that most directly results in the medical condition, symptom or sign. For example, the HIV virus could be considered a cause of AIDS. Or in a diagnostic context, if a patient fell and sustained a hip fracture and two days later sustained a pulmonary embolism which eventuated in a cardiac arrest, the cause of the cardiac arrest (the proximate cause) would be the pulmonary embolism and not the fall. Medical causes can include cardiovascular, chemical, dermatologic, endocrine, environmental, gastroenterologic, genetic, hematologic, gynecologic, iatrogenic, infectious, musculoskeletal, neurologic, nutritional, obstetric, oncologic, otolaryngologic, pharmacologic, psychiatric, pulmonary, renal, rheumatologic, toxic, traumatic, or urologic causes; medical conditions can be causes as well.

Properties used on this type:

- causeOf

Properties whose values are of this type:

[^top]

#### MedicalClinic

A facility, often associated with a hospital or medical school, that is devoted to the specific diagnosis and/or healthcare. Previously limited to outpatients but with evolution it may be open to inpatients as well.

Properties used on this type:

- availableService
- medicalSpecialty

Properties whose values are of this type:

[^top]

#### MedicalCode

A code for a medical entity.

Properties used on this type:

- codeValue
- codingSystem

Properties whose values are of this type:

- code

[^top]

#### MedicalCondition

Any condition of the human body that affects the normal functioning of a person, whether physically or mentally. Includes diseases, injuries, disabilities, disorders, syndromes, etc.

Properties used on this type:

- associatedAnatomy
- differentialDiagnosis
- drug
- epidemiology
- expectedPrognosis
- naturalProgression
- pathophysiology
- possibleComplication
- possibleTreatment
- primaryPrevention
- riskFactor
- secondaryPrevention
- signOrSymptom
- stage
- status
- typicalTest

Properties whose values are of this type:

- diagnosis
- healthCondition
- relatedCondition
- usedToDiagnose

[^top]

#### MedicalConditionStage

A stage of a medical condition, such as 'Stage IIIa'.

Properties used on this type:

- stageAsNumber
- subStageSuffix

Properties whose values are of this type:

- stage

[^top]

#### MedicalContraindication

A condition or factor that serves as a reason to withhold a certain medical therapy. Contraindications can be absolute (there are no reasonable circumstances for undertaking a course of action) or relative (the patient is at higher risk of complications, but that these risks may be outweighed by other considerations or mitigated by other measures).

Properties used on this type:

Properties whose values are of this type:

- contraindication

[^top]

#### MedicalDevice

Any object used in a medical capacity, such as to diagnose or treat a patient.

Properties used on this type:

- adverseOutcome
- contraindication
- postOp
- preOp
- procedure
- seriousAdverseOutcome

Properties whose values are of this type:

- usesDevice

[^top]

#### MedicalDevicePurpose

An Enumeration

Categories of medical devices, organized by the purpose or intended use of the device.

Properties used on this type:

Enumeration members of this type:

- Diagnostic
- Therapeutic

Properties whose values are of this type:

[^top]

#### MedicalEntity

The most generic type of entity related to health and the practice of medicine.

Properties used on this type:

- code
- guideline
- legalStatus
- medicineSystem
- recognizingAuthority
- relevantSpecialty
- study

Properties whose values are of this type:

- adverseOutcome
- causeOf
- estimatesRiskOf
- functionalClass
- guidelineSubject
- increasesRiskOf
- preparation
- seriousAdverseOutcome
- studySubject

[^top]

#### MedicalEnumeration

An Enumeration

Enumerations related to health and the practice of medicine: A concept that is used to attribute a quality to another concept, as a qualifier, a collection of items or a listing of all of the elements of a set in medicine practice.

Properties used on this type:

Enumeration members of this type:

Properties whose values are of this type:

- legalStatus
- normalRange

[^top]

#### MedicalEvidenceLevel

An Enumeration

Level of evidence for a medical guideline. Enumerated type.

Properties used on this type:

Enumeration members of this type:

- EvidenceLevelA
- EvidenceLevelB
- EvidenceLevelC

Properties whose values are of this type:

- evidenceLevel

[^top]

#### MedicalGuideline

Any recommendation made by a standard society (e.g. ACC/AHA) or consensus statement that denotes how to diagnose and treat a particular condition. Note: this type should be used to tag the actual guideline recommendation; if the guideline recommendation occurs in a larger scholarly article, use MedicalScholarlyArticle to tag the overall article, not this type. Note also: the organization making the recommendation should be captured in the recognizingAuthority base property of MedicalEntity.

Properties used on this type:

- evidenceLevel
- evidenceOrigin
- guidelineDate
- guidelineSubject

Properties whose values are of this type:

- guideline

[^top]

#### MedicalGuidelineContraindication

A guideline contraindication that designates a process as harmful and where quality of the data supporting the contraindication is sound.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MedicalGuidelineRecommendation

A guideline recommendation that is regarded as efficacious and where quality of the data supporting the recommendation is sound.

Properties used on this type:

- recommendationStrength

Properties whose values are of this type:

[^top]

#### MedicalImagingTechnique

An Enumeration

Any medical imaging modality typically used for diagnostic purposes. Enumerated type.

Properties used on this type:

Enumeration members of this type:

- CT
- MRI
- PET
- Radiography
- Ultrasound
- XRay

Properties whose values are of this type:

- imagingTechnique

[^top]

#### MedicalIndication

A condition or factor that indicates use of a medical therapy, including signs, symptoms, risk factors, anatomical states, etc.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MedicalIntangible

A utility class that serves as the umbrella for a number of 'intangible' things in the medical space.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MedicalObservationalStudy

An observational study is a type of medical study that attempts to infer the possible effect of a treatment through observation of a cohort of subjects over a period of time. In an observational study, the assignment of subjects into treatment groups versus control groups is outside the control of the investigator. This is in contrast with controlled studies, such as the randomized controlled trials represented by MedicalTrial, where each subject is randomly assigned to a treatment group or a control group before the start of the treatment.

Properties used on this type:

- studyDesign

Properties whose values are of this type:

[^top]

#### MedicalObservationalStudyDesign

An Enumeration

Design models for observational medical studies. Enumerated type.

Properties used on this type:

Enumeration members of this type:

- CaseSeries
- CohortStudy
- CrossSectional
- Longitudinal
- Observational
- Registry

Properties whose values are of this type:

- studyDesign

[^top]

#### MedicalOrganization

A medical organization (physical or not), such as hospital, institution or clinic.

Properties used on this type:

- healthPlanNetworkId
- isAcceptingNewPatients
- medicalSpecialty

Properties whose values are of this type:

[^top]

#### MedicalProcedure

A process of care used in either a diagnostic, therapeutic, preventive or palliative capacity that relies on invasive (surgical), non-invasive, or other techniques.

Properties used on this type:

- bodyLocation
- followup
- howPerformed
- preparation
- procedureType
- status

Properties whose values are of this type:

- availableService

[^top]

#### MedicalProcedureType

An Enumeration

An enumeration that describes different types of medical procedures.

Properties used on this type:

Enumeration members of this type:

- NoninvasiveProcedure
- PercutaneousProcedure

Properties whose values are of this type:

- procedureType

[^top]

#### MedicalResearcher

An Enumeration member

Medical researchers.

Member of Enumeration: MedicalAudienceType
[^top]

#### MedicalRiskCalculator

A complex mathematical calculation requiring an online calculator, used to assess prognosis. Note: use the url property of Thing to record any URLs for online calculators.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MedicalRiskEstimator

Any rule set or interactive tool for estimating the risk of developing a complication or condition.

Properties used on this type:

- estimatesRiskOf
- includedRiskFactor

Properties whose values are of this type:

[^top]

#### MedicalRiskFactor

A risk factor is anything that increases a person's likelihood of developing or contracting a disease, medical condition, or complication.

Properties used on this type:

- increasesRiskOf

Properties whose values are of this type:

- includedRiskFactor
- riskFactor

[^top]

#### MedicalRiskScore

A simple system that adds up the number of risk factors to yield a score that is associated with prognosis, e.g. CHAD score, TIMI risk score.

Properties used on this type:

- algorithm

Properties whose values are of this type:

[^top]

#### MedicalScholarlyArticle

A scholarly article in the medical domain.

Properties used on this type:

- publicationType

Properties whose values are of this type:

[^top]

#### MedicalSign

Any physical manifestation of a person's medical condition discoverable by objective diagnostic tests or physical examination.

Properties used on this type:

- identifyingExam
- identifyingTest

Properties whose values are of this type:

- signDetected

[^top]

#### MedicalSignOrSymptom

Any feature associated or not with a medical condition. In medicine a symptom is generally subjective while a sign is objective.

Properties used on this type:

- possibleTreatment

Properties whose values are of this type:

- distinguishingSign
- signOrSymptom

[^top]

#### MedicalSpecialty

An Enumeration

Any specific branch of medical science or practice. Medical specialities include clinical specialties that pertain to particular organ systems and their respective disease states, as well as allied health specialties. Enumerated type.

Properties used on this type:

Enumeration members of this type:

- Anesthesia
- Cardiovascular
- CommunityHealth
- Dentistry
- Dermatologic
- Dermatology
- DietNutrition
- Emergency
- Endocrine
- Gastroenterologic
- Genetic
- Geriatric
- Gynecologic
- Hematologic
- Infectious
- LaboratoryScience
- Midwifery
- Musculoskeletal
- Neurologic
- Nursing
- Obstetric
- Oncologic
- Optometric
- Otolaryngologic
- Pathology
- Pediatric
- PharmacySpecialty
- Physiotherapy
- PlasticSurgery
- Podiatric
- PrimaryCare
- Psychiatric
- PublicHealth
- Pulmonary
- Radiography
- Renal
- RespiratoryTherapy
- Rheumatologic
- SpeechPathology
- Surgical
- Toxicologic
- Urologic

Properties whose values are of this type:

- medicalSpecialty
- relevantSpecialty

[^top]

#### MedicalStudy

A medical study is an umbrella type covering all kinds of research studies relating to human medicine or health, including observational studies and interventional trials and registries, randomized, controlled or not. When the specific type of study is known, use one of the extensions of this type, such as MedicalTrial or MedicalObservationalStudy. Also, note that this type should be used to mark up data that describes the study itself; to tag an article that publishes the results of a study, use MedicalScholarlyArticle. Note: use the code property of MedicalEntity to store study IDs, e.g. clinicaltrials.gov ID.

Properties used on this type:

- healthCondition
- sponsor
- status
- studyLocation
- studySubject

Properties whose values are of this type:

- study

[^top]

#### MedicalStudyStatus

An Enumeration

The status of a medical study. Enumerated type.

Properties used on this type:

Enumeration members of this type:

- ActiveNotRecruiting
- Completed
- EnrollingByInvitation
- NotYetRecruiting
- Recruiting
- ResultsAvailable
- ResultsNotAvailable
- Suspended
- Terminated
- Withdrawn

Properties whose values are of this type:

- status

[^top]

#### MedicalSymptom

Any complaint sensed and expressed by the patient (therefore defined as subjective) like stomachache, lower-back pain, or fatigue.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MedicalTest

Any medical test, typically performed for diagnostic purposes.

Properties used on this type:

- affectedBy
- normalRange
- signDetected
- usedToDiagnose
- usesDevice

Properties whose values are of this type:

- availableService
- availableTest
- identifyingTest
- subTest
- typicalTest

[^top]

#### MedicalTestPanel

Any collection of tests commonly ordered together.

Properties used on this type:

- subTest

Properties whose values are of this type:

[^top]

#### MedicalTherapy

Any medical intervention designed to prevent, treat, and cure human diseases and medical conditions, including both curative and palliative therapies. Medical therapies are typically processes of care relying upon pharmacotherapy, behavioral therapy, supportive therapy (with fluid or nutrition for example), or detoxification (e.g. hemodialysis) aimed at improving or preventing a health condition.

Properties used on this type:

- contraindication
- duplicateTherapy
- seriousAdverseOutcome

Properties whose values are of this type:

- availableService
- duplicateTherapy
- possibleTreatment
- primaryPrevention
- relatedTherapy
- secondaryPrevention

[^top]

#### MedicalTrial

A medical trial is a type of medical study that uses scientific process used to compare the safety and efficacy of medical therapies or medical procedures. In general, medical trials are controlled and subjects are allocated at random to the different treatment and/or control groups.

Properties used on this type:

- trialDesign

Properties whose values are of this type:

[^top]

#### MedicalTrialDesign

An Enumeration

Design models for medical trials. Enumerated type.

Properties used on this type:

Enumeration members of this type:

- DoubleBlindedTrial
- InternationalTrial
- MultiCenterTrial
- OpenTrial
- PlaceboControlledTrial
- RandomizedTrial
- SingleBlindedTrial
- SingleCenterTrial
- TripleBlindedTrial

Properties whose values are of this type:

- trialDesign

[^top]

#### MedicalWebPage

A web page that provides medical information.

Properties used on this type:

- aspect
- medicalAudience

Properties whose values are of this type:

[^top]

#### MedicineSystem

An Enumeration

Systems of medical practice.

Properties used on this type:

Enumeration members of this type:

- Ayurvedic
- Chiropractic
- Homeopathic
- Osteopathic
- TraditionalChinese
- WesternConventional

Properties whose values are of this type:

- medicineSystem

[^top]

#### MeetingRoom

A meeting room, conference room, or conference hall is a room provided for singular events such as business conferences and meetings (Source: Wikipedia, the free encyclopedia, see http://en.wikipedia.org/wiki/Conference_hall).
See also the dedicated document on the use of schema.org for marking up hotels and other forms of accommodations.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MensClothingStore

A men's clothing store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Menu

A structured representation of food or drink items available from a FoodEstablishment.

Properties used on this type:

- hasMenuItem
- hasMenuSection

Properties whose values are of this type:

- hasMenu
- menu

[^top]

#### MenuItem

A food or drink item listed in a menu or menu section.

Properties used on this type:

- menuAddOn
- nutrition
- offers
- suitableForDiet

Properties whose values are of this type:

- hasMenuItem
- itemOffered
- menuAddOn

[^top]

#### MenuSection

A sub-grouping of food or drink items in a menu. E.g. courses (such as 'Dinner', 'Breakfast', etc.), specific type of dishes (such as 'Meat', 'Vegan', 'Drinks', etc.), or some other classification made by the menu provider.

Properties used on this type:

- hasMenuItem
- hasMenuSection

Properties whose values are of this type:

- hasMenuSection
- menuAddOn

[^top]

#### MerchantReturnEnumeration

An Enumeration

MerchantReturnEnumeration enumerates several kinds of product return policy. Note that this structure may not capture all aspects of the policy.

Properties used on this type:

Enumeration members of this type:

- MerchantReturnFiniteReturnWindow
- MerchantReturnNotPermitted
- MerchantReturnUnlimitedWindow
- MerchantReturnUnspecified

Properties whose values are of this type:

- returnPolicyCategory

[^top]

#### MerchantReturnFiniteReturnWindow

An Enumeration member

MerchantReturnFiniteReturnWindow: there is a finite window for product returns.

Member of Enumeration: MerchantReturnEnumeration
[^top]

#### MerchantReturnNotPermitted

An Enumeration member

MerchantReturnNotPermitted: product returns are not permitted.

Member of Enumeration: MerchantReturnEnumeration
[^top]

#### MerchantReturnPolicy

A MerchantReturnPolicy provides information about product return policies associated with an Organization or Product.

Properties used on this type:

- inStoreReturnsOffered
- merchantReturnDays
- merchantReturnLink
- refundType
- returnFees
- returnPolicyCategory

Properties whose values are of this type:

- hasMerchantReturnPolicy

[^top]

#### MerchantReturnUnlimitedWindow

An Enumeration member

MerchantReturnUnlimitedWindow: there is an unlimited window for product returns.

Member of Enumeration: MerchantReturnEnumeration
[^top]

#### MerchantReturnUnspecified

An Enumeration member

MerchantReturnUnspecified: a product return policy is not specified here.

Member of Enumeration: MerchantReturnEnumeration
[^top]

#### Message

A single message from a sender to one or more organizations or people.

Properties used on this type:

- bccRecipient
- ccRecipient
- dateRead
- dateReceived
- dateSent
- messageAttachment
- recipient
- sender
- toRecipient

Properties whose values are of this type:

[^top]

#### MiddleSchool

A middle school (typically for children aged around 11-14, although this varies somewhat).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Midwifery

An Enumeration member

A nurse-like health profession that deals with pregnancy, childbirth, and the postpartum period (including care of the newborn), besides sexual and reproductive health of women throughout their lives.

Member of Enumeration: MedicalSpecialty
[^top]

#### MinimumAdvertisedPrice

An Enumeration member

Represents the minimum advertised price ("MAP") (as dictated by the manufacturer) of an offered product.

Member of Enumeration: PriceTypeEnumeration
[^top]

#### MisconceptionsHealthAspect

An Enumeration member

Content about common misconceptions and myths that are related to a topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### MixedEventAttendanceMode

An Enumeration member

MixedEventAttendanceMode - an event that is conducted as a combination of both offline and online modes.

Member of Enumeration: EventAttendanceModeEnumeration
[^top]

#### MixtapeAlbum

An Enumeration member

MixtapeAlbum.

Member of Enumeration: MusicAlbumProductionType
[^top]

#### MobileApplication

A software application designed specifically to work well on a mobile device such as a telephone.

Properties used on this type:

- carrierRequirements

Properties whose values are of this type:

[^top]

#### MobilePhoneStore

A store that sells mobile phones and related accessories.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Monday

An Enumeration member

The day of the week between Sunday and Tuesday.

Member of Enumeration: DayOfWeek
[^top]

#### MonetaryAmount

A monetary value or range. This type can be used to describe an amount of money such as $50 USD, or a range as in describing a bank account being suitable for a balance between £1,000 and £1,000,000 GBP, or the value of a salary, etc. It is recommended to use PriceSpecification Types to describe the price of an Offer, Invoice, etc.

Properties used on this type:

- currency
- maxValue
- minValue
- validFrom
- validThrough
- value

Properties whose values are of this type:

- accountMinimumInflow
- accountOverdraftLimit
- amount
- baseSalary
- downPayment
- earlyPrepaymentPenalty
- estimatedCost
- estimatedSalary
- exchangeRateSpread
- floorLimit
- freeShippingThreshold
- loanMortgageMandateAmount
- loanPaymentAmount
- minimumPaymentDue
- monthlyMinimumRepaymentAmount
- netWorth
- shippingRate
- totalPaymentDue

[^top]

#### MonetaryAmountDistribution

A statistical distribution of monetary amounts.

Properties used on this type:

- currency

Properties whose values are of this type:

- estimatedSalary
- salaryUponCompletion
- trainingSalary

[^top]

#### MonetaryGrant

A monetary grant.

Properties used on this type:

- amount
- funder

Properties whose values are of this type:

[^top]

#### MoneyTransfer

The act of transferring money from one place to another place. This may occur electronically or physically.

Properties used on this type:

- amount
- beneficiaryBank

Properties whose values are of this type:

[^top]

#### MortgageLoan

A loan in which property or real estate is used as collateral. (A loan securitized against some real estate).

Properties used on this type:

- domiciledMortgage
- loanMortgageMandateAmount

Properties whose values are of this type:

[^top]

#### Mosque

A mosque.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Motel

A motel.
See also the dedicated document on the use of schema.org for marking up hotels and other forms of accommodations.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Motorcycle

A motorcycle or motorbike is a single-track, two-wheeled motor vehicle.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MotorcycleDealer

A motorcycle dealer.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MotorcycleRepair

A motorcycle repair shop.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MotorizedBicycle

A motorized bicycle is a bicycle with an attached motor used to power the vehicle, or to assist with pedaling.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Mountain

A mountain, like Mount Whitney or Mount Everest.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MoveAction

The act of an agent relocating to a place.
Related actions:

- TransferAction: Unlike TransferAction, the subject of the move is a living Person or Organization rather than an inanimate object.

Properties used on this type:

- fromLocation
- toLocation

Properties whose values are of this type:

[^top]

#### Movie

A movie.

Properties used on this type:

- actor
- actors
- countryOfOrigin
- director
- directors
- duration
- musicBy
- productionCompany
- subtitleLanguage
- titleEIDR
- trailer

Properties whose values are of this type:

- workPresented

[^top]

#### MovieClip

A short segment/part of a movie.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MovieRentalStore

A movie rental store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MovieSeries

A series of movies. Included movies can be indicated with the hasPart property.

Properties used on this type:

- actor
- actors
- director
- directors
- musicBy
- productionCompany
- trailer

Properties whose values are of this type:

[^top]

#### MovieTheater

A movie theater.

Properties used on this type:

- screenCount

Properties whose values are of this type:

[^top]

#### MovingCompany

A moving company.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MultiCenterTrial

An Enumeration member

A trial that takes place at multiple centers.

Member of Enumeration: MedicalTrialDesign
[^top]

#### MultiPlayer

An Enumeration member

Play mode: MultiPlayer. Requiring or allowing multiple human players to play simultaneously.

Member of Enumeration: GamePlayMode
[^top]

#### MulticellularParasite

An Enumeration member

Multicellular parasite that causes an infection.

Member of Enumeration: InfectiousAgentClass
[^top]

#### Muscle

A muscle is an anatomical structure consisting of a contractile form of tissue that animals use to effect movement.

Properties used on this type:

- antagonist
- bloodSupply
- insertion
- muscleAction
- nerve

Properties whose values are of this type:

- antagonist
- nerveMotor

[^top]

#### Musculoskeletal

An Enumeration member

A specific branch of medical science that pertains to diagnosis and treatment of disorders of muscles, ligaments and skeletal system.

Member of Enumeration: MedicalSpecialty
[^top]

#### MusculoskeletalExam

An Enumeration member

Musculoskeletal system clinical examination.

Member of Enumeration: PhysicalExam
[^top]

#### Museum

A museum.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MusicAlbum

A collection of music tracks.

Properties used on this type:

- albumProductionType
- albumRelease
- albumReleaseType
- byArtist

Properties whose values are of this type:

- album
- albums
- inAlbum
- releaseOf

[^top]

#### MusicAlbumProductionType

An Enumeration

Classification of the album by it's type of content: soundtrack, live album, studio album, etc.

Properties used on this type:

Enumeration members of this type:

- CompilationAlbum
- DJMixAlbum
- DemoAlbum
- LiveAlbum
- MixtapeAlbum
- RemixAlbum
- SoundtrackAlbum
- SpokenWordAlbum
- StudioAlbum

Properties whose values are of this type:

- albumProductionType

[^top]

#### MusicAlbumReleaseType

An Enumeration

The kind of release which this album is: single, EP or album.

Properties used on this type:

Enumeration members of this type:

- AlbumRelease
- BroadcastRelease
- EPRelease
- SingleRelease

Properties whose values are of this type:

- albumReleaseType

[^top]

#### MusicComposition

A musical composition.

Properties used on this type:

- composer
- firstPerformance
- includedComposition
- iswcCode
- lyricist
- lyrics
- musicArrangement
- musicCompositionForm
- musicalKey
- recordedAs

Properties whose values are of this type:

- includedComposition
- musicArrangement
- recordingOf

[^top]

#### MusicEvent

Event type: Music event.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MusicGroup

A musical group, such as a band, an orchestra, or a choir. Can also be a solo musician.

Properties used on this type:

- album
- albums
- genre
- musicGroupMember
- track
- tracks

Properties whose values are of this type:

- byArtist
- musicBy

[^top]

#### MusicPlaylist

A collection of music tracks in playlist form.

Properties used on this type:

- numTracks
- track
- tracks

Properties whose values are of this type:

- inPlaylist

[^top]

#### MusicRecording

A music recording (track), usually a single song.

Properties used on this type:

- byArtist
- duration
- inAlbum
- inPlaylist
- isrcCode
- recordingOf

Properties whose values are of this type:

- audio
- recordedAs
- track
- tracks

[^top]

#### MusicRelease

A MusicRelease is a specific release of a music album.

Properties used on this type:

- catalogNumber
- creditedTo
- duration
- musicReleaseFormat
- recordLabel
- releaseOf

Properties whose values are of this type:

- albumRelease

[^top]

#### MusicReleaseFormatType

An Enumeration

Format of this release (the type of recording media used, ie. compact disc, digital media, LP, etc.).

Properties used on this type:

Enumeration members of this type:

- CDFormat
- CassetteFormat
- DVDFormat
- DigitalAudioTapeFormat
- DigitalFormat
- LaserDiscFormat
- VinylFormat

Properties whose values are of this type:

- musicReleaseFormat

[^top]

#### MusicStore

A music store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MusicVenue

A music venue.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### MusicVideoObject

A music video file.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### NGO

Organization: Non-governmental Organization.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### NLNonprofitType

An Enumeration

NLNonprofitType: Non-profit organization type originating from the Netherlands.

Properties used on this type:

Enumeration members of this type:

- NonprofitANBI
- NonprofitSBBI

Properties whose values are of this type:

[^top]

#### NailSalon

A nail salon.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Neck

An Enumeration member

Neck assessment with clinical examination.

Member of Enumeration: PhysicalExam
[^top]

#### Nerve

A common pathway for the electrochemical nerve impulses that are transmitted along each of the axons.

Properties used on this type:

- branch
- nerveMotor
- sensoryUnit
- sourcedFrom

Properties whose values are of this type:

- nerve

[^top]

#### Neuro

An Enumeration member

Neurological system clinical examination.

Member of Enumeration: PhysicalExam
[^top]

#### Neurologic

An Enumeration member

A specific branch of medical science that studies the nerves and nervous system and its respective disease states.

Member of Enumeration: MedicalSpecialty
[^top]

#### NewCondition

An Enumeration member

Indicates that the item is new.

Member of Enumeration: OfferItemCondition
[^top]

#### NewsArticle

A NewsArticle is an article whose content reports news, or provides background context and supporting materials for understanding the news.
A more detailed overview of schema.org News markup is also available.

Properties used on this type:

- dateline
- printColumn
- printEdition
- printPage
- printSection

Properties whose values are of this type:

- associatedArticle

[^top]

#### NewsMediaOrganization

A News/Media organization such as a newspaper or TV station.

Properties used on this type:

- actionableFeedbackPolicy
- correctionsPolicy
- diversityPolicy
- diversityStaffingReport
- ethicsPolicy
- masthead
- missionCoveragePrioritiesPolicy
- noBylinesPolicy
- ownershipFundingInfo
- unnamedSourcesPolicy
- verificationFactCheckingPolicy

Properties whose values are of this type:

[^top]

#### Newspaper

A publication containing information about varied topics that are pertinent to general information, a geographic area, or a specific subject matter (i.e. business, culture, education). Often published daily.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### NightClub

A nightclub or discotheque.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### NoninvasiveProcedure

An Enumeration member

A type of medical procedure that involves noninvasive techniques.

Member of Enumeration: MedicalProcedureType
[^top]

#### Nonprofit501a

An Enumeration member

Nonprofit501a: Non-profit type referring to Farmers’ Cooperative Associations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c1

An Enumeration member

Nonprofit501c1: Non-profit type referring to Corporations Organized Under Act of Congress, including Federal Credit Unions and National Farm Loan Associations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c10

An Enumeration member

Nonprofit501c10: Non-profit type referring to Domestic Fraternal Societies and Associations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c11

An Enumeration member

Nonprofit501c11: Non-profit type referring to Teachers' Retirement Fund Associations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c12

An Enumeration member

Nonprofit501c12: Non-profit type referring to Benevolent Life Insurance Associations, Mutual Ditch or Irrigation Companies, Mutual or Cooperative Telephone Companies.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c13

An Enumeration member

Nonprofit501c13: Non-profit type referring to Cemetery Companies.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c14

An Enumeration member

Nonprofit501c14: Non-profit type referring to State-Chartered Credit Unions, Mutual Reserve Funds.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c15

An Enumeration member

Nonprofit501c15: Non-profit type referring to Mutual Insurance Companies or Associations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c16

An Enumeration member

Nonprofit501c16: Non-profit type referring to Cooperative Organizations to Finance Crop Operations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c17

An Enumeration member

Nonprofit501c17: Non-profit type referring to Supplemental Unemployment Benefit Trusts.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c18

An Enumeration member

Nonprofit501c18: Non-profit type referring to Employee Funded Pension Trust (created before 25 June 1959).

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c19

An Enumeration member

Nonprofit501c19: Non-profit type referring to Post or Organization of Past or Present Members of the Armed Forces.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c2

An Enumeration member

Nonprofit501c2: Non-profit type referring to Title-holding Corporations for Exempt Organizations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c20

An Enumeration member

Nonprofit501c20: Non-profit type referring to Group Legal Services Plan Organizations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c21

An Enumeration member

Nonprofit501c21: Non-profit type referring to Black Lung Benefit Trusts.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c22

An Enumeration member

Nonprofit501c22: Non-profit type referring to Withdrawal Liability Payment Funds.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c23

An Enumeration member

Nonprofit501c23: Non-profit type referring to Veterans Organizations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c24

An Enumeration member

Nonprofit501c24: Non-profit type referring to Section 4049 ERISA Trusts.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c25

An Enumeration member

Nonprofit501c25: Non-profit type referring to Real Property Title-Holding Corporations or Trusts with Multiple Parents.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c26

An Enumeration member

Nonprofit501c26: Non-profit type referring to State-Sponsored Organizations Providing Health Coverage for High-Risk Individuals.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c27

An Enumeration member

Nonprofit501c27: Non-profit type referring to State-Sponsored Workers' Compensation Reinsurance Organizations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c28

An Enumeration member

Nonprofit501c28: Non-profit type referring to National Railroad Retirement Investment Trusts.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c3

An Enumeration member

Nonprofit501c3: Non-profit type referring to Religious, Educational, Charitable, Scientific, Literary, Testing for Public Safety, to Foster National or International Amateur Sports Competition, or Prevention of Cruelty to Children or Animals Organizations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c4

An Enumeration member

Nonprofit501c4: Non-profit type referring to Civic Leagues, Social Welfare Organizations, and Local Associations of Employees.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c5

An Enumeration member

Nonprofit501c5: Non-profit type referring to Labor, Agricultural and Horticultural Organizations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c6

An Enumeration member

Nonprofit501c6: Non-profit type referring to Business Leagues, Chambers of Commerce, Real Estate Boards.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c7

An Enumeration member

Nonprofit501c7: Non-profit type referring to Social and Recreational Clubs.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c8

An Enumeration member

Nonprofit501c8: Non-profit type referring to Fraternal Beneficiary Societies and Associations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501c9

An Enumeration member

Nonprofit501c9: Non-profit type referring to Voluntary Employee Beneficiary Associations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501d

An Enumeration member

Nonprofit501d: Non-profit type referring to Religious and Apostolic Associations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501e

An Enumeration member

Nonprofit501e: Non-profit type referring to Cooperative Hospital Service Organizations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501f

An Enumeration member

Nonprofit501f: Non-profit type referring to Cooperative Service Organizations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501k

An Enumeration member

Nonprofit501k: Non-profit type referring to Child Care Organizations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501n

An Enumeration member

Nonprofit501n: Non-profit type referring to Charitable Risk Pools.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit501q

An Enumeration member

Nonprofit501q: Non-profit type referring to Credit Counseling Organizations.

Member of Enumeration: USNonprofitType
[^top]

#### Nonprofit527

An Enumeration member

Nonprofit527: Non-profit type referring to Political organizations.

Member of Enumeration: USNonprofitType
[^top]

#### NonprofitANBI

An Enumeration member

NonprofitANBI: Non-profit type referring to a Public Benefit Organization (NL).

Member of Enumeration: NLNonprofitType
[^top]

#### NonprofitSBBI

An Enumeration member

NonprofitSBBI: Non-profit type referring to a Social Interest Promoting Institution (NL).

Member of Enumeration: NLNonprofitType
[^top]

#### NonprofitType

An Enumeration

NonprofitType enumerates several kinds of official non-profit types of which a non-profit organization can be.

Properties used on this type:

Enumeration members of this type:

Properties whose values are of this type:

- nonprofitStatus

[^top]

#### Nose

An Enumeration member

Nose function assessment with clinical examination.

Member of Enumeration: PhysicalExam
[^top]

#### NotInForce

An Enumeration member

Indicates that a legislation is currently not in force.

Member of Enumeration: LegalForceStatus
[^top]

#### NotYetRecruiting

An Enumeration member

Not yet recruiting.

Member of Enumeration: MedicalStudyStatus
[^top]

#### Notary

A notary.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### NoteDigitalDocument

A file containing a note, primarily for the author.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Number

A Datatype

Data type: Number.
Usage guidelines:

- Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similiar Unicode symbols.
- Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.

Properties used on this type:

Properties whose values are of this type:

- additionalNumberOfGuests
- amount
- amountOfThisGood
- annualPercentageRate
- baseSalary
- bestRating
- billingDuration
- billingIncrement
- billingStart
- broadcastFrequencyValue
- cashBack
- childMaxAge
- childMinAge
- copyrightYear
- costPerUnit
- cvdNumBeds
- cvdNumBedsOcc
- cvdNumC19Died
- cvdNumC19HOPats
- cvdNumC19HospPats
- cvdNumC19MechVentPats
- cvdNumC19OFMechVentPats
- cvdNumC19OverflowPats
- cvdNumICUBeds
- cvdNumICUBedsOcc
- cvdNumTotBeds
- cvdNumVent
- cvdNumVentUse
- discount
- doseValue
- downPayment
- elevation
- emissionsCO2
- endOffset
- estimatedSalary
- exchangeRateSpread
- geoRadius
- healthPlanCoinsuranceRate
- highPrice
- interestRate
- latitude
- loanPaymentFrequency
- longitude
- lowPrice
- maxPrice
- maxValue
- median
- membershipPointsEarned
- minPrice
- minValue
- monthlyMinimumRepaymentAmount
- monthsOfExperience
- numberOfAirbags
- numberOfAxles
- numberOfBedrooms
- numberOfBeds
- numberOfDoors
- numberOfForwardGears
- numberOfFullBathrooms
- numberOfLoanPayments
- numberOfPartialBathrooms
- numberOfPreviousOwners
- numberOfRooms
- numberedPosition
- orderQuantity
- percentile10
- percentile25
- percentile75
- percentile90
- price
- ratingValue
- repetitions
- requiredQuantity
- screenCount
- seatingCapacity
- stageAsNumber
- startOffset
- stepValue
- strengthValue
- suggestedMaxAge
- suggestedMinAge
- termsPerYear
- totalPrice
- value
- valueMaxLength
- valueMinLength
- vehicleSeatingCapacity
- version
- worstRating
- yearBuilt

[^top]

#### Nursing

An Enumeration member

A health profession of a person formally educated and trained in the care of the sick or infirm person.

Member of Enumeration: MedicalSpecialty
[^top]

#### NutritionInformation

Nutritional information about the recipe.

Properties used on this type:

- calories
- carbohydrateContent
- cholesterolContent
- fatContent
- fiberContent
- proteinContent
- saturatedFatContent
- servingSize
- sodiumContent
- sugarContent
- transFatContent
- unsaturatedFatContent

Properties whose values are of this type:

- nutrition

[^top]

#### OTC

An Enumeration member

The character of a medical substance, typically a medicine, of being available over the counter or not.

Member of Enumeration: DrugPrescriptionStatus
[^top]

#### Observation

Instances of the class Observation are used to specify observations about an entity (which may or may not be an instance of a StatisticalPopulation), at a particular time. The principal properties of an Observation are observedNode, measuredProperty, measuredValue (or median, etc.) and observationDate (measuredProperty properties can, but need not always, be W3C RDF Data Cube "measure properties", as in the lifeExpectancy example). See also StatisticalPopulation, and the data and datasets overview for more details.

Properties used on this type:

- marginOfError
- measuredProperty
- measuredValue
- observationDate
- observedNode

Properties whose values are of this type:

- diseaseSpreadStatistics

[^top]

#### Observational

An Enumeration member

An observational study design.

Member of Enumeration: MedicalObservationalStudyDesign
[^top]

#### Obstetric

An Enumeration member

A specific branch of medical science that specializes in the care of women during the prenatal and postnatal care and with the delivery of the child.

Member of Enumeration: MedicalSpecialty
[^top]

#### Occupation

A profession, may involve prolonged training and/or a formal qualification.

Properties used on this type:

- educationRequirements
- estimatedSalary
- experienceRequirements
- occupationLocation
- occupationalCategory
- qualifications
- responsibilities
- skills

Properties whose values are of this type:

- hasOccupation
- relevantOccupation

[^top]

#### OccupationalActivity

An Enumeration member

Any physical activity engaged in for job-related purposes. Examples may include waiting tables, maid service, carrying a mailbag, picking fruits or vegetables, construction work, etc.

Member of Enumeration: PhysicalActivityCategory
[^top]

#### OccupationalExperienceRequirements

Indicates employment-related experience requirements, e.g. monthsOfExperience.

Properties used on this type:

- monthsOfExperience

Properties whose values are of this type:

- experienceRequirements

[^top]

#### OccupationalTherapy

A treatment of people with physical, emotional, or social problems, using purposeful activity to help them overcome or learn to deal with their problems.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### OceanBodyOfWater

An ocean (for example, the Pacific).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Offer

An offer to transfer some rights to an item or to provide a service — for example, an offer to sell tickets to an event, to rent the DVD of a movie, to stream a TV show over the internet, to repair a motorcycle, or to loan a book.
Note: As the businessFunction property, which identifies the form of offer (e.g. sell, lease, repair, dispose), defaults to http://purl.org/goodrelations/v1#Sell; an Offer without a defined businessFunction value can be assumed to be an offer to sell.
For GTIN-related fields, see Check Digit calculator and validation guide from GS1.

Properties used on this type:

- acceptedPaymentMethod
- addOn
- advanceBookingRequirement
- aggregateRating
- areaServed
- availability
- availabilityEnds
- availabilityStarts
- availableAtOrFrom
- availableDeliveryMethod
- businessFunction
- category
- deliveryLeadTime
- eligibleCustomerType
- eligibleDuration
- eligibleQuantity
- eligibleRegion
- eligibleTransactionVolume
- gtin
- gtin12
- gtin13
- gtin14
- gtin8
- hasMeasurement
- includesObject
- ineligibleRegion
- inventoryLevel
- itemCondition
- itemOffered
- leaseLength
- mpn
- offeredBy
- price
- priceCurrency
- priceSpecification
- priceValidUntil
- review
- reviews
- seller
- serialNumber
- shippingDetails
- sku
- validFrom
- validThrough
- warranty

Properties whose values are of this type:

- acceptedOffer
- addOn
- expectsAcceptanceOf
- makesOffer
- offers

[^top]

#### OfferCatalog

An OfferCatalog is an ItemList that contains related Offers and/or further OfferCatalogs that are offeredBy the same provider.

Properties used on this type:

Properties whose values are of this type:

- hasOfferCatalog

[^top]

#### OfferForLease

An OfferForLease in Schema.org represents an Offer to lease out something, i.e. an Offer whose businessFunction is lease out. See Good Relations for background on the underlying concepts.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### OfferForPurchase

An OfferForPurchase in Schema.org represents an Offer to sell something, i.e. an Offer whose businessFunction is sell. See Good Relations for background on the underlying concepts.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### OfferItemCondition

An Enumeration

A list of possible conditions for the item.

Properties used on this type:

Enumeration members of this type:

- DamagedCondition
- NewCondition
- RefurbishedCondition
- UsedCondition

Properties whose values are of this type:

- itemCondition

[^top]

#### OfferShippingDetails

OfferShippingDetails represents information about shipping destinations.
Multiple of these entities can be used to represent different shipping rates for different destinations:
One entity for Alaska/Hawaii. A different one for continental US.A different one for all France.
Multiple of these entities can be used to represent different shipping costs and delivery times.
Two entities that are identical but differ in rate and time:
e.g. Cheaper and slower: $5 in 5-7days or Fast and expensive: $15 in 1-2 days.

Properties used on this type:

- deliveryTime
- doesNotShip
- shippingDestination
- shippingLabel
- shippingRate
- shippingSettingsLink
- transitTimeLabel

Properties whose values are of this type:

- shippingDetails

[^top]

#### OfficeEquipmentStore

An office equipment store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### OfficialLegalValue

An Enumeration member

All the documents published by an official publisher should have at least the legal value level "OfficialLegalValue". This indicates that the document was published by an organisation with the public task of making it available (e.g. a consolidated version of a EU directive published by the EU Office of Publications).

Member of Enumeration: LegalValueLevel
[^top]

#### OfflineEventAttendanceMode

An Enumeration member

OfflineEventAttendanceMode - an event that is primarily conducted offline.

Member of Enumeration: EventAttendanceModeEnumeration
[^top]

#### OfflinePermanently

An Enumeration member

Game server status: OfflinePermanently. Server is offline and not available.

Member of Enumeration: GameServerStatus
[^top]

#### OfflineTemporarily

An Enumeration member

Game server status: OfflineTemporarily. Server is offline now but it can be online soon.

Member of Enumeration: GameServerStatus
[^top]

#### OnDemandEvent

A publication event e.g. catch-up TV or radio podcast, during which a program is available on-demand.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### OnSitePickup

An Enumeration member

A DeliveryMethod in which an item is collected on site, e.g. in a store or at a box office.

Member of Enumeration: DeliveryMethod
[^top]

#### Oncologic

An Enumeration member

A specific branch of medical science that deals with benign and malignant tumors, including the study of their development, diagnosis, treatment and prevention.

Member of Enumeration: MedicalSpecialty
[^top]

#### OneTimePayments

An Enumeration member

OneTimePayments: this is a benefit for one-time payments for individuals.

Member of Enumeration: GovernmentBenefitsType
[^top]

#### Online

An Enumeration member

Game server status: Online. Server is available.

Member of Enumeration: GameServerStatus
[^top]

#### OnlineEventAttendanceMode

An Enumeration member

OnlineEventAttendanceMode - an event that is primarily conducted online.

Member of Enumeration: EventAttendanceModeEnumeration
[^top]

#### OnlineFull

An Enumeration member

Game server status: OnlineFull. Server is online but unavailable. The maximum number of players has reached.

Member of Enumeration: GameServerStatus
[^top]

#### OnlineOnly

An Enumeration member

Indicates that the item is available only online.

Member of Enumeration: ItemAvailability
[^top]

#### OpenTrial

An Enumeration member

A trial design in which the researcher knows the full details of the treatment, and so does the patient.

Member of Enumeration: MedicalTrialDesign
[^top]

#### OpeningHoursSpecification

A structured value providing information about the opening hours of a place or a certain service inside a place.
The place is open if the opens property is specified, and closed otherwise.
If the value for the closes property is less than the value for the opens property then the hour range is assumed to span over the next day.

Properties used on this type:

- closes
- dayOfWeek
- opens
- validFrom
- validThrough

Properties whose values are of this type:

- businessDays
- hoursAvailable
- openingHoursSpecification
- specialOpeningHoursSpecification

[^top]

#### OpinionNewsArticle

An OpinionNewsArticle is a NewsArticle that primarily expresses opinions rather than journalistic reporting of news and events. For example, a NewsArticle consisting of a column or Blog/BlogPosting entry in the Opinions section of a news publication.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Optician

A store that sells reading glasses and similar devices for improving vision.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Optometric

An Enumeration member

The science or practice of testing visual acuity and prescribing corrective lenses.

Member of Enumeration: MedicalSpecialty
[^top]

#### Order

An order is a confirmation of a transaction (a receipt), which can contain multiple line items, each represented by an Offer that has been accepted by the customer.

Properties used on this type:

- acceptedOffer
- billingAddress
- broker
- confirmationNumber
- customer
- discount
- discountCode
- discountCurrency
- isGift
- merchant
- orderDate
- orderDelivery
- orderNumber
- orderStatus
- orderedItem
- partOfInvoice
- paymentDue
- paymentDueDate
- paymentMethod
- paymentMethodId
- paymentUrl
- seller

Properties whose values are of this type:

- partOfOrder
- referencesOrder

[^top]

#### OrderAction

An agent orders an object/product/service to be delivered/sent.

Properties used on this type:

- deliveryMethod

Properties whose values are of this type:

[^top]

#### OrderCancelled

An Enumeration member

OrderStatus representing cancellation of an order.

Member of Enumeration: OrderStatus
[^top]

#### OrderDelivered

An Enumeration member

OrderStatus representing successful delivery of an order.

Member of Enumeration: OrderStatus
[^top]

#### OrderInTransit

An Enumeration member

OrderStatus representing that an order is in transit.

Member of Enumeration: OrderStatus
[^top]

#### OrderItem

An order item is a line of an order. It includes the quantity and shipping details of a bought offer.

Properties used on this type:

- orderDelivery
- orderItemNumber
- orderItemStatus
- orderQuantity
- orderedItem

Properties whose values are of this type:

- orderedItem

[^top]

#### OrderPaymentDue

An Enumeration member

OrderStatus representing that payment is due on an order.

Member of Enumeration: OrderStatus
[^top]

#### OrderPickupAvailable

An Enumeration member

OrderStatus representing availability of an order for pickup.

Member of Enumeration: OrderStatus
[^top]

#### OrderProblem

An Enumeration member

OrderStatus representing that there is a problem with the order.

Member of Enumeration: OrderStatus
[^top]

#### OrderProcessing

An Enumeration member

OrderStatus representing that an order is being processed.

Member of Enumeration: OrderStatus
[^top]

#### OrderReturned

An Enumeration member

OrderStatus representing that an order has been returned.

Member of Enumeration: OrderStatus
[^top]

#### OrderStatus

An Enumeration

Enumerated status values for Order.

Properties used on this type:

Enumeration members of this type:

- OrderCancelled
- OrderDelivered
- OrderInTransit
- OrderPaymentDue
- OrderPickupAvailable
- OrderProblem
- OrderProcessing
- OrderReturned

Properties whose values are of this type:

- orderItemStatus
- orderStatus

[^top]

#### Organization

An organization such as a school, NGO, corporation, club, etc.

Properties used on this type:

- actionableFeedbackPolicy
- address
- aggregateRating
- alumni
- areaServed
- award
- awards
- brand
- contactPoint
- contactPoints
- correctionsPolicy
- department
- dissolutionDate
- diversityPolicy
- diversityStaffingReport
- duns
- email
- employee
- employees
- ethicsPolicy
- event
- events
- faxNumber
- founder
- founders
- foundingDate
- foundingLocation
- funder
- globalLocationNumber
- hasCredential
- hasMerchantReturnPolicy
- hasOfferCatalog
- hasPOS
- hasProductReturnPolicy
- interactionStatistic
- isicV4
- knowsAbout
- knowsLanguage
- legalName
- leiCode
- location
- logo
- makesOffer
- member
- memberOf
- members
- naics
- nonprofitStatus
- numberOfEmployees
- ownershipFundingInfo
- owns
- parentOrganization
- publishingPrinciples
- review
- reviews
- seeks
- serviceArea
- slogan
- sponsor
- subOrganization
- taxID
- telephone
- unnamedSourcesPolicy
- vatID

Properties whose values are of this type:

- acquiredFrom
- affiliation
- agent
- alumniOf
- attendee
- attendees
- authenticator
- author
- bccRecipient
- bookingAgent
- branchOf
- brand
- broadcastAffiliateOf
- broadcaster
- broker
- carrier
- ccRecipient
- composer
- contributor
- copyrightHolder
- creator
- creditedTo
- customer
- department
- employmentUnit
- endorsee
- endorsers
- followee
- funder
- grantee
- hiringOrganization
- hostingOrganization
- issuedBy
- landlord
- legislationPassedBy
- legislationResponsible
- lender
- maintainer
- manufacturer
- member
- memberOf
- members
- merchant
- offeredBy
- organizer
- parentOrganization
- participant
- performer
- performers
- producer
- productionCompany
- provider
- publishedBy
- publisher
- publisherImprint
- recipient
- recognizedBy
- recognizingAuthority
- recordLabel
- reviewedBy
- sdPublisher
- seller
- sender
- serviceOperator
- sourceOrganization
- spokenByCharacter
- sponsor
- subOrganization
- toRecipient
- translator
- underName
- vendor
- worksFor

[^top]

#### OrganizationRole

A subclass of Role used to describe roles within organizations.

Properties used on this type:

- numberedPosition

Properties whose values are of this type:

[^top]

#### OrganizeAction

The act of manipulating/administering/supervising/controlling one or more objects.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### OriginalMediaContent

An Enumeration member

Content coded 'as original media content' in a MediaReview, considered in the context of how it was published or shared.
For a VideoObject to be 'original': No evidence the footage has been misleadingly altered or manipulated, though it may contain false or misleading claims.
For an ImageObject to be 'original': No evidence the image has been misleadingly altered or manipulated, though it may still contain false or misleading claims.
For an ImageObject with embedded text to be 'original': No evidence the image has been misleadingly altered or manipulated, though it may still contain false or misleading claims.
For an AudioObject to be 'original': No evidence the audio has been misleadingly altered or manipulated, though it may contain false or misleading claims.

Member of Enumeration: MediaManipulationRatingEnumeration
[^top]

#### OriginalShippingFees

An Enumeration member

OriginalShippingFees ...

Member of Enumeration: ReturnFeesEnumeration
[^top]

#### Osteopathic

An Enumeration member

A system of medicine focused on promoting the body's innate ability to heal itself.

Member of Enumeration: MedicineSystem
[^top]

#### Otolaryngologic

An Enumeration member

A specific branch of medical science that is concerned with the ear, nose and throat and their respective disease states.

Member of Enumeration: MedicalSpecialty
[^top]

#### OutOfStock

An Enumeration member

Indicates that the item is out of stock.

Member of Enumeration: ItemAvailability
[^top]

#### OutletStore

An outlet store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### OverviewHealthAspect

An Enumeration member

Overview of the content. Contains a summarized view of the topic with the most relevant information for an introduction.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### OwnershipInfo

A structured value providing information about when a certain organization or person owned a certain product.

Properties used on this type:

- acquiredFrom
- ownedFrom
- ownedThrough
- typeOfGood

Properties whose values are of this type:

- owns

[^top]

#### PET

An Enumeration member

Positron emission tomography imaging.

Member of Enumeration: MedicalImagingTechnique
[^top]

#### PaidLeave

An Enumeration member

PaidLeave: this is a benefit for paid leave.

Member of Enumeration: GovernmentBenefitsType
[^top]

#### PaintAction

The act of producing a painting, typically with paint and canvas as instruments.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Painting

A painting.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PalliativeProcedure

A medical procedure intended primarily for palliative purposes, aimed at relieving the symptoms of an underlying health condition.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Paperback

An Enumeration member

Book format: Paperback.

Member of Enumeration: BookFormatType
[^top]

#### ParcelDelivery

The delivery of a parcel either via the postal service or a commercial service.

Properties used on this type:

- carrier
- deliveryAddress
- deliveryStatus
- expectedArrivalFrom
- expectedArrivalUntil
- hasDeliveryMethod
- itemShipped
- originAddress
- partOfOrder
- provider
- trackingNumber
- trackingUrl

Properties whose values are of this type:

- orderDelivery

[^top]

#### ParcelService

An Enumeration member

A private parcel service as the delivery mode available for a certain offer.
Commonly used values:

- http://purl.org/goodrelations/v1#DHL
- http://purl.org/goodrelations/v1#FederalExpress
- http://purl.org/goodrelations/v1#UPS

Member of Enumeration: DeliveryMethod
[^top]

#### ParentAudience

A set of characteristics describing parents, who can be interested in viewing some content.

Properties used on this type:

- childMaxAge
- childMinAge

Properties whose values are of this type:

[^top]

#### ParentalSupport

An Enumeration member

ParentalSupport: this is a benefit for parental support.

Member of Enumeration: GovernmentBenefitsType
[^top]

#### Park

A park.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ParkingFacility

A parking lot or other parking facility.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ParkingMap

An Enumeration member

A parking map.

Member of Enumeration: MapCategoryType
[^top]

#### PartiallyInForce

An Enumeration member

Indicates that parts of the legislation are in force, and parts are not.

Member of Enumeration: LegalForceStatus
[^top]

#### Pathology

An Enumeration member

A specific branch of medical science that is concerned with the study of the cause, origin and nature of a disease state, including its consequences as a result of manifestation of the disease. In clinical care, the term is used to designate a branch of medicine using laboratory tests to diagnose and determine the prognostic significance of illness.

Member of Enumeration: MedicalSpecialty
[^top]

#### PathologyTest

A medical test performed by a laboratory that typically involves examination of a tissue sample by a pathologist.

Properties used on this type:

- tissueSample

Properties whose values are of this type:

[^top]

#### Patient

A patient is any person recipient of health care services.

Properties used on this type:

- diagnosis
- drug
- healthCondition

Properties whose values are of this type:

[^top]

#### PatientExperienceHealthAspect

An Enumeration member

Content about the real life experience of patients or people that have lived a similar experience about the topic. May be forums, topics, Q-and-A and related material.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### PawnShop

A shop that will buy, or lend money against the security of, personal possessions.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PayAction

An agent pays a price to a participant.

Properties used on this type:

- recipient

Properties whose values are of this type:

[^top]

#### PaymentAutomaticallyApplied

An Enumeration member

An automatic payment system is in place and will be used.

Member of Enumeration: PaymentStatusType
[^top]

#### PaymentCard

An Enumeration

A payment method using a credit, debit, store or other card to associate the payment with an account.

Properties used on this type:

- cashBack
- contactlessPayment
- floorLimit
- monthlyMinimumRepaymentAmount

Enumeration members of this type:

Properties whose values are of this type:

[^top]

#### PaymentChargeSpecification

The costs of settling the payment using a particular payment method.

Properties used on this type:

- appliesToDeliveryMethod
- appliesToPaymentMethod

Properties whose values are of this type:

[^top]

#### PaymentComplete

An Enumeration member

The payment has been received and processed.

Member of Enumeration: PaymentStatusType
[^top]

#### PaymentDeclined

An Enumeration member

The payee received the payment, but it was declined for some reason.

Member of Enumeration: PaymentStatusType
[^top]

#### PaymentDue

An Enumeration member

The payment is due, but still within an acceptable time to be received.

Member of Enumeration: PaymentStatusType
[^top]

#### PaymentMethod

An Enumeration

A payment method is a standardized procedure for transferring the monetary amount for a purchase. Payment methods are characterized by the legal and technical structures used, and by the organization or group carrying out the transaction.
Commonly used values:

- http://purl.org/goodrelations/v1#ByBankTransferInAdvance
- http://purl.org/goodrelations/v1#ByInvoice
- http://purl.org/goodrelations/v1#Cash
- http://purl.org/goodrelations/v1#CheckInAdvance
- http://purl.org/goodrelations/v1#COD
- http://purl.org/goodrelations/v1#DirectDebit
- http://purl.org/goodrelations/v1#GoogleCheckout
- http://purl.org/goodrelations/v1#PayPal
- http://purl.org/goodrelations/v1#PaySwarm

Properties used on this type:

Enumeration members of this type:

Properties whose values are of this type:

- acceptedPaymentMethod
- appliesToPaymentMethod
- paymentMethod

[^top]

#### PaymentPastDue

An Enumeration member

The payment is due and considered late.

Member of Enumeration: PaymentStatusType
[^top]

#### PaymentService

A Service to transfer funds from a person or organization to a beneficiary person or organization.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PaymentStatusType

An Enumeration

A specific payment status. For example, PaymentDue, PaymentComplete, etc.

Properties used on this type:

Enumeration members of this type:

- PaymentAutomaticallyApplied
- PaymentComplete
- PaymentDeclined
- PaymentDue
- PaymentPastDue

Properties whose values are of this type:

- paymentStatus

[^top]

#### Pediatric

An Enumeration member

A specific branch of medical science that specializes in the care of infants, children and adolescents.

Member of Enumeration: MedicalSpecialty
[^top]

#### PeopleAudience

A set of characteristics belonging to people, e.g. who compose an item's target audience.

Properties used on this type:

- healthCondition
- requiredGender
- requiredMaxAge
- requiredMinAge
- suggestedAge
- suggestedGender
- suggestedMaxAge
- suggestedMeasurement
- suggestedMinAge

Properties whose values are of this type:

[^top]

#### PercutaneousProcedure

An Enumeration member

A type of medical procedure that involves percutaneous techniques, where access to organs or tissue is achieved via needle-puncture of the skin. For example, catheter-based procedures like stent delivery.

Member of Enumeration: MedicalProcedureType
[^top]

#### PerformAction

The act of participating in performance arts.

Properties used on this type:

- entertainmentBusiness

Properties whose values are of this type:

[^top]

#### PerformanceRole

A PerformanceRole is a Role that some entity places with regard to a theatrical performance, e.g. in a Movie, TVSeries etc.

Properties used on this type:

- characterName

Properties whose values are of this type:

[^top]

#### PerformingArtsTheater

A theater or other performing art center.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PerformingGroup

A performance group, such as a band, an orchestra, or a circus.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Periodical

A publication in any medium issued in successive parts bearing numerical or chronological designations and intended, such as a magazine, scholarly journal, or newspaper to continue indefinitely.
See also blog post.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Permit

A permit issued by an organization, e.g. a parking pass.

Properties used on this type:

- issuedBy
- issuedThrough
- permitAudience
- validFor
- validFrom
- validIn
- validUntil

Properties whose values are of this type:

[^top]

#### Person

A person (alive, dead, undead, or fictional).

Properties used on this type:

- additionalName
- address
- affiliation
- alumniOf
- award
- awards
- birthDate
- birthPlace
- brand
- callSign
- children
- colleague
- colleagues
- contactPoint
- contactPoints
- deathDate
- deathPlace
- duns
- email
- familyName
- faxNumber
- follows
- funder
- gender
- givenName
- globalLocationNumber
- hasCredential
- hasOccupation
- hasOfferCatalog
- hasPOS
- height
- homeLocation
- honorificPrefix
- honorificSuffix
- interactionStatistic
- isicV4
- jobTitle
- knows
- knowsAbout
- knowsLanguage
- makesOffer
- memberOf
- naics
- nationality
- netWorth
- owns
- parent
- parents
- performerIn
- publishingPrinciples
- relatedTo
- seeks
- sibling
- siblings
- sponsor
- spouse
- taxID
- telephone
- vatID
- weight
- workLocation
- worksFor

Properties whose values are of this type:

- accountablePerson
- acquiredFrom
- actor
- actors
- agent
- alumni
- artist
- athlete
- attendee
- attendees
- author
- awayTeam
- bccRecipient
- bookingAgent
- borrower
- broker
- buyer
- byArtist
- candidate
- ccRecipient
- character
- children
- coach
- colleague
- colleagues
- colorist
- competitor
- composer
- contributor
- copyrightHolder
- creator
- creditedTo
- customer
- director
- directors
- editor
- employee
- employees
- endorsee
- endorsers
- followee
- follows
- founder
- founders
- funder
- grantee
- homeTeam
- illustrator
- inker
- instructor
- knows
- landlord
- legislationPassedBy
- legislationResponsible
- lender
- letterer
- loser
- lyricist
- maintainer
- member
- members
- merchant
- musicBy
- musicGroupMember
- offeredBy
- opponent
- organizer
- parent
- parents
- participant
- penciler
- performer
- performers
- producer
- provider
- publishedBy
- publisher
- readBy
- recipient
- relatedTo
- reviewedBy
- sdPublisher
- seller
- sender
- sibling
- siblings
- spokenByCharacter
- sponsor
- spouse
- toRecipient
- translator
- underName
- vendor
- winner

[^top]

#### PetStore

A pet store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Pharmacy

A pharmacy or drugstore.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PharmacySpecialty

An Enumeration member

The practice or art and science of preparing and dispensing drugs and medicines.

Member of Enumeration: MedicalSpecialty
[^top]

#### Photograph

A photograph.

Properties used on this type:

Properties whose values are of this type:

- photo
- photos

[^top]

#### PhotographAction

The act of capturing still images of objects using a camera.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PhysicalActivity

Any bodily activity that enhances or maintains physical fitness and overall health and wellness. Includes activity that is part of daily living and routine, structured exercise, and exercise prescribed as part of a medical treatment or recovery plan.

Properties used on this type:

- associatedAnatomy
- category
- epidemiology
- pathophysiology

Properties whose values are of this type:

[^top]

#### PhysicalActivityCategory

An Enumeration

Categories of physical activity, organized by physiologic classification.

Properties used on this type:

Enumeration members of this type:

- AerobicActivity
- AnaerobicActivity
- Balance
- Flexibility
- LeisureTimeActivity
- OccupationalActivity
- StrengthTraining

Properties whose values are of this type:

- category

[^top]

#### PhysicalExam

An Enumeration

A type of physical examination of a patient performed by a physician.

Properties used on this type:

Enumeration members of this type:

- Abdomen
- Appearance
- CardiovascularExam
- Ear
- Eye
- Genitourinary
- Head
- Lung
- MusculoskeletalExam
- Neck
- Neuro
- Nose
- Skin
- Throat

Properties whose values are of this type:

- identifyingExam

[^top]

#### PhysicalTherapy

A process of progressive physical care and rehabilitation aimed at improving a health condition.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Physician

A doctor's office.

Properties used on this type:

- availableService
- hospitalAffiliation
- medicalSpecialty

Properties whose values are of this type:

[^top]

#### Physiotherapy

An Enumeration member

The practice of treatment of disease, injury, or deformity by physical methods such as massage, heat treatment, and exercise rather than by drugs or surgery..

Member of Enumeration: MedicalSpecialty
[^top]

#### Place

Entities that have a somewhat fixed, physical extension.

Properties used on this type:

- additionalProperty
- address
- aggregateRating
- amenityFeature
- branchCode
- containedIn
- containedInPlace
- containsPlace
- event
- events
- faxNumber
- geo
- geoContains
- geoCoveredBy
- geoCovers
- geoCrosses
- geoDisjoint
- geoEquals
- geoIntersects
- geoOverlaps
- geoTouches
- geoWithin
- globalLocationNumber
- hasDriveThroughService
- hasMap
- isAccessibleForFree
- isicV4
- latitude
- logo
- longitude
- map
- maps
- maximumAttendeeCapacity
- openingHoursSpecification
- photo
- photos
- publicAccess
- review
- reviews
- slogan
- smokingAllowed
- specialOpeningHoursSpecification
- telephone
- tourBookingPage

Properties whose values are of this type:

- area
- areaServed
- availableAtOrFrom
- birthPlace
- containedIn
- containedInPlace
- containsPlace
- contentLocation
- course
- deathPlace
- dropoffLocation
- eligibleRegion
- exerciseCourse
- foodEstablishment
- foundingLocation
- fromLocation
- gameLocation
- geoContains
- geoCoveredBy
- geoCovers
- geoCrosses
- geoDisjoint
- geoEquals
- geoIntersects
- geoOverlaps
- geoTouches
- geoWithin
- hasPOS
- homeLocation
- ineligibleRegion
- itemLocation
- itinerary
- jobLocation
- location
- locationCreated
- pickupLocation
- regionsAllowed
- serviceArea
- serviceLocation
- spatial
- spatialCoverage
- toLocation
- workLocation

[^top]

#### PlaceOfWorship

Place of worship, such as a church, synagogue, or mosque.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PlaceboControlledTrial

An Enumeration member

A placebo-controlled trial design.

Member of Enumeration: MedicalTrialDesign
[^top]

#### PlanAction

The act of planning the execution of an event/task/action/reservation/plan to a future date.

Properties used on this type:

- scheduledTime

Properties whose values are of this type:

[^top]

#### PlasticSurgery

An Enumeration member

A specific branch of medical science that pertains to therapeutic or cosmetic repair or re-formation of missing, injured or malformed tissues or body parts by manual and instrumental means.

Member of Enumeration: MedicalSpecialty
[^top]

#### Play

A play is a form of literature, usually consisting of dialogue between characters, intended for theatrical performance rather than just reading. Note the peformance of a Play would be a TheaterEvent - the Play being the workPerformed.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PlayAction

The act of playing/exercising/training/performing for enjoyment, leisure, recreation, Competition or exercise.
Related actions:

- ListenAction: Unlike ListenAction (which is under ConsumeAction), PlayAction refers to performing for an audience or at an event, rather than consuming music.
- WatchAction: Unlike WatchAction (which is under ConsumeAction), PlayAction refers to showing/displaying for an audience or at an event, rather than consuming visual content.

Properties used on this type:

- audience
- event

Properties whose values are of this type:

[^top]

#### Playground

A playground.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Plumber

A plumbing service.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PodcastEpisode

A single episode of a podcast series.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PodcastSeason

A single season of a podcast. Many podcasts do not break down into separate seasons. In that case, PodcastSeries should be used.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PodcastSeries

A podcast is an episodic series of digital audio or video files which a user can download and listen to.

Properties used on this type:

- webFeed

Properties whose values are of this type:

[^top]

#### Podiatric

An Enumeration member

Podiatry is the care of the human foot, especially the diagnosis and treatment of foot disorders.

Member of Enumeration: MedicalSpecialty
[^top]

#### PoliceStation

A police station.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Pond

A pond.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PostOffice

A post office.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PostalAddress

The mailing address.

Properties used on this type:

- addressCountry
- addressLocality
- addressRegion
- postOfficeBoxNumber
- postalCode
- streetAddress

Properties whose values are of this type:

- address
- billingAddress
- deliveryAddress
- gameLocation
- itemLocation
- location
- originAddress
- servicePostalAddress

[^top]

#### PostalCodeRangeSpecification

Indicates a range of postalcodes, usually defined as the set of valid codes between postalCodeBegin and postalCodeEnd, inclusively.

Properties used on this type:

- postalCodeBegin
- postalCodeEnd

Properties whose values are of this type:

- postalCodeRange

[^top]

#### Poster

A large, usually printed placard, bill, or announcement, often illustrated, that is posted to advertise or publicize something.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PotentialActionStatus

An Enumeration member

A description of an action that is supported.

Member of Enumeration: ActionStatusType
[^top]

#### PreOrder

An Enumeration member

Indicates that the item is available for pre-order.

Member of Enumeration: ItemAvailability
[^top]

#### PreOrderAction

An agent orders a (not yet released) object/product/service to be delivered/sent.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PreSale

An Enumeration member

Indicates that the item is available for ordering and delivery before general availability.

Member of Enumeration: ItemAvailability
[^top]

#### PregnancyHealthAspect

An Enumeration member

Content discussing pregnancy-related aspects of a health topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### PrependAction

The act of inserting at the beginning if an ordered collection.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Preschool

A preschool.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PrescriptionOnly

An Enumeration member

Available by prescription only.

Member of Enumeration: DrugPrescriptionStatus
[^top]

#### PresentationDigitalDocument

A file containing slides or used for a presentation.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PreventionHealthAspect

An Enumeration member

Information about actions or measures that can be taken to avoid getting the topic or reaching a critical situation related to the topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### PreventionIndication

An indication for preventing an underlying condition, symptom, etc.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PriceComponentTypeEnumeration

An Enumeration

Enumerates different price components that together make up the total price for an offered product.

Properties used on this type:

Enumeration members of this type:

- ActivationFee
- CleaningFee
- DistanceFee
- Downpayment
- Installment
- Subscription

Properties whose values are of this type:

- priceComponentType

[^top]

#### PriceSpecification

A structured value representing a price or price range. Typically, only the subclasses of this type are used for markup. It is recommended to use MonetaryAmount to describe independent amounts of money such as a salary, credit card limits, etc.

Properties used on this type:

- eligibleQuantity
- eligibleTransactionVolume
- maxPrice
- minPrice
- price
- priceCurrency
- validFrom
- validThrough
- valueAddedTaxIncluded

Properties whose values are of this type:

- baseSalary
- eligibleTransactionVolume
- healthPlanCopay
- minimumPaymentDue
- netWorth
- priceSpecification
- totalPaymentDue
- totalPrice

[^top]

#### PriceTypeEnumeration

An Enumeration

Enumerates different price types, for example list price, invoice price, and sale price.

Properties used on this type:

Enumeration members of this type:

- InvoicePrice
- ListPrice
- MSRP
- MinimumAdvertisedPrice
- SRP
- SalePrice

Properties whose values are of this type:

- priceType

[^top]

#### PrimaryCare

An Enumeration member

The medical care by a physician, or other health-care professional, who is the patient's first contact with the health-care system and who may recommend a specialist if necessary.

Member of Enumeration: MedicalSpecialty
[^top]

#### Prion

An Enumeration member

A prion is an infectious agent composed of protein in a misfolded form.

Member of Enumeration: InfectiousAgentClass
[^top]

#### Product

Any offered product or service. For example: a pair of shoes; a concert ticket; the rental of a car; a haircut; or an episode of a TV show streamed online.

Properties used on this type:

- additionalProperty
- aggregateRating
- audience
- award
- awards
- brand
- category
- color
- depth
- gtin
- gtin12
- gtin13
- gtin14
- gtin8
- hasEnergyConsumptionDetails
- hasMeasurement
- hasMerchantReturnPolicy
- hasProductReturnPolicy
- height
- inProductGroupWithID
- isAccessoryOrSparePartFor
- isConsumableFor
- isRelatedTo
- isSimilarTo
- isVariantOf
- itemCondition
- logo
- manufacturer
- material
- model
- mpn
- nsn
- offers
- pattern
- productID
- productionDate
- purchaseDate
- releaseDate
- review
- reviews
- size
- sku
- slogan
- weight
- width

Properties whose values are of this type:

- hasVariant
- isAccessoryOrSparePartFor
- isBasedOn
- isBasedOnUrl
- isConsumableFor
- isRelatedTo
- isSimilarTo
- itemOffered
- itemShipped
- material
- orderedItem
- owns
- productSupported
- typeOfGood

[^top]

#### ProductCollection

A set of products (either ProductGroups or specific variants) that are listed together e.g. in an Offer.

Properties used on this type:

- includesObject

Properties whose values are of this type:

[^top]

#### ProductGroup

A ProductGroup represents a group of Products that vary only in certain well-described ways, such as by size, color, material etc.
While a ProductGroup itself is not directly offered for sale, the various varying products that it represents can be. The ProductGroup serves as a prototype or template, standing in for all of the products who have an isVariantOf relationship to it. As such, properties (including additional types) can be applied to the ProductGroup to represent characteristics shared by each of the (possibly very many) variants. Properties that reference a ProductGroup are not included in this mechanism; neither are the following specific properties variesBy, hasVariant, url.

Properties used on this type:

- hasVariant
- productGroupID
- variesBy

Properties whose values are of this type:

- isVariantOf

[^top]

#### ProductModel

A datasheet or vendor specification of a product (in the sense of a prototypical description).

Properties used on this type:

- isVariantOf
- predecessorOf
- successorOf

Properties whose values are of this type:

- isVariantOf
- model
- predecessorOf
- successorOf

[^top]

#### ProfessionalService

Original definition: "provider of professional services."
The general ProfessionalService type for local businesses was deprecated due to confusion with Service. For reference, the types that it included were: Dentist, AccountingService, Attorney, Notary, as well as types for several kinds of HomeAndConstructionBusiness: Electrician, GeneralContractor, HousePainter, Locksmith, Plumber, RoofingContractor. LegalService was introduced as a more inclusive supertype of Attorney.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ProfilePage

Web page type: Profile page.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PrognosisHealthAspect

An Enumeration member

Typical progression and happenings of life course of the topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### ProgramMembership

Used to describe membership in a loyalty programs (e.g. "StarAliance"), traveler clubs (e.g. "AAA"), purchase clubs ("Safeway Club"), etc.

Properties used on this type:

- hostingOrganization
- member
- members
- membershipNumber
- membershipPointsEarned
- programName

Properties whose values are of this type:

- memberOf
- programMembershipUsed

[^top]

#### Project

An enterprise (potentially individual but typically collaborative), planned to achieve a particular aim. Use properties from Organization, subOrganization/parentOrganization to indicate project sub-structures.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PronounceableText

Data type: PronounceableText.

Properties used on this type:

- inLanguage
- phoneticText
- speechToTextMarkup
- textValue

Properties whose values are of this type:

[^top]

#### Property

A property, used to indicate attributes and relationships of some Thing; equivalent to rdf:Property.

Properties used on this type:

- domainIncludes
- inverseOf
- rangeIncludes
- supersededBy

Properties whose values are of this type:

- inverseOf
- measuredProperty
- supersededBy

[^top]

#### PropertyValue

A property-value pair, e.g. representing a feature of a product or place. Use the 'name' property for the name of the property. If there is an additional human-readable version of the value, put that into the 'description' property.
Always use specific schema.org properties when a) they exist and b) you can populate them. Using PropertyValue as a substitute will typically not trigger the same effect as using the original, specific property.

Properties used on this type:

- maxValue
- measurementTechnique
- minValue
- propertyID
- unitCode
- unitText
- value
- valueReference

Properties whose values are of this type:

- additionalProperty
- exifData
- identifier
- valueReference
- variableMeasured
- variablesMeasured

[^top]

#### PropertyValueSpecification

A Property value specification.

Properties used on this type:

- defaultValue
- maxValue
- minValue
- multipleValues
- readonlyValue
- stepValue
- valueMaxLength
- valueMinLength
- valueName
- valuePattern
- valueRequired

Properties whose values are of this type:

[^top]

#### Protozoa

An Enumeration member

Single-celled organism that causes an infection.

Member of Enumeration: InfectiousAgentClass
[^top]

#### Psychiatric

An Enumeration member

A specific branch of medical science that is concerned with the study, treatment, and prevention of mental illness, using both medical and psychological therapies.

Member of Enumeration: MedicalSpecialty
[^top]

#### PsychologicalTreatment

A process of care relying upon counseling, dialogue and communication aimed at improving a mental health condition without use of drugs.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PublicHealth

An Enumeration member

Branch of medicine that pertains to the health services to improve and protect community health, especially epidemiology, sanitation, immunization, and preventive medicine.

Member of Enumeration: MedicalSpecialty
[^top]

#### PublicHolidays

An Enumeration member

This stands for any day that is a public holiday; it is a placeholder for all official public holidays in some particular location. While not technically a "day of the week", it can be used with OpeningHoursSpecification. In the context of an opening hours specification it can be used to indicate opening hours on public holidays, overriding general opening hours for the day of the week on which a public holiday occurs.

Member of Enumeration: DayOfWeek
[^top]

#### PublicSwimmingPool

A public swimming pool.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PublicToilet

A public toilet is a room or small building containing one or more toilets (and possibly also urinals) which is available for use by the general public, or by customers or employees of certain businesses.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### PublicationEvent

A PublicationEvent corresponds indifferently to the event of publication for a CreativeWork of any type e.g. a broadcast event, an on-demand event, a book/journal publication via a variety of delivery media.

Properties used on this type:

- free
- publishedBy
- publishedOn

Properties whose values are of this type:

- publication
- releasedEvent

[^top]

#### PublicationIssue

A part of a successively published publication such as a periodical or publication volume, often numbered, usually containing a grouping of works such as articles.
See also blog post.

Properties used on this type:

- issueNumber
- pageEnd
- pageStart
- pagination

Properties whose values are of this type:

[^top]

#### PublicationVolume

A part of a successively published publication such as a periodical or multi-volume work, often numbered. It may represent a time span, such as a year.
See also blog post.

Properties used on this type:

- pageEnd
- pageStart
- pagination
- volumeNumber

Properties whose values are of this type:

[^top]

#### Pulmonary

An Enumeration member

A specific branch of medical science that pertains to the study of the respiratory system and its respective disease states.

Member of Enumeration: MedicalSpecialty
[^top]

#### QAPage

A QAPage is a WebPage focussed on a specific Question and its Answer(s), e.g. in a question answering site or documenting Frequently Asked Questions (FAQs).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### QualitativeValue

An Enumeration

A predefined value for a product characteristic, e.g. the power cord plug type 'US' or the garment sizes 'S', 'M', 'L', and 'XL'.

Properties used on this type:

- additionalProperty
- equal
- greater
- greaterOrEqual
- lesser
- lesserOrEqual
- nonEqual
- valueReference

Enumeration members of this type:

Properties whose values are of this type:

- bodyType
- broadcastSignalModulation
- costPerUnit
- doseValue
- engineType
- equal
- fuelType
- greater
- greaterOrEqual
- lesser
- lesserOrEqual
- lodgingUnitType
- meetsEmissionStandard
- nonEqual
- passengerPriorityStatus
- seatingType
- valueReference
- vehicleTransmission

[^top]

#### QuantitativeValue

A point value or interval for product characteristics and other purposes.

Properties used on this type:

- additionalProperty
- maxValue
- minValue
- unitCode
- unitText
- value
- valueReference

Properties whose values are of this type:

- accelerationTime
- activityDuration
- activityFrequency
- advanceBookingRequirement
- annualPercentageRate
- billingDuration
- broadcastFrequencyValue
- cargoVolume
- deliveryLeadTime
- depth
- durationOfWarranty
- eligibleDuration
- eligibleQuantity
- engineDisplacement
- enginePower
- floorSize
- fuelCapacity
- fuelConsumption
- fuelEfficiency
- handlingTime
- hasMeasurement
- height
- intensity
- interestRate
- inventoryLevel
- leaseLength
- loanTerm
- marginOfError
- materialExtent
- membershipPointsEarned
- mileageFromOdometer
- numAdults
- numChildren
- numberOfAccommodationUnits
- numberOfAvailableAccommodationUnits
- numberOfAxles
- numberOfBedrooms
- numberOfDoors
- numberOfEmployees
- numberOfForwardGears
- numberOfPlayers
- numberOfPreviousOwners
- numberOfRooms
- occupancy
- partySize
- payload
- recipeYield
- referenceQuantity
- repetitions
- requiredQuantity
- restPeriods
- roofLoad
- seatingCapacity
- size
- speed
- stupidProperty
- suggestedAge
- suggestedMeasurement
- tongueWeight
- torque
- trailerWeight
- transitTime
- valueReference
- vehicleSeatingCapacity
- weight
- weightTotal
- wheelbase
- width
- workload
- yearlyRevenue
- yearsInOperation
- yield

[^top]

#### QuantitativeValueDistribution

A statistical distribution of values.

Properties used on this type:

- duration
- median
- percentile10
- percentile25
- percentile75
- percentile90

Properties whose values are of this type:

[^top]

#### Quantity

Quantities such as distance, time, mass, weight, etc. Particular instances of say Mass are entities like '3 Kg' or '4 milligrams'.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Question

A specific question - e.g. from a user seeking answers online, or collected in a Frequently Asked Questions (FAQ) document.

Properties used on this type:

- acceptedAnswer
- answerCount
- eduQuestionType
- suggestedAnswer

Properties whose values are of this type:

- question

[^top]

#### Quiz

Quiz: A test of knowledge, skills and abilities.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Quotation

A quotation. Often but not necessarily from some written work, attributable to a real world author and - if associated with a fictional character - to any fictional Person. Use isBasedOn to link to source/origin. The recordedIn property can be used to reference a Quotation from an Event.

Properties used on this type:

- spokenByCharacter

Properties whose values are of this type:

[^top]

#### QuoteAction

An agent quotes/estimates/appraises an object/product/service with a price at a location/store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### RVPark

A place offering space for "Recreational Vehicles", Caravans, mobile homes and the like.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### RadiationTherapy

A process of care using radiation aimed at improving a health condition.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### RadioBroadcastService

A delivery service through which radio content is provided via broadcast over the air or online.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### RadioChannel

A unique instance of a radio BroadcastService on a CableOrSatelliteService lineup.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### RadioClip

A short radio program or a segment/part of a radio program.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### RadioEpisode

A radio episode which can be part of a series or season.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### RadioSeason

Season dedicated to radio broadcast and associated online delivery.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### RadioSeries

CreativeWorkSeries dedicated to radio broadcast and associated online delivery.

Properties used on this type:

- actor
- actors
- containsSeason
- director
- directors
- episode
- episodes
- musicBy
- numberOfEpisodes
- numberOfSeasons
- productionCompany
- season
- seasons
- trailer

Properties whose values are of this type:

[^top]

#### RadioStation

A radio station.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Radiography

An Enumeration member

Radiography is an imaging technique that uses electromagnetic radiation other than visible light, especially X-rays, to view the internal structure of a non-uniformly composed and opaque object such as the human body.

Member of Enumeration: MedicalImagingTechnique
[^top]

#### RandomizedTrial

An Enumeration member

A randomized trial design.

Member of Enumeration: MedicalTrialDesign
[^top]

#### Rating

A rating is an evaluation on a numeric scale, such as 1 to 5 stars.

Properties used on this type:

- author
- bestRating
- ratingExplanation
- ratingValue
- reviewAspect
- worstRating

Properties whose values are of this type:

- contentRating
- reviewRating
- starRating

[^top]

#### ReactAction

The act of responding instinctively and emotionally to an object, expressing a sentiment.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ReadAction

The act of consuming written content.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ReadPermission

An Enumeration member

Permission to read or view the document.

Member of Enumeration: DigitalDocumentPermissionType
[^top]

#### RealEstateAgent

A real-estate agent.

Properties used on this type:

Properties whose values are of this type:

- realEstateAgent

[^top]

#### RealEstateListing

A RealEstateListing is a listing that describes one or more real-estate Offers (whose businessFunction is typically to lease out, or to sell). The RealEstateListing type itself represents the overall listing, as manifested in some WebPage.

Properties used on this type:

- datePosted
- leaseLength

Properties whose values are of this type:

[^top]

#### RearWheelDriveConfiguration

An Enumeration member

Real-wheel drive is a transmission layout where the engine drives the rear wheels.

Member of Enumeration: DriveWheelConfigurationValue
[^top]

#### ReceiveAction

The act of physically/electronically taking delivery of an object that has been transferred from an origin to a destination. Reciprocal of SendAction.
Related actions:

- SendAction: The reciprocal of ReceiveAction.
- TakeAction: Unlike TakeAction, ReceiveAction does not imply that the ownership has been transfered (e.g. I can receive a package, but it does not mean the package is now mine).

Properties used on this type:

- deliveryMethod
- sender

Properties whose values are of this type:

[^top]

#### Recipe

A recipe. For dietary restrictions covered by the recipe, a few common restrictions are enumerated via suitableForDiet. The keywords property can also be used to add more detail.

Properties used on this type:

- cookTime
- cookingMethod
- ingredients
- nutrition
- recipeCategory
- recipeCuisine
- recipeIngredient
- recipeInstructions
- recipeYield
- suitableForDiet

Properties whose values are of this type:

- recipe

[^top]

#### Recommendation

Recommendation is a type of Review that suggests or proposes something as the best option or best course of action. Recommendations may be for products or services, or other concrete things, as in the case of a ranked list or product guide. A Guide may list multiple recommendations for different categories. For example, in a Guide about which TVs to buy, the author may have several Recommendations.

Properties used on this type:

- category

Properties whose values are of this type:

[^top]

#### RecommendedDoseSchedule

A recommended dosing schedule for a drug or supplement as prescribed or recommended by an authority or by the drug/supplement's manufacturer. Capture the recommending authority in the recognizingAuthority property of MedicalEntity.

Properties used on this type:

Properties whose values are of this type:

- recommendedIntake

[^top]

#### Recruiting

An Enumeration member

Recruiting participants.

Member of Enumeration: MedicalStudyStatus
[^top]

#### RecyclingCenter

A recycling center.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### RefundTypeEnumeration

An Enumeration

RefundTypeEnumeration enumerates several kinds of product return refund types.

Properties used on this type:

Enumeration members of this type:

- ExchangeRefund
- FullRefund
- StoreCreditRefund

Properties whose values are of this type:

- refundType

[^top]

#### RefurbishedCondition

An Enumeration member

Indicates that the item is refurbished.

Member of Enumeration: OfferItemCondition
[^top]

#### RegisterAction

The act of registering to be a user of a service, product or web page.
Related actions:

- JoinAction: Unlike JoinAction, RegisterAction implies you are registering to be a user of a service, not a group/team of people.
- [FollowAction]]: Unlike FollowAction, RegisterAction doesn't imply that the agent is expecting to poll for updates from the object.
- SubscribeAction: Unlike SubscribeAction, RegisterAction doesn't imply that the agent is expecting updates from the object.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Registry

An Enumeration member

A registry-based study design.

Member of Enumeration: MedicalObservationalStudyDesign
[^top]

#### ReimbursementCap

An Enumeration member

The drug's cost represents the maximum reimbursement paid by an insurer for the drug.

Member of Enumeration: DrugCostCategory
[^top]

#### RejectAction

The act of rejecting to/adopting an object.
Related actions:

- AcceptAction: The antonym of RejectAction.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### RelatedTopicsHealthAspect

An Enumeration member

Other prominent or relevant topics tied to the main topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### RemixAlbum

An Enumeration member

RemixAlbum.

Member of Enumeration: MusicAlbumProductionType
[^top]

#### Renal

An Enumeration member

A specific branch of medical science that pertains to the study of the kidneys and its respective disease states.

Member of Enumeration: MedicalSpecialty
[^top]

#### RentAction

The act of giving money in return for temporary use, but not ownership, of an object such as a vehicle or property. For example, an agent rents a property from a landlord in exchange for a periodic payment.

Properties used on this type:

- landlord
- realEstateAgent

Properties whose values are of this type:

[^top]

#### RentalCarReservation

A reservation for a rental car.
Note: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations.

Properties used on this type:

- dropoffLocation
- dropoffTime
- pickupLocation
- pickupTime

Properties whose values are of this type:

[^top]

#### RentalVehicleUsage

An Enumeration member

Indicates the usage of the vehicle as a rental car.

Member of Enumeration: CarUsageType
[^top]

#### RepaymentSpecification

A structured value representing repayment.

Properties used on this type:

- downPayment
- earlyPrepaymentPenalty
- loanPaymentAmount
- loanPaymentFrequency
- numberOfLoanPayments

Properties whose values are of this type:

- loanRepaymentForm

[^top]

#### ReplaceAction

The act of editing a recipient by replacing an old object with a new object.

Properties used on this type:

- replacee
- replacer

Properties whose values are of this type:

[^top]

#### ReplyAction

The act of responding to a question/message asked/sent by the object. Related to AskAction
Related actions:

- AskAction: Appears generally as an origin of a ReplyAction.

Properties used on this type:

- resultComment

Properties whose values are of this type:

[^top]

#### Report

A Report generated by governmental or non-governmental organization.

Properties used on this type:

- reportNumber

Properties whose values are of this type:

[^top]

#### ReportageNewsArticle

The ReportageNewsArticle type is a subtype of NewsArticle representing news articles which are the result of journalistic news reporting conventions.
In practice many news publishers produce a wide variety of article types, many of which might be considered a NewsArticle but not a ReportageNewsArticle. For example, opinion pieces, reviews, analysis, sponsored or satirical articles, or articles that combine several of these elements.
The ReportageNewsArticle type is based on a stricter ideal for "news" as a work of journalism, with articles based on factual information either observed or verified by the author, or reported and verified from knowledgeable sources. This often includes perspectives from multiple viewpoints on a particular issue (distinguishing news reports from public relations or propaganda). News reports in the ReportageNewsArticle sense de-emphasize the opinion of the author, with commentary and value judgements typically expressed elsewhere.
A ReportageNewsArticle which goes deeper into analysis can also be marked with an additional type of AnalysisNewsArticle.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ReportedDoseSchedule

A patient-reported or observed dosing schedule for a drug or supplement.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ResearchProject

A Research project.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Researcher

Researchers.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Reservation

Describes a reservation for travel, dining or an event. Some reservations require tickets.
Note: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations. For offers of tickets, restaurant reservations, flights, or rental cars, use Offer.

Properties used on this type:

- bookingAgent
- bookingTime
- broker
- modifiedTime
- priceCurrency
- programMembershipUsed
- provider
- reservationFor
- reservationId
- reservationStatus
- reservedTicket
- totalPrice
- underName

Properties whose values are of this type:

- subReservation

[^top]

#### ReservationCancelled

An Enumeration member

The status for a previously confirmed reservation that is now cancelled.

Member of Enumeration: ReservationStatusType
[^top]

#### ReservationConfirmed

An Enumeration member

The status of a confirmed reservation.

Member of Enumeration: ReservationStatusType
[^top]

#### ReservationHold

An Enumeration member

The status of a reservation on hold pending an update like credit card number or flight changes.

Member of Enumeration: ReservationStatusType
[^top]

#### ReservationPackage

A group of multiple reservations with common values for all sub-reservations.

Properties used on this type:

- subReservation

Properties whose values are of this type:

[^top]

#### ReservationPending

An Enumeration member

The status of a reservation when a request has been sent, but not confirmed.

Member of Enumeration: ReservationStatusType
[^top]

#### ReservationStatusType

An Enumeration

Enumerated status values for Reservation.

Properties used on this type:

Enumeration members of this type:

- ReservationCancelled
- ReservationConfirmed
- ReservationHold
- ReservationPending

Properties whose values are of this type:

- reservationStatus

[^top]

#### ReserveAction

Reserving a concrete object.
Related actions:

- ScheduleAction: Unlike ScheduleAction, ReserveAction reserves concrete objects (e.g. a table, a hotel) towards a time slot / spatial allocation.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Reservoir

A reservoir of water, typically an artificially created lake, like the Lake Kariba reservoir.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Residence

The place where a person lives.

Properties used on this type:

- accommodationFloorPlan

Properties whose values are of this type:

[^top]

#### Resort

A resort is a place used for relaxation or recreation, attracting visitors for holidays or vacations. Resorts are places, towns or sometimes commercial establishment operated by a single company (Source: Wikipedia, the free encyclopedia, see http://en.wikipedia.org/wiki/Resort).
See also the dedicated document on the use of schema.org for marking up hotels and other forms of accommodations.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### RespiratoryTherapy

An Enumeration member

The therapy that is concerned with the maintenance or improvement of respiratory function (as in patients with pulmonary disease).

Member of Enumeration: MedicalSpecialty
[^top]

#### Restaurant

A restaurant.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### RestockingFees

An Enumeration member

RestockingFees ...

Member of Enumeration: ReturnFeesEnumeration
[^top]

#### RestrictedDiet

An Enumeration

A diet restricted to certain foods or preparations for cultural, religious, health or lifestyle reasons.

Properties used on this type:

Enumeration members of this type:

- DiabeticDiet
- GlutenFreeDiet
- HalalDiet
- HinduDiet
- KosherDiet
- LowCalorieDiet
- LowFatDiet
- LowLactoseDiet
- LowSaltDiet
- VeganDiet
- VegetarianDiet

Properties whose values are of this type:

- suitableForDiet

[^top]

#### ResultsAvailable

An Enumeration member

Results are available.

Member of Enumeration: MedicalStudyStatus
[^top]

#### ResultsNotAvailable

An Enumeration member

Results are not available.

Member of Enumeration: MedicalStudyStatus
[^top]

#### ResumeAction

The act of resuming a device or application which was formerly paused (e.g. resume music playback or resume a timer).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Retail

An Enumeration member

The drug's cost represents the retail cost of the drug.

Member of Enumeration: DrugCostCategory
[^top]

#### ReturnAction

The act of returning to the origin that which was previously received (concrete objects) or taken (ownership).

Properties used on this type:

- recipient

Properties whose values are of this type:

[^top]

#### ReturnFeesEnumeration

An Enumeration

ReturnFeesEnumeration expresses policies for return fees.

Properties used on this type:

Enumeration members of this type:

- OriginalShippingFees
- RestockingFees
- ReturnShippingFees

Properties whose values are of this type:

- returnFees

[^top]

#### ReturnShippingFees

An Enumeration member

ReturnShippingFees ...

Member of Enumeration: ReturnFeesEnumeration
[^top]

#### Review

A review of an item - for example, of a restaurant, movie, or store.

Properties used on this type:

- itemReviewed
- reviewAspect
- reviewBody
- reviewRating

Properties whose values are of this type:

- resultReview
- review
- reviews

[^top]

#### ReviewAction

The act of producing a balanced opinion about the object for an audience. An agent reviews an object with participants resulting in a review.

Properties used on this type:

- resultReview

Properties whose values are of this type:

[^top]

#### ReviewNewsArticle

A NewsArticle and CriticReview providing a professional critic's assessment of a service, product, performance, or artistic or literary work.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Rheumatologic

An Enumeration member

A specific branch of medical science that deals with the study and treatment of rheumatic, autoimmune or joint diseases.

Member of Enumeration: MedicalSpecialty
[^top]

#### RightHandDriving

An Enumeration member

The steering position is on the right side of the vehicle (viewed from the main direction of driving).

Member of Enumeration: SteeringPositionValue
[^top]

#### RisksOrComplicationsHealthAspect

An Enumeration member

Information about the risk factors and possible complications that may follow a topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### RiverBodyOfWater

A river (for example, the broad majestic Shannon).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Role

Represents additional information about a relationship or property. For example a Role can be used to say that a 'member' role linking some SportsTeam to a player occurred during a particular time period. Or that a Person's 'actor' role in a Movie was for some particular characterName. Such properties can be attached to a Role entity, which is then associated with the main entities using ordinary properties like 'member' or 'actor'.
See also blog post.

Properties used on this type:

- endDate
- namedPosition
- roleName
- startDate

Properties whose values are of this type:

[^top]

#### RoofingContractor

A roofing contractor.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Room

A room is a distinguishable space within a structure, usually separated from other spaces by interior walls. (Source: Wikipedia, the free encyclopedia, see http://en.wikipedia.org/wiki/Room).
See also the dedicated document on the use of schema.org for marking up hotels and other forms of accommodations.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### RsvpAction

The act of notifying an event organizer as to whether you expect to attend the event.

Properties used on this type:

- additionalNumberOfGuests
- comment
- rsvpResponse

Properties whose values are of this type:

[^top]

#### RsvpResponseMaybe

An Enumeration member

The invitee may or may not attend.

Member of Enumeration: RsvpResponseType
[^top]

#### RsvpResponseNo

An Enumeration member

The invitee will not attend.

Member of Enumeration: RsvpResponseType
[^top]

#### RsvpResponseType

An Enumeration

RsvpResponseType is an enumeration type whose instances represent responding to an RSVP request.

Properties used on this type:

Enumeration members of this type:

- RsvpResponseMaybe
- RsvpResponseNo
- RsvpResponseYes

Properties whose values are of this type:

- rsvpResponse

[^top]

#### RsvpResponseYes

An Enumeration member

The invitee will attend.

Member of Enumeration: RsvpResponseType
[^top]

#### SRP

An Enumeration member

Represents the suggested retail price ("SRP") of an offered product.

Member of Enumeration: PriceTypeEnumeration
[^top]

#### SafetyHealthAspect

An Enumeration member

Content about the safety-related aspects of a health topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### SaleEvent

Event type: Sales event.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### SalePrice

An Enumeration member

Represents a sale price (usually active for a limited period) of an offered product.

Member of Enumeration: PriceTypeEnumeration
[^top]

#### SatireOrParodyContent

An Enumeration member

Content coded 'satire or content' in a MediaReview, considered in the context of how it was published or shared.
For a VideoObject to be 'satire or parody content': A video that was created as political or humorous commentary and is presented in that context. (Reshares of satire/parody content that do not include relevant context are more likely to fall under the “missing context” rating.)
For an ImageObject to be 'satire or parody content': An image that was created as political or humorous commentary and is presented in that context. (Reshares of satire/parody content that do not include relevant context are more likely to fall under the “missing context” rating.)
For an ImageObject with embedded text to be 'satire or parody content': An image that was created as political or humorous commentary and is presented in that context. (Reshares of satire/parody content that do not include relevant context are more likely to fall under the “missing context” rating.)
For an AudioObject to be 'satire or parody content': Audio that was created as political or humorous commentary and is presented in that context. (Reshares of satire/parody content that do not include relevant context are more likely to fall under the “missing context” rating.)

Member of Enumeration: MediaManipulationRatingEnumeration
[^top]

#### SatiricalArticle

An Article whose content is primarily [satirical] in nature, i.e. unlikely to be literally true. A satirical article is sometimes but not necessarily also a NewsArticle. ScholarlyArticles are also sometimes satirized.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Saturday

An Enumeration member

The day of the week between Friday and Sunday.

Member of Enumeration: DayOfWeek
[^top]

#### Schedule

A schedule defines a repeating time period used to describe a regularly occurring Event. At a minimum a schedule will specify repeatFrequency which describes the interval between occurences of the event. Additional information can be provided to specify the schedule more precisely. This includes identifying the day(s) of the week or month when the recurring event will take place, in addition to its start and end time. Schedules may also have start and end dates to indicate when they are active, e.g. to define a limited calendar of events.

Properties used on this type:

- byDay
- byMonth
- byMonthDay
- byMonthWeek
- duration
- endDate
- endTime
- exceptDate
- repeatCount
- repeatFrequency
- scheduleTimezone
- startDate
- startTime

Properties whose values are of this type:

- eventSchedule

[^top]

#### ScheduleAction

Scheduling future actions, events, or tasks.
Related actions:

- ReserveAction: Unlike ReserveAction, ScheduleAction allocates future actions (e.g. an event, a task, etc) towards a time slot / spatial allocation.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ScholarlyArticle

A scholarly article.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### School

A school.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### SchoolDistrict

A School District is an administrative area for the administration of schools.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ScreeningEvent

A screening of a movie or other video.

Properties used on this type:

- subtitleLanguage
- videoFormat
- workPresented

Properties whose values are of this type:

[^top]

#### ScreeningHealthAspect

An Enumeration member

Content about how to screen or further filter a topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### Sculpture

A piece of sculpture.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### SeaBodyOfWater

A sea (for example, the Caspian sea).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### SearchAction

The act of searching for an object.
Related actions:

- FindAction: SearchAction generally leads to a FindAction, but not necessarily.

Properties used on this type:

- query

Properties whose values are of this type:

[^top]

#### SearchResultsPage

Web page type: Search results page.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Season

A media season e.g. tv, radio, video game etc.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Seat

Used to describe a seat, such as a reserved seat in an event reservation.

Properties used on this type:

- seatNumber
- seatRow
- seatSection
- seatingType

Properties whose values are of this type:

- ticketedSeat

[^top]

#### SeatingMap

An Enumeration member

A seating map.

Member of Enumeration: MapCategoryType
[^top]

#### SeeDoctorHealthAspect

An Enumeration member

Information about questions that may be asked, when to see a professional, measures before seeing a doctor or content about the first consultation.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### SeekToAction

This is the Action of navigating to a specific startOffset timestamp within a VideoObject, typically represented with a URL template structure.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### SelfCareHealthAspect

An Enumeration member

Self care actions or measures that can be taken to sooth, health or avoid a topic. This may be carried at home and can be carried/managed by the person itself.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### SelfStorage

A self-storage facility.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### SellAction

The act of taking money from a buyer in exchange for goods or services rendered. An agent sells an object, product, or service to a buyer for a price. Reciprocal of BuyAction.

Properties used on this type:

- buyer
- warrantyPromise

Properties whose values are of this type:

[^top]

#### SendAction

The act of physically/electronically dispatching an object for transfer from an origin to a destination.Related actions:

- ReceiveAction: The reciprocal of SendAction.
- GiveAction: Unlike GiveAction, SendAction does not imply the transfer of ownership (e.g. I can send you my laptop, but I'm not necessarily giving it to you).

Properties used on this type:

- deliveryMethod
- recipient

Properties whose values are of this type:

[^top]

#### Series

A Series in schema.org is a group of related items, typically but not necessarily of the same kind. See also CreativeWorkSeries, EventSeries.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Service

A service provided by an organization, e.g. delivery service, print services, etc.

Properties used on this type:

- aggregateRating
- areaServed
- audience
- availableChannel
- award
- brand
- broker
- category
- hasOfferCatalog
- hoursAvailable
- isRelatedTo
- isSimilarTo
- logo
- offers
- produces
- provider
- providerMobility
- review
- serviceArea
- serviceAudience
- serviceOutput
- serviceType
- slogan
- termsOfService

Properties whose values are of this type:

- isRelatedTo
- isSimilarTo
- issuedThrough
- itemOffered
- orderedItem
- providesService
- typeOfGood

[^top]

#### ServiceChannel

A means for accessing a service, e.g. a government office location, web site, or phone number.

Properties used on this type:

- availableLanguage
- processingTime
- providesService
- serviceLocation
- servicePhone
- servicePostalAddress
- serviceSmsNumber
- serviceUrl

Properties whose values are of this type:

- availableChannel

[^top]

#### ShareAction

The act of distributing content to people for their amusement or edification.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### SheetMusic

Printed music, as opposed to performed or recorded music.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ShippingDeliveryTime

ShippingDeliveryTime provides various pieces of information about delivery times for shipping.

Properties used on this type:

- businessDays
- cutoffTime
- handlingTime
- transitTime

Properties whose values are of this type:

- deliveryTime

[^top]

#### ShippingRateSettings

A ShippingRateSettings represents re-usable pieces of shipping information. It is designed for publication on an URL that may be referenced via the shippingSettingsLink property of an OfferShippingDetails. Several occurrences can be published, distinguished and matched (i.e. identified/referenced) by their different values for shippingLabel.

Properties used on this type:

- doesNotShip
- freeShippingThreshold
- isUnlabelledFallback
- shippingDestination
- shippingLabel
- shippingRate

Properties whose values are of this type:

[^top]

#### ShoeStore

A shoe store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ShoppingCenter

A shopping center or mall.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### ShortStory

Short story or tale. A brief work of literature, usually written in narrative prose.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### SideEffectsHealthAspect

An Enumeration member

Side effects that can be observed from the usage of the topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### SingleBlindedTrial

An Enumeration member

A trial design in which the researcher knows which treatment the patient was randomly assigned to but the patient does not.

Member of Enumeration: MedicalTrialDesign
[^top]

#### SingleCenterTrial

An Enumeration member

A trial that takes place at a single center.

Member of Enumeration: MedicalTrialDesign
[^top]

#### SingleFamilyResidence

Residence type: Single-family home.

Properties used on this type:

- numberOfRooms
- occupancy

Properties whose values are of this type:

[^top]

#### SinglePlayer

An Enumeration member

Play mode: SinglePlayer. Which is played by a lone player.

Member of Enumeration: GamePlayMode
[^top]

#### SingleRelease

An Enumeration member

SingleRelease.

Member of Enumeration: MusicAlbumReleaseType
[^top]

#### SiteNavigationElement

A navigation element of the page.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### SizeGroupEnumeration

An Enumeration

Enumerates common size groups for various product categories.

Properties used on this type:

Enumeration members of this type:

Properties whose values are of this type:

- sizeGroup

[^top]

#### SizeSpecification

An Enumeration

Size related properties of a product, typically a size code (name) and optionally a sizeSystem, sizeGroup, and product measurements (hasMeasurement). In addition, the intended audience can be defined through suggestedAge, suggestedGender, and suggested body measurements (suggestedMeasurement).

Properties used on this type:

- hasMeasurement
- sizeGroup
- sizeSystem
- suggestedAge
- suggestedGender
- suggestedMeasurement

Enumeration members of this type:

Properties whose values are of this type:

- size

[^top]

#### SizeSystemEnumeration

An Enumeration

Enumerates common size systems for different categories of products, for example "EN-13402" or "UK" for wearables or "Imperial" for screws.

Properties used on this type:

Enumeration members of this type:

- SizeSystemImperial
- SizeSystemMetric

Properties whose values are of this type:

- sizeSystem

[^top]

#### SizeSystemImperial

An Enumeration member

Imperial size system.

Member of Enumeration: SizeSystemEnumeration
[^top]

#### SizeSystemMetric

An Enumeration member

Metric size system.

Member of Enumeration: SizeSystemEnumeration
[^top]

#### SkiResort

A ski resort.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Skin

An Enumeration member

Skin assessment with clinical examination.

Member of Enumeration: PhysicalExam
[^top]

#### SocialEvent

Event type: Social event.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### SocialMediaPosting

A post to a social media platform, including blog posts, tweets, Facebook posts, etc.

Properties used on this type:

- sharedContent

Properties whose values are of this type:

[^top]

#### SoftwareApplication

A software application.

Properties used on this type:

- applicationCategory
- applicationSubCategory
- applicationSuite
- availableOnDevice
- countriesNotSupported
- countriesSupported
- device
- downloadUrl
- featureList
- fileSize
- installUrl
- memoryRequirements
- operatingSystem
- permissions
- processorRequirements
- releaseNotes
- requirements
- screenshot
- softwareAddOn
- softwareHelp
- softwareRequirements
- softwareVersion
- storageRequirements
- supportingData

Properties whose values are of this type:

- actionApplication
- application
- interactionService
- softwareAddOn
- targetProduct

[^top]

#### SoftwareSourceCode

Computer programming source code. Example: Full (compile ready) solutions, code snippet samples, scripts, templates.

Properties used on this type:

- codeRepository
- codeSampleType
- programmingLanguage
- runtime
- runtimePlatform
- sampleType
- targetProduct

Properties whose values are of this type:

[^top]

#### SoldOut

An Enumeration member

Indicates that the item has sold out.

Member of Enumeration: ItemAvailability
[^top]

#### SolveMathAction

The action that takes in a math expression and directs users to a page potentially capable of solving/simplifying that expression.

Properties used on this type:

- eduQuestionType

Properties whose values are of this type:

- mathExpression

[^top]

#### SomeProducts

A placeholder for multiple similar products of the same kind.

Properties used on this type:

- inventoryLevel

Properties whose values are of this type:

[^top]

#### SoundtrackAlbum

An Enumeration member

SoundtrackAlbum.

Member of Enumeration: MusicAlbumProductionType
[^top]

#### SpeakableSpecification

A SpeakableSpecification indicates (typically via xpath or cssSelector) sections of a document that are highlighted as particularly speakable. Instances of this type are expected to be used primarily as values of the speakable property.

Properties used on this type:

- cssSelector
- xpath

Properties whose values are of this type:

- speakable

[^top]

#### SpecialAnnouncement

A SpecialAnnouncement combines a simple date-stamped textual information update with contextualized Web links and other structured data. It represents an information update made by a locally-oriented organization, for example schools, pharmacies, healthcare providers, community groups, police, local government.
For work in progress guidelines on Coronavirus-related markup see this doc.
The motivating scenario for SpecialAnnouncement is the Coronavirus pandemic, and the initial vocabulary is oriented to this urgent situation. Schema.org expect to improve the markup iteratively as it is deployed and as feedback emerges from use. In addition to our usual Github entry, feedback comments can also be provided in this document.
While this schema is designed to communicate urgent crisis-related information, it is not the same as an emergency warning technology like CAP, although there may be overlaps. The intent is to cover the kinds of everyday practical information being posted to existing websites during an emergency situation.
Several kinds of information can be provided:
We encourage the provision of "name", "text", "datePosted", "expires" (if appropriate), "category" and "url" as a simple baseline. It is important to provide a value for "category" where possible, most ideally as a well known URL from Wikipedia or Wikidata. In the case of the 2019-2020 Coronavirus pandemic, this should be "https://en.wikipedia.org/w/index.php?title=2019-20_coronavirus_pandemic" or "https://www.wikidata.org/wiki/Q81068910".
For many of the possible properties, values can either be simple links or an inline description, depending on whether a summary is available. For a link, provide just the URL of the appropriate page as the property's value. For an inline description, use a WebContent type, and provide the url as a property of that, alongside at least a simple "text" summary of the page. It is unlikely that a single SpecialAnnouncement will need all of the possible properties simultaneously.
We expect that in many cases the page referenced might contain more specialized structured data, e.g. contact info, openingHours, Event, FAQPage etc. By linking to those pages from a SpecialAnnouncement you can help make it clearer that the events are related to the situation (e.g. Coronavirus) indicated by the category property of the SpecialAnnouncement.
Many SpecialAnnouncements will relate to particular regions and to identifiable local organizations. Use spatialCoverage for the region, and announcementLocation to indicate specific LocalBusinesses and CivicStructures. If the announcement affects both a particular region and a specific location (for example, a library closure that serves an entire region), use both spatialCoverage and announcementLocation.
The about property can be used to indicate entities that are the focus of the announcement. We now recommend using about only for representing non-location entities (e.g. a Course or a RadioStation). For places, use announcementLocation and spatialCoverage. Consumers of this markup should be aware that the initial design encouraged the use of /about for locations too.
The basic content of SpecialAnnouncement is similar to that of an RSS or Atom feed. For publishers without such feeds, basic feed-like information can be shared by posting SpecialAnnouncement updates in a page, e.g. using JSON-LD. For sites with Atom/RSS functionality, you can point to a feed with the webFeed property. This can be a simple URL, or an inline DataFeed object, with encodingFormat providing media type information e.g. "application/rss+xml" or "application/atom+xml".

Properties used on this type:

- announcementLocation
- category
- datePosted
- diseasePreventionInfo
- diseaseSpreadStatistics
- gettingTestedInfo
- governmentBenefitsInfo
- newsUpdatesAndGuidelines
- publicTransportClosuresInfo
- quarantineGuidelines
- schoolClosuresInfo
- travelBans
- webFeed

Properties whose values are of this type:

[^top]

#### Specialty

An Enumeration

Any branch of a field in which people typically develop specific expertise, usually after significant study, time, and effort.

Properties used on this type:

Enumeration members of this type:

Properties whose values are of this type:

- specialty

[^top]

#### SpeechPathology

An Enumeration member

The scientific study and treatment of defects, disorders, and malfunctions of speech and voice, as stuttering, lisping, or lalling, and of language disturbances, as aphasia or delayed language acquisition.

Member of Enumeration: MedicalSpecialty
[^top]

#### SpokenWordAlbum

An Enumeration member

SpokenWordAlbum.

Member of Enumeration: MusicAlbumProductionType
[^top]

#### SportingGoodsStore

A sporting goods store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### SportsActivityLocation

A sports location, such as a playing field.

Properties used on this type:

Properties whose values are of this type:

- sportsActivityLocation

[^top]

#### SportsClub

A sports club.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### SportsEvent

Event type: Sports event.

Properties used on this type:

- awayTeam
- competitor
- homeTeam
- sport

Properties whose values are of this type:

- sportsEvent

[^top]

#### SportsOrganization

Represents the collection of all sports organizations, including sports teams, governing bodies, and sports associations.

Properties used on this type:

- sport

Properties whose values are of this type:

[^top]

#### SportsTeam

Organization: Sports team.

Properties used on this type:

- athlete
- coach
- gender

Properties whose values are of this type:

- awayTeam
- competitor
- homeTeam
- sportsTeam

[^top]

#### SpreadsheetDigitalDocument

A spreadsheet file.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### StadiumOrArena

A stadium.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### StagedContent

An Enumeration member

Content coded 'staged content' in a MediaReview, considered in the context of how it was published or shared.
For a VideoObject to be 'staged content': A video that has been created using actors or similarly contrived.
For an ImageObject to be 'staged content': An image that was created using actors or similarly contrived, such as a screenshot of a fake tweet.
For an ImageObject with embedded text to be 'staged content': An image that was created using actors or similarly contrived, such as a screenshot of a fake tweet.
For an AudioObject to be 'staged content': Audio that has been created using actors or similarly contrived.

Member of Enumeration: MediaManipulationRatingEnumeration
[^top]

#### StagesHealthAspect

An Enumeration member

Stages that can be observed from a topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### State

A state or province of a country.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### StatisticalPopulation

A StatisticalPopulation is a set of instances of a certain given type that satisfy some set of constraints. The property populationType is used to specify the type. Any property that can be used on instances of that type can appear on the statistical population. For example, a StatisticalPopulation representing all Persons with a homeLocation of East Podunk California, would be described by applying the appropriate homeLocation and populationType properties to a StatisticalPopulation item that stands for that set of people. The properties numConstraints and constrainingProperty are used to specify which of the populations properties are used to specify the population. Note that the sense of "population" used here is the general sense of a statistical population, and does not imply that the population consists of people. For example, a populationType of Event or NewsArticle could be used. See also Observation, and the data and datasets overview for more details.

Properties used on this type:

- constrainingProperty
- numConstraints
- populationType

Properties whose values are of this type:

- observedNode

[^top]

#### StatusEnumeration

An Enumeration

Lists or enumerations dealing with status types.

Properties used on this type:

Enumeration members of this type:

Properties whose values are of this type:

[^top]

#### SteeringPositionValue

An Enumeration

A value indicating a steering position.

Properties used on this type:

Enumeration members of this type:

- LeftHandDriving
- RightHandDriving

Properties whose values are of this type:

- steeringPosition

[^top]

#### Store

A retail good store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### StoreCreditRefund

An Enumeration member

A StoreCreditRefund ...

Member of Enumeration: RefundTypeEnumeration
[^top]

#### StrengthTraining

An Enumeration member

Physical activity that is engaged in to improve muscle and bone strength. Also referred to as resistance training.

Member of Enumeration: PhysicalActivityCategory
[^top]

#### StructuredValue

Structured values are used when the value of a property has a more complex structure than simply being a textual value or a reference to another thing.

Properties used on this type:

Properties whose values are of this type:

- numberOfCredits
- typicalCreditsPerTerm
- value
- valueReference

[^top]

#### StudioAlbum

An Enumeration member

StudioAlbum.

Member of Enumeration: MusicAlbumProductionType
[^top]

#### SubscribeAction

The act of forming a personal connection with someone/something (object) unidirectionally/asymmetrically to get updates pushed to.
Related actions:

- FollowAction: Unlike FollowAction, SubscribeAction implies that the subscriber acts as a passive agent being constantly/actively pushed for updates.
- RegisterAction: Unlike RegisterAction, SubscribeAction implies that the agent is interested in continuing receiving updates from the object.
- JoinAction: Unlike JoinAction, SubscribeAction implies that the agent is interested in continuing receiving updates from the object.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Subscription

An Enumeration member

Represents the subscription pricing component of the total price for an offered product.

Member of Enumeration: PriceComponentTypeEnumeration
[^top]

#### Substance

Any matter of defined composition that has discrete existence, whose origin may be biological, mineral or chemical.

Properties used on this type:

- activeIngredient
- maximumIntake

Properties whose values are of this type:

[^top]

#### SubwayStation

A subway station.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Suite

A suite in a hotel or other public accommodation, denotes a class of luxury accommodations, the key feature of which is multiple rooms (Source: Wikipedia, the free encyclopedia, see http://en.wikipedia.org/wiki/Suite_(hotel)).
See also the dedicated document on the use of schema.org for marking up hotels and other forms of accommodations.

Properties used on this type:

- bed
- numberOfRooms
- occupancy

Properties whose values are of this type:

[^top]

#### Sunday

An Enumeration member

The day of the week between Saturday and Monday.

Member of Enumeration: DayOfWeek
[^top]

#### SuperficialAnatomy

Anatomical features that can be observed by sight (without dissection), including the form and proportions of the human body as well as surface landmarks that correspond to deeper subcutaneous structures. Superficial anatomy plays an important role in sports medicine, phlebotomy, and other medical specialties as underlying anatomical structures can be identified through surface palpation. For example, during back surgery, superficial anatomy can be used to palpate and count vertebrae to find the site of incision. Or in phlebotomy, superficial anatomy can be used to locate an underlying vein; for example, the median cubital vein can be located by palpating the borders of the cubital fossa (such as the epicondyles of the humerus) and then looking for the superficial signs of the vein, such as size, prominence, ability to refill after depression, and feel of surrounding tissue support. As another example, in a subluxation (dislocation) of the glenohumeral joint, the bony structure becomes pronounced with the deltoid muscle failing to cover the glenohumeral joint allowing the edges of the scapula to be superficially visible. Here, the superficial anatomy is the visible edges of the scapula, implying the underlying dislocation of the joint (the related anatomical structure).

Properties used on this type:

- associatedPathophysiology
- relatedAnatomy
- relatedCondition
- relatedTherapy
- significance

Properties whose values are of this type:

- associatedAnatomy
- sensoryUnit

[^top]

#### Surgical

An Enumeration member

A specific branch of medical science that pertains to treating diseases, injuries and deformities by manual and instrumental means.

Member of Enumeration: MedicalSpecialty
[^top]

#### SurgicalProcedure

A medical procedure involving an incision with instruments; performed for diagnose, or therapeutic purposes.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### SuspendAction

The act of momentarily pausing a device or application (e.g. pause music playback or pause a timer).

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Suspended

An Enumeration member

Suspended.

Member of Enumeration: MedicalStudyStatus
[^top]

#### SymptomsHealthAspect

An Enumeration member

Symptoms or related symptoms of a Topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### Synagogue

A synagogue.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TVClip

A short TV program or a segment/part of a TV program.

Properties used on this type:

- partOfTVSeries

Properties whose values are of this type:

[^top]

#### TVEpisode

A TV episode which can be part of a series or season.

Properties used on this type:

- countryOfOrigin
- partOfTVSeries
- subtitleLanguage
- titleEIDR

Properties whose values are of this type:

[^top]

#### TVSeason

Season dedicated to TV broadcast and associated online delivery.

Properties used on this type:

- countryOfOrigin
- partOfTVSeries

Properties whose values are of this type:

[^top]

#### TVSeries

CreativeWorkSeries dedicated to TV broadcast and associated online delivery.

Properties used on this type:

- actor
- actors
- containsSeason
- countryOfOrigin
- director
- directors
- episode
- episodes
- musicBy
- numberOfEpisodes
- numberOfSeasons
- productionCompany
- season
- seasons
- trailer

Properties whose values are of this type:

- partOfTVSeries

[^top]

#### Table

A table on a Web page.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TakeAction

The act of gaining ownership of an object from an origin. Reciprocal of GiveAction.
Related actions:

- GiveAction: The reciprocal of TakeAction.
- ReceiveAction: Unlike ReceiveAction, TakeAction implies that ownership has been transfered.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TattooParlor

A tattoo parlor.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Taxi

A taxi.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TaxiReservation

A reservation for a taxi.
Note: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations. For offers of tickets, use Offer.

Properties used on this type:

- partySize
- pickupLocation
- pickupTime

Properties whose values are of this type:

[^top]

#### TaxiService

A service for a vehicle for hire with a driver for local travel. Fares are usually calculated based on distance traveled.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TaxiStand

A taxi stand.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TaxiVehicleUsage

An Enumeration member

Indicates the usage of the car as a taxi.

Member of Enumeration: CarUsageType
[^top]

#### TechArticle

A technical article - Example: How-to (task) topics, step-by-step, procedural troubleshooting, specifications, etc.

Properties used on this type:

- dependencies
- proficiencyLevel

Properties whose values are of this type:

[^top]

#### TelevisionChannel

A unique instance of a television BroadcastService on a CableOrSatelliteService lineup.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TelevisionStation

A television station.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TennisComplex

A tennis complex.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Terminated

An Enumeration member

Terminated.

Member of Enumeration: MedicalStudyStatus
[^top]

#### Text

A Datatype

Data type: Text.

Properties used on this type:

Properties whose values are of this type:

- abstract
- acceptsReservations
- accessCode
- accessMode
- accessibilityAPI
- accessibilityControl
- accessibilityFeature
- accessibilityHazard
- accessibilitySummary
- accommodationCategory
- accountId
- acrissCode
- actionOption
- actionPlatform
- activeIngredient
- activityFrequency
- additionalName
- additionalVariable
- address
- addressCountry
- addressLocality
- addressRegion
- administrationRoute
- aircraft
- alcoholWarning
- algorithm
- alignmentType
- alternateName
- alternativeHeadline
- applicationCategory
- applicationSubCategory
- applicationSuite
- areaServed
- arrivalGate
- arrivalPlatform
- arrivalTerminal
- artEdition
- artMedium
- artform
- articleBody
- articleSection
- artworkSurface
- aspect
- assembly
- assemblyVersion
- assesses
- associatedPathophysiology
- audienceType
- availableLanguage
- availableOnDevice
- award
- awards
- backstory
- bankAccountType
- bed
- beneficiaryBank
- benefits
- bestRating
- biomechnicalClass
- bitrate
- boardingGroup
- bodyLocation
- bodyType
- bookEdition
- box
- branchCode
- breadcrumb
- breastfeedingWarning
- broadcastChannelId
- broadcastDisplayName
- broadcastFrequency
- broadcastServiceTier
- broadcastSignalModulation
- broadcastSubChannel
- broadcastTimezone
- browserRequirements
- busName
- busNumber
- byDay
- callSign
- caption
- carrierRequirements
- catalogNumber
- category
- characterName
- circle
- citation
- claimReviewed
- clincalPharmacology
- clinicalPharmacology
- clipNumber
- codeSampleType
- codeValue
- codingSystem
- color
- commentText
- competencyRequired
- conditionsOfAccess
- confirmationNumber
- contactType
- contentRating
- contentSize
- contentType
- contraindication
- cookingMethod
- copyrightNotice
- correction
- costCurrency
- costOrigin
- costPerUnit
- countriesNotSupported
- countriesSupported
- courseCode
- courseMode
- coursePrerequisites
- courseWorkload
- creativeWorkStatus
- credentialCategory
- creditText
- currenciesAccepted
- currency
- cvdCollectionDate
- cvdFacilityCounty
- cvdFacilityId
- dataFeedElement
- dateline
- defaultValue
- departureGate
- departurePlatform
- departureTerminal
- dependencies
- description
- device
- dietFeatures
- disambiguatingDescription
- discount
- discountCode
- discountCurrency
- dosageForm
- doseUnit
- driveWheelConfiguration
- drugUnit
- duns
- editEIDR
- eduQuestionType
- educationRequirements
- educationalCredentialAwarded
- educationalFramework
- educationalLevel
- educationalProgramMode
- educationalRole
- educationalUse
- elevation
- eligibilityToWorkRequirement
- eligibleRegion
- email
- employerOverview
- employmentType
- encodingFormat
- encodingType
- engineType
- epidemiology
- episodeNumber
- estimatedCost
- estimatedFlightDuration
- evidenceOrigin
- executableLibraryName
- exerciseType
- exifData
- expectedPrognosis
- experienceRequirements
- expertConsiderations
- familyName
- faxNumber
- featureList
- feesAndCommissionsSpecification
- fileFormat
- fileSize
- financialAidEligible
- flightDistance
- flightNumber
- floorLevel
- followup
- foodWarning
- frequency
- fuelType
- functionalClass
- gamePlatform
- gender
- genre
- geoRadius
- givenName
- globalLocationNumber
- gtin
- gtin12
- gtin13
- gtin14
- gtin8
- hasMenu
- headline
- healthPlanCoinsuranceOption
- healthPlanCopayOption
- healthPlanDrugOption
- healthPlanDrugTier
- healthPlanId
- healthPlanNetworkId
- healthPlanNetworkTier
- healthPlanPharmacyCategory
- highPrice
- honorificPrefix
- honorificSuffix
- howPerformed
- httpMethod
- iataCode
- icaoCode
- identifier
- inLanguage
- inProductGroupWithID
- inSupportOf
- incentiveCompensation
- incentives
- industry
- ineligibleRegion
- infectiousAgent
- ingredients
- intensity
- interactivityType
- isbn
- isicV4
- isrcCode
- issn
- issueNumber
- iswcCode
- itemListElement
- itemListOrder
- itemLocation
- jobBenefits
- jobLocationType
- jobStartDate
- jobTitle
- jurisdiction
- keywords
- knownVehicleDamages
- knowsAbout
- knowsLanguage
- latitude
- learningResourceType
- legalName
- legalStatus
- legislationIdentifier
- legislationJurisdiction
- legislationType
- leiCode
- line
- linkRelationship
- loanType
- location
- lodgingUnitDescription
- lodgingUnitType
- longitude
- lowPrice
- material
- materialExtent
- mathExpression
- mealService
- measurementTechnique
- mechanismOfAction
- meetsEmissionStandard
- membershipNumber
- memoryRequirements
- menu
- model
- mpn
- muscleAction
- musicCompositionForm
- musicalKey
- naics
- name
- namedPosition
- naturalProgression
- nonProprietaryName
- normalRange
- nsn
- numberOfAirbags
- occupationalCategory
- occupationalCredentialAwarded
- openingHours
- operatingSystem
- option
- orderItemNumber
- orderNumber
- overdosage
- ownershipFundingInfo
- pageEnd
- pageStart
- pagination
- passengerPriorityStatus
- passengerSequenceNumber
- pathophysiology
- pattern
- paymentAccepted
- paymentMethodId
- paymentStatus
- permissions
- permittedUsage
- petsAllowed
- phoneticText
- physicalRequirement
- physiologicalBenefits
- playerType
- polygon
- position
- possibleComplication
- postOfficeBoxNumber
- postOp
- postalCode
- postalCodeBegin
- postalCodeEnd
- postalCodePrefix
- preOp
- pregnancyWarning
- preparation
- prescriptionStatus
- price
- priceCurrency
- priceRange
- priceType
- printColumn
- printEdition
- printPage
- printSection
- procedure
- processorRequirements
- productGroupID
- productID
- productSupported
- proficiencyLevel
- programName
- programPrerequisites
- programType
- programmingLanguage
- programmingModel
- propertyID
- proprietaryName
- providerMobility
- publicationType
- qualifications
- query
- ratingExplanation
- ratingValue
- recipeCategory
- recipeCuisine
- recipeIngredient
- recipeInstructions
- recipeYield
- recommendationStrength
- releaseNotes
- repeatFrequency
- reportNumber
- requiredCollateral
- requiredGender
- requiredQuantity
- requirements
- reservationId
- responsibilities
- restPeriods
- reviewAspect
- reviewBody
- risks
- roleName
- runtime
- runtimePlatform
- rxcui
- safetyConsideration
- salaryCurrency
- sampleType
- scheduleTimezone
- schemaVersion
- seasonNumber
- seatNumber
- seatRow
- seatSection
- seatingType
- securityClearanceRequirement
- securityScreening
- sensoryRequirement
- serialNumber
- servesCuisine
- serviceType
- servingSize
- shippingLabel
- significance
- size
- sizeGroup
- sizeSystem
- skills
- sku
- slogan
- softwareRequirements
- softwareVersion
- specialCommitments
- speechToTextMarkup
- sport
- status
- step
- steps
- storageRequirements
- streetAddress
- strengthUnit
- structuralClass
- subStageSuffix
- subtitleLanguage
- suggestedGender
- supply
- surface
- targetDescription
- targetName
- targetPlatform
- targetPopulation
- taxID
- teaches
- telephone
- temporal
- temporalCoverage
- termCode
- termsOfService
- text
- textValue
- tickerSymbol
- ticketNumber
- ticketToken
- timeOfDay
- tissueSample
- title
- titleEIDR
- tool
- totalPrice
- touristType
- trackingNumber
- trainName
- trainNumber
- transcript
- transitTimeLabel
- transmissionMethod
- typeOfBed
- typicalAgeRange
- unitCode
- unitText
- urlTemplate
- usesHealthPlanIdStandard
- utterances
- value
- valueName
- valuePattern
- valueReference
- variableMeasured
- variablesMeasured
- variantCover
- variesBy
- vatID
- vehicleConfiguration
- vehicleIdentificationNumber
- vehicleInteriorColor
- vehicleInteriorType
- vehicleSpecialUsage
- vehicleTransmission
- version
- videoFormat
- videoFrameSize
- videoQuality
- volumeNumber
- warning
- workHours
- worstRating
- yield

[^top]

#### TextDigitalDocument

A file composed primarily of text.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TheaterEvent

Event type: Theater performance.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TheaterGroup

A theater group or company, for example, the Royal Shakespeare Company or Druid Theatre.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Therapeutic

An Enumeration member

A medical device used for therapeutic purposes.

Member of Enumeration: MedicalDevicePurpose
[^top]

#### TherapeuticProcedure

A medical procedure intended primarily for therapeutic purposes, aimed at improving a health condition.

Properties used on this type:

- adverseOutcome
- doseSchedule
- drug

Properties whose values are of this type:

[^top]

#### Thesis

A thesis or dissertation document submitted in support of candidature for an academic degree or professional qualification.

Properties used on this type:

- inSupportOf

Properties whose values are of this type:

[^top]

#### Thing

The most generic type of item.

Properties used on this type:

- additionalType
- alternateName
- description
- disambiguatingDescription
- identifier
- image
- mainEntityOfPage
- name
- potentialAction
- sameAs
- subjectOf
- url

Properties whose values are of this type:

- about
- actionOption
- category
- characterAttribute
- collection
- dataFeedElement
- defaultValue
- error
- fundedItem
- gameItem
- gamePlatform
- instrument
- item
- itemListElement
- itemReviewed
- knowsAbout
- mainEntity
- mentions
- object
- option
- produces
- quest
- replacee
- replacer
- requiredCollateral
- reservationFor
- result
- serviceOutput
- targetCollection

[^top]

#### Throat

An Enumeration member

Throat assessment with clinical examination.

Member of Enumeration: PhysicalExam
[^top]

#### Thursday

An Enumeration member

The day of the week between Wednesday and Friday.

Member of Enumeration: DayOfWeek
[^top]

#### Ticket

Used to describe a ticket to an event, a flight, a bus ride, etc.

Properties used on this type:

- dateIssued
- issuedBy
- priceCurrency
- ticketNumber
- ticketToken
- ticketedSeat
- totalPrice
- underName

Properties whose values are of this type:

- reservedTicket

[^top]

#### TieAction

The act of reaching a draw in a competitive activity.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Time

A Datatype

A point in time recurring on multiple days in the form hh:mm:ss[Z|(+|-)hh:mm] (see XML schema for details).

Properties used on this type:

Properties whose values are of this type:

- arrivalTime
- availabilityEnds
- availabilityStarts
- checkinTime
- checkoutTime
- closes
- cutoffTime
- departureTime
- doorTime
- endTime
- opens
- startTime

[^top]

#### TipAction

The act of giving money voluntarily to a beneficiary in recognition of services rendered.

Properties used on this type:

- recipient

Properties whose values are of this type:

[^top]

#### TireShop

A tire shop.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TollFree

An Enumeration member

The associated telephone number is toll free.

Member of Enumeration: ContactPointOption
[^top]

#### TouristAttraction

A tourist attraction. In principle any Thing can be a TouristAttraction, from a Mountain and LandmarksOrHistoricalBuildings to a LocalBusiness. This Type can be used on its own to describe a general TouristAttraction, or be used as an additionalType to add tourist attraction properties to any other type. (See examples below)

Properties used on this type:

- availableLanguage
- touristType

Properties whose values are of this type:

- includesAttraction

[^top]

#### TouristDestination

A tourist destination. In principle any Place can be a TouristDestination from a City, Region or Country to an AmusementPark or Hotel. This Type can be used on its own to describe a general TouristDestination, or be used as an additionalType to add tourist relevant properties to any other Place. A TouristDestination is defined as a Place that contains, or is colocated with, one or more TouristAttractions, often linked by a similar theme or interest to a particular touristType. The UNWTO defines Destination (main destination of a tourism trip) as the place visited that is central to the decision to take the trip. (See examples below).

Properties used on this type:

- includesAttraction
- touristType

Properties whose values are of this type:

[^top]

#### TouristInformationCenter

A tourist information center.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TouristTrip

A tourist trip. A created itinerary of visits to one or more places of interest (TouristAttraction/TouristDestination) often linked by a similar theme, geographic area, or interest to a particular touristType. The UNWTO defines tourism trip as the Trip taken by visitors. (See examples below).

Properties used on this type:

- touristType

Properties whose values are of this type:

[^top]

#### Toxicologic

An Enumeration member

A specific branch of medical science that is concerned with poisons, their nature, effects and detection and involved in the treatment of poisoning.

Member of Enumeration: MedicalSpecialty
[^top]

#### ToyStore

A toy store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TrackAction

An agent tracks an object for updates.
Related actions:

- FollowAction: Unlike FollowAction, TrackAction refers to the interest on the location of innanimates objects.
- SubscribeAction: Unlike SubscribeAction, TrackAction refers to the interest on the location of innanimate objects.

Properties used on this type:

- deliveryMethod

Properties whose values are of this type:

[^top]

#### TradeAction

The act of participating in an exchange of goods and services for monetary compensation. An agent trades an object, product or service with a participant in exchange for a one time or periodic payment.

Properties used on this type:

- price
- priceCurrency
- priceSpecification

Properties whose values are of this type:

[^top]

#### TraditionalChinese

An Enumeration member

A system of medicine based on common theoretical concepts that originated in China and evolved over thousands of years, that uses herbs, acupuncture, exercise, massage, dietary therapy, and other methods to treat a wide range of conditions.

Member of Enumeration: MedicineSystem
[^top]

#### TrainReservation

A reservation for train travel.
Note: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations. For offers of tickets, use Offer.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TrainStation

A train station.

Properties used on this type:

Properties whose values are of this type:

- arrivalStation
- departureStation

[^top]

#### TrainTrip

A trip on a commercial train line.

Properties used on this type:

- arrivalPlatform
- arrivalStation
- departurePlatform
- departureStation
- trainName
- trainNumber

Properties whose values are of this type:

[^top]

#### TransferAction

The act of transferring/moving (abstract or concrete) animate or inanimate objects from one place to another.

Properties used on this type:

- fromLocation
- toLocation

Properties whose values are of this type:

[^top]

#### TransformedContent

An Enumeration member

Content coded 'transformed content' in a MediaReview, considered in the context of how it was published or shared.
For a VideoObject to be 'transformed content': or all of the video has been manipulated to transform the footage itself. This category includes using tools like the Adobe Suite to change the speed of the video, add or remove visual elements or dub audio. Deepfakes are also a subset of transformation.
For an ImageObject to be transformed content': Adding or deleting visual elements to give the image a different meaning with the intention to mislead.
For an ImageObject with embedded text to be 'transformed content': Adding or deleting visual elements to give the image a different meaning with the intention to mislead.
For an AudioObject to be 'transformed content': Part or all of the audio has been manipulated to alter the words or sounds, or the audio has been synthetically generated, such as to create a sound-alike voice.

Member of Enumeration: MediaManipulationRatingEnumeration
[^top]

#### TransitMap

An Enumeration member

A transit map.

Member of Enumeration: MapCategoryType
[^top]

#### TravelAction

The act of traveling from an fromLocation to a destination by a specified mode of transport, optionally with participants.

Properties used on this type:

- distance

Properties whose values are of this type:

[^top]

#### TravelAgency

A travel agency.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TreatmentIndication

An indication for treating an underlying condition, symptom, etc.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### TreatmentsHealthAspect

An Enumeration member

Treatments or related therapies for a Topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### Trip

A trip or journey. An itinerary of visits to one or more places.

Properties used on this type:

- arrivalTime
- departureTime
- itinerary
- offers
- partOfTrip
- provider
- subTrip

Properties whose values are of this type:

- itemOffered
- partOfTrip
- subTrip

[^top]

#### TripleBlindedTrial

An Enumeration member

A trial design in which neither the researcher, the person administering the therapy nor the patient knows the details of the treatment the patient was randomly assigned to.

Member of Enumeration: MedicalTrialDesign
[^top]

#### Tuesday

An Enumeration member

The day of the week between Monday and Wednesday.

Member of Enumeration: DayOfWeek
[^top]

#### TypeAndQuantityNode

A structured value indicating the quantity, unit of measurement, and business function of goods included in a bundle offer.

Properties used on this type:

- amountOfThisGood
- businessFunction
- typeOfGood
- unitCode
- unitText

Properties whose values are of this type:

- includesObject

[^top]

#### TypesHealthAspect

An Enumeration member

Categorization and other types related to a topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### UKNonprofitType

An Enumeration

UKNonprofitType: Non-profit organization type originating from the United Kingdom.

Properties used on this type:

Enumeration members of this type:

- CharitableIncorporatedOrganization
- LimitedByGuaranteeCharity
- UKTrust
- UnincorporatedAssociationCharity

Properties whose values are of this type:

[^top]

#### UKTrust

An Enumeration member

UKTrust: Non-profit type referring to a UK trust.

Member of Enumeration: UKNonprofitType
[^top]

#### URL

Data type: URL.

Properties used on this type:

Properties whose values are of this type:

- acceptsReservations
- acquireLicensePage
- actionPlatform
- actionableFeedbackPolicy
- additionalType
- afterMedia
- applicationCategory
- applicationSubCategory
- artMedium
- artform
- artworkSurface
- bankAccountType
- beforeMedia
- benefitsSummaryUrl
- bodyType
- category
- codeRepository
- colleague
- competencyRequired
- contentUrl
- correction
- correctionsPolicy
- courseMode
- credentialCategory
- discussionUrl
- diseasePreventionInfo
- diseaseSpreadStatistics
- diversityPolicy
- diversityStaffingReport
- documentation
- downloadUrl
- duringMedia
- editEIDR
- educationalCredentialAwarded
- educationalLevel
- educationalProgramMode
- embedUrl
- encodingFormat
- engineType
- ethicsPolicy
- featureList
- feesAndCommissionsSpecification
- fileFormat
- fuelType
- gameLocation
- gamePlatform
- genre
- gettingTestedInfo
- hasMap
- hasMenu
- healthPlanMarketingUrl
- identifier
- image
- inCodeSet
- inDefinedTermSet
- installUrl
- isBasedOn
- isBasedOnUrl
- isPartOf
- keywords
- knowsAbout
- labelDetails
- layoutImage
- legislationIdentifier
- license
- loanType
- logo
- mainEntityOfPage
- map
- maps
- masthead
- material
- measurementTechnique
- meetsEmissionStandard
- memoryRequirements
- menu
- merchantReturnLink
- missionCoveragePrioritiesPolicy
- namedPosition
- newsUpdatesAndGuidelines
- noBylinesPolicy
- occupationalCredentialAwarded
- ownershipFundingInfo
- paymentUrl
- physicalRequirement
- prescribingInfo
- productReturnLink
- propertyID
- publicTransportClosuresInfo
- publishingPrinciples
- quarantineGuidelines
- relatedLink
- releaseNotes
- replyToUrl
- requirements
- roleName
- sameAs
- schemaVersion
- schoolClosuresInfo
- screenshot
- sdLicense
- season
- securityClearanceRequirement
- sensoryRequirement
- serviceUrl
- shippingSettingsLink
- significantLink
- significantLinks
- softwareRequirements
- speakable
- sport
- storageRequirements
- surface
- targetUrl
- temporalCoverage
- termsOfService
- thumbnailUrl
- ticketToken
- titleEIDR
- tourBookingPage
- trackingUrl
- travelBans
- unitCode
- unnamedSourcesPolicy
- url
- usageInfo
- usesHealthPlanIdStandard
- vehicleTransmission
- verificationFactCheckingPolicy
- warning
- webFeed

[^top]

#### USNonprofitType

An Enumeration

USNonprofitType: Non-profit organization type originating from the United States.

Properties used on this type:

Enumeration members of this type:

- Nonprofit501a
- Nonprofit501c1
- Nonprofit501c10
- Nonprofit501c11
- Nonprofit501c12
- Nonprofit501c13
- Nonprofit501c14
- Nonprofit501c15
- Nonprofit501c16
- Nonprofit501c17
- Nonprofit501c18
- Nonprofit501c19
- Nonprofit501c2
- Nonprofit501c20
- Nonprofit501c21
- Nonprofit501c22
- Nonprofit501c23
- Nonprofit501c24
- Nonprofit501c25
- Nonprofit501c26
- Nonprofit501c27
- Nonprofit501c28
- Nonprofit501c3
- Nonprofit501c4
- Nonprofit501c5
- Nonprofit501c6
- Nonprofit501c7
- Nonprofit501c8
- Nonprofit501c9
- Nonprofit501d
- Nonprofit501e
- Nonprofit501f
- Nonprofit501k
- Nonprofit501n
- Nonprofit501q
- Nonprofit527

Properties whose values are of this type:

[^top]

#### Ultrasound

An Enumeration member

Ultrasound imaging.

Member of Enumeration: MedicalImagingTechnique
[^top]

#### UnRegisterAction

The act of un-registering from a service.
Related actions:

- RegisterAction: antonym of UnRegisterAction.
- LeaveAction: Unlike LeaveAction, UnRegisterAction implies that you are unregistering from a service you werer previously registered, rather than leaving a team/group of people.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### UnemploymentSupport

An Enumeration member

UnemploymentSupport: this is a benefit for unemployment support.

Member of Enumeration: GovernmentBenefitsType
[^top]

#### UnincorporatedAssociationCharity

An Enumeration member

UnincorporatedAssociationCharity: Non-profit type referring to a charitable company that is not incorporated (UK).

Member of Enumeration: UKNonprofitType
[^top]

#### UnitPriceSpecification

The price asked for a given offer by the respective organization or person.

Properties used on this type:

- billingDuration
- billingIncrement
- billingStart
- priceComponentType
- priceType
- referenceQuantity
- unitCode
- unitText

Properties whose values are of this type:

- currentExchangeRate
- priceComponent

[^top]

#### UnofficialLegalValue

An Enumeration member

Indicates that a document has no particular or special standing (e.g. a republication of a law by a private publisher).

Member of Enumeration: LegalValueLevel
[^top]

#### UpdateAction

The act of managing by changing/editing the state of the object.

Properties used on this type:

- collection
- targetCollection

Properties whose values are of this type:

[^top]

#### Urologic

An Enumeration member

A specific branch of medical science that is concerned with the diagnosis and treatment of diseases pertaining to the urinary tract and the urogenital system.

Member of Enumeration: MedicalSpecialty
[^top]

#### UsageOrScheduleHealthAspect

An Enumeration member

Content about how, when, frequency and dosage of a topic.

Member of Enumeration: HealthAspectEnumeration
[^top]

#### UseAction

The act of applying an object to its intended purpose.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### UsedCondition

An Enumeration member

Indicates that the item is used.

Member of Enumeration: OfferItemCondition
[^top]

#### UserBlocks

UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally better to use Action-based vocabulary, alongside types such as Comment.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### UserCheckins

UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally better to use Action-based vocabulary, alongside types such as Comment.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### UserComments

UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally better to use Action-based vocabulary, alongside types such as Comment.

Properties used on this type:

- commentText
- commentTime
- creator
- discusses
- replyToUrl

Properties whose values are of this type:

[^top]

#### UserDownloads

UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally better to use Action-based vocabulary, alongside types such as Comment.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### UserInteraction

UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally better to use Action-based vocabulary, alongside types such as Comment.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### UserLikes

UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally better to use Action-based vocabulary, alongside types such as Comment.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### UserPageVisits

UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally better to use Action-based vocabulary, alongside types such as Comment.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### UserPlays

UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally better to use Action-based vocabulary, alongside types such as Comment.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### UserPlusOnes

UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally better to use Action-based vocabulary, alongside types such as Comment.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### UserReview

A review created by an end-user (e.g. consumer, purchaser, attendee etc.), in contrast with CriticReview.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### UserTweets

UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally better to use Action-based vocabulary, alongside types such as Comment.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### VeganDiet

An Enumeration member

A diet exclusive of all animal products.

Member of Enumeration: RestrictedDiet
[^top]

#### VegetarianDiet

An Enumeration member

A diet exclusive of animal meat.

Member of Enumeration: RestrictedDiet
[^top]

#### Vehicle

A vehicle is a device that is designed or used to transport people or cargo over land, water, air, or through space.

Properties used on this type:

- accelerationTime
- bodyType
- callSign
- cargoVolume
- dateVehicleFirstRegistered
- driveWheelConfiguration
- emissionsCO2
- fuelCapacity
- fuelConsumption
- fuelEfficiency
- fuelType
- knownVehicleDamages
- meetsEmissionStandard
- mileageFromOdometer
- modelDate
- numberOfAirbags
- numberOfAxles
- numberOfDoors
- numberOfForwardGears
- numberOfPreviousOwners
- payload
- productionDate
- purchaseDate
- seatingCapacity
- speed
- steeringPosition
- stupidProperty
- tongueWeight
- trailerWeight
- vehicleConfiguration
- vehicleEngine
- vehicleIdentificationNumber
- vehicleInteriorColor
- vehicleInteriorType
- vehicleModelDate
- vehicleSeatingCapacity
- vehicleSpecialUsage
- vehicleTransmission
- weightTotal
- wheelbase

Properties whose values are of this type:

- aircraft

[^top]

#### Vein

A type of blood vessel that specifically carries blood to the heart.

Properties used on this type:

- drainsTo
- regionDrained
- tributary

Properties whose values are of this type:

[^top]

#### VenueMap

An Enumeration member

A venue map (e.g. for malls, auditoriums, museums, etc.).

Member of Enumeration: MapCategoryType
[^top]

#### Vessel

A component of the human body circulatory system comprised of an intricate network of hollow tubes that transport blood throughout the entire body.

Properties used on this type:

Properties whose values are of this type:

- bloodSupply
- drainsTo
- originatesFrom
- runsTo

[^top]

#### VeterinaryCare

A vet's office.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### VideoGallery

Web page type: Video gallery page.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### VideoGame

A video game is an electronic game that involves human interaction with a user interface to generate visual feedback on a video device.

Properties used on this type:

- actor
- actors
- cheatCode
- director
- directors
- gamePlatform
- gameServer
- gameTip
- musicBy
- playMode
- trailer

Properties whose values are of this type:

- game

[^top]

#### VideoGameClip

A short segment/part of a video game.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### VideoGameSeries

A video game series.

Properties used on this type:

- actor
- actors
- characterAttribute
- cheatCode
- containsSeason
- director
- directors
- episode
- episodes
- gameItem
- gameLocation
- gamePlatform
- musicBy
- numberOfEpisodes
- numberOfPlayers
- numberOfSeasons
- playMode
- productionCompany
- quest
- season
- seasons
- trailer

Properties whose values are of this type:

[^top]

#### VideoObject

A video file.

Properties used on this type:

- actor
- actors
- caption
- director
- directors
- musicBy
- thumbnail
- transcript
- videoFrameSize
- videoQuality

Properties whose values are of this type:

- trailer
- video

[^top]

#### ViewAction

The act of consuming static visual content.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### VinylFormat

An Enumeration member

VinylFormat.

Member of Enumeration: MusicReleaseFormatType
[^top]

#### VirtualLocation

An online or virtual location for attending events. For example, one may attend an online seminar or educational event. While a virtual location may be used as the location of an event, virtual locations should not be confused with physical locations in the real world.

Properties used on this type:

Properties whose values are of this type:

- location

[^top]

#### Virus

An Enumeration member

Pathogenic virus that causes viral infection.

Member of Enumeration: InfectiousAgentClass
[^top]

#### VisualArtsEvent

Event type: Visual arts event.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### VisualArtwork

A work of art that is primarily visual in character.

Properties used on this type:

- artEdition
- artMedium
- artform
- artist
- artworkSurface
- colorist
- depth
- height
- inker
- letterer
- penciler
- surface
- width

Properties whose values are of this type:

[^top]

#### VitalSign

Vital signs are measures of various physiological functions in order to assess the most basic body functions.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Volcano

A volcano, like Fuji san.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### VoteAction

The act of expressing a preference from a fixed/finite/structured set of choices/options.

Properties used on this type:

- candidate

Properties whose values are of this type:

[^top]

#### WPAdBlock

An advertising section of the page.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### WPFooter

The footer section of the page.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### WPHeader

The header section of the page.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### WPSideBar

A sidebar section of the page.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### WantAction

The act of expressing a desire about the object. An agent wants an object.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### WarrantyPromise

A structured value representing the duration and scope of services that will be provided to a customer free of charge in case of a defect or malfunction of a product.

Properties used on this type:

- durationOfWarranty
- warrantyScope

Properties whose values are of this type:

- warranty
- warrantyPromise

[^top]

#### WarrantyScope

An Enumeration

A range of of services that will be provided to a customer free of charge in case of a defect or malfunction of a product.
Commonly used values:

- http://purl.org/goodrelations/v1#Labor-BringIn
- http://purl.org/goodrelations/v1#PartsAndLabor-BringIn
- http://purl.org/goodrelations/v1#PartsAndLabor-PickUp

Properties used on this type:

Enumeration members of this type:

Properties whose values are of this type:

- warrantyScope

[^top]

#### WatchAction

The act of consuming dynamic/moving visual content.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Waterfall

A waterfall, like Niagara.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### WearAction

The act of dressing oneself in clothing.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### WearableMeasurementBack

An Enumeration member

Measurement of the back section, for example of a jacket

Member of Enumeration: WearableMeasurementTypeEnumeration
[^top]

#### WearableMeasurementChestOrBust

An Enumeration member

Measurement of the chest/bust section, for example of a suit

Member of Enumeration: WearableMeasurementTypeEnumeration
[^top]

#### WearableMeasurementCollar

An Enumeration member

Measurement of the collar, for example of a shirt

Member of Enumeration: WearableMeasurementTypeEnumeration
[^top]

#### WearableMeasurementCup

An Enumeration member

Measurement of the cup, for example of a bra

Member of Enumeration: WearableMeasurementTypeEnumeration
[^top]

#### WearableMeasurementHeight

An Enumeration member

Measurement of the height, for example the heel height of a shoe

Member of Enumeration: WearableMeasurementTypeEnumeration
[^top]

#### WearableMeasurementHips

An Enumeration member

Measurement of the hip section, for example of a skirt

Member of Enumeration: WearableMeasurementTypeEnumeration
[^top]

#### WearableMeasurementInseam

An Enumeration member

Measurement of the inseam, for example of pants

Member of Enumeration: WearableMeasurementTypeEnumeration
[^top]

#### WearableMeasurementLength

An Enumeration member

Represents the length, for example of a dress

Member of Enumeration: WearableMeasurementTypeEnumeration
[^top]

#### WearableMeasurementOutsideLeg

An Enumeration member

Measurement of the outside leg, for example of pants

Member of Enumeration: WearableMeasurementTypeEnumeration
[^top]

#### WearableMeasurementSleeve

An Enumeration member

Measurement of the sleeve length, for example of a shirt

Member of Enumeration: WearableMeasurementTypeEnumeration
[^top]

#### WearableMeasurementTypeEnumeration

An Enumeration

Enumerates common types of measurement for wearables products.

Properties used on this type:

Enumeration members of this type:

- WearableMeasurementBack
- WearableMeasurementChestOrBust
- WearableMeasurementCollar
- WearableMeasurementCup
- WearableMeasurementHeight
- WearableMeasurementHips
- WearableMeasurementInseam
- WearableMeasurementLength
- WearableMeasurementOutsideLeg
- WearableMeasurementSleeve
- WearableMeasurementWaist
- WearableMeasurementWidth

Properties whose values are of this type:

[^top]

#### WearableMeasurementWaist

An Enumeration member

Measurement of the waist section, for example of pants

Member of Enumeration: WearableMeasurementTypeEnumeration
[^top]

#### WearableMeasurementWidth

An Enumeration member

Measurement of the width, for example of shoes

Member of Enumeration: WearableMeasurementTypeEnumeration
[^top]

#### WearableSizeGroupBig

An Enumeration member

Size group "Big" for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupBoys

An Enumeration member

Size group "Boys" for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupEnumeration

An Enumeration

Enumerates common size groups (also known as "size types") for wearable products.

Properties used on this type:

Enumeration members of this type:

- WearableSizeGroupBig
- WearableSizeGroupBoys
- WearableSizeGroupExtraShort
- WearableSizeGroupExtraTall
- WearableSizeGroupGirls
- WearableSizeGroupHusky
- WearableSizeGroupInfants
- WearableSizeGroupJuniors
- WearableSizeGroupMaternity
- WearableSizeGroupMens
- WearableSizeGroupMisses
- WearableSizeGroupPetite
- WearableSizeGroupPlus
- WearableSizeGroupRegular
- WearableSizeGroupShort
- WearableSizeGroupTall
- WearableSizeGroupWomens

Properties whose values are of this type:

[^top]

#### WearableSizeGroupExtraShort

An Enumeration member

Size group "Extra Short" for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupExtraTall

An Enumeration member

Size group "Extra Tall" for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupGirls

An Enumeration member

Size group "Girls" for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupHusky

An Enumeration member

Size group "Husky" (or "Stocky") for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupInfants

An Enumeration member

Size group "Infants" for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupJuniors

An Enumeration member

Size group "Juniors" for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupMaternity

An Enumeration member

Size group "Maternity" for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupMens

An Enumeration member

Size group "Mens" for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupMisses

An Enumeration member

Size group "Misses" (also known as "Missy") for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupPetite

An Enumeration member

Size group "Petite" for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupPlus

An Enumeration member

Size group "Plus" for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupRegular

An Enumeration member

Size group "Regular" for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupShort

An Enumeration member

Size group "Short" for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupTall

An Enumeration member

Size group "Tall" for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeGroupWomens

An Enumeration member

Size group "Womens" for wearables.

Member of Enumeration: WearableSizeGroupEnumeration
[^top]

#### WearableSizeSystemAU

An Enumeration member

Australian size system for wearables.

Member of Enumeration: WearableSizeSystemEnumeration
[^top]

#### WearableSizeSystemBR

An Enumeration member

Brazilian size system for wearables.

Member of Enumeration: WearableSizeSystemEnumeration
[^top]

#### WearableSizeSystemCN

An Enumeration member

Chinese size system for wearables.

Member of Enumeration: WearableSizeSystemEnumeration
[^top]

#### WearableSizeSystemContinental

An Enumeration member

Continental size system for wearables.

Member of Enumeration: WearableSizeSystemEnumeration
[^top]

#### WearableSizeSystemDE

An Enumeration member

German size system for wearables.

Member of Enumeration: WearableSizeSystemEnumeration
[^top]

#### WearableSizeSystemEN13402

An Enumeration member

EN 13402 (joint European standard for size labelling of clothes).

Member of Enumeration: WearableSizeSystemEnumeration
[^top]

#### WearableSizeSystemEnumeration

An Enumeration

Enumerates common size systems specific for wearable products

Properties used on this type:

Enumeration members of this type:

- WearableSizeSystemAU
- WearableSizeSystemBR
- WearableSizeSystemCN
- WearableSizeSystemContinental
- WearableSizeSystemDE
- WearableSizeSystemEN13402
- WearableSizeSystemEurope
- WearableSizeSystemFR
- WearableSizeSystemGS1
- WearableSizeSystemIT
- WearableSizeSystemJP
- WearableSizeSystemMX
- WearableSizeSystemUK
- WearableSizeSystemUS

Properties whose values are of this type:

[^top]

#### WearableSizeSystemEurope

An Enumeration member

European size system for wearables.

Member of Enumeration: WearableSizeSystemEnumeration
[^top]

#### WearableSizeSystemFR

An Enumeration member

French size system for wearables.

Member of Enumeration: WearableSizeSystemEnumeration
[^top]

#### WearableSizeSystemGS1

An Enumeration member

GS1 (formerly NRF) size system for wearables.

Member of Enumeration: WearableSizeSystemEnumeration
[^top]

#### WearableSizeSystemIT

An Enumeration member

Italian size system for wearables.

Member of Enumeration: WearableSizeSystemEnumeration
[^top]

#### WearableSizeSystemJP

An Enumeration member

Japanese size system for wearables.

Member of Enumeration: WearableSizeSystemEnumeration
[^top]

#### WearableSizeSystemMX

An Enumeration member

Mexican size system for wearables.

Member of Enumeration: WearableSizeSystemEnumeration
[^top]

#### WearableSizeSystemUK

An Enumeration member

United Kingdom size system for wearables.

Member of Enumeration: WearableSizeSystemEnumeration
[^top]

#### WearableSizeSystemUS

An Enumeration member

United States size system for wearables.

Member of Enumeration: WearableSizeSystemEnumeration
[^top]

#### WebAPI

An application programming interface accessible over Web/Internet technologies.

Properties used on this type:

- documentation

Properties whose values are of this type:

[^top]

#### WebApplication

Web applications.

Properties used on this type:

- browserRequirements

Properties whose values are of this type:

[^top]

#### WebContent

WebContent is a type representing all WebPage, WebSite and WebPageElement content. It is sometimes the case that detailed distinctions between Web pages, sites and their parts is not always important or obvious. The WebContent type makes it easier to describe Web-addressable content without requiring such distinctions to always be stated. (The intent is that the existing types WebPage, WebSite and WebPageElement will eventually be declared as subtypes of WebContent).

Properties used on this type:

Properties whose values are of this type:

- answerExplanation
- diseasePreventionInfo
- diseaseSpreadStatistics
- gettingTestedInfo
- newsUpdatesAndGuidelines
- publicTransportClosuresInfo
- quarantineGuidelines
- schoolClosuresInfo
- travelBans

[^top]

#### WebPage

A web page. Every web page is implicitly assumed to be declared to be of type WebPage, so the various properties about that webpage, such as `breadcrumb` may be used. We recommend explicit declaration if these properties are specified, but if they are found outside of an itemscope, they will be assumed to be about the page.

Properties used on this type:

- breadcrumb
- lastReviewed
- mainContentOfPage
- primaryImageOfPage
- relatedLink
- reviewedBy
- significantLink
- significantLinks
- speakable
- specialty

Properties whose values are of this type:

[^top]

#### WebPageElement

A web page element, like a table or an image.

Properties used on this type:

- cssSelector
- xpath

Properties whose values are of this type:

- mainContentOfPage

[^top]

#### WebSite

A WebSite is a set of related web pages and other items typically served from a single web domain and accessible via URLs.

Properties used on this type:

- issn

Properties whose values are of this type:

- interactionService

[^top]

#### Wednesday

An Enumeration member

The day of the week between Tuesday and Thursday.

Member of Enumeration: DayOfWeek
[^top]

#### WesternConventional

An Enumeration member

The conventional Western system of medicine, that aims to apply the best available evidence gained from the scientific method to clinical decision making. Also known as conventional or Western medicine.

Member of Enumeration: MedicineSystem
[^top]

#### Wholesale

An Enumeration member

The drug's cost represents the wholesale acquisition cost of the drug.

Member of Enumeration: DrugCostCategory
[^top]

#### WholesaleStore

A wholesale store.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### WinAction

The act of achieving victory in a competitive activity.

Properties used on this type:

- loser

Properties whose values are of this type:

[^top]

#### Winery

A winery.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### Withdrawn

An Enumeration member

Withdrawn.

Member of Enumeration: MedicalStudyStatus
[^top]

#### WorkBasedProgram

A program with both an educational and employment component. Typically based at a workplace and structured around work-based learning, with the aim of instilling competencies related to an occupation. WorkBasedProgram is used to distinguish programs such as apprenticeships from school, college or other classroom based educational programs.

Properties used on this type:

- occupationalCategory
- trainingSalary

Properties whose values are of this type:

[^top]

#### WorkersUnion

A Workers Union (also known as a Labor Union, Labour Union, or Trade Union) is an organization that promotes the interests of its worker members by collectively bargaining with management, organizing, and political lobbying.

Properties used on this type:

Properties whose values are of this type:

[^top]

#### WriteAction

The act of authoring written creative content.

Properties used on this type:

- inLanguage
- language

Properties whose values are of this type:

[^top]

#### WritePermission

An Enumeration member

Permission to write or edit the document.

Member of Enumeration: DigitalDocumentPermissionType
[^top]

#### XPathType

Text representing an XPath (typically but not necessarily version 1.0).

Properties used on this type:

Properties whose values are of this type:

- xpath

[^top]

#### XRay

An Enumeration member

X-ray imaging.

Member of Enumeration: MedicalImagingTechnique
[^top]

#### ZoneBoardingPolicy

An Enumeration member

The airline boards by zones of the plane.

Member of Enumeration: BoardingPolicyType
[^top]

#### Zoo

A zoo.

Properties used on this type:

Properties whose values are of this type:

[^top]

## Properties A-Z

about , abridged , abstract , accelerationTime , acceptedAnswer , acceptedOffer , acceptedPaymentMethod , acceptsReservations , accessCode , accessMode , accessModeSufficient , accessibilityAPI , accessibilityControl , accessibilityFeature , accessibilityHazard , accessibilitySummary , accommodationCategory , accommodationFloorPlan , accountId , accountMinimumInflow , accountOverdraftLimit , accountablePerson , acquireLicensePage , acquiredFrom , acrissCode , actionAccessibilityRequirement , actionApplication , actionOption , actionPlatform , actionStatus , actionableFeedbackPolicy , activeIngredient , activityDuration , activityFrequency , actor , actors , addOn , additionalName , additionalNumberOfGuests , additionalProperty , additionalType , additionalVariable , address , addressCountry , addressLocality , addressRegion , administrationRoute , advanceBookingRequirement , adverseOutcome , affectedBy , affiliation , afterMedia , agent , aggregateRating , aircraft , album , albumProductionType , albumRelease , albumReleaseType , albums , alcoholWarning , algorithm , alignmentType , alternateName , alternativeHeadline , alumni , alumniOf , amenityFeature , amount , amountOfThisGood , announcementLocation , annualPercentageRate , answerCount , answerExplanation , antagonist , appearance , applicableLocation , applicantLocationRequirements , application , applicationCategory , applicationContact , applicationDeadline , applicationStartDate , applicationSubCategory , applicationSuite , appliesToDeliveryMethod , appliesToPaymentMethod , archiveHeld , area , areaServed , arrivalAirport , arrivalBoatTerminal , arrivalBusStop , arrivalGate , arrivalPlatform , arrivalStation , arrivalTerminal , arrivalTime , artEdition , artMedium , arterialBranch , artform , articleBody , articleSection , artist , artworkSurface , aspect , assembly , assemblyVersion , assesses , associatedAnatomy , associatedArticle , associatedMedia , associatedPathophysiology , athlete , attendee , attendees , audience , audienceType , audio , authenticator , author , availability , availabilityEnds , availabilityStarts , availableAtOrFrom , availableChannel , availableDeliveryMethod , availableFrom , availableIn , availableLanguage , availableOnDevice , availableService , availableStrength , availableTest , availableThrough , award , awards , awayTeam , backstory , bankAccountType , baseSalary , bccRecipient , bed , beforeMedia , beneficiaryBank , benefits , benefitsSummaryUrl , bestRating , billingAddress , billingDuration , billingIncrement , billingPeriod , billingStart , biomechnicalClass , birthDate , birthPlace , bitrate , blogPost , blogPosts , bloodSupply , boardingGroup , boardingPolicy , bodyLocation , bodyType , bookEdition , bookFormat , bookingAgent , bookingTime , borrower , box , branch , branchCode , branchOf , brand , breadcrumb , breastfeedingWarning , broadcastAffiliateOf , broadcastChannelId , broadcastDisplayName , broadcastFrequency , broadcastFrequencyValue , broadcastOfEvent , broadcastServiceTier , broadcastSignalModulation , broadcastSubChannel , broadcastTimezone , broadcaster , broker , browserRequirements , busName , busNumber , businessDays , businessFunction , buyer , byArtist , byDay , byMonth , byMonthDay , byMonthWeek , callSign , calories , candidate , caption , carbohydrateContent , cargoVolume , carrier , carrierRequirements , cashBack , catalog , catalogNumber , category , causeOf , ccRecipient , character , characterAttribute , characterName , cheatCode , checkinTime , checkoutTime , childMaxAge , childMinAge , children , cholesterolContent , circle , citation , claimReviewed , clincalPharmacology , clinicalPharmacology , clipNumber , closes , coach , code , codeRepository , codeSampleType , codeValue , codingSystem , colleague , colleagues , collection , collectionSize , color , colorist , comment , commentCount , commentText , commentTime , competencyRequired , competitor , composer , comprisedOf , conditionsOfAccess , confirmationNumber , connectedTo , constrainingProperty , contactOption , contactPoint , contactPoints , contactType , contactlessPayment , containedIn , containedInPlace , containsPlace , containsSeason , contentLocation , contentRating , contentReferenceTime , contentSize , contentType , contentUrl , contraindication , contributor , cookTime , cookingMethod , copyrightHolder , copyrightNotice , copyrightYear , correction , correctionsPolicy , costCategory , costCurrency , costOrigin , costPerUnit , countriesNotSupported , countriesSupported , countryOfOrigin , course , courseCode , courseMode , coursePrerequisites , courseWorkload , coverageEndTime , coverageStartTime , creativeWorkStatus , creator , credentialCategory , creditText , creditedTo , cssSelector , currenciesAccepted , currency , currentExchangeRate , customer , cutoffTime , cvdCollectionDate , cvdFacilityCounty , cvdFacilityId , cvdNumBeds , cvdNumBedsOcc , cvdNumC19Died , cvdNumC19HOPats , cvdNumC19HospPats , cvdNumC19MechVentPats , cvdNumC19OFMechVentPats , cvdNumC19OverflowPats , cvdNumICUBeds , cvdNumICUBedsOcc , cvdNumTotBeds , cvdNumVent , cvdNumVentUse , dataFeedElement , dataset , datasetTimeInterval , dateCreated , dateDeleted , dateIssued , dateModified , datePosted , datePublished , dateRead , dateReceived , dateSent , dateVehicleFirstRegistered , dateline , dayOfWeek , deathDate , deathPlace , defaultValue , deliveryAddress , deliveryLeadTime , deliveryMethod , deliveryStatus , deliveryTime , department , departureAirport , departureBoatTerminal , departureBusStop , departureGate , departurePlatform , departureStation , departureTerminal , departureTime , dependencies , depth , description , device , diagnosis , diagram , diet , dietFeatures , differentialDiagnosis , director , directors , disambiguatingDescription , discount , discountCode , discountCurrency , discusses , discussionUrl , diseasePreventionInfo , diseaseSpreadStatistics , dissolutionDate , distance , distinguishingSign , distribution , diversityPolicy , diversityStaffingReport , documentation , doesNotShip , domainIncludes , domiciledMortgage , doorTime , dosageForm , doseSchedule , doseUnit , doseValue , downPayment , downloadUrl , downvoteCount , drainsTo , driveWheelConfiguration , dropoffLocation , dropoffTime , drug , drugClass , drugUnit , duns , duplicateTherapy , duration , durationOfWarranty , duringMedia , earlyPrepaymentPenalty , editEIDR , editor , eduQuestionType , educationRequirements , educationalAlignment , educationalCredentialAwarded , educationalFramework , educationalLevel , educationalProgramMode , educationalRole , educationalUse , elevation , eligibilityToWorkRequirement , eligibleCustomerType , eligibleDuration , eligibleQuantity , eligibleRegion , eligibleTransactionVolume , email , embedUrl , emissionsCO2 , employee , employees , employerOverview , employmentType , employmentUnit , encodesCreativeWork , encoding , encodingFormat , encodingType , encodings , endDate , endOffset , endTime , endorsee , endorsers , energyEfficiencyScaleMax , energyEfficiencyScaleMin , engineDisplacement , enginePower , engineType , entertainmentBusiness , epidemiology , episode , episodeNumber , episodes , equal , error , estimatedCost , estimatedFlightDuration , estimatedSalary , estimatesRiskOf , ethicsPolicy , event , eventAttendanceMode , eventSchedule , eventStatus , events , evidenceLevel , evidenceOrigin , exampleOfWork , exceptDate , exchangeRateSpread , executableLibraryName , exerciseCourse , exercisePlan , exerciseRelatedDiet , exerciseType , exifData , expectedArrivalFrom , expectedArrivalUntil , expectedPrognosis , expectsAcceptanceOf , experienceInPlaceOfEducation , experienceRequirements , expertConsiderations , expires , familyName , fatContent , faxNumber , featureList , feesAndCommissionsSpecification , fiberContent , fileFormat , fileSize , financialAidEligible , firstAppearance , firstPerformance , flightDistance , flightNumber , floorLevel , floorLimit , floorSize , followee , follows , followup , foodEstablishment , foodEvent , foodWarning , founder , founders , foundingDate , foundingLocation , free , freeShippingThreshold , frequency , fromLocation , fuelCapacity , fuelConsumption , fuelEfficiency , fuelType , functionalClass , fundedItem , funder , game , gameItem , gameLocation , gamePlatform , gameServer , gameTip , gender , genre , geo , geoContains , geoCoveredBy , geoCovers , geoCrosses , geoDisjoint , geoEquals , geoIntersects , geoMidpoint , geoOverlaps , geoRadius , geoTouches , geoWithin , geographicArea , gettingTestedInfo , givenName , globalLocationNumber , governmentBenefitsInfo , gracePeriod , grantee , greater , greaterOrEqual , gtin , gtin12 , gtin13 , gtin14 , gtin8 , guideline , guidelineDate , guidelineSubject , handlingTime , hasBroadcastChannel , hasCategoryCode , hasCourse , hasCourseInstance , hasCredential , hasDefinedTerm , hasDeliveryMethod , hasDigitalDocumentPermission , hasDriveThroughService , hasEnergyConsumptionDetails , hasEnergyEfficiencyCategory , hasHealthAspect , hasMap , hasMeasurement , hasMenu , hasMenuItem , hasMenuSection , hasMerchantReturnPolicy , hasOccupation , hasOfferCatalog , hasPOS , hasPart , hasProductReturnPolicy , hasVariant , headline , healthCondition , healthPlanCoinsuranceOption , healthPlanCoinsuranceRate , healthPlanCopay , healthPlanCopayOption , healthPlanCostSharing , healthPlanDrugOption , healthPlanDrugTier , healthPlanId , healthPlanMarketingUrl , healthPlanNetworkId , healthPlanNetworkTier , healthPlanPharmacyCategory , healthcareReportingData , height , highPrice , hiringOrganization , holdingArchive , homeLocation , homeTeam , honorificPrefix , honorificSuffix , hospitalAffiliation , hostingOrganization , hoursAvailable , howPerformed , httpMethod , iataCode , icaoCode , identifier , identifyingExam , identifyingTest , illustrator , image , imagingTechnique , inAlbum , inBroadcastLineup , inCodeSet , inDefinedTermSet , inLanguage , inPlaylist , inProductGroupWithID , inStoreReturnsOffered , inSupportOf , incentiveCompensation , incentives , includedComposition , includedDataCatalog , includedInDataCatalog , includedInHealthInsurancePlan , includedRiskFactor , includesAttraction , includesHealthPlanFormulary , includesHealthPlanNetwork , includesObject , increasesRiskOf , industry , ineligibleRegion , infectiousAgent , infectiousAgentClass , ingredients , inker , insertion , installUrl , instructor , instrument , intensity , interactingDrug , interactionCount , interactionService , interactionStatistic , interactionType , interactivityType , interestRate , inventoryLevel , inverseOf , isAcceptingNewPatients , isAccessibleForFree , isAccessoryOrSparePartFor , isAvailableGenerically , isBasedOn , isBasedOnUrl , isConsumableFor , isFamilyFriendly , isGift , isLiveBroadcast , isPartOf , isPlanForApartment , isProprietary , isRelatedTo , isResizable , isSimilarTo , isUnlabelledFallback , isVariantOf , isbn , isicV4 , isrcCode , issn , issueNumber , issuedBy , issuedThrough , iswcCode , item , itemCondition , itemListElement , itemListOrder , itemLocation , itemOffered , itemReviewed , itemShipped , itinerary , jobBenefits , jobImmediateStart , jobLocation , jobLocationType , jobStartDate , jobTitle , jurisdiction , keywords , knownVehicleDamages , knows , knowsAbout , knowsLanguage , labelDetails , landlord , language , lastReviewed , latitude , layoutImage , learningResourceType , leaseLength , legalName , legalStatus , legislationApplies , legislationChanges , legislationConsolidates , legislationDate , legislationDateVersion , legislationIdentifier , legislationJurisdiction , legislationLegalForce , legislationLegalValue , legislationPassedBy , legislationResponsible , legislationTransposes , legislationType , leiCode , lender , lesser , lesserOrEqual , letterer , license , line , linkRelationship , liveBlogUpdate , loanMortgageMandateAmount , loanPaymentAmount , loanPaymentFrequency , loanRepaymentForm , loanTerm , loanType , location , locationCreated , lodgingUnitDescription , lodgingUnitType , logo , longitude , loser , lowPrice , lyricist , lyrics , mainContentOfPage , mainEntity , mainEntityOfPage , maintainer , makesOffer , manufacturer , map , mapType , maps , marginOfError , masthead , material , materialExtent , mathExpression , maxPrice , maxValue , maximumAttendeeCapacity , maximumEnrollment , maximumIntake , maximumPhysicalAttendeeCapacity , maximumVirtualAttendeeCapacity , mealService , measuredProperty , measuredValue , measurementTechnique , mechanismOfAction , mediaAuthenticityCategory , median , medicalAudience , medicalSpecialty , medicineSystem , meetsEmissionStandard , member , memberOf , members , membershipNumber , membershipPointsEarned , memoryRequirements , mentions , menu , menuAddOn , merchant , merchantReturnDays , merchantReturnLink , messageAttachment , mileageFromOdometer , minPrice , minValue , minimumPaymentDue , missionCoveragePrioritiesPolicy , model , modelDate , modifiedTime , monthlyMinimumRepaymentAmount , monthsOfExperience , mpn , multipleValues , muscleAction , musicArrangement , musicBy , musicCompositionForm , musicGroupMember , musicReleaseFormat , musicalKey , naics , name , namedPosition , nationality , naturalProgression , nerve , nerveMotor , netWorth , newsUpdatesAndGuidelines , nextItem , noBylinesPolicy , nonEqual , nonProprietaryName , nonprofitStatus , normalRange , nsn , numAdults , numChildren , numConstraints , numTracks , numberOfAccommodationUnits , numberOfAirbags , numberOfAvailableAccommodationUnits , numberOfAxles , numberOfBathroomsTotal , numberOfBedrooms , numberOfBeds , numberOfCredits , numberOfDoors , numberOfEmployees , numberOfEpisodes , numberOfForwardGears , numberOfFullBathrooms , numberOfItems , numberOfLoanPayments , numberOfPages , numberOfPartialBathrooms , numberOfPlayers , numberOfPreviousOwners , numberOfRooms , numberOfSeasons , numberedPosition , nutrition , object , observationDate , observedNode , occupancy , occupationLocation , occupationalCategory , occupationalCredentialAwarded , offerCount , offeredBy , offers , offersPrescriptionByMail , openingHours , openingHoursSpecification , opens , operatingSystem , opponent , option , orderDate , orderDelivery , orderItemNumber , orderItemStatus , orderNumber , orderQuantity , orderStatus , orderedItem , organizer , originAddress , originatesFrom , overdosage , ownedFrom , ownedThrough , ownershipFundingInfo , owns , pageEnd , pageStart , pagination , parent , parentItem , parentOrganization , parentService , parents , partOfEpisode , partOfInvoice , partOfOrder , partOfSeason , partOfSeries , partOfSystem , partOfTVSeries , partOfTrip , participant , partySize , passengerPriorityStatus , passengerSequenceNumber , pathophysiology , pattern , payload , paymentAccepted , paymentDue , paymentDueDate , paymentMethod , paymentMethodId , paymentStatus , paymentUrl , penciler , percentile10 , percentile25 , percentile75 , percentile90 , performTime , performer , performerIn , performers , permissionType , permissions , permitAudience , permittedUsage , petsAllowed , phoneticText , photo , photos , physicalRequirement , physiologicalBenefits , pickupLocation , pickupTime , playMode , playerType , playersOnline , polygon , populationType , position , possibleComplication , possibleTreatment , postOfficeBoxNumber , postOp , postalCode , postalCodeBegin , postalCodeEnd , postalCodePrefix , postalCodeRange , potentialAction , preOp , predecessorOf , pregnancyCategory , pregnancyWarning , prepTime , preparation , prescribingInfo , prescriptionStatus , previousItem , previousStartDate , price , priceComponent , priceComponentType , priceCurrency , priceRange , priceSpecification , priceType , priceValidUntil , primaryImageOfPage , primaryPrevention , printColumn , printEdition , printPage , printSection , procedure , procedureType , processingTime , processorRequirements , producer , produces , productGroupID , productID , productReturnDays , productReturnLink , productSupported , productionCompany , productionDate , proficiencyLevel , programMembershipUsed , programName , programPrerequisites , programType , programmingLanguage , programmingModel , propertyID , proprietaryName , proteinContent , provider , providerMobility , providesBroadcastService , providesService , publicAccess , publicTransportClosuresInfo , publication , publicationType , publishedBy , publishedOn , publisher , publisherImprint , publishingPrinciples , purchaseDate , qualifications , quarantineGuidelines , query , quest , question , rangeIncludes , ratingCount , ratingExplanation , ratingValue , readBy , readonlyValue , realEstateAgent , recipe , recipeCategory , recipeCuisine , recipeIngredient , recipeInstructions , recipeYield , recipient , recognizedBy , recognizingAuthority , recommendationStrength , recommendedIntake , recordLabel , recordedAs , recordedAt , recordedIn , recordingOf , recourseLoan , referenceQuantity , referencesOrder , refundType , regionDrained , regionsAllowed , relatedAnatomy , relatedCondition , relatedDrug , relatedLink , relatedStructure , relatedTherapy , relatedTo , releaseDate , releaseNotes , releaseOf , releasedEvent , relevantOccupation , relevantSpecialty , remainingAttendeeCapacity , renegotiableLoan , repeatCount , repeatFrequency , repetitions , replacee , replacer , replyToUrl , reportNumber , representativeOfPage , requiredCollateral , requiredGender , requiredMaxAge , requiredMinAge , requiredQuantity , requirements , requiresSubscription , reservationFor , reservationId , reservationStatus , reservedTicket , responsibilities , restPeriods , result , resultComment , resultReview , returnFees , returnPolicyCategory , review , reviewAspect , reviewBody , reviewCount , reviewRating , reviewedBy , reviews , riskFactor , risks , roleName , roofLoad , rsvpResponse , runsTo , runtime , runtimePlatform , rxcui , safetyConsideration , salaryCurrency , salaryUponCompletion , sameAs , sampleType , saturatedFatContent , scheduleTimezone , scheduledPaymentDate , scheduledTime , schemaVersion , schoolClosuresInfo , screenCount , screenshot , sdDatePublished , sdLicense , sdPublisher , season , seasonNumber , seasons , seatNumber , seatRow , seatSection , seatingCapacity , seatingType , secondaryPrevention , securityClearanceRequirement , securityScreening , seeks , seller , sender , sensoryRequirement , sensoryUnit , serialNumber , seriousAdverseOutcome , serverStatus , servesCuisine , serviceArea , serviceAudience , serviceLocation , serviceOperator , serviceOutput , servicePhone , servicePostalAddress , serviceSmsNumber , serviceType , serviceUrl , servingSize , sharedContent , shippingDestination , shippingDetails , shippingLabel , shippingRate , shippingSettingsLink , sibling , siblings , signDetected , signOrSymptom , significance , significantLink , significantLinks , size , sizeGroup , sizeSystem , skills , sku , slogan , smokingAllowed , sodiumContent , softwareAddOn , softwareHelp , softwareRequirements , softwareVersion , sourceOrganization , sourcedFrom , spatial , spatialCoverage , speakable , specialCommitments , specialOpeningHoursSpecification , specialty , speechToTextMarkup , speed , spokenByCharacter , sponsor , sport , sportsActivityLocation , sportsEvent , sportsTeam , spouse , stage , stageAsNumber , starRating , startDate , startOffset , startTime , status , steeringPosition , step , stepValue , steps , storageRequirements , streetAddress , strengthUnit , strengthValue , structuralClass , study , studyDesign , studyLocation , studySubject , stupidProperty , subEvent , subEvents , subOrganization , subReservation , subStageSuffix , subStructure , subTest , subTrip , subjectOf , subtitleLanguage , successorOf , sugarContent , suggestedAge , suggestedAnswer , suggestedGender , suggestedMaxAge , suggestedMeasurement , suggestedMinAge , suitableForDiet , superEvent , supersededBy , supply , supplyTo , supportingData , surface , target , targetCollection , targetDescription , targetName , targetPlatform , targetPopulation , targetProduct , targetUrl , taxID , teaches , telephone , temporal , temporalCoverage , termCode , termDuration , termsOfService , termsPerYear , text , textValue , thumbnail , thumbnailUrl , tickerSymbol , ticketNumber , ticketToken , ticketedSeat , timeOfDay , timeRequired , timeToComplete , tissueSample , title , titleEIDR , toLocation , toRecipient , tocContinuation , tocEntry , tongueWeight , tool , torque , totalJobOpenings , totalPaymentDue , totalPrice , totalTime , tourBookingPage , touristType , track , trackingNumber , trackingUrl , tracks , trailer , trailerWeight , trainName , trainNumber , trainingSalary , transFatContent , transcript , transitTime , transitTimeLabel , translationOfWork , translator , transmissionMethod , travelBans , trialDesign , tributary , typeOfBed , typeOfGood , typicalAgeRange , typicalCreditsPerTerm , typicalTest , underName , unitCode , unitText , unnamedSourcesPolicy , unsaturatedFatContent , uploadDate , upvoteCount , url , urlTemplate , usageInfo , usedToDiagnose , userInteractionCount , usesDevice , usesHealthPlanIdStandard , utterances , validFor , validFrom , validIn , validThrough , validUntil , value , valueAddedTaxIncluded , valueMaxLength , valueMinLength , valueName , valuePattern , valueReference , valueRequired , variableMeasured , variablesMeasured , variantCover , variesBy , vatID , vehicleConfiguration , vehicleEngine , vehicleIdentificationNumber , vehicleInteriorColor , vehicleInteriorType , vehicleModelDate , vehicleSeatingCapacity , vehicleSpecialUsage , vehicleTransmission , vendor , verificationFactCheckingPolicy , version , video , videoFormat , videoFrameSize , videoQuality , volumeNumber , warning , warranty , warrantyPromise , warrantyScope , webCheckinTime , webFeed , weight , weightTotal , wheelbase , width , winner , wordCount , workExample , workFeatured , workHours , workLocation , workPerformed , workPresented , workTranslation , workload , worksFor , worstRating , xpath , yearBuilt , yearlyRevenue , yearsInOperation , yield

#### about

The subject matter of the content.

Relevant types:

- CommunicateAction
Relevant types:

- CreativeWork
Relevant types:

- Event

Values:

[^top]

#### abridged

Indicates whether the book is an abridged edition.

Relevant types:

- Book

Values:

[^top]

#### abstract

An abstract is a short description that summarizes a CreativeWork.

Relevant types:

- CreativeWork

Values:

[^top]

#### accelerationTime

The time needed to accelerate the vehicle from a given start velocity to a given target velocity.
Typical unit code(s): SEC for seconds

- Note: There are unfortunately no standard unit codes for seconds/0..100 km/h or seconds/0..60 mph. Simply use "SEC" for seconds and indicate the velocities in the name of the QuantitativeValue, or use valueReference with a QuantitativeValue of 0..60 mph or 0..100 km/h to specify the reference speeds.

Relevant types:

- Vehicle

Values:

[^top]

#### acceptedAnswer

The answer(s) that has been accepted as best, typically on a Question/Answer site. Sites vary in their selection mechanisms, e.g. drawing on community opinion and/or the view of the Question author.

Relevant types:

- Question

Values:

[^top]

#### acceptedOffer

The offer(s) -- e.g., product, quantity and price combinations -- included in the order.

Relevant types:

- Order

Values:

[^top]

#### acceptedPaymentMethod

The payment method(s) accepted by seller for this offer.

Relevant types:

- Demand
Relevant types:

- Offer

Values:

[^top]

#### acceptsReservations

Indicates whether a FoodEstablishment accepts reservations. Values can be Boolean, an URL at which reservations can be made or (for backwards compatibility) the strings `Yes` or `No`.

Relevant types:

- FoodEstablishment

Values:

[^top]

#### accessCode

Password, PIN, or access code needed for delivery (e.g. from a locker).

Relevant types:

- DeliveryEvent

Values:

[^top]

#### accessMode

The human sensory perceptual system or cognitive faculty through which a person may process or perceive information. Expected values include: auditory, tactile, textual, visual, colorDependent, chartOnVisual, chemOnVisual, diagramOnVisual, mathOnVisual, musicOnVisual, textOnVisual.

Relevant types:

- CreativeWork

Values:

[^top]

#### accessModeSufficient

A list of single or combined accessModes that are sufficient to understand all the intellectual content of a resource. Expected values include: auditory, tactile, textual, visual.

Relevant types:

- CreativeWork

Values:

[^top]

#### accessibilityAPI

Indicates that the resource is compatible with the referenced accessibility API (WebSchemas wiki lists possible values).

Relevant types:

- CreativeWork

Values:

[^top]

#### accessibilityControl

Identifies input methods that are sufficient to fully control the described resource (WebSchemas wiki lists possible values).

Relevant types:

- CreativeWork

Values:

[^top]

#### accessibilityFeature

Content features of the resource, such as accessible media, alternatives and supported enhancements for accessibility (WebSchemas wiki lists possible values).

Relevant types:

- CreativeWork

Values:

[^top]

#### accessibilityHazard

A characteristic of the described resource that is physiologically dangerous to some users. Related to WCAG 2.0 guideline 2.3 (WebSchemas wiki lists possible values).

Relevant types:

- CreativeWork

Values:

[^top]

#### accessibilitySummary

A human-readable summary of specific accessibility features or deficiencies, consistent with the other accessibility metadata but expressing subtleties such as "short descriptions are present but long descriptions will be needed for non-visual users" or "short descriptions are present and no long descriptions are needed."

Relevant types:

- CreativeWork

Values:

[^top]

#### accommodationCategory

Category of an Accommodation, following real estate conventions e.g. RESO (see PropertySubType, and PropertyType fields for suggested values).

Relevant types:

- Accommodation

Values:

[^top]

#### accommodationFloorPlan

A floorplan of some Accommodation.

Relevant types:

- Accommodation
Relevant types:

- Residence

Values:

[^top]

#### accountId

The identifier for the account the payment will be applied to.

Relevant types:

- Invoice

Values:

[^top]

#### accountMinimumInflow

A minimum amount that has to be paid in every month.

Relevant types:

- BankAccount

Values:

[^top]

#### accountOverdraftLimit

An overdraft is an extension of credit from a lending institution when an account reaches zero. An overdraft allows the individual to continue withdrawing money even if the account has no funds in it. Basically the bank allows people to borrow a set amount of money.

Relevant types:

- BankAccount

Values:

[^top]

#### accountablePerson

Specifies the Person that is legally accountable for the CreativeWork.

Relevant types:

- CreativeWork

Values:

[^top]

#### acquireLicensePage

Indicates a page documenting how licenses can be purchased or otherwise acquired, for the current item.

Relevant types:

- CreativeWork

Values:

[^top]

#### acquiredFrom

The organization or person from which the product was acquired.

Relevant types:

- OwnershipInfo

Values:

[^top]

#### acrissCode

The ACRISS Car Classification Code is a code used by many car rental companies, for classifying vehicles. ACRISS stands for Association of Car Rental Industry Systems and Standards.

Relevant types:

- BusOrCoach
Relevant types:

- Car

Values:

[^top]

#### actionAccessibilityRequirement

A set of requirements that a must be fulfilled in order to perform an Action. If more than one value is specied, fulfilling one set of requirements will allow the Action to be performed.

Relevant types:

- ConsumeAction

Values:

[^top]

#### actionApplication

An application that can complete the request.

Relevant types:

- EntryPoint

Values:

[^top]

#### actionOption

A sub property of object. The options subject to this action.

Relevant types:

- ChooseAction

Values:

[^top]

#### actionPlatform

The high level platform(s) where the Action can be performed for the given URL. To specify a specific application or operating system instance, use actionApplication.

Relevant types:

- EntryPoint

Values:

[^top]

#### actionStatus

Indicates the current disposition of the Action.

Relevant types:

- Action

Values:

[^top]

#### actionableFeedbackPolicy

For a NewsMediaOrganization or other news-related Organization, a statement about public engagement activities (for news media, the newsroom’s), including involving the public - digitally or otherwise -- in coverage decisions, reporting and activities after publication.

Relevant types:

- NewsMediaOrganization
Relevant types:

- Organization

Values:

[^top]

#### activeIngredient

An active ingredient, typically chemical compounds and/or biologic substances.

Relevant types:

- DietarySupplement
Relevant types:

- Drug
Relevant types:

- DrugStrength
Relevant types:

- Substance

Values:

[^top]

#### activityDuration

Length of time to engage in the activity.

Relevant types:

- ExercisePlan

Values:

[^top]

#### activityFrequency

How often one should engage in the activity.

Relevant types:

- ExercisePlan

Values:

[^top]

#### actor

An actor, e.g. in tv, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip.

Relevant types:

- Clip
Relevant types:

- CreativeWorkSeason
Relevant types:

- Episode
Relevant types:

- Event
Relevant types:

- Movie
Relevant types:

- MovieSeries
Relevant types:

- RadioSeries
Relevant types:

- TVSeries
Relevant types:

- VideoGame
Relevant types:

- VideoGameSeries
Relevant types:

- VideoObject

Values:

[^top]

#### actors

An actor, e.g. in tv, radio, movie, video games etc. Actors can be associated with individual items or with a series, episode, clip.

Relevant types:

- Clip
Relevant types:

- Episode
Relevant types:

- Movie
Relevant types:

- MovieSeries
Relevant types:

- RadioSeries
Relevant types:

- TVSeries
Relevant types:

- VideoGame
Relevant types:

- VideoGameSeries
Relevant types:

- VideoObject

Values:

[^top]

#### addOn

An additional offer that can only be obtained in combination with the first base offer (e.g. supplements and extensions that are available for a surcharge).

Relevant types:

- Offer

Values:

[^top]

#### additionalName

An additional name for a Person, can be used for a middle name.

Relevant types:

- Person

Values:

[^top]

#### additionalNumberOfGuests

If responding yes, the number of guests who will attend in addition to the invitee.

Relevant types:

- RsvpAction

Values:

[^top]

#### additionalProperty

A property-value pair representing an additional characteristics of the entitity, e.g. a product feature or another characteristic for which there is no matching property in schema.org.
Note: Publishers should be aware that applications designed to use specific schema.org properties (e.g. https://schema.org/width, https://schema.org/color, https://schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.

Relevant types:

- Place
Relevant types:

- Product
Relevant types:

- QualitativeValue
Relevant types:

- QuantitativeValue

Values:

[^top]

#### additionalType

An additional type for the item, typically used for adding more specific types from external vocabularies in microdata syntax. This is a relationship between something and a class that the thing is in. In RDFa syntax, it is better to use the native RDFa syntax - the 'typeof' attribute - for multiple types. Schema.org tools may have only weaker understanding of extra types, in particular those defined externally.

Relevant types:

- Thing

Values:

[^top]

#### additionalVariable

Any additional component of the exercise prescription that may need to be articulated to the patient. This may include the order of exercises, the number of repetitions of movement, quantitative distance, progressions over time, etc.

Relevant types:

- ExercisePlan

Values:

[^top]

#### address

Physical address of the item.

Relevant types:

- GeoCoordinates
Relevant types:

- GeoShape
Relevant types:

- Organization
Relevant types:

- Person
Relevant types:

- Place

Values:

[^top]

#### addressCountry

The country. For example, USA. You can also provide the two-letter ISO 3166-1 alpha-2 country code.

Relevant types:

- DefinedRegion
Relevant types:

- GeoCoordinates
Relevant types:

- GeoShape
Relevant types:

- PostalAddress

Values:

[^top]

#### addressLocality

The locality in which the street address is, and which is in the region. For example, Mountain View.

Relevant types:

- PostalAddress

Values:

[^top]

#### addressRegion

The region in which the locality is, and which is in the country. For example, California or another appropriate first-level Administrative division

Relevant types:

- DefinedRegion
Relevant types:

- PostalAddress

Values:

[^top]

#### administrationRoute

A route by which this drug may be administered, e.g. 'oral'.

Relevant types:

- Drug

Values:

[^top]

#### advanceBookingRequirement

The amount of time that is required between accepting the offer and the actual usage of the resource or service.

Relevant types:

- Demand
Relevant types:

- Offer

Values:

[^top]

#### adverseOutcome

A possible complication and/or side effect of this therapy. If it is known that an adverse outcome is serious (resulting in death, disability, or permanent damage; requiring hospitalization; or is otherwise life-threatening or requires immediate medical attention), tag it as a seriouseAdverseOutcome instead.

Relevant types:

- MedicalDevice
Relevant types:

- TherapeuticProcedure

Values:

[^top]

#### affectedBy

Drugs that affect the test's results.

Relevant types:

- MedicalTest

Values:

[^top]

#### affiliation

An organization that this person is affiliated with. For example, a school/university, a club, or a team.

Relevant types:

- Person

Values:

[^top]

#### afterMedia

A media object representing the circumstances after performing this direction.

Relevant types:

- HowToDirection

Values:

[^top]

#### agent

The direct performer or driver of the action (animate or inanimate). e.g. John wrote a book.

Relevant types:

- Action

Values:

[^top]

#### aggregateRating

The overall rating, based on a collection of reviews or ratings, of the item.

Relevant types:

- Brand
Relevant types:

- CreativeWork
Relevant types:

- Event
Relevant types:

- Offer
Relevant types:

- Organization
Relevant types:

- Place
Relevant types:

- Product
Relevant types:

- Service

Values:

[^top]

#### aircraft

The kind of aircraft (e.g., "Boeing 747").

Relevant types:

- Flight

Values:

[^top]

#### album

A music album.

Relevant types:

- MusicGroup

Values:

[^top]

#### albumProductionType

Classification of the album by it's type of content: soundtrack, live album, studio album, etc.

Relevant types:

- MusicAlbum

Values:

[^top]

#### albumRelease

A release of this album.

Relevant types:

- MusicAlbum

Values:

[^top]

#### albumReleaseType

The kind of release which this album is: single, EP or album.

Relevant types:

- MusicAlbum

Values:

[^top]

#### albums

A collection of music albums.

Relevant types:

- MusicGroup

Values:

[^top]

#### alcoholWarning

Any precaution, guidance, contraindication, etc. related to consumption of alcohol while taking this drug.

Relevant types:

- Drug

Values:

[^top]

#### algorithm

The algorithm or rules to follow to compute the score.

Relevant types:

- MedicalRiskScore

Values:

[^top]

#### alignmentType

A category of alignment between the learning resource and the framework node. Recommended values include: 'requires', 'textComplexity', 'readingLevel', and 'educationalSubject'.

Relevant types:

- AlignmentObject

Values:

[^top]

#### alternateName

An alias for the item.

Relevant types:

- Thing

Values:

[^top]

#### alternativeHeadline

A secondary title of the CreativeWork.

Relevant types:

- CreativeWork

Values:

[^top]

#### alumni

Alumni of an organization.

Relevant types:

- EducationalOrganization
Relevant types:

- Organization

Values:

[^top]

#### alumniOf

An organization that the person is an alumni of.

Relevant types:

- Person

Values:

[^top]

#### amenityFeature

An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs.

Relevant types:

- Accommodation
Relevant types:

- FloorPlan
Relevant types:

- LodgingBusiness
Relevant types:

- Place

Values:

[^top]

#### amount

The amount of money.

Relevant types:

- DatedMoneySpecification
Relevant types:

- InvestmentOrDeposit
Relevant types:

- LoanOrCredit
Relevant types:

- MonetaryGrant
Relevant types:

- MoneyTransfer

Values:

[^top]

#### amountOfThisGood

The quantity of the goods included in the offer.

Relevant types:

- TypeAndQuantityNode

Values:

[^top]

#### announcementLocation

Indicates a specific CivicStructure or LocalBusiness associated with the SpecialAnnouncement. For example, a specific testing facility or business with special opening hours. For a larger geographic region like a quarantine of an entire region, use spatialCoverage.

Relevant types:

- SpecialAnnouncement

Values:

[^top]

#### annualPercentageRate

The annual rate that is charged for borrowing (or made by investing), expressed as a single percentage number that represents the actual yearly cost of funds over the term of a loan. This includes any fees or additional costs associated with the transaction.

Relevant types:

- FinancialProduct

Values:

[^top]

#### answerCount

The number of answers this question has received.

Relevant types:

- Question

Values:

[^top]

#### answerExplanation

A step-by-step or full explanation about Answer. Can outline how this Answer was achieved or contain more broad clarification or statement about it.

Relevant types:

- Answer

Values:

[^top]

#### antagonist

The muscle whose action counteracts the specified muscle.

Relevant types:

- Muscle

Values:

[^top]

#### appearance

Indicates an occurence of a Claim in some CreativeWork.

Relevant types:

- Claim

Values:

[^top]

#### applicableLocation

The location in which the status applies.

Relevant types:

- DrugCost
Relevant types:

- DrugLegalStatus

Values:

[^top]

#### applicantLocationRequirements

The location(s) applicants can apply from. This is usually used for telecommuting jobs where the applicant does not need to be in a physical office. Note: This should not be used for citizenship or work visa requirements.

Relevant types:

- JobPosting

Values:

[^top]

#### application

An application that can complete the request.

Relevant types:

- EntryPoint

Values:

[^top]

#### applicationCategory

Type of software application, e.g. 'Game, Multimedia'.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### applicationContact

Contact details for further information relevant to this job posting.

Relevant types:

- JobPosting

Values:

[^top]

#### applicationDeadline

The date at which the program stops collecting applications for the next enrollment cycle.

Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### applicationStartDate

The date at which the program begins collecting applications for the next enrollment cycle.

Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### applicationSubCategory

Subcategory of the application, e.g. 'Arcade Game'.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### applicationSuite

The name of the application suite to which the application belongs (e.g. Excel belongs to Office).

Relevant types:

- SoftwareApplication

Values:

[^top]

#### appliesToDeliveryMethod

The delivery method(s) to which the delivery charge or payment charge specification applies.

Relevant types:

- DeliveryChargeSpecification
Relevant types:

- PaymentChargeSpecification

Values:

[^top]

#### appliesToPaymentMethod

The payment method(s) to which the payment charge specification applies.

Relevant types:

- PaymentChargeSpecification

Values:

[^top]

#### archiveHeld

Collection, fonds, or item held, kept or maintained by an ArchiveOrganization.

Relevant types:

- ArchiveOrganization

Values:

[^top]

#### area

The area within which users can expect to reach the broadcast service.

Relevant types:

- BroadcastService

Values:

[^top]

#### areaServed

The geographic area where a service or offered item is provided.

Relevant types:

- ContactPoint
Relevant types:

- DeliveryChargeSpecification
Relevant types:

- Demand
Relevant types:

- Offer
Relevant types:

- Organization
Relevant types:

- Service

Values:

[^top]

#### arrivalAirport

The airport where the flight terminates.

Relevant types:

- Flight

Values:

[^top]

#### arrivalBoatTerminal

The terminal or port from which the boat arrives.

Relevant types:

- BoatTrip

Values:

[^top]

#### arrivalBusStop

The stop or station from which the bus arrives.

Relevant types:

- BusTrip

Values:

[^top]

#### arrivalGate

Identifier of the flight's arrival gate.

Relevant types:

- Flight

Values:

[^top]

#### arrivalPlatform

The platform where the train arrives.

Relevant types:

- TrainTrip

Values:

[^top]

#### arrivalStation

The station where the train trip ends.

Relevant types:

- TrainTrip

Values:

[^top]

#### arrivalTerminal

Identifier of the flight's arrival terminal.

Relevant types:

- Flight

Values:

[^top]

#### arrivalTime

The expected arrival time.

Relevant types:

- Trip

Values:

[^top]

#### artEdition

The number of copies when multiple copies of a piece of artwork are produced - e.g. for a limited edition of 20 prints, 'artEdition' refers to the total number of copies (in this example "20").

Relevant types:

- VisualArtwork

Values:

[^top]

#### artMedium

The material used. (e.g. Oil, Watercolour, Acrylic, Linoprint, Marble, Cyanotype, Digital, Lithograph, DryPoint, Intaglio, Pastel, Woodcut, Pencil, Mixed Media, etc.)

Relevant types:

- VisualArtwork

Values:

[^top]

#### arterialBranch

The branches that comprise the arterial structure.

Relevant types:

- Artery

Values:

[^top]

#### artform

e.g. Painting, Drawing, Sculpture, Print, Photograph, Assemblage, Collage, etc.

Relevant types:

- VisualArtwork

Values:

[^top]

#### articleBody

The actual body of the article.

Relevant types:

- Article

Values:

[^top]

#### articleSection

Articles may belong to one or more 'sections' in a magazine or newspaper, such as Sports, Lifestyle, etc.

Relevant types:

- Article

Values:

[^top]

#### artist

The primary artist for a work in a medium other than pencils or digital line art--for example, if the primary artwork is done in watercolors or digital paints.

Relevant types:

- ComicIssue
Relevant types:

- ComicStory
Relevant types:

- VisualArtwork

Values:

[^top]

#### artworkSurface

The supporting materials for the artwork, e.g. Canvas, Paper, Wood, Board, etc.

Relevant types:

- VisualArtwork

Values:

[^top]

#### aspect

An aspect of medical practice that is considered on the page, such as 'diagnosis', 'treatment', 'causes', 'prognosis', 'etiology', 'epidemiology', etc.

Relevant types:

- MedicalWebPage

Values:

[^top]

#### assembly

Library file name e.g., mscorlib.dll, system.web.dll.

Relevant types:

- APIReference

Values:

[^top]

#### assemblyVersion

Associated product/technology version. e.g., .NET Framework 4.5.

Relevant types:

- APIReference

Values:

[^top]

#### assesses

The item being described is intended to assess the competency or learning outcome defined by the referenced term.

Relevant types:

- CreativeWork
Relevant types:

- EducationEvent
Relevant types:

- LearningResource

Values:

[^top]

#### associatedAnatomy

The anatomy of the underlying organ system or structures associated with this entity.

Relevant types:

- MedicalCondition
Relevant types:

- PhysicalActivity

Values:

[^top]

#### associatedArticle

A NewsArticle associated with the Media Object.

Relevant types:

- MediaObject

Values:

[^top]

#### associatedMedia

A media object that encodes this CreativeWork. This property is a synonym for encoding.

Relevant types:

- CreativeWork
Relevant types:

- HyperToc
Relevant types:

- HyperTocEntry

Values:

[^top]

#### associatedPathophysiology

If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.

Relevant types:

- AnatomicalStructure
Relevant types:

- AnatomicalSystem
Relevant types:

- SuperficialAnatomy

Values:

[^top]

#### athlete

A person that acts as performing member of a sports team; a player as opposed to a coach.

Relevant types:

- SportsTeam

Values:

[^top]

#### attendee

A person or organization attending the event.

Relevant types:

- Event

Values:

[^top]

#### attendees

A person attending the event.

Relevant types:

- Event

Values:

[^top]

#### audience

An intended audience, i.e. a group for whom something was created.

Relevant types:

- CreativeWork
Relevant types:

- Event
Relevant types:

- LodgingBusiness
Relevant types:

- PlayAction
Relevant types:

- Product
Relevant types:

- Service

Values:

[^top]

#### audienceType

The target group associated with a given audience (e.g. veterans, car owners, musicians, etc.).

Relevant types:

- Audience

Values:

[^top]

#### audio

An embedded audio object.

Relevant types:

- CreativeWork

Values:

[^top]

#### authenticator

The Organization responsible for authenticating the user's subscription. For example, many media apps require a cable/satellite provider to authenticate your subscription before playing media.

Relevant types:

- MediaSubscription

Values:

[^top]

#### author

The author of this content or rating. Please note that author is special in that HTML 5 provides a special mechanism for indicating authorship via the rel tag. That is equivalent to this and may be used interchangeably.

Relevant types:

- CreativeWork
Relevant types:

- Rating

Values:

[^top]

#### availability

The availability of this item—for example In stock, Out of stock, Pre-order, etc.

Relevant types:

- Demand
Relevant types:

- Offer

Values:

[^top]

#### availabilityEnds

The end of the availability of the product or service included in the offer.

Relevant types:

- ActionAccessSpecification
Relevant types:

- Demand
Relevant types:

- Offer

Values:

[^top]

#### availabilityStarts

The beginning of the availability of the product or service included in the offer.

Relevant types:

- ActionAccessSpecification
Relevant types:

- Demand
Relevant types:

- Offer

Values:

[^top]

#### availableAtOrFrom

The place(s) from which the offer can be obtained (e.g. store locations).

Relevant types:

- Demand
Relevant types:

- Offer

Values:

[^top]

#### availableChannel

A means of accessing the service (e.g. a phone bank, a web site, a location, etc.).

Relevant types:

- Service

Values:

[^top]

#### availableDeliveryMethod

The delivery method(s) available for this offer.

Relevant types:

- Demand
Relevant types:

- Offer

Values:

[^top]

#### availableFrom

When the item is available for pickup from the store, locker, etc.

Relevant types:

- DeliveryEvent

Values:

[^top]

#### availableIn

The location in which the strength is available.

Relevant types:

- DrugStrength

Values:

[^top]

#### availableLanguage

A language someone may use with or at the item, service or place. Please use one of the language codes from the IETF BCP 47 standard. See also inLanguage

Relevant types:

- ContactPoint
Relevant types:

- LodgingBusiness
Relevant types:

- ServiceChannel
Relevant types:

- TouristAttraction

Values:

[^top]

#### availableOnDevice

Device required to run the application. Used in cases where a specific make/model is required to run the application.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### availableService

A medical service available from this provider.

Relevant types:

- Hospital
Relevant types:

- MedicalClinic
Relevant types:

- Physician

Values:

[^top]

#### availableStrength

An available dosage strength for the drug.

Relevant types:

- Drug

Values:

[^top]

#### availableTest

A diagnostic test or procedure offered by this lab.

Relevant types:

- DiagnosticLab

Values:

[^top]

#### availableThrough

After this date, the item will no longer be available for pickup.

Relevant types:

- DeliveryEvent

Values:

[^top]

#### award

An award won by or for this item.

Relevant types:

- CreativeWork
Relevant types:

- Organization
Relevant types:

- Person
Relevant types:

- Product
Relevant types:

- Service

Values:

[^top]

#### awards

Awards won by or for this item.

Relevant types:

- CreativeWork
Relevant types:

- Organization
Relevant types:

- Person
Relevant types:

- Product

Values:

[^top]

#### awayTeam

The away team in a sports event.

Relevant types:

- SportsEvent

Values:

[^top]

#### backstory

For an Article, typically a NewsArticle, the backstory property provides a textual summary giving a brief explanation of why and how an article was created. In a journalistic setting this could include information about reporting process, methods, interviews, data sources, etc.

Relevant types:

- Article

Values:

[^top]

#### bankAccountType

The type of a bank account.

Relevant types:

- BankAccount

Values:

[^top]

#### baseSalary

The base salary of the job or of an employee in an EmployeeRole.

Relevant types:

- EmployeeRole
Relevant types:

- JobPosting

Values:

[^top]

#### bccRecipient

A sub property of recipient. The recipient blind copied on a message.

Relevant types:

- Message

Values:

[^top]

#### bed

The type of bed or beds included in the accommodation. For the single case of just one bed of a certain type, you use bed directly with a text. If you want to indicate the quantity of a certain kind of bed, use an instance of BedDetails. For more detailed information, use the amenityFeature property.

Relevant types:

- HotelRoom
Relevant types:

- Suite

Values:

[^top]

#### beforeMedia

A media object representing the circumstances before performing this direction.

Relevant types:

- HowToDirection

Values:

[^top]

#### beneficiaryBank

A bank or bank’s branch, financial institution or international financial institution operating the beneficiary’s bank account or releasing funds for the beneficiary.

Relevant types:

- MoneyTransfer

Values:

[^top]

#### benefits

Description of benefits associated with the job.

Relevant types:

- JobPosting

Values:

[^top]

#### benefitsSummaryUrl

The URL that goes directly to the summary of benefits and coverage for the specific standard plan or plan variation.

Relevant types:

- HealthInsurancePlan

Values:

[^top]

#### bestRating

The highest value allowed in this rating system. If bestRating is omitted, 5 is assumed.

Relevant types:

- Rating

Values:

[^top]

#### billingAddress

The billing address for the order.

Relevant types:

- Order

Values:

[^top]

#### billingDuration

Specifies for how long this price (or price component) will be billed. Can be used, for example, to model the contractual duration of a subscription or payment plan. Type can be either a Duration or a Number (in which case the unit of measurement, for example month, is specified by the unitCode property).

Relevant types:

- UnitPriceSpecification

Values:

[^top]

#### billingIncrement

This property specifies the minimal quantity and rounding increment that will be the basis for the billing. The unit of measurement is specified by the unitCode property.

Relevant types:

- UnitPriceSpecification

Values:

[^top]

#### billingPeriod

The time interval used to compute the invoice.

Relevant types:

- Invoice

Values:

[^top]

#### billingStart

Specifies after how much time this price (or price component) becomes valid and billing starts. Can be used, for example, to model a price increase after the first year of a subscription. The unit of measurement is specified by the unitCode property.

Relevant types:

- UnitPriceSpecification

Values:

[^top]

#### biomechnicalClass

The biomechanical properties of the bone.

Relevant types:

- Joint

Values:

[^top]

#### birthDate

Date of birth.

Relevant types:

- Person

Values:

[^top]

#### birthPlace

The place where the person was born.

Relevant types:

- Person

Values:

[^top]

#### bitrate

The bitrate of the media object.

Relevant types:

- MediaObject

Values:

[^top]

#### blogPost

A posting that is part of this blog.

Relevant types:

- Blog

Values:

[^top]

#### blogPosts

The postings that are part of this blog.

Relevant types:

- Blog

Values:

[^top]

#### bloodSupply

The blood vessel that carries blood from the heart to the muscle.

Relevant types:

- Muscle

Values:

[^top]

#### boardingGroup

The airline-specific indicator of boarding order / preference.

Relevant types:

- FlightReservation

Values:

[^top]

#### boardingPolicy

The type of boarding policy used by the airline (e.g. zone-based or group-based).

Relevant types:

- Airline
Relevant types:

- Flight

Values:

[^top]

#### bodyLocation

Location in the body of the anatomical structure.

Relevant types:

- AnatomicalStructure
Relevant types:

- MedicalProcedure

Values:

[^top]

#### bodyType

Indicates the design and body style of the vehicle (e.g. station wagon, hatchback, etc.).

Relevant types:

- Vehicle

Values:

[^top]

#### bookEdition

The edition of the book.

Relevant types:

- Book

Values:

[^top]

#### bookFormat

The format of the book.

Relevant types:

- Book

Values:

[^top]

#### bookingAgent

'bookingAgent' is an out-dated term indicating a 'broker' that serves as a booking agent.

Relevant types:

- Reservation

Values:

[^top]

#### bookingTime

The date and time the reservation was booked.

Relevant types:

- Reservation

Values:

[^top]

#### borrower

A sub property of participant. The person that borrows the object being lent.

Relevant types:

- LendAction

Values:

[^top]

#### box

A box is the area enclosed by the rectangle formed by two points. The first point is the lower corner, the second point is the upper corner. A box is expressed as two points separated by a space character.

Relevant types:

- GeoShape

Values:

[^top]

#### branch

The branches that delineate from the nerve bundle. Not to be confused with branchOf.

Relevant types:

- Nerve

Values:

[^top]

#### branchCode

A short textual code (also called "store code") that uniquely identifies a place of business. The code is typically assigned by the parentOrganization and used in structured URLs.
For example, in the URL http://www.starbucks.co.uk/store-locator/etc/detail/3047 the code "3047" is a branchCode for a particular branch.

Relevant types:

- Place

Values:

[^top]

#### branchOf

The larger organization that this local business is a branch of, if any. Not to be confused with (anatomical)branch.

Relevant types:

- LocalBusiness

Values:

[^top]

#### brand

The brand(s) associated with a product or service, or the brand(s) maintained by an organization or business person.

Relevant types:

- Organization
Relevant types:

- Person
Relevant types:

- Product
Relevant types:

- Service

Values:

[^top]

#### breadcrumb

A set of links that can help a user understand and navigate a website hierarchy.

Relevant types:

- WebPage

Values:

[^top]

#### breastfeedingWarning

Any precaution, guidance, contraindication, etc. related to this drug's use by breastfeeding mothers.

Relevant types:

- Drug

Values:

[^top]

#### broadcastAffiliateOf

The media network(s) whose content is broadcast on this station.

Relevant types:

- BroadcastService

Values:

[^top]

#### broadcastChannelId

The unique address by which the BroadcastService can be identified in a provider lineup. In US, this is typically a number.

Relevant types:

- BroadcastChannel

Values:

[^top]

#### broadcastDisplayName

The name displayed in the channel guide. For many US affiliates, it is the network name.

Relevant types:

- BroadcastService

Values:

[^top]

#### broadcastFrequency

The frequency used for over-the-air broadcasts. Numeric values or simple ranges e.g. 87-99. In addition a shortcut idiom is supported for frequences of AM and FM radio channels, e.g. "87 FM".

Relevant types:

- BroadcastChannel
Relevant types:

- BroadcastService

Values:

[^top]

#### broadcastFrequencyValue

The frequency in MHz for a particular broadcast.

Relevant types:

- BroadcastFrequencySpecification

Values:

[^top]

#### broadcastOfEvent

The event being broadcast such as a sporting event or awards ceremony.

Relevant types:

- BroadcastEvent

Values:

[^top]

#### broadcastServiceTier

The type of service required to have access to the channel (e.g. Standard or Premium).

Relevant types:

- BroadcastChannel

Values:

[^top]

#### broadcastSignalModulation

The modulation (e.g. FM, AM, etc) used by a particular broadcast service.

Relevant types:

- BroadcastFrequencySpecification

Values:

[^top]

#### broadcastSubChannel

The subchannel used for the broadcast.

Relevant types:

- BroadcastFrequencySpecification

Values:

[^top]

#### broadcastTimezone

The timezone in ISO 8601 format for which the service bases its broadcasts

Relevant types:

- BroadcastService

Values:

[^top]

#### broadcaster

The organization owning or operating the broadcast service.

Relevant types:

- BroadcastService

Values:

[^top]

#### broker

An entity that arranges for an exchange between a buyer and a seller. In most cases a broker never acquires or releases ownership of a product or service involved in an exchange. If it is not clear whether an entity is a broker, seller, or buyer, the latter two terms are preferred.

Relevant types:

- Invoice
Relevant types:

- Order
Relevant types:

- Reservation
Relevant types:

- Service

Values:

[^top]

#### browserRequirements

Specifies browser requirements in human-readable text. For example, 'requires HTML5 support'.

Relevant types:

- WebApplication

Values:

[^top]

#### busName

The name of the bus (e.g. Bolt Express).

Relevant types:

- BusTrip

Values:

[^top]

#### busNumber

The unique identifier for the bus.

Relevant types:

- BusTrip

Values:

[^top]

#### businessDays

Days of the week when the merchant typically operates, indicated via opening hours markup.

Relevant types:

- ShippingDeliveryTime

Values:

[^top]

#### businessFunction

The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode). The default is http://purl.org/goodrelations/v1#Sell.

Relevant types:

- Demand
Relevant types:

- Offer
Relevant types:

- TypeAndQuantityNode

Values:

[^top]

#### buyer

A sub property of participant. The participant/person/organization that bought the object.

Relevant types:

- SellAction

Values:

[^top]

#### byArtist

The artist that performed this album or recording.

Relevant types:

- MusicAlbum
Relevant types:

- MusicRecording

Values:

[^top]

#### byDay

Defines the day(s) of the week on which a recurring Event takes place. May be specified using either DayOfWeek, or alternatively Text conforming to iCal's syntax for byDay recurrence rules.

Relevant types:

- Schedule

Values:

[^top]

#### byMonth

Defines the month(s) of the year on which a recurring Event takes place. Specified as an Integer between 1-12. January is 1.

Relevant types:

- Schedule

Values:

[^top]

#### byMonthDay

Defines the day(s) of the month on which a recurring Event takes place. Specified as an Integer between 1-31.

Relevant types:

- Schedule

Values:

[^top]

#### byMonthWeek

Defines the week(s) of the month on which a recurring Event takes place. Specified as an Integer between 1-5. For clarity, byMonthWeek is best used in conjunction with byDay to indicate concepts like the first and third Mondays of a month.

Relevant types:

- Schedule

Values:

[^top]

#### callSign

A callsign, as used in broadcasting and radio communications to identify people, radio and TV stations, or vehicles.

Relevant types:

- BroadcastService
Relevant types:

- Person
Relevant types:

- Vehicle

Values:

[^top]

#### calories

The number of calories.

Relevant types:

- NutritionInformation

Values:

[^top]

#### candidate

A sub property of object. The candidate subject of this action.

Relevant types:

- VoteAction

Values:

[^top]

#### caption

The caption for this object. For downloadable machine formats (closed caption, subtitles etc.) use MediaObject and indicate the encodingFormat.

Relevant types:

- AudioObject
Relevant types:

- ImageObject
Relevant types:

- VideoObject

Values:

[^top]

#### carbohydrateContent

The number of grams of carbohydrates.

Relevant types:

- NutritionInformation

Values:

[^top]

#### cargoVolume

The available volume for cargo or luggage. For automobiles, this is usually the trunk volume.
Typical unit code(s): LTR for liters, FTQ for cubic foot/feet
Note: You can use minValue and maxValue to indicate ranges.

Relevant types:

- Vehicle

Values:

[^top]

#### carrier

'carrier' is an out-dated term indicating the 'provider' for parcel delivery and flights.

Relevant types:

- Flight
Relevant types:

- ParcelDelivery

Values:

[^top]

#### carrierRequirements

Specifies specific carrier(s) requirements for the application (e.g. an application may only work on a specific carrier network).

Relevant types:

- MobileApplication

Values:

[^top]

#### cashBack

A cardholder benefit that pays the cardholder a small percentage of their net expenditures.

Relevant types:

- PaymentCard

Values:

[^top]

#### catalog

A data catalog which contains this dataset.

Relevant types:

- Dataset

Values:

[^top]

#### catalogNumber

The catalog number for the release.

Relevant types:

- MusicRelease

Values:

[^top]

#### category

A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.

Relevant types:

- ActionAccessSpecification
Relevant types:

- Invoice
Relevant types:

- Offer
Relevant types:

- PhysicalActivity
Relevant types:

- Product
Relevant types:

- Recommendation
Relevant types:

- Service
Relevant types:

- SpecialAnnouncement

Values:

[^top]

#### causeOf

The condition, complication, symptom, sign, etc. caused.

Relevant types:

- MedicalCause

Values:

[^top]

#### ccRecipient

A sub property of recipient. The recipient copied on a message.

Relevant types:

- Message

Values:

[^top]

#### character

Fictional person connected with a creative work.

Relevant types:

- CreativeWork

Values:

[^top]

#### characterAttribute

A piece of data that represents a particular aspect of a fictional character (skill, power, character points, advantage, disadvantage).

Relevant types:

- Game
Relevant types:

- VideoGameSeries

Values:

[^top]

#### characterName

The name of a character played in some acting or performing role, i.e. in a PerformanceRole.

Relevant types:

- PerformanceRole

Values:

[^top]

#### cheatCode

Cheat codes to the game.

Relevant types:

- VideoGame
Relevant types:

- VideoGameSeries

Values:

[^top]

#### checkinTime

The earliest someone may check into a lodging establishment.

Relevant types:

- LodgingBusiness
Relevant types:

- LodgingReservation

Values:

[^top]

#### checkoutTime

The latest someone may check out of a lodging establishment.

Relevant types:

- LodgingBusiness
Relevant types:

- LodgingReservation

Values:

[^top]

#### childMaxAge

Maximal age of the child.

Relevant types:

- ParentAudience

Values:

[^top]

#### childMinAge

Minimal age of the child.

Relevant types:

- ParentAudience

Values:

[^top]

#### children

A child of the person.

Relevant types:

- Person

Values:

[^top]

#### cholesterolContent

The number of milligrams of cholesterol.

Relevant types:

- NutritionInformation

Values:

[^top]

#### circle

A circle is the circular region of a specified radius centered at a specified latitude and longitude. A circle is expressed as a pair followed by a radius in meters.

Relevant types:

- GeoShape

Values:

[^top]

#### citation

A citation or reference to another creative work, such as another publication, web page, scholarly article, etc.

Relevant types:

- CreativeWork

Values:

[^top]

#### claimReviewed

A short summary of the specific claims reviewed in a ClaimReview.

Relevant types:

- ClaimReview

Values:

[^top]

#### clincalPharmacology

Description of the absorption and elimination of drugs, including their concentration (pharmacokinetics, pK) and biological effects (pharmacodynamics, pD).

Relevant types:

- Drug

Values:

[^top]

#### clinicalPharmacology

Description of the absorption and elimination of drugs, including their concentration (pharmacokinetics, pK) and biological effects (pharmacodynamics, pD).

Relevant types:

- Drug

Values:

[^top]

#### clipNumber

Position of the clip within an ordered group of clips.

Relevant types:

- Clip

Values:

[^top]

#### closes

The closing hour of the place or service on the given day(s) of the week.

Relevant types:

- OpeningHoursSpecification

Values:

[^top]

#### coach

A person that acts in a coaching role for a sports team.

Relevant types:

- SportsTeam

Values:

[^top]

#### code

A medical code for the entity, taken from a controlled vocabulary or ontology such as ICD-9, DiseasesDB, MeSH, SNOMED-CT, RxNorm, etc.

Relevant types:

- MedicalEntity

Values:

[^top]

#### codeRepository

Link to the repository where the un-compiled, human readable code and related code is located (SVN, github, CodePlex).

Relevant types:

- SoftwareSourceCode

Values:

[^top]

#### codeSampleType

What type of code sample: full (compile ready) solution, code snippet, inline code, scripts, template.

Relevant types:

- SoftwareSourceCode

Values:

[^top]

#### codeValue

A short textual code that uniquely identifies the value.

Relevant types:

- CategoryCode
Relevant types:

- MedicalCode

Values:

[^top]

#### codingSystem

The coding system, e.g. 'ICD-10'.

Relevant types:

- MedicalCode

Values:

[^top]

#### colleague

A colleague of the person.

Relevant types:

- Person

Values:

[^top]

#### colleagues

A colleague of the person.

Relevant types:

- Person

Values:

[^top]

#### collection

A sub property of object. The collection target of the action.

Relevant types:

- UpdateAction

Values:

[^top]

#### collectionSize

The number of items in the Collection.

Relevant types:

- Collection

Values:

[^top]

#### color

The color of the product.

Relevant types:

- Product

Values:

[^top]

#### colorist

The individual who adds color to inked drawings.

Relevant types:

- ComicIssue
Relevant types:

- ComicStory
Relevant types:

- VisualArtwork

Values:

[^top]

#### comment

Comments, typically from users.

Relevant types:

- CreativeWork
Relevant types:

- RsvpAction

Values:

[^top]

#### commentCount

The number of comments this CreativeWork (e.g. Article, Question or Answer) has received. This is most applicable to works published in Web sites with commenting system; additional comments may exist elsewhere.

Relevant types:

- CreativeWork

Values:

[^top]

#### commentText

The text of the UserComment.

Relevant types:

- UserComments

Values:

[^top]

#### commentTime

The time at which the UserComment was made.

Relevant types:

- UserComments

Values:

[^top]

#### competencyRequired

Knowledge, skill, ability or personal attribute that must be demonstrated by a person or other entity in order to do something such as earn an Educational Occupational Credential or understand a LearningResource.

Relevant types:

- EducationalOccupationalCredential
Relevant types:

- LearningResource

Values:

[^top]

#### competitor

A competitor in a sports event.

Relevant types:

- SportsEvent

Values:

[^top]

#### composer

The person or organization who wrote a composition, or who is the composer of a work performed at some event.

Relevant types:

- Event
Relevant types:

- MusicComposition

Values:

[^top]

#### comprisedOf

Specifying something physically contained by something else. Typically used here for the underlying anatomical structures, such as organs, that comprise the anatomical system.

Relevant types:

- AnatomicalSystem

Values:

[^top]

#### conditionsOfAccess

Conditions that affect the availability of, or method(s) of access to, an item. Typically used for real world items such as an ArchiveComponent held by an ArchiveOrganization. This property is not suitable for use as a general Web access control mechanism. It is expressed only in natural language.
For example "Available by appointment from the Reading Room" or "Accessible only from logged-in accounts ".

Relevant types:

- CreativeWork

Values:

[^top]

#### confirmationNumber

A number that confirms the given order or payment has been received.

Relevant types:

- Invoice
Relevant types:

- Order

Values:

[^top]

#### connectedTo

Other anatomical structures to which this structure is connected.

Relevant types:

- AnatomicalStructure

Values:

[^top]

#### constrainingProperty

Indicates a property used as a constraint to define a StatisticalPopulation with respect to the set of entities corresponding to an indicated type (via populationType).

Relevant types:

- StatisticalPopulation

Values:

[^top]

#### contactOption

An option available on this contact point (e.g. a toll-free number or support for hearing-impaired callers).

Relevant types:

- ContactPoint

Values:

[^top]

#### contactPoint

A contact point for a person or organization.

Relevant types:

- HealthInsurancePlan
Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### contactPoints

A contact point for a person or organization.

Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### contactType

A person or organization can have different contact points, for different purposes. For example, a sales contact point, a PR contact point and so on. This property is used to specify the kind of contact point.

Relevant types:

- ContactPoint

Values:

[^top]

#### contactlessPayment

A secure method for consumers to purchase products or services via debit, credit or smartcards by using RFID or NFC technology.

Relevant types:

- PaymentCard

Values:

[^top]

#### containedIn

The basic containment relation between a place and one that contains it.

Relevant types:

- Place

Values:

[^top]

#### containedInPlace

The basic containment relation between a place and one that contains it.

Relevant types:

- Place

Values:

[^top]

#### containsPlace

The basic containment relation between a place and another that it contains.

Relevant types:

- Place

Values:

[^top]

#### containsSeason

A season that is part of the media series.

Relevant types:

- RadioSeries
Relevant types:

- TVSeries
Relevant types:

- VideoGameSeries

Values:

[^top]

#### contentLocation

The location depicted or described in the content. For example, the location in a photograph or painting.

Relevant types:

- CreativeWork

Values:

[^top]

#### contentRating

Official rating of a piece of content—for example,'MPAA PG-13'.

Relevant types:

- CreativeWork

Values:

[^top]

#### contentReferenceTime

The specific time described by a creative work, for works (e.g. articles, video objects etc.) that emphasise a particular moment within an Event.

Relevant types:

- CreativeWork

Values:

[^top]

#### contentSize

File size in (mega/kilo) bytes.

Relevant types:

- MediaObject

Values:

[^top]

#### contentType

The supported content type(s) for an EntryPoint response.

Relevant types:

- EntryPoint

Values:

[^top]

#### contentUrl

Actual bytes of the media object, for example the image file or video file.

Relevant types:

- MediaObject

Values:

[^top]

#### contraindication

A contraindication for this therapy.

Relevant types:

- MedicalDevice
Relevant types:

- MedicalTherapy

Values:

[^top]

#### contributor

A secondary contributor to the CreativeWork or Event.

Relevant types:

- CreativeWork
Relevant types:

- Event

Values:

[^top]

#### cookTime

The time it takes to actually cook the dish, in ISO 8601 duration format.

Relevant types:

- Recipe

Values:

[^top]

#### cookingMethod

The method of cooking, such as Frying, Steaming, ...

Relevant types:

- Recipe

Values:

[^top]

#### copyrightHolder

The party holding the legal copyright to the CreativeWork.

Relevant types:

- CreativeWork

Values:

[^top]

#### copyrightNotice

Text of a notice appropriate for describing the copyright aspects of this Creative Work, ideally indicating the owner of the copyright for the Work.

Relevant types:

- CreativeWork

Values:

[^top]

#### copyrightYear

The year during which the claimed copyright for the CreativeWork was first asserted.

Relevant types:

- CreativeWork

Values:

[^top]

#### correction

Indicates a correction to a CreativeWork, either via a CorrectionComment, textually or in another document.

Relevant types:

- CreativeWork

Values:

[^top]

#### correctionsPolicy

For an Organization (e.g. NewsMediaOrganization), a statement describing (in news media, the newsroom’s) disclosure and correction policy for errors.

Relevant types:

- NewsMediaOrganization
Relevant types:

- Organization

Values:

[^top]

#### costCategory

The category of cost, such as wholesale, retail, reimbursement cap, etc.

Relevant types:

- DrugCost

Values:

[^top]

#### costCurrency

The currency (in 3-letter of the drug cost. See: http://en.wikipedia.org/wiki/ISO_4217.

Relevant types:

- DrugCost

Values:

[^top]

#### costOrigin

Additional details to capture the origin of the cost data. For example, 'Medicare Part B'.

Relevant types:

- DrugCost

Values:

[^top]

#### costPerUnit

The cost per unit of the drug.

Relevant types:

- DrugCost

Values:

[^top]

#### countriesNotSupported

Countries for which the application is not supported. You can also provide the two-letter ISO 3166-1 alpha-2 country code.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### countriesSupported

Countries for which the application is supported. You can also provide the two-letter ISO 3166-1 alpha-2 country code.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### countryOfOrigin

The country of the principal offices of the production company or individual responsible for the movie or program.

Relevant types:

- Movie
Relevant types:

- TVEpisode
Relevant types:

- TVSeason
Relevant types:

- TVSeries

Values:

[^top]

#### course

A sub property of location. The course where this action was taken.

Relevant types:

- ExerciseAction

Values:

[^top]

#### courseCode

The identifier for the Course used by the course provider (e.g. CS101 or 6.001).

Relevant types:

- Course

Values:

[^top]

#### courseMode

The medium or means of delivery of the course instance or the mode of study, either as a text label (e.g. "online", "onsite" or "blended"; "synchronous" or "asynchronous"; "full-time" or "part-time") or as a URL reference to a term from a controlled vocabulary (e.g. https://ceds.ed.gov/element/001311#Asynchronous ).

Relevant types:

- CourseInstance

Values:

[^top]

#### coursePrerequisites

Requirements for taking the Course. May be completion of another Course or a textual description like "permission of instructor". Requirements may be a pre-requisite competency, referenced using AlignmentObject.

Relevant types:

- Course

Values:

[^top]

#### courseWorkload

The amount of work expected of students taking the course, often provided as a figure per week or per month, and may be broken down by type. For example, "2 hours of lectures, 1 hour of lab work and 3 hours of independent study per week".

Relevant types:

- CourseInstance

Values:

[^top]

#### coverageEndTime

The time when the live blog will stop covering the Event. Note that coverage may continue after the Event concludes.

Relevant types:

- LiveBlogPosting

Values:

[^top]

#### coverageStartTime

The time when the live blog will begin covering the Event. Note that coverage may begin before the Event's start time. The LiveBlogPosting may also be created before coverage begins.

Relevant types:

- LiveBlogPosting

Values:

[^top]

#### creativeWorkStatus

The status of a creative work in terms of its stage in a lifecycle. Example terms include Incomplete, Draft, Published, Obsolete. Some organizations define a set of terms for the stages of their publication lifecycle.

Relevant types:

- CreativeWork

Values:

[^top]

#### creator

The creator/author of this CreativeWork. This is the same as the Author property for CreativeWork.

Relevant types:

- CreativeWork
Relevant types:

- UserComments

Values:

[^top]

#### credentialCategory

The category or type of credential being described, for example "degree”, “certificate”, “badge”, or more specific term.

Relevant types:

- EducationalOccupationalCredential

Values:

[^top]

#### creditText

Text that can be used to credit person(s) and/or organization(s) associated with a published Creative Work.

Relevant types:

- CreativeWork

Values:

[^top]

#### creditedTo

The group the release is credited to if different than the byArtist. For example, Red and Blue is credited to "Stefani Germanotta Band", but by Lady Gaga.

Relevant types:

- MusicRelease

Values:

[^top]

#### cssSelector

A CSS selector, e.g. of a SpeakableSpecification or WebPageElement. In the latter case, multiple matches within a page can constitute a single conceptual "Web page element".

Relevant types:

- SpeakableSpecification
Relevant types:

- WebPageElement

Values:

[^top]

#### currenciesAccepted

The currency accepted.
Use standard formats: ISO 4217 currency format e.g. "USD"; Ticker symbol for cryptocurrencies e.g. "BTC"; well known names for Local Exchange Tradings Systems (LETS) and other currency types e.g. "Ithaca HOUR".

Relevant types:

- LocalBusiness

Values:

[^top]

#### currency

The currency in which the monetary amount is expressed.
Use standard formats: ISO 4217 currency format e.g. "USD"; Ticker symbol for cryptocurrencies e.g. "BTC"; well known names for Local Exchange Tradings Systems (LETS) and other currency types e.g. "Ithaca HOUR".

Relevant types:

- DatedMoneySpecification
Relevant types:

- ExchangeRateSpecification
Relevant types:

- LoanOrCredit
Relevant types:

- MonetaryAmount
Relevant types:

- MonetaryAmountDistribution

Values:

[^top]

#### currentExchangeRate

The current price of a currency.

Relevant types:

- ExchangeRateSpecification

Values:

[^top]

#### customer

Party placing the order or paying the invoice.

Relevant types:

- Invoice
Relevant types:

- Order

Values:

[^top]

#### cutoffTime

Order cutoff time allows merchants to describe the time after which they will no longer process orders received on that day. For orders processed after cutoff time, one day gets added to the delivery time estimate. This property is expected to be most typically used via the ShippingRateSettings publication pattern. The time is indicated using the ISO-8601 Time format, e.g. "23:30:00-05:00" would represent 6:30 pm Eastern Standard Time (EST) which is 5 hours behind Coordinated Universal Time (UTC).

Relevant types:

- ShippingDeliveryTime

Values:

[^top]

#### cvdCollectionDate

collectiondate - Date for which patient counts are reported.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### cvdFacilityCounty

Name of the County of the NHSN facility that this data record applies to. Use cvdFacilityId to identify the facility. To provide other details, healthcareReportingData can be used on a Hospital entry.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### cvdFacilityId

Identifier of the NHSN facility that this data record applies to. Use cvdFacilityCounty to indicate the county. To provide other details, healthcareReportingData can be used on a Hospital entry.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### cvdNumBeds

numbeds - HOSPITAL INPATIENT BEDS: Inpatient beds, including all staffed, licensed, and overflow (surge) beds used for inpatients.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### cvdNumBedsOcc

numbedsocc - HOSPITAL INPATIENT BED OCCUPANCY: Total number of staffed inpatient beds that are occupied.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### cvdNumC19Died

numc19died - DEATHS: Patients with suspected or confirmed COVID-19 who died in the hospital, ED, or any overflow location.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### cvdNumC19HOPats

numc19hopats - HOSPITAL ONSET: Patients hospitalized in an NHSN inpatient care location with onset of suspected or confirmed COVID-19 14 or more days after hospitalization.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### cvdNumC19HospPats

numc19hosppats - HOSPITALIZED: Patients currently hospitalized in an inpatient care location who have suspected or confirmed COVID-19.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### cvdNumC19MechVentPats

numc19mechventpats - HOSPITALIZED and VENTILATED: Patients hospitalized in an NHSN inpatient care location who have suspected or confirmed COVID-19 and are on a mechanical ventilator.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### cvdNumC19OFMechVentPats

numc19ofmechventpats - ED/OVERFLOW and VENTILATED: Patients with suspected or confirmed COVID-19 who are in the ED or any overflow location awaiting an inpatient bed and on a mechanical ventilator.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### cvdNumC19OverflowPats

numc19overflowpats - ED/OVERFLOW: Patients with suspected or confirmed COVID-19 who are in the ED or any overflow location awaiting an inpatient bed.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### cvdNumICUBeds

numicubeds - ICU BEDS: Total number of staffed inpatient intensive care unit (ICU) beds.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### cvdNumICUBedsOcc

numicubedsocc - ICU BED OCCUPANCY: Total number of staffed inpatient ICU beds that are occupied.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### cvdNumTotBeds

numtotbeds - ALL HOSPITAL BEDS: Total number of all Inpatient and outpatient beds, including all staffed,ICU, licensed, and overflow (surge) beds used for inpatients or outpatients.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### cvdNumVent

numvent - MECHANICAL VENTILATORS: Total number of ventilators available.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### cvdNumVentUse

numventuse - MECHANICAL VENTILATORS IN USE: Total number of ventilators in use.

Relevant types:

- CDCPMDRecord

Values:

[^top]

#### dataFeedElement

An item within in a data feed. Data feeds may have many elements.

Relevant types:

- DataFeed

Values:

[^top]

#### dataset

A dataset contained in this catalog.

Relevant types:

- DataCatalog

Values:

[^top]

#### datasetTimeInterval

The range of temporal applicability of a dataset, e.g. for a 2011 census dataset, the year 2011 (in ISO 8601 time interval format).

Relevant types:

- Dataset

Values:

[^top]

#### dateCreated

The date on which the CreativeWork was created or the item was added to a DataFeed.

Relevant types:

- CreativeWork
Relevant types:

- DataFeedItem

Values:

[^top]

#### dateDeleted

The datetime the item was removed from the DataFeed.

Relevant types:

- DataFeedItem

Values:

[^top]

#### dateIssued

The date the ticket was issued.

Relevant types:

- Ticket

Values:

[^top]

#### dateModified

The date on which the CreativeWork was most recently modified or when the item's entry was modified within a DataFeed.

Relevant types:

- CreativeWork
Relevant types:

- DataFeedItem

Values:

[^top]

#### datePosted

Publication date of an online listing.

Relevant types:

- CDCPMDRecord
Relevant types:

- JobPosting
Relevant types:

- RealEstateListing
Relevant types:

- SpecialAnnouncement

Values:

[^top]

#### datePublished

Date of first broadcast/publication.

Relevant types:

- CreativeWork

Values:

[^top]

#### dateRead

The date/time at which the message has been read by the recipient if a single recipient exists.

Relevant types:

- Message

Values:

[^top]

#### dateReceived

The date/time the message was received if a single recipient exists.

Relevant types:

- Message

Values:

[^top]

#### dateSent

The date/time at which the message was sent.

Relevant types:

- Message

Values:

[^top]

#### dateVehicleFirstRegistered

The date of the first registration of the vehicle with the respective public authorities.

Relevant types:

- Vehicle

Values:

[^top]

#### dateline

A dateline is a brief piece of text included in news articles that describes where and when the story was written or filed though the date is often omitted. Sometimes only a placename is provided.
Structured representations of dateline-related information can also be expressed more explicitly using locationCreated (which represents where a work was created e.g. where a news report was written). For location depicted or described in the content, use contentLocation.
Dateline summaries are oriented more towards human readers than towards automated processing, and can vary substantially. Some examples: "BEIRUT, Lebanon, June 2.", "Paris, France", "December 19, 2017 11:43AM Reporting from Washington", "Beijing/Moscow", "QUEZON CITY, Philippines".

Relevant types:

- NewsArticle

Values:

[^top]

#### dayOfWeek

The day of the week for which these opening hours are valid.

Relevant types:

- EducationalOccupationalProgram
Relevant types:

- OpeningHoursSpecification

Values:

[^top]

#### deathDate

Date of death.

Relevant types:

- Person

Values:

[^top]

#### deathPlace

The place where the person died.

Relevant types:

- Person

Values:

[^top]

#### defaultValue

The default value of the input. For properties that expect a literal, the default is a literal value, for properties that expect an object, it's an ID reference to one of the current values.

Relevant types:

- PropertyValueSpecification

Values:

[^top]

#### deliveryAddress

Destination address.

Relevant types:

- ParcelDelivery

Values:

[^top]

#### deliveryLeadTime

The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup.

Relevant types:

- Demand
Relevant types:

- Offer

Values:

[^top]

#### deliveryMethod

A sub property of instrument. The method of delivery.

Relevant types:

- OrderAction
Relevant types:

- ReceiveAction
Relevant types:

- SendAction
Relevant types:

- TrackAction

Values:

[^top]

#### deliveryStatus

New entry added as the package passes through each leg of its journey (from shipment to final delivery).

Relevant types:

- ParcelDelivery

Values:

[^top]

#### deliveryTime

The total delay between the receipt of the order and the goods reaching the final customer.

Relevant types:

- DeliveryTimeSettings
Relevant types:

- OfferShippingDetails

Values:

[^top]

#### department

A relationship between an organization and a department of that organization, also described as an organization (allowing different urls, logos, opening hours). For example: a store with a pharmacy, or a bakery with a cafe.

Relevant types:

- Organization

Values:

[^top]

#### departureAirport

The airport where the flight originates.

Relevant types:

- Flight

Values:

[^top]

#### departureBoatTerminal

The terminal or port from which the boat departs.

Relevant types:

- BoatTrip

Values:

[^top]

#### departureBusStop

The stop or station from which the bus departs.

Relevant types:

- BusTrip

Values:

[^top]

#### departureGate

Identifier of the flight's departure gate.

Relevant types:

- Flight

Values:

[^top]

#### departurePlatform

The platform from which the train departs.

Relevant types:

- TrainTrip

Values:

[^top]

#### departureStation

The station from which the train departs.

Relevant types:

- TrainTrip

Values:

[^top]

#### departureTerminal

Identifier of the flight's departure terminal.

Relevant types:

- Flight

Values:

[^top]

#### departureTime

The expected departure time.

Relevant types:

- Trip

Values:

[^top]

#### dependencies

Prerequisites needed to fulfill steps in article.

Relevant types:

- TechArticle

Values:

[^top]

#### depth

The depth of the item.

Relevant types:

- Product
Relevant types:

- VisualArtwork

Values:

[^top]

#### description

A description of the item.

Relevant types:

- Thing

Values:

[^top]

#### device

Device required to run the application. Used in cases where a specific make/model is required to run the application.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### diagnosis

One or more alternative conditions considered in the differential diagnosis process as output of a diagnosis process.

Relevant types:

- DDxElement
Relevant types:

- Patient

Values:

[^top]

#### diagram

An image containing a diagram that illustrates the structure and/or its component substructures and/or connections with other structures.

Relevant types:

- AnatomicalStructure

Values:

[^top]

#### diet

A sub property of instrument. The diet used in this action.

Relevant types:

- ExerciseAction

Values:

[^top]

#### dietFeatures

Nutritional information specific to the dietary plan. May include dietary recommendations on what foods to avoid, what foods to consume, and specific alterations/deviations from the USDA or other regulatory body's approved dietary guidelines.

Relevant types:

- Diet

Values:

[^top]

#### differentialDiagnosis

One of a set of differential diagnoses for the condition. Specifically, a closely-related or competing diagnosis typically considered later in the cognitive process whereby this medical condition is distinguished from others most likely responsible for a similar collection of signs and symptoms to reach the most parsimonious diagnosis or diagnoses in a patient.

Relevant types:

- MedicalCondition

Values:

[^top]

#### director

A director of e.g. tv, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip.

Relevant types:

- Clip
Relevant types:

- CreativeWorkSeason
Relevant types:

- Episode
Relevant types:

- Event
Relevant types:

- Movie
Relevant types:

- MovieSeries
Relevant types:

- RadioSeries
Relevant types:

- TVSeries
Relevant types:

- VideoGame
Relevant types:

- VideoGameSeries
Relevant types:

- VideoObject

Values:

[^top]

#### directors

A director of e.g. tv, radio, movie, video games etc. content. Directors can be associated with individual items or with a series, episode, clip.

Relevant types:

- Clip
Relevant types:

- Episode
Relevant types:

- Movie
Relevant types:

- MovieSeries
Relevant types:

- RadioSeries
Relevant types:

- TVSeries
Relevant types:

- VideoGame
Relevant types:

- VideoGameSeries
Relevant types:

- VideoObject

Values:

[^top]

#### disambiguatingDescription

A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.

Relevant types:

- Thing

Values:

[^top]

#### discount

Any discount applied (to an Order).

Relevant types:

- Order

Values:

[^top]

#### discountCode

Code used to redeem a discount.

Relevant types:

- Order

Values:

[^top]

#### discountCurrency

The currency of the discount.
Use standard formats: ISO 4217 currency format e.g. "USD"; Ticker symbol for cryptocurrencies e.g. "BTC"; well known names for Local Exchange Tradings Systems (LETS) and other currency types e.g. "Ithaca HOUR".

Relevant types:

- Order

Values:

[^top]

#### discusses

Specifies the CreativeWork associated with the UserComment.

Relevant types:

- UserComments

Values:

[^top]

#### discussionUrl

A link to the page containing the comments of the CreativeWork.

Relevant types:

- CreativeWork

Values:

[^top]

#### diseasePreventionInfo

Information about disease prevention.

Relevant types:

- SpecialAnnouncement

Values:

[^top]

#### diseaseSpreadStatistics

Statistical information about the spread of a disease, either as WebContent, or described directly as a Dataset, or the specific Observations in the dataset. When a WebContent URL is provided, the page indicated might also contain more such markup.

Relevant types:

- SpecialAnnouncement

Values:

[^top]

#### dissolutionDate

The date that this organization was dissolved.

Relevant types:

- Organization

Values:

[^top]

#### distance

The distance travelled, e.g. exercising or travelling.

Relevant types:

- ExerciseAction
Relevant types:

- TravelAction

Values:

[^top]

#### distinguishingSign

One of a set of signs and symptoms that can be used to distinguish this diagnosis from others in the differential diagnosis.

Relevant types:

- DDxElement

Values:

[^top]

#### distribution

A downloadable form of this dataset, at a specific location, in a specific format.

Relevant types:

- Dataset

Values:

[^top]

#### diversityPolicy

Statement on diversity policy by an Organization e.g. a NewsMediaOrganization. For a NewsMediaOrganization, a statement describing the newsroom’s diversity policy on both staffing and sources, typically providing staffing data.

Relevant types:

- NewsMediaOrganization
Relevant types:

- Organization

Values:

[^top]

#### diversityStaffingReport

For an Organization (often but not necessarily a NewsMediaOrganization), a report on staffing diversity issues. In a news context this might be for example ASNE or RTDNA (US) reports, or self-reported.

Relevant types:

- NewsMediaOrganization
Relevant types:

- Organization

Values:

[^top]

#### documentation

Further documentation describing the Web API in more detail.

Relevant types:

- WebAPI

Values:

[^top]

#### doesNotShip

Indicates when shipping to a particular shippingDestination is not available.

Relevant types:

- OfferShippingDetails
Relevant types:

- ShippingRateSettings

Values:

[^top]

#### domainIncludes

Relates a property to a class that is (one of) the type(s) the property is expected to be used on.

Relevant types:

- Property

Values:

[^top]

#### domiciledMortgage

Whether borrower is a resident of the jurisdiction where the property is located.

Relevant types:

- MortgageLoan

Values:

[^top]

#### doorTime

The time admission will commence.

Relevant types:

- Event

Values:

[^top]

#### dosageForm

A dosage form in which this drug/supplement is available, e.g. 'tablet', 'suspension', 'injection'.

Relevant types:

- Drug

Values:

[^top]

#### doseSchedule

A dosing schedule for the drug for a given population, either observed, recommended, or maximum dose based on the type used.

Relevant types:

- Drug
Relevant types:

- TherapeuticProcedure

Values:

[^top]

#### doseUnit

The unit of the dose, e.g. 'mg'.

Relevant types:

- DoseSchedule

Values:

[^top]

#### doseValue

The value of the dose, e.g. 500.

Relevant types:

- DoseSchedule

Values:

[^top]

#### downPayment

a type of payment made in cash during the onset of the purchase of an expensive good/service. The payment typically represents only a percentage of the full purchase price.

Relevant types:

- RepaymentSpecification

Values:

[^top]

#### downloadUrl

If the file can be downloaded, URL to download the binary.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### downvoteCount

The number of downvotes this question, answer or comment has received from the community.

Relevant types:

- Comment

Values:

[^top]

#### drainsTo

The vasculature that the vein drains into.

Relevant types:

- Vein

Values:

[^top]

#### driveWheelConfiguration

The drive wheel configuration, i.e. which roadwheels will receive torque from the vehicle's engine via the drivetrain.

Relevant types:

- Vehicle

Values:

[^top]

#### dropoffLocation

Where a rental car can be dropped off.

Relevant types:

- RentalCarReservation

Values:

[^top]

#### dropoffTime

When a rental car can be dropped off.

Relevant types:

- RentalCarReservation

Values:

[^top]

#### drug

Specifying a drug or medicine used in a medication procedure.

Relevant types:

- DrugClass
Relevant types:

- MedicalCondition
Relevant types:

- Patient
Relevant types:

- TherapeuticProcedure

Values:

[^top]

#### drugClass

The class of drug this belongs to (e.g., statins).

Relevant types:

- Drug

Values:

[^top]

#### drugUnit

The unit in which the drug is measured, e.g. '5 mg tablet'.

Relevant types:

- Drug
Relevant types:

- DrugCost

Values:

[^top]

#### duns

The Dun & Bradstreet DUNS number for identifying an organization or business person.

Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### duplicateTherapy

A therapy that duplicates or overlaps this one.

Relevant types:

- MedicalTherapy

Values:

[^top]

#### duration

The duration of the item (movie, audio recording, event, etc.) in ISO 8601 date format.

Relevant types:

- Audiobook
Relevant types:

- Episode
Relevant types:

- Event
Relevant types:

- MediaObject
Relevant types:

- Movie
Relevant types:

- MusicRecording
Relevant types:

- MusicRelease
Relevant types:

- QuantitativeValueDistribution
Relevant types:

- Schedule

Values:

[^top]

#### durationOfWarranty

The duration of the warranty promise. Common unitCode values are ANN for year, MON for months, or DAY for days.

Relevant types:

- WarrantyPromise

Values:

[^top]

#### duringMedia

A media object representing the circumstances while performing this direction.

Relevant types:

- HowToDirection

Values:

[^top]

#### earlyPrepaymentPenalty

The amount to be paid as a penalty in the event of early payment of the loan.

Relevant types:

- RepaymentSpecification

Values:

[^top]

#### editEIDR

An EIDR (Entertainment Identifier Registry) identifier representing a specific edit / edition for a work of film or television.
For example, the motion picture known as "Ghostbusters" whose titleEIDR is "10.5240/7EC7-228A-510A-053E-CBB8-J", has several edits e.g. "10.5240/1F2A-E1C5-680A-14C6-E76B-I" and "10.5240/8A35-3BEE-6497-5D12-9E4F-3".
Since schema.org types like Movie and TVEpisode can be used for both works and their multiple expressions, it is possible to use titleEIDR alone (for a general description), or alongside editEIDR for a more edit-specific description.

Relevant types:

- CreativeWork

Values:

[^top]

#### editor

Specifies the Person who edited the CreativeWork.

Relevant types:

- CreativeWork

Values:

[^top]

#### eduQuestionType

For questions that are part of learning resources (e.g. Quiz), eduQuestionType indicates the format of question being given. Example: "Multiple choice", "Open ended", "Flashcard".

Relevant types:

- Question
Relevant types:

- SolveMathAction

Values:

[^top]

#### educationRequirements

Educational background needed for the position or Occupation.

Relevant types:

- JobPosting
Relevant types:

- Occupation

Values:

[^top]

#### educationalAlignment

An alignment to an established educational framework.
This property should not be used where the nature of the alignment can be described using a simple property, for example to express that a resource teaches or assesses a competency.

Relevant types:

- CreativeWork
Relevant types:

- LearningResource

Values:

[^top]

#### educationalCredentialAwarded

A description of the qualification, award, certificate, diploma or other educational credential awarded as a consequence of successful completion of this course or program.

Relevant types:

- Course
Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### educationalFramework

The framework to which the resource being described is aligned.

Relevant types:

- AlignmentObject

Values:

[^top]

#### educationalLevel

The level in terms of progression through an educational or training context. Examples of educational levels include 'beginner', 'intermediate' or 'advanced', and formal sets of level indicators.

Relevant types:

- CreativeWork
Relevant types:

- EducationEvent
Relevant types:

- EducationalOccupationalCredential
Relevant types:

- LearningResource

Values:

[^top]

#### educationalProgramMode

Similar to courseMode, The medium or means of delivery of the program as a whole. The value may either be a text label (e.g. "online", "onsite" or "blended"; "synchronous" or "asynchronous"; "full-time" or "part-time") or a URL reference to a term from a controlled vocabulary (e.g. https://ceds.ed.gov/element/001311#Asynchronous ).

Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### educationalRole

An educationalRole of an EducationalAudience.

Relevant types:

- EducationalAudience

Values:

[^top]

#### educationalUse

The purpose of a work in the context of education; for example, 'assignment', 'group work'.

Relevant types:

- CreativeWork
Relevant types:

- LearningResource

Values:

[^top]

#### elevation

The elevation of a location (WGS 84). Values may be of the form 'NUMBER UNITOFMEASUREMENT' (e.g., '1,000 m', '3,200 ft') while numbers alone should be assumed to be a value in meters.

Relevant types:

- GeoCoordinates
Relevant types:

- GeoShape

Values:

[^top]

#### eligibilityToWorkRequirement

The legal requirements such as citizenship, visa and other documentation required for an applicant to this job.

Relevant types:

- JobPosting

Values:

[^top]

#### eligibleCustomerType

The type(s) of customers for which the given offer is valid.

Relevant types:

- Demand
Relevant types:

- Offer

Values:

[^top]

#### eligibleDuration

The duration for which the given offer is valid.

Relevant types:

- Demand
Relevant types:

- Offer

Values:

[^top]

#### eligibleQuantity

The interval and unit of measurement of ordering quantities for which the offer or price specification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity.

Relevant types:

- Demand
Relevant types:

- Offer
Relevant types:

- PriceSpecification

Values:

[^top]

#### eligibleRegion

The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.
See also ineligibleRegion.

Relevant types:

- ActionAccessSpecification
Relevant types:

- DeliveryChargeSpecification
Relevant types:

- Demand
Relevant types:

- Offer

Values:

[^top]

#### eligibleTransactionVolume

The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g. for indicating a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases to a certain minimal amount.

Relevant types:

- Demand
Relevant types:

- Offer
Relevant types:

- PriceSpecification

Values:

[^top]

#### email

Email address.

Relevant types:

- ContactPoint
Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### embedUrl

A URL pointing to a player for a specific video. In general, this is the information in the `src` element of an `embed` tag and should not be the same as the content of the `loc` tag.

Relevant types:

- MediaObject

Values:

[^top]

#### emissionsCO2

The CO2 emissions in g/km. When used in combination with a QuantitativeValue, put "g/km" into the unitText property of that value, since there is no UN/CEFACT Common Code for "g/km".

Relevant types:

- Vehicle

Values:

[^top]

#### employee

Someone working for this organization.

Relevant types:

- Organization

Values:

[^top]

#### employees

People working for this organization.

Relevant types:

- Organization

Values:

[^top]

#### employerOverview

A description of the employer, career opportunities and work environment for this position.

Relevant types:

- JobPosting

Values:

[^top]

#### employmentType

Type of employment (e.g. full-time, part-time, contract, temporary, seasonal, internship).

Relevant types:

- JobPosting

Values:

[^top]

#### employmentUnit

Indicates the department, unit and/or facility where the employee reports and/or in which the job is to be performed.

Relevant types:

- JobPosting

Values:

[^top]

#### encodesCreativeWork

The CreativeWork encoded by this media object.

Relevant types:

- MediaObject

Values:

[^top]

#### encoding

A media object that encodes this CreativeWork. This property is a synonym for associatedMedia.

Relevant types:

- CreativeWork

Values:

[^top]

#### encodingFormat

Media type typically expressed using a MIME format (see IANA site and MDN reference) e.g. application/zip for a SoftwareApplication binary, audio/mpeg for .mp3 etc.).
In cases where a CreativeWork has several media type representations, encoding can be used to indicate each MediaObject alongside particular encodingFormat information.
Unregistered or niche encoding and file formats can be indicated instead via the most appropriate URL, e.g. defining Web page or a Wikipedia/Wikidata entry.

Relevant types:

- CreativeWork
Relevant types:

- MediaObject

Values:

[^top]

#### encodingType

The supported encoding type(s) for an EntryPoint request.

Relevant types:

- EntryPoint

Values:

[^top]

#### encodings

A media object that encodes this CreativeWork.

Relevant types:

- CreativeWork

Values:

[^top]

#### endDate

The end date and time of the item (in ISO 8601 date format).

Relevant types:

- CreativeWorkSeason
Relevant types:

- CreativeWorkSeries
Relevant types:

- DatedMoneySpecification
Relevant types:

- EducationalOccupationalProgram
Relevant types:

- Event
Relevant types:

- Role
Relevant types:

- Schedule

Values:

[^top]

#### endOffset

The end time of the clip expressed as the number of seconds from the beginning of the work.

Relevant types:

- Clip

Values:

[^top]

#### endTime

The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. e.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the end of a clip within a larger file.
Note that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.

Relevant types:

- Action
Relevant types:

- FoodEstablishmentReservation
Relevant types:

- MediaObject
Relevant types:

- Schedule

Values:

[^top]

#### endorsee

A sub property of participant. The person/organization being supported.

Relevant types:

- EndorseAction

Values:

[^top]

#### endorsers

People or organizations that endorse the plan.

Relevant types:

- Diet

Values:

[^top]

#### energyEfficiencyScaleMax

Specifies the most energy efficient class on the regulated EU energy consumption scale for the product category a product belongs to. For example, energy consumption for televisions placed on the market after January 1, 2020 is scaled from D to A+++.

Relevant types:

- EnergyConsumptionDetails

Values:

[^top]

#### energyEfficiencyScaleMin

Specifies the least energy efficient class on the regulated EU energy consumption scale for the product category a product belongs to. For example, energy consumption for televisions placed on the market after January 1, 2020 is scaled from D to A+++.

Relevant types:

- EnergyConsumptionDetails

Values:

[^top]

#### engineDisplacement

The volume swept by all of the pistons inside the cylinders of an internal combustion engine in a single movement.
Typical unit code(s): CMQ for cubic centimeter, LTR for liters, INQ for cubic inches * Note 1: You can link to information about how the given value has been determined using the valueReference property. * Note 2: You can use minValue and maxValue to indicate ranges.

Relevant types:

- EngineSpecification

Values:

[^top]

#### enginePower

The power of the vehicle's engine. Typical unit code(s): KWT for kilowatt, BHP for brake horsepower, N12 for metric horsepower (PS, with 1 PS = 735,49875 W)

- Note 1: There are many different ways of measuring an engine's power. For an overview, see http://en.wikipedia.org/wiki/Horsepower#Enginepowertest_codes.
- Note 2: You can link to information about how the given value has been determined using the valueReference property.
- Note 3: You can use minValue and maxValue to indicate ranges.

Relevant types:

- EngineSpecification

Values:

[^top]

#### engineType

The type of engine or engines powering the vehicle.

Relevant types:

- EngineSpecification

Values:

[^top]

#### entertainmentBusiness

A sub property of location. The entertainment business where the action occurred.

Relevant types:

- PerformAction

Values:

[^top]

#### epidemiology

The characteristics of associated patients, such as age, gender, race etc.

Relevant types:

- MedicalCondition
Relevant types:

- PhysicalActivity

Values:

[^top]

#### episode

An episode of a tv, radio or game media within a series or season.

Relevant types:

- CreativeWorkSeason
Relevant types:

- RadioSeries
Relevant types:

- TVSeries
Relevant types:

- VideoGameSeries

Values:

[^top]

#### episodeNumber

Position of the episode within an ordered group of episodes.

Relevant types:

- Episode

Values:

[^top]

#### episodes

An episode of a TV/radio series or season.

Relevant types:

- CreativeWorkSeason
Relevant types:

- RadioSeries
Relevant types:

- TVSeries
Relevant types:

- VideoGameSeries

Values:

[^top]

#### equal

This ordering relation for qualitative values indicates that the subject is equal to the object.

Relevant types:

- QualitativeValue

Values:

[^top]

#### error

For failed actions, more information on the cause of the failure.

Relevant types:

- Action

Values:

[^top]

#### estimatedCost

The estimated cost of the supply or supplies consumed when performing instructions.

Relevant types:

- HowTo
Relevant types:

- HowToSupply

Values:

[^top]

#### estimatedFlightDuration

The estimated time the flight will take.

Relevant types:

- Flight

Values:

[^top]

#### estimatedSalary

An estimated salary for a job posting or occupation, based on a variety of variables including, but not limited to industry, job title, and location. Estimated salaries are often computed by outside organizations rather than the hiring organization, who may not have committed to the estimated value.

Relevant types:

- JobPosting
Relevant types:

- Occupation

Values:

[^top]

#### estimatesRiskOf

The condition, complication, or symptom whose risk is being estimated.

Relevant types:

- MedicalRiskEstimator

Values:

[^top]

#### ethicsPolicy

Statement about ethics policy, e.g. of a NewsMediaOrganization regarding journalistic and publishing practices, or of a Restaurant, a page describing food source policies. In the case of a NewsMediaOrganization, an ethicsPolicy is typically a statement describing the personal, organizational, and corporate standards of behavior expected by the organization.

Relevant types:

- NewsMediaOrganization
Relevant types:

- Organization

Values:

[^top]

#### event

Upcoming or past event associated with this place, organization, or action.

Relevant types:

- InformAction
Relevant types:

- InviteAction
Relevant types:

- JoinAction
Relevant types:

- LeaveAction
Relevant types:

- Organization
Relevant types:

- Place
Relevant types:

- PlayAction

Values:

[^top]

#### eventAttendanceMode

The eventAttendanceMode of an event indicates whether it occurs online, offline, or a mix.

Relevant types:

- Event

Values:

[^top]

#### eventSchedule

Associates an Event with a Schedule. There are circumstances where it is preferable to share a schedule for a series of repeating events rather than data on the individual events themselves. For example, a website or application might prefer to publish a schedule for a weekly gym class rather than provide data on every event. A schedule could be processed by applications to add forthcoming events to a calendar. An Event that is associated with a Schedule using this property should not have startDate or endDate properties. These are instead defined within the associated Schedule, this avoids any ambiguity for clients using the data. The property might have repeated values to specify different schedules, e.g. for different months or seasons.

Relevant types:

- Event

Values:

[^top]

#### eventStatus

An eventStatus of an event represents its status; particularly useful when an event is cancelled or rescheduled.

Relevant types:

- Event

Values:

[^top]

#### events

Upcoming or past events associated with this place or organization.

Relevant types:

- Organization
Relevant types:

- Place

Values:

[^top]

#### evidenceLevel

Strength of evidence of the data used to formulate the guideline (enumerated).

Relevant types:

- MedicalGuideline

Values:

[^top]

#### evidenceOrigin

Source of the data used to formulate the guidance, e.g. RCT, consensus opinion, etc.

Relevant types:

- MedicalGuideline

Values:

[^top]

#### exampleOfWork

A creative work that this work is an example/instance/realization/derivation of.

Relevant types:

- CreativeWork

Values:

[^top]

#### exceptDate

Defines a Date or DateTime during which a scheduled Event will not take place. The property allows exceptions to a Schedule to be specified. If an exception is specified as a DateTime then only the event that would have started at that specific date and time should be excluded from the schedule. If an exception is specified as a Date then any event that is scheduled for that 24 hour period should be excluded from the schedule. This allows a whole day to be excluded from the schedule without having to itemise every scheduled event.

Relevant types:

- Schedule

Values:

[^top]

#### exchangeRateSpread

The difference between the price at which a broker or other intermediary buys and sells foreign currency.

Relevant types:

- ExchangeRateSpecification

Values:

[^top]

#### executableLibraryName

Library file name e.g., mscorlib.dll, system.web.dll.

Relevant types:

- APIReference

Values:

[^top]

#### exerciseCourse

A sub property of location. The course where this action was taken.

Relevant types:

- ExerciseAction

Values:

[^top]

#### exercisePlan

A sub property of instrument. The exercise plan used on this action.

Relevant types:

- ExerciseAction

Values:

[^top]

#### exerciseRelatedDiet

A sub property of instrument. The diet used in this action.

Relevant types:

- ExerciseAction

Values:

[^top]

#### exerciseType

Type(s) of exercise or activity, such as strength training, flexibility training, aerobics, cardiac rehabilitation, etc.

Relevant types:

- ExerciseAction
Relevant types:

- ExercisePlan

Values:

[^top]

#### exifData

exif data for this object.

Relevant types:

- ImageObject

Values:

[^top]

#### expectedArrivalFrom

The earliest date the package may arrive.

Relevant types:

- ParcelDelivery

Values:

[^top]

#### expectedArrivalUntil

The latest date the package may arrive.

Relevant types:

- ParcelDelivery

Values:

[^top]

#### expectedPrognosis

The likely outcome in either the short term or long term of the medical condition.

Relevant types:

- MedicalCondition

Values:

[^top]

#### expectsAcceptanceOf

An Offer which must be accepted before the user can perform the Action. For example, the user may need to buy a movie before being able to watch it.

Relevant types:

- ActionAccessSpecification
Relevant types:

- ConsumeAction
Relevant types:

- MediaSubscription

Values:

[^top]

#### experienceInPlaceOfEducation

Indicates whether a JobPosting will accept experience (as indicated by OccupationalExperienceRequirements) in place of its formal educational qualifications (as indicated by educationRequirements). If true, indicates that satisfying one of these requirements is sufficient.

Relevant types:

- JobPosting

Values:

[^top]

#### experienceRequirements

Description of skills and experience needed for the position or Occupation.

Relevant types:

- JobPosting
Relevant types:

- Occupation

Values:

[^top]

#### expertConsiderations

Medical expert advice related to the plan.

Relevant types:

- Diet

Values:

[^top]

#### expires

Date the content expires and is no longer useful or available. For example a VideoObject or NewsArticle whose availability or relevance is time-limited, or a ClaimReview fact check whose publisher wants to indicate that it may no longer be relevant (or helpful to highlight) after some date.

Relevant types:

- CreativeWork

Values:

[^top]

#### familyName

Family name. In the U.S., the last name of a Person.

Relevant types:

- Person

Values:

[^top]

#### fatContent

The number of grams of fat.

Relevant types:

- NutritionInformation

Values:

[^top]

#### faxNumber

The fax number.

Relevant types:

- ContactPoint
Relevant types:

- Organization
Relevant types:

- Person
Relevant types:

- Place

Values:

[^top]

#### featureList

Features or modules provided by this application (and possibly required by other applications).

Relevant types:

- SoftwareApplication

Values:

[^top]

#### feesAndCommissionsSpecification

Description of fees, commissions, and other terms applied either to a class of financial product, or by a financial service organization.

Relevant types:

- FinancialProduct
Relevant types:

- FinancialService

Values:

[^top]

#### fiberContent

The number of grams of fiber.

Relevant types:

- NutritionInformation

Values:

[^top]

#### fileFormat

Media type, typically MIME format (see IANA site) of the content e.g. application/zip of a SoftwareApplication binary. In cases where a CreativeWork has several media type representations, 'encoding' can be used to indicate each MediaObject alongside particular fileFormat information. Unregistered or niche file formats can be indicated instead via the most appropriate URL, e.g. defining Web page or a Wikipedia entry.

Relevant types:

- CreativeWork

Values:

[^top]

#### fileSize

Size of the application / package (e.g. 18MB). In the absence of a unit (MB, KB etc.), KB will be assumed.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### financialAidEligible

A financial aid type or program which students may use to pay for tuition or fees associated with the program.

Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### firstAppearance

Indicates the first known occurence of a Claim in some CreativeWork.

Relevant types:

- Claim

Values:

[^top]

#### firstPerformance

The date and place the work was first performed.

Relevant types:

- MusicComposition

Values:

[^top]

#### flightDistance

The distance of the flight.

Relevant types:

- Flight

Values:

[^top]

#### flightNumber

The unique identifier for a flight including the airline IATA code. For example, if describing United flight 110, where the IATA code for United is 'UA', the flightNumber is 'UA110'.

Relevant types:

- Flight

Values:

[^top]

#### floorLevel

The floor level for an Accommodation in a multi-storey building. Since counting systems vary internationally, the local system should be used where possible.

Relevant types:

- Accommodation

Values:

[^top]

#### floorLimit

A floor limit is the amount of money above which credit card transactions must be authorized.

Relevant types:

- PaymentCard

Values:

[^top]

#### floorSize

The size of the accommodation, e.g. in square meter or squarefoot. Typical unit code(s): MTK for square meter, FTK for square foot, or YDK for square yard

Relevant types:

- Accommodation
Relevant types:

- FloorPlan

Values:

[^top]

#### followee

A sub property of object. The person or organization being followed.

Relevant types:

- FollowAction

Values:

[^top]

#### follows

The most generic uni-directional social relation.

Relevant types:

- Person

Values:

[^top]

#### followup

Typical or recommended followup care after the procedure is performed.

Relevant types:

- MedicalProcedure

Values:

[^top]

#### foodEstablishment

A sub property of location. The specific food establishment where the action occurred.

Relevant types:

- CookAction

Values:

[^top]

#### foodEvent

A sub property of location. The specific food event where the action occurred.

Relevant types:

- CookAction

Values:

[^top]

#### foodWarning

Any precaution, guidance, contraindication, etc. related to consumption of specific foods while taking this drug.

Relevant types:

- Drug

Values:

[^top]

#### founder

A person who founded this organization.

Relevant types:

- Organization

Values:

[^top]

#### founders

A person who founded this organization.

Relevant types:

- Organization

Values:

[^top]

#### foundingDate

The date that this organization was founded.

Relevant types:

- Organization

Values:

[^top]

#### foundingLocation

The place where the Organization was founded.

Relevant types:

- Organization

Values:

[^top]

#### free

A flag to signal that the item, event, or place is accessible for free.

Relevant types:

- PublicationEvent

Values:

[^top]

#### freeShippingThreshold

A monetary value above which (or equal to) the shipping rate becomes free. Intended to be used via an OfferShippingDetails with shippingSettingsLink matching this ShippingRateSettings.

Relevant types:

- ShippingRateSettings

Values:

[^top]

#### frequency

How often the dose is taken, e.g. 'daily'.

Relevant types:

- DoseSchedule

Values:

[^top]

#### fromLocation

A sub property of location. The original location of the object or the agent before the action.

Relevant types:

- ExerciseAction
Relevant types:

- MoveAction
Relevant types:

- TransferAction

Values:

[^top]

#### fuelCapacity

The capacity of the fuel tank or in the case of electric cars, the battery. If there are multiple components for storage, this should indicate the total of all storage of the same type.
Typical unit code(s): LTR for liters, GLL of US gallons, GLI for UK / imperial gallons, AMH for ampere-hours (for electrical vehicles).

Relevant types:

- Vehicle

Values:

[^top]

#### fuelConsumption

The amount of fuel consumed for traveling a particular distance or temporal duration with the given vehicle (e.g. liters per 100 km).

- Note 1: There are unfortunately no standard unit codes for liters per 100 km. Use unitText to indicate the unit of measurement, e.g. L/100 km.
- Note 2: There are two ways of indicating the fuel consumption, fuelConsumption (e.g. 8 liters per 100 km) and fuelEfficiency (e.g. 30 miles per gallon). They are reciprocal.
- Note 3: Often, the absolute value is useful only when related to driving speed ("at 80 km/h") or usage pattern ("city traffic"). You can use valueReference to link the value for the fuel consumption to another value.

Relevant types:

- Vehicle

Values:

[^top]

#### fuelEfficiency

The distance traveled per unit of fuel used; most commonly miles per gallon (mpg) or kilometers per liter (km/L).

- Note 1: There are unfortunately no standard unit codes for miles per gallon or kilometers per liter. Use unitText to indicate the unit of measurement, e.g. mpg or km/L.
- Note 2: There are two ways of indicating the fuel consumption, fuelConsumption (e.g. 8 liters per 100 km) and fuelEfficiency (e.g. 30 miles per gallon). They are reciprocal.
- Note 3: Often, the absolute value is useful only when related to driving speed ("at 80 km/h") or usage pattern ("city traffic"). You can use valueReference to link the value for the fuel economy to another value.

Relevant types:

- Vehicle

Values:

[^top]

#### fuelType

The type of fuel suitable for the engine or engines of the vehicle. If the vehicle has only one engine, this property can be attached directly to the vehicle.

Relevant types:

- EngineSpecification
Relevant types:

- Vehicle

Values:

[^top]

#### functionalClass

The degree of mobility the joint allows.

Relevant types:

- Joint

Values:

[^top]

#### fundedItem

Indicates an item funded or sponsored through a Grant.

Relevant types:

- Grant

Values:

[^top]

#### funder

A person or organization that supports (sponsors) something through some kind of financial contribution.

Relevant types:

- CreativeWork
Relevant types:

- Event
Relevant types:

- MonetaryGrant
Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### game

Video game which is played on this server.

Relevant types:

- GameServer

Values:

[^top]

#### gameItem

An item is an object within the game world that can be collected by a player or, occasionally, a non-player character.

Relevant types:

- Game
Relevant types:

- VideoGameSeries

Values:

[^top]

#### gameLocation

Real or fictional location of the game (or part of game).

Relevant types:

- Game
Relevant types:

- VideoGameSeries

Values:

[^top]

#### gamePlatform

The electronic systems used to play video games.

Relevant types:

- VideoGame
Relevant types:

- VideoGameSeries

Values:

[^top]

#### gameServer

The server on which it is possible to play the game.

Relevant types:

- VideoGame

Values:

[^top]

#### gameTip

Links to tips, tactics, etc.

Relevant types:

- VideoGame

Values:

[^top]

#### gender

Gender of something, typically a Person, but possibly also fictional characters, animals, etc. While https://schema.org/Male and https://schema.org/Female may be used, text strings are also acceptable for people who do not identify as a binary gender. The gender property can also be used in an extended sense to cover e.g. the gender of sports teams. As with the gender of individuals, we do not try to enumerate all possibilities. A mixed-gender SportsTeam can be indicated with a text value of "Mixed".

Relevant types:

- Person
Relevant types:

- SportsTeam

Values:

[^top]

#### genre

Genre of the creative work, broadcast channel or group.

Relevant types:

- BroadcastChannel
Relevant types:

- CreativeWork
Relevant types:

- MusicGroup

Values:

[^top]

#### geo

The geo coordinates of the place.

Relevant types:

- Place

Values:

[^top]

#### geoContains

Represents a relationship between two geometries (or the places they represent), relating a containing geometry to a contained geometry. "a contains b iff no points of b lie in the exterior of a, and at least one point of the interior of b lies in the interior of a". As defined in DE-9IM.

Relevant types:

- GeospatialGeometry
Relevant types:

- Place

Values:

[^top]

#### geoCoveredBy

Represents a relationship between two geometries (or the places they represent), relating a geometry to another that covers it. As defined in DE-9IM.

Relevant types:

- GeospatialGeometry
Relevant types:

- Place

Values:

[^top]

#### geoCovers

Represents a relationship between two geometries (or the places they represent), relating a covering geometry to a covered geometry. "Every point of b is a point of (the interior or boundary of) a". As defined in DE-9IM.

Relevant types:

- GeospatialGeometry
Relevant types:

- Place

Values:

[^top]

#### geoCrosses

Represents a relationship between two geometries (or the places they represent), relating a geometry to another that crosses it: "a crosses b: they have some but not all interior points in common, and the dimension of the intersection is less than that of at least one of them". As defined in DE-9IM.

Relevant types:

- GeospatialGeometry
Relevant types:

- Place

Values:

[^top]

#### geoDisjoint

Represents spatial relations in which two geometries (or the places they represent) are topologically disjoint: they have no point in common. They form a set of disconnected geometries." (a symmetric relationship, as defined in DE-9IM)

Relevant types:

- GeospatialGeometry
Relevant types:

- Place

Values:

[^top]

#### geoEquals

Represents spatial relations in which two geometries (or the places they represent) are topologically equal, as defined in DE-9IM. "Two geometries are topologically equal if their interiors intersect and no part of the interior or boundary of one geometry intersects the exterior of the other" (a symmetric relationship)

Relevant types:

- GeospatialGeometry
Relevant types:

- Place

Values:

[^top]

#### geoIntersects

Represents spatial relations in which two geometries (or the places they represent) have at least one point in common. As defined in DE-9IM.

Relevant types:

- GeospatialGeometry
Relevant types:

- Place

Values:

[^top]

#### geoMidpoint

Indicates the GeoCoordinates at the centre of a GeoShape e.g. GeoCircle.

Relevant types:

- GeoCircle

Values:

[^top]

#### geoOverlaps

Represents a relationship between two geometries (or the places they represent), relating a geometry to another that geospatially overlaps it, i.e. they have some but not all points in common. As defined in DE-9IM.

Relevant types:

- GeospatialGeometry
Relevant types:

- Place

Values:

[^top]

#### geoRadius

Indicates the approximate radius of a GeoCircle (metres unless indicated otherwise via Distance notation).

Relevant types:

- GeoCircle

Values:

[^top]

#### geoTouches

Represents spatial relations in which two geometries (or the places they represent) touch: they have at least one boundary point in common, but no interior points." (a symmetric relationship, as defined in DE-9IM )

Relevant types:

- GeospatialGeometry
Relevant types:

- Place

Values:

[^top]

#### geoWithin

Represents a relationship between two geometries (or the places they represent), relating a geometry to one that contains it, i.e. it is inside (i.e. within) its interior. As defined in DE-9IM.

Relevant types:

- GeospatialGeometry
Relevant types:

- Place

Values:

[^top]

#### geographicArea

The geographic area associated with the audience.

Relevant types:

- Audience

Values:

[^top]

#### gettingTestedInfo

Information about getting tested (for a MedicalCondition), e.g. in the context of a pandemic.

Relevant types:

- SpecialAnnouncement

Values:

[^top]

#### givenName

Given name. In the U.S., the first name of a Person.

Relevant types:

- Person

Values:

[^top]

#### globalLocationNumber

The Global Location Number (GLN, sometimes also referred to as International Location Number or ILN) of the respective organization, person, or place. The GLN is a 13-digit number used to identify parties and physical locations.

Relevant types:

- Organization
Relevant types:

- Person
Relevant types:

- Place

Values:

[^top]

#### governmentBenefitsInfo

governmentBenefitsInfo provides information about government benefits associated with a SpecialAnnouncement.

Relevant types:

- SpecialAnnouncement

Values:

[^top]

#### gracePeriod

The period of time after any due date that the borrower has to fulfil its obligations before a default (failure to pay) is deemed to have occurred.

Relevant types:

- LoanOrCredit

Values:

[^top]

#### grantee

The person, organization, contact point, or audience that has been granted this permission.

Relevant types:

- DigitalDocumentPermission

Values:

[^top]

#### greater

This ordering relation for qualitative values indicates that the subject is greater than the object.

Relevant types:

- QualitativeValue

Values:

[^top]

#### greaterOrEqual

This ordering relation for qualitative values indicates that the subject is greater than or equal to the object.

Relevant types:

- QualitativeValue

Values:

[^top]

#### gtin

A Global Trade Item Number (GTIN). GTINs identify trade items, including products and services, using numeric identification codes. The gtin property generalizes the earlier gtin8, gtin12, gtin13, and gtin14 properties. The GS1 digital link specifications express GTINs as URLs. A correct gtin value should be a valid GTIN, which means that it should be an all-numeric string of either 8, 12, 13 or 14 digits, or a "GS1 Digital Link" URL based on such a string. The numeric component should also have a valid GS1 check digit and meet the other rules for valid GTINs. See also GS1's GTIN Summary and Wikipedia for more details. Left-padding of the gtin values is not required or encouraged.

Relevant types:

- Demand
Relevant types:

- Offer
Relevant types:

- Product

Values:

[^top]

#### gtin12

The GTIN-12 code of the product, or the product to which the offer refers. The GTIN-12 is the 12-digit GS1 Identification Key composed of a U.P.C. Company Prefix, Item Reference, and Check Digit used to identify trade items. See GS1 GTIN Summary for more details.

Relevant types:

- Demand
Relevant types:

- Offer
Relevant types:

- Product

Values:

[^top]

#### gtin13

The GTIN-13 code of the product, or the product to which the offer refers. This is equivalent to 13-digit ISBN codes and EAN UCC-13. Former 12-digit UPC codes can be converted into a GTIN-13 code by simply adding a preceding zero. See GS1 GTIN Summary for more details.

Relevant types:

- Demand
Relevant types:

- Offer
Relevant types:

- Product

Values:

[^top]

#### gtin14

The GTIN-14 code of the product, or the product to which the offer refers. See GS1 GTIN Summary for more details.

Relevant types:

- Demand
Relevant types:

- Offer
Relevant types:

- Product

Values:

[^top]

#### gtin8

The GTIN-8 code of the product, or the product to which the offer refers. This code is also known as EAN/UCC-8 or 8-digit EAN. See GS1 GTIN Summary for more details.

Relevant types:

- Demand
Relevant types:

- Offer
Relevant types:

- Product

Values:

[^top]

#### guideline

A medical guideline related to this entity.

Relevant types:

- MedicalEntity

Values:

[^top]

#### guidelineDate

Date on which this guideline's recommendation was made.

Relevant types:

- MedicalGuideline

Values:

[^top]

#### guidelineSubject

The medical conditions, treatments, etc. that are the subject of the guideline.

Relevant types:

- MedicalGuideline

Values:

[^top]

#### handlingTime

The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup. Typical properties: minValue, maxValue, unitCode (d for DAY). This is by common convention assumed to mean business days (if a unitCode is used, coded as "d"), i.e. only counting days when the business normally operates.

Relevant types:

- ShippingDeliveryTime

Values:

[^top]

#### hasBroadcastChannel

A broadcast channel of a broadcast service.

Relevant types:

- BroadcastService

Values:

[^top]

#### hasCategoryCode

A Category code contained in this code set.

Relevant types:

- CategoryCodeSet

Values:

[^top]

#### hasCourse

A course or class that is one of the learning opportunities that constitute an educational / occupational program. No information is implied about whether the course is mandatory or optional; no guarantee is implied about whether the course will be available to everyone on the program.

Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### hasCourseInstance

An offering of the course at a specific time and place or through specific media or mode of study or to a specific section of students.

Relevant types:

- Course

Values:

[^top]

#### hasCredential

A credential awarded to the Person or Organization.

Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### hasDefinedTerm

A Defined Term contained in this term set.

Relevant types:

- DefinedTermSet

Values:

[^top]

#### hasDeliveryMethod

Method used for delivery or shipping.

Relevant types:

- DeliveryEvent
Relevant types:

- ParcelDelivery

Values:

[^top]

#### hasDigitalDocumentPermission

A permission related to the access to this document (e.g. permission to read or write an electronic document). For a public document, specify a grantee with an Audience with audienceType equal to "public".

Relevant types:

- DigitalDocument

Values:

[^top]

#### hasDriveThroughService

Indicates whether some facility (e.g. FoodEstablishment, CovidTestingFacility) offers a service that can be used by driving through in a car. In the case of CovidTestingFacility such facilities could potentially help with social distancing from other potentially-infected users.

Relevant types:

- Place

Values:

[^top]

#### hasEnergyConsumptionDetails

Defines the energy efficiency Category (also known as "class" or "rating") for a product according to an international energy efficiency standard.

Relevant types:

- Product

Values:

[^top]

#### hasEnergyEfficiencyCategory

Defines the energy efficiency Category (which could be either a rating out of range of values or a yes/no certification) for a product according to an international energy efficiency standard.

Relevant types:

- EnergyConsumptionDetails

Values:

[^top]

#### hasHealthAspect

Indicates the aspect or aspects specifically addressed in some HealthTopicContent. For example, that the content is an overview, or that it talks about treatment, self-care, treatments or their side-effects.

Relevant types:

- HealthTopicContent

Values:

[^top]

#### hasMap

A URL to a map of the place.

Relevant types:

- Place

Values:

[^top]

#### hasMeasurement

A product measurement, for example the inseam of pants, the wheel size of a bicycle, or the gauge of a screw. Usually an exact measurement, but can also be a range of measurements for adjustable products, for example belts and ski bindings.

Relevant types:

- Offer
Relevant types:

- Product
Relevant types:

- SizeSpecification

Values:

[^top]

#### hasMenu

Either the actual menu as a structured representation, as text, or a URL of the menu.

Relevant types:

- FoodEstablishment

Values:

[^top]

#### hasMenuItem

A food or drink item contained in a menu or menu section.

Relevant types:

- Menu
Relevant types:

- MenuSection

Values:

[^top]

#### hasMenuSection

A subgrouping of the menu (by dishes, course, serving time period, etc.).

Relevant types:

- Menu
Relevant types:

- MenuSection

Values:

[^top]

#### hasMerchantReturnPolicy

Indicates a MerchantReturnPolicy that may be applicable.

Relevant types:

- Organization
Relevant types:

- Product

Values:

[^top]

#### hasOccupation

The Person's occupation. For past professions, use Role for expressing dates.

Relevant types:

- Person

Values:

[^top]

#### hasOfferCatalog

Indicates an OfferCatalog listing for this Organization, Person, or Service.

Relevant types:

- Organization
Relevant types:

- Person
Relevant types:

- Service

Values:

[^top]

#### hasPOS

Points-of-Sales operated by the organization or person.

Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### hasPart

Indicates an item or CreativeWork that is part of this item, or CreativeWork (in some sense).

Relevant types:

- CreativeWork

Values:

[^top]

#### hasProductReturnPolicy

Indicates a ProductReturnPolicy that may be applicable.

Relevant types:

- Organization
Relevant types:

- Product

Values:

[^top]

#### hasVariant

Indicates a Product that is a member of this ProductGroup (or ProductModel).

Relevant types:

- ProductGroup

Values:

[^top]

#### headline

Headline of the article.

Relevant types:

- CreativeWork

Values:

[^top]

#### healthCondition

Specifying the health condition(s) of a patient, medical study, or other target audience.

Relevant types:

- MedicalStudy
Relevant types:

- Patient
Relevant types:

- PeopleAudience

Values:

[^top]

#### healthPlanCoinsuranceOption

Whether the coinsurance applies before or after deductible, etc. TODO: Is this a closed set?

Relevant types:

- HealthPlanCostSharingSpecification

Values:

[^top]

#### healthPlanCoinsuranceRate

Whether The rate of coinsurance expressed as a number between 0.0 and 1.0.

Relevant types:

- HealthPlanCostSharingSpecification

Values:

[^top]

#### healthPlanCopay

Whether The copay amount.

Relevant types:

- HealthPlanCostSharingSpecification

Values:

[^top]

#### healthPlanCopayOption

Whether the copay is before or after deductible, etc. TODO: Is this a closed set?

Relevant types:

- HealthPlanCostSharingSpecification

Values:

[^top]

#### healthPlanCostSharing

Whether The costs to the patient for services under this network or formulary.

Relevant types:

- HealthPlanFormulary
Relevant types:

- HealthPlanNetwork

Values:

[^top]

#### healthPlanDrugOption

TODO.

Relevant types:

- HealthInsurancePlan

Values:

[^top]

#### healthPlanDrugTier

The tier(s) of drugs offered by this formulary or insurance plan.

Relevant types:

- HealthInsurancePlan
Relevant types:

- HealthPlanFormulary

Values:

[^top]

#### healthPlanId

The 14-character, HIOS-generated Plan ID number. (Plan IDs must be unique, even across different markets.)

Relevant types:

- HealthInsurancePlan

Values:

[^top]

#### healthPlanMarketingUrl

The URL that goes directly to the plan brochure for the specific standard plan or plan variation.

Relevant types:

- HealthInsurancePlan

Values:

[^top]

#### healthPlanNetworkId

Name or unique ID of network. (Networks are often reused across different insurance plans).

Relevant types:

- HealthPlanNetwork
Relevant types:

- MedicalOrganization

Values:

[^top]

#### healthPlanNetworkTier

The tier(s) for this network.

Relevant types:

- HealthPlanNetwork

Values:

[^top]

#### healthPlanPharmacyCategory

The category or type of pharmacy associated with this cost sharing.

Relevant types:

- HealthPlanCostSharingSpecification

Values:

[^top]

#### healthcareReportingData

Indicates data describing a hospital, e.g. a CDC CDCPMDRecord or as some kind of Dataset.

Relevant types:

- Hospital

Values:

[^top]

#### height

The height of the item.

Relevant types:

- MediaObject
Relevant types:

- Person
Relevant types:

- Product
Relevant types:

- VisualArtwork

Values:

[^top]

#### highPrice

The highest price of all offers available.
Usage guidelines:

- Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similiar Unicode symbols.
- Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.

Relevant types:

- AggregateOffer

Values:

[^top]

#### hiringOrganization

Organization offering the job position.

Relevant types:

- JobPosting

Values:

[^top]

#### holdingArchive

ArchiveOrganization that holds, keeps or maintains the ArchiveComponent.

Relevant types:

- ArchiveComponent

Values:

[^top]

#### homeLocation

A contact location for a person's residence.

Relevant types:

- Person

Values:

[^top]

#### homeTeam

The home team in a sports event.

Relevant types:

- SportsEvent

Values:

[^top]

#### honorificPrefix

An honorific prefix preceding a Person's name such as Dr/Mrs/Mr.

Relevant types:

- Person

Values:

[^top]

#### honorificSuffix

An honorific suffix following a Person's name such as M.D. /PhD/MSCSW.

Relevant types:

- Person

Values:

[^top]

#### hospitalAffiliation

A hospital with which the physician or office is affiliated.

Relevant types:

- Physician

Values:

[^top]

#### hostingOrganization

The organization (airline, travelers' club, etc.) the membership is made with.

Relevant types:

- ProgramMembership

Values:

[^top]

#### hoursAvailable

The hours during which this service or contact is available.

Relevant types:

- ContactPoint
Relevant types:

- LocationFeatureSpecification
Relevant types:

- Service

Values:

[^top]

#### howPerformed

How the procedure is performed.

Relevant types:

- MedicalProcedure

Values:

[^top]

#### httpMethod

An HTTP method that specifies the appropriate HTTP method for a request to an HTTP EntryPoint. Values are capitalized strings as used in HTTP.

Relevant types:

- EntryPoint

Values:

[^top]

#### iataCode

IATA identifier for an airline or airport.

Relevant types:

- Airline
Relevant types:

- Airport

Values:

[^top]

#### icaoCode

ICAO identifier for an airport.

Relevant types:

- Airport

Values:

[^top]

#### identifier

The identifier property represents any kind of identifier for any kind of Thing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.

Relevant types:

- Thing

Values:

[^top]

#### identifyingExam

A physical examination that can identify this sign.

Relevant types:

- MedicalSign

Values:

[^top]

#### identifyingTest

A diagnostic test that can identify this sign.

Relevant types:

- MedicalSign

Values:

[^top]

#### illustrator

The illustrator of the book.

Relevant types:

- Book

Values:

[^top]

#### image

An image of the item. This can be a URL or a fully described ImageObject.

Relevant types:

- Thing

Values:

[^top]

#### imagingTechnique

Imaging technique used.

Relevant types:

- ImagingTest

Values:

[^top]

#### inAlbum

The album to which this recording belongs.

Relevant types:

- MusicRecording

Values:

[^top]

#### inBroadcastLineup

The CableOrSatelliteService offering the channel.

Relevant types:

- BroadcastChannel

Values:

[^top]

#### inCodeSet

A CategoryCodeSet that contains this category code.

Relevant types:

- CategoryCode

Values:

[^top]

#### inDefinedTermSet

A DefinedTermSet that contains this term.

Relevant types:

- DefinedTerm

Values:

[^top]

#### inLanguage

The language of the content or performance or used in an action. Please use one of the language codes from the IETF BCP 47 standard. See also availableLanguage.

Relevant types:

- BroadcastService
Relevant types:

- CommunicateAction
Relevant types:

- CreativeWork
Relevant types:

- Event
Relevant types:

- LinkRole
Relevant types:

- PronounceableText
Relevant types:

- WriteAction

Values:

[^top]

#### inPlaylist

The playlist to which this recording belongs.

Relevant types:

- MusicRecording

Values:

[^top]

#### inProductGroupWithID

Indicates the productGroupID for a ProductGroup that this product isVariantOf.

Relevant types:

- Product

Values:

[^top]

#### inStoreReturnsOffered

Are in-store returns offered?

Relevant types:

- MerchantReturnPolicy

Values:

[^top]

#### inSupportOf

Qualification, candidature, degree, application that Thesis supports.

Relevant types:

- Thesis

Values:

[^top]

#### incentiveCompensation

Description of bonus and commission compensation aspects of the job.

Relevant types:

- JobPosting

Values:

[^top]

#### incentives

Description of bonus and commission compensation aspects of the job.

Relevant types:

- JobPosting

Values:

[^top]

#### includedComposition

Smaller compositions included in this work (e.g. a movement in a symphony).

Relevant types:

- MusicComposition

Values:

[^top]

#### includedDataCatalog

A data catalog which contains this dataset (this property was previously 'catalog', preferred name is now 'includedInDataCatalog').

Relevant types:

- Dataset

Values:

[^top]

#### includedInDataCatalog

A data catalog which contains this dataset.

Relevant types:

- Dataset

Values:

[^top]

#### includedInHealthInsurancePlan

The insurance plans that cover this drug.

Relevant types:

- Drug

Values:

[^top]

#### includedRiskFactor

A modifiable or non-modifiable risk factor included in the calculation, e.g. age, coexisting condition.

Relevant types:

- MedicalRiskEstimator

Values:

[^top]

#### includesAttraction

Attraction located at destination.

Relevant types:

- TouristDestination

Values:

[^top]

#### includesHealthPlanFormulary

Formularies covered by this plan.

Relevant types:

- HealthInsurancePlan

Values:

[^top]

#### includesHealthPlanNetwork

Networks covered by this plan.

Relevant types:

- HealthInsurancePlan

Values:

[^top]

#### includesObject

This links to a node or nodes indicating the exact quantity of the products included in an Offer or ProductCollection.

Relevant types:

- Demand
Relevant types:

- Offer
Relevant types:

- ProductCollection

Values:

[^top]

#### increasesRiskOf

The condition, complication, etc. influenced by this factor.

Relevant types:

- MedicalRiskFactor

Values:

[^top]

#### industry

The industry associated with the job position.

Relevant types:

- JobPosting

Values:

[^top]

#### ineligibleRegion

The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed.
See also eligibleRegion.

Relevant types:

- ActionAccessSpecification
Relevant types:

- DeliveryChargeSpecification
Relevant types:

- Demand
Relevant types:

- MediaObject
Relevant types:

- Offer

Values:

[^top]

#### infectiousAgent

The actual infectious agent, such as a specific bacterium.

Relevant types:

- InfectiousDisease

Values:

[^top]

#### infectiousAgentClass

The class of infectious agent (bacteria, prion, etc.) that causes the disease.

Relevant types:

- InfectiousDisease

Values:

[^top]

#### ingredients

A single ingredient used in the recipe, e.g. sugar, flour or garlic.

Relevant types:

- Recipe

Values:

[^top]

#### inker

The individual who traces over the pencil drawings in ink after pencils are complete.

Relevant types:

- ComicIssue
Relevant types:

- ComicStory
Relevant types:

- VisualArtwork

Values:

[^top]

#### insertion

The place of attachment of a muscle, or what the muscle moves.

Relevant types:

- Muscle

Values:

[^top]

#### installUrl

URL at which the app may be installed, if different from the URL of the item.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### instructor

A person assigned to instruct or provide instructional assistance for the CourseInstance.

Relevant types:

- CourseInstance

Values:

[^top]

#### instrument

The object that helped the agent perform the action. e.g. John wrote a book with a pen.

Relevant types:

- Action

Values:

[^top]

#### intensity

Quantitative measure gauging the degree of force involved in the exercise, for example, heartbeats per minute. May include the velocity of the movement.

Relevant types:

- ExercisePlan

Values:

[^top]

#### interactingDrug

Another drug that is known to interact with this drug in a way that impacts the effect of this drug or causes a risk to the patient. Note: disease interactions are typically captured as contraindications.

Relevant types:

- Drug

Values:

[^top]

#### interactionCount

This property is deprecated, alongside the UserInteraction types on which it depended.

[^top]

#### interactionService

The WebSite or SoftwareApplication where the interactions took place.

Relevant types:

- InteractionCounter

Values:

[^top]

#### interactionStatistic

The number of interactions for the CreativeWork using the WebSite or SoftwareApplication. The most specific child type of InteractionCounter should be used.

Relevant types:

- CreativeWork
Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### interactionType

The Action representing the type of interaction. For up votes, +1s, etc. use LikeAction. For down votes use DislikeAction. Otherwise, use the most specific Action.

Relevant types:

- InteractionCounter

Values:

[^top]

#### interactivityType

The predominant mode of learning supported by the learning resource. Acceptable values are 'active', 'expositive', or 'mixed'.

Relevant types:

- CreativeWork

Values:

[^top]

#### interestRate

The interest rate, charged or paid, applicable to the financial product. Note: This is different from the calculated annualPercentageRate.

Relevant types:

- FinancialProduct

Values:

[^top]

#### inventoryLevel

The current approximate inventory level for the item or items.

Relevant types:

- Demand
Relevant types:

- Offer
Relevant types:

- SomeProducts

Values:

[^top]

#### inverseOf

Relates a property to a property that is its inverse. Inverse properties relate the same pairs of items to each other, but in reversed direction. For example, the 'alumni' and 'alumniOf' properties are inverseOf each other. Some properties don't have explicit inverses; in these situations RDFa and JSON-LD syntax for reverse properties can be used.

Relevant types:

- Property

Values:

[^top]

#### isAcceptingNewPatients

Whether the provider is accepting new patients.

Relevant types:

- MedicalOrganization

Values:

[^top]

#### isAccessibleForFree

A flag to signal that the item, event, or place is accessible for free.

Relevant types:

- CreativeWork
Relevant types:

- Event
Relevant types:

- Place

Values:

[^top]

#### isAccessoryOrSparePartFor

A pointer to another product (or multiple products) for which this product is an accessory or spare part.

Relevant types:

- Product

Values:

[^top]

#### isAvailableGenerically

True if the drug is available in a generic form (regardless of name).

Relevant types:

- Drug

Values:

[^top]

#### isBasedOn

A resource from which this work is derived or from which it is a modification or adaption.

Relevant types:

- CreativeWork

Values:

[^top]

#### isBasedOnUrl

A resource that was used in the creation of this resource. This term can be repeated for multiple sources. For example, http://example.com/great-multiplication-intro.html.

Relevant types:

- CreativeWork

Values:

[^top]

#### isConsumableFor

A pointer to another product (or multiple products) for which this product is a consumable.

Relevant types:

- Product

Values:

[^top]

#### isFamilyFriendly

Indicates whether this content is family friendly.

Relevant types:

- CreativeWork

Values:

[^top]

#### isGift

Was the offer accepted as a gift for someone other than the buyer.

Relevant types:

- Order

Values:

[^top]

#### isLiveBroadcast

True if the broadcast is of a live event.

Relevant types:

- BroadcastEvent

Values:

[^top]

#### isPartOf

Indicates an item or CreativeWork that this item, or CreativeWork (in some sense), is part of.

Relevant types:

- CreativeWork

Values:

[^top]

#### isPlanForApartment

Indicates some accommodation that this floor plan describes.

Relevant types:

- FloorPlan

Values:

[^top]

#### isProprietary

True if this item's name is a proprietary/brand name (vs. generic name).

Relevant types:

- DietarySupplement
Relevant types:

- Drug

Values:

[^top]

#### isRelatedTo

A pointer to another, somehow related product (or multiple products).

Relevant types:

- Product
Relevant types:

- Service

Values:

[^top]

#### isResizable

Whether the 3DModel allows resizing. For example, room layout applications often do not allow 3DModel elements to be resized to reflect reality.

Relevant types:

- 3DModel

Values:

[^top]

#### isSimilarTo

A pointer to another, functionally similar product (or multiple products).

Relevant types:

- Product
Relevant types:

- Service

Values:

[^top]

#### isUnlabelledFallback

This can be marked 'true' to indicate that some published DeliveryTimeSettings or ShippingRateSettings are intended to apply to all OfferShippingDetails published by the same merchant, when referenced by a shippingSettingsLink in those settings. It is not meaningful to use a 'true' value for this property alongside a transitTimeLabel (for DeliveryTimeSettings) or shippingLabel (for ShippingRateSettings), since this property is for use with unlabelled settings.

Relevant types:

- DeliveryTimeSettings
Relevant types:

- ShippingRateSettings

Values:

[^top]

#### isVariantOf

Indicates the kind of product that this is a variant of. In the case of ProductModel, this is a pointer (from a ProductModel) to a base product from which this product is a variant. It is safe to infer that the variant inherits all product features from the base model, unless defined locally. This is not transitive. In the case of a ProductGroup, the group description also serves as a template, representing a set of Products that vary on explicitly defined, specific dimensions only (so it defines both a set of variants, as well as which values distinguish amongst those variants). When used with ProductGroup, this property can apply to any Product included in the group.

Relevant types:

- Product
Relevant types:

- ProductModel

Values:

[^top]

#### isbn

The ISBN of the book.

Relevant types:

- Book

Values:

[^top]

#### isicV4

The International Standard of Industrial Classification of All Economic Activities (ISIC), Revision 4 code for a particular organization, business person, or place.

Relevant types:

- Organization
Relevant types:

- Person
Relevant types:

- Place

Values:

[^top]

#### isrcCode

The International Standard Recording Code for the recording.

Relevant types:

- MusicRecording

Values:

[^top]

#### issn

The International Standard Serial Number (ISSN) that identifies this serial publication. You can repeat this property to identify different formats of, or the linking ISSN (ISSN-L) for, this serial publication.

Relevant types:

- Blog
Relevant types:

- CreativeWorkSeries
Relevant types:

- Dataset
Relevant types:

- WebSite

Values:

[^top]

#### issueNumber

Identifies the issue of publication; for example, "iii" or "2".

Relevant types:

- PublicationIssue

Values:

[^top]

#### issuedBy

The organization issuing the ticket or permit.

Relevant types:

- Permit
Relevant types:

- Ticket

Values:

[^top]

#### issuedThrough

The service through with the permit was granted.

Relevant types:

- Permit

Values:

[^top]

#### iswcCode

The International Standard Musical Work Code for the composition.

Relevant types:

- MusicComposition

Values:

[^top]

#### item

An entity represented by an entry in a list or data feed (e.g. an 'artist' in a list of 'artists')’.

Relevant types:

- DataFeedItem
Relevant types:

- ListItem

Values:

[^top]

#### itemCondition

A predefined value from OfferItemCondition or a textual description of the condition of the product or service, or the products or services included in the offer.

Relevant types:

- Demand
Relevant types:

- Offer
Relevant types:

- Product

Values:

[^top]

#### itemListElement

For itemListElement values, you can use simple strings (e.g. "Peter", "Paul", "Mary"), existing entities, or use ListItem.
Text values are best if the elements in the list are plain strings. Existing entities are best for a simple, unordered list of existing things in your data. ListItem is used with ordered lists when you want to provide additional context about the element in that list or when the same item might be in different places in different lists.
Note: The order of elements in your mark-up is not sufficient for indicating the order or elements. Use ListItem with a 'position' property in such cases.

Relevant types:

- ItemList

Values:

[^top]

#### itemListOrder

Type of ordering (e.g. Ascending, Descending, Unordered).

Relevant types:

- ItemList

Values:

[^top]

#### itemLocation

Current location of the item.

Relevant types:

- ArchiveComponent

Values:

[^top]

#### itemOffered

An item being offered (or demanded). The transactional nature of the offer or demand is documented using businessFunction, e.g. sell, lease etc. While several common expected types are listed explicitly in this definition, others can be used. Using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.

Relevant types:

- Demand
Relevant types:

- Offer

Values:

[^top]

#### itemReviewed

The item that is being reviewed/rated.

Relevant types:

- AggregateRating
Relevant types:

- Review

Values:

[^top]

#### itemShipped

Item(s) being shipped.

Relevant types:

- ParcelDelivery

Values:

[^top]

#### itinerary

Destination(s) ( Place ) that make up a trip. For a trip where destination order is important use ItemList to specify that order (see examples).

Relevant types:

- Trip

Values:

[^top]

#### jobBenefits

Description of benefits associated with the job.

Relevant types:

- JobPosting

Values:

[^top]

#### jobImmediateStart

An indicator as to whether a position is available for an immediate start.

Relevant types:

- JobPosting

Values:

[^top]

#### jobLocation

A (typically single) geographic location associated with the job position.

Relevant types:

- JobPosting

Values:

[^top]

#### jobLocationType

A description of the job location (e.g TELECOMMUTE for telecommute jobs).

Relevant types:

- JobPosting

Values:

[^top]

#### jobStartDate

The date on which a successful applicant for this job would be expected to start work. Choose a specific date in the future or use the jobImmediateStart property to indicate the position is to be filled as soon as possible.

Relevant types:

- JobPosting

Values:

[^top]

#### jobTitle

The job title of the person (for example, Financial Manager).

Relevant types:

- Person

Values:

[^top]

#### jurisdiction

Indicates a legal jurisdiction, e.g. of some legislation, or where some government service is based.

Relevant types:

- GovernmentService
Relevant types:

- Legislation

Values:

[^top]

#### keywords

Keywords or tags used to describe this content. Multiple entries in a keywords list are typically delimited by commas.

Relevant types:

- CreativeWork

Values:

[^top]

#### knownVehicleDamages

A textual description of known damages, both repaired and unrepaired.

Relevant types:

- Vehicle

Values:

[^top]

#### knows

The most generic bi-directional social/work relation.

Relevant types:

- Person

Values:

[^top]

#### knowsAbout

Of a Person, and less typically of an Organization, to indicate a topic that is known about - suggesting possible expertise but not implying it. We do not distinguish skill levels here, or relate this to educational content, events, objectives or JobPosting descriptions.

Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### knowsLanguage

Of a Person, and less typically of an Organization, to indicate a known language. We do not distinguish skill levels or reading/writing/speaking/signing here. Use language codes from the IETF BCP 47 standard.

Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### labelDetails

Link to the drug's label details.

Relevant types:

- Drug

Values:

[^top]

#### landlord

A sub property of participant. The owner of the real estate property.

Relevant types:

- RentAction

Values:

[^top]

#### language

A sub property of instrument. The language used on this action.

Relevant types:

- CommunicateAction
Relevant types:

- WriteAction

Values:

[^top]

#### lastReviewed

Date on which the content on this web page was last reviewed for accuracy and/or completeness.

Relevant types:

- WebPage

Values:

[^top]

#### latitude

The latitude of a location. For example `37.42242` (WGS 84).

Relevant types:

- GeoCoordinates
Relevant types:

- Place

Values:

[^top]

#### layoutImage

A schematic image showing the floorplan layout.

Relevant types:

- FloorPlan

Values:

[^top]

#### learningResourceType

The predominant type or kind characterizing the learning resource. For example, 'presentation', 'handout'.

Relevant types:

- CreativeWork
Relevant types:

- LearningResource

Values:

[^top]

#### leaseLength

Length of the lease for some Accommodation, either particular to some Offer or in some cases intrinsic to the property.

Relevant types:

- Accommodation
Relevant types:

- Offer
Relevant types:

- RealEstateListing

Values:

[^top]

#### legalName

The official name of the organization, e.g. the registered company name.

Relevant types:

- Organization

Values:

[^top]

#### legalStatus

The drug or supplement's legal status, including any controlled substance schedules that apply.

Relevant types:

- DietarySupplement
Relevant types:

- Drug
Relevant types:

- MedicalEntity

Values:

[^top]

#### legislationApplies

Indicates that this legislation (or part of a legislation) somehow transfers another legislation in a different legislative context. This is an informative link, and it has no legal value. For legally-binding links of transposition, use the legislationTransposes property. For example an informative consolidated law of a European Union's member state "applies" the consolidated version of the European Directive implemented in it.

Relevant types:

- Legislation

Values:

[^top]

#### legislationChanges

Another legislation that this legislation changes. This encompasses the notions of amendment, replacement, correction, repeal, or other types of change. This may be a direct change (textual or non-textual amendment) or a consequential or indirect change. The property is to be used to express the existence of a change relationship between two acts rather than the existence of a consolidated version of the text that shows the result of the change. For consolidation relationships, use the legislationConsolidates property.

Relevant types:

- Legislation

Values:

[^top]

#### legislationConsolidates

Indicates another legislation taken into account in this consolidated legislation (which is usually the product of an editorial process that revises the legislation). This property should be used multiple times to refer to both the original version or the previous consolidated version, and to the legislations making the change.

Relevant types:

- Legislation

Values:

[^top]

#### legislationDate

The date of adoption or signature of the legislation. This is the date at which the text is officially aknowledged to be a legislation, even though it might not even be published or in force.

Relevant types:

- Legislation

Values:

[^top]

#### legislationDateVersion

The point-in-time at which the provided description of the legislation is valid (e.g. : when looking at the law on the 2016-04-07 (= dateVersion), I get the consolidation of 2015-04-12 of the "National Insurance Contributions Act 2015")

Relevant types:

- Legislation

Values:

[^top]

#### legislationIdentifier

An identifier for the legislation. This can be either a string-based identifier, like the CELEX at EU level or the NOR in France, or a web-based, URL/URI identifier, like an ELI (European Legislation Identifier) or an URN-Lex.

Relevant types:

- Legislation

Values:

[^top]

#### legislationJurisdiction

The jurisdiction from which the legislation originates.

Relevant types:

- Legislation

Values:

[^top]

#### legislationLegalForce

Whether the legislation is currently in force, not in force, or partially in force.

Relevant types:

- Legislation

Values:

[^top]

#### legislationLegalValue

The legal value of this legislation file. The same legislation can be written in multiple files with different legal values. Typically a digitally signed PDF have a "stronger" legal value than the HTML file of the same act.

Relevant types:

- LegislationObject

Values:

[^top]

#### legislationPassedBy

The person or organization that originally passed or made the law : typically parliament (for primary legislation) or government (for secondary legislation). This indicates the "legal author" of the law, as opposed to its physical author.

Relevant types:

- Legislation

Values:

[^top]

#### legislationResponsible

An individual or organization that has some kind of responsibility for the legislation. Typically the ministry who is/was in charge of elaborating the legislation, or the adressee for potential questions about the legislation once it is published.

Relevant types:

- Legislation

Values:

[^top]

#### legislationTransposes

Indicates that this legislation (or part of legislation) fulfills the objectives set by another legislation, by passing appropriate implementation measures. Typically, some legislations of European Union's member states or regions transpose European Directives. This indicates a legally binding link between the 2 legislations.

Relevant types:

- Legislation

Values:

[^top]

#### legislationType

The type of the legislation. Examples of values are "law", "act", "directive", "decree", "regulation", "statutory instrument", "loi organique", "règlement grand-ducal", etc., depending on the country.

Relevant types:

- Legislation

Values:

[^top]

#### leiCode

An organization identifier that uniquely identifies a legal entity as defined in ISO 17442.

Relevant types:

- Organization

Values:

[^top]

#### lender

A sub property of participant. The person that lends the object being borrowed.

Relevant types:

- BorrowAction

Values:

[^top]

#### lesser

This ordering relation for qualitative values indicates that the subject is lesser than the object.

Relevant types:

- QualitativeValue

Values:

[^top]

#### lesserOrEqual

This ordering relation for qualitative values indicates that the subject is lesser than or equal to the object.

Relevant types:

- QualitativeValue

Values:

[^top]

#### letterer

The individual who adds lettering, including speech balloons and sound effects, to artwork.

Relevant types:

- ComicIssue
Relevant types:

- ComicStory
Relevant types:

- VisualArtwork

Values:

[^top]

#### license

A license document that applies to this content, typically indicated by URL.

Relevant types:

- CreativeWork

Values:

[^top]

#### line

A line is a point-to-point path consisting of two or more points. A line is expressed as a series of two or more point objects separated by space.

Relevant types:

- GeoShape

Values:

[^top]

#### linkRelationship

Indicates the relationship type of a Web link.

Relevant types:

- LinkRole

Values:

[^top]

#### liveBlogUpdate

An update to the LiveBlog.

Relevant types:

- LiveBlogPosting

Values:

[^top]

#### loanMortgageMandateAmount

Amount of mortgage mandate that can be converted into a proper mortgage at a later stage.

Relevant types:

- MortgageLoan

Values:

[^top]

#### loanPaymentAmount

The amount of money to pay in a single payment.

Relevant types:

- RepaymentSpecification

Values:

[^top]

#### loanPaymentFrequency

Frequency of payments due, i.e. number of months between payments. This is defined as a frequency, i.e. the reciprocal of a period of time.

Relevant types:

- RepaymentSpecification

Values:

[^top]

#### loanRepaymentForm

A form of paying back money previously borrowed from a lender. Repayment usually takes the form of periodic payments that normally include part principal plus interest in each payment.

Relevant types:

- LoanOrCredit

Values:

[^top]

#### loanTerm

The duration of the loan or credit agreement.

Relevant types:

- LoanOrCredit

Values:

[^top]

#### loanType

The type of a loan or credit.

Relevant types:

- LoanOrCredit

Values:

[^top]

#### location

The location of, for example, where an event is happening, where an organization is located, or where an action takes place.

Relevant types:

- Action
Relevant types:

- Event
Relevant types:

- Organization

Values:

[^top]

#### locationCreated

The location where the CreativeWork was created, which may not be the same as the location depicted in the CreativeWork.

Relevant types:

- CreativeWork

Values:

[^top]

#### lodgingUnitDescription

A full description of the lodging unit.

Relevant types:

- LodgingReservation

Values:

[^top]

#### lodgingUnitType

Textual description of the unit type (including suite vs. room, size of bed, etc.).

Relevant types:

- LodgingReservation

Values:

[^top]

#### logo

An associated logo.

Relevant types:

- Brand
Relevant types:

- Organization
Relevant types:

- Place
Relevant types:

- Product
Relevant types:

- Service

Values:

[^top]

#### longitude

The longitude of a location. For example `-122.08585` (WGS 84).

Relevant types:

- GeoCoordinates
Relevant types:

- Place

Values:

[^top]

#### loser

A sub property of participant. The loser of the action.

Relevant types:

- WinAction

Values:

[^top]

#### lowPrice

The lowest price of all offers available.
Usage guidelines:

- Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similiar Unicode symbols.
- Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.

Relevant types:

- AggregateOffer

Values:

[^top]

#### lyricist

The person who wrote the words.

Relevant types:

- MusicComposition

Values:

[^top]

#### lyrics

The words in the song.

Relevant types:

- MusicComposition

Values:

[^top]

#### mainContentOfPage

Indicates if this web page element is the main subject of the page.

Relevant types:

- WebPage

Values:

[^top]

#### mainEntity

Indicates the primary entity described in some page or other CreativeWork.

Relevant types:

- CreativeWork

Values:

[^top]

#### mainEntityOfPage

Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.

Relevant types:

- Thing

Values:

[^top]

#### maintainer

A maintainer of a Dataset, software package (SoftwareApplication), or other Project. A maintainer is a Person or Organization that manages contributions to, and/or publication of, some (typically complex) artifact. It is common for distributions of software and data to be based on "upstream" sources. When maintainer is applied to a specific version of something e.g. a particular version or packaging of a Dataset, it is always possible that the upstream source has a different maintainer. The isBasedOn property can be used to indicate such relationships between datasets to make the different maintenance roles clear. Similarly in the case of software, a package may have dedicated maintainers working on integration into software distributions such as Ubuntu, as well as upstream maintainers of the underlying work.

Relevant types:

- CreativeWork

Values:

[^top]

#### makesOffer

A pointer to products or services offered by the organization or person.

Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### manufacturer

The manufacturer of the product.

Relevant types:

- DietarySupplement
Relevant types:

- Drug
Relevant types:

- Product

Values:

[^top]

#### map

A URL to a map of the place.

Relevant types:

- Place

Values:

[^top]

#### mapType

Indicates the kind of Map, from the MapCategoryType Enumeration.

Relevant types:

- Map

Values:

[^top]

#### maps

A URL to a map of the place.

Relevant types:

- Place

Values:

[^top]

#### marginOfError

A marginOfError for an Observation.

Relevant types:

- Observation

Values:

[^top]

#### masthead

For a NewsMediaOrganization, a link to the masthead page or a page listing top editorial management.

Relevant types:

- NewsMediaOrganization

Values:

[^top]

#### material

A material that something is made from, e.g. leather, wool, cotton, paper.

Relevant types:

- CreativeWork
Relevant types:

- Product

Values:

[^top]

#### materialExtent

The quantity of the materials being described or an expression of the physical space they occupy.

Relevant types:

- CreativeWork

Values:

[^top]

#### mathExpression

A mathematical expression (e.g. 'x^2-3x=0') that may be solved for a specific variable, simplified, or transformed. This can take many formats, e.g. LaTeX, Ascii-Math, or math as you would write with a keyboard.

Relevant types:

- MathSolver

Values:

[^top]

#### maxPrice

The highest price if the price is a range.

Relevant types:

- PriceSpecification

Values:

[^top]

#### maxValue

The upper value of some characteristic or property.

Relevant types:

- MonetaryAmount
Relevant types:

- PropertyValue
Relevant types:

- PropertyValueSpecification
Relevant types:

- QuantitativeValue

Values:

[^top]

#### maximumAttendeeCapacity

The total number of individuals that may attend an event or venue.

Relevant types:

- Event
Relevant types:

- Place

Values:

[^top]

#### maximumEnrollment

The maximum number of students who may be enrolled in the program.

Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### maximumIntake

Recommended intake of this supplement for a given population as defined by a specific recommending authority.

Relevant types:

- DietarySupplement
Relevant types:

- Drug
Relevant types:

- DrugStrength
Relevant types:

- Substance

Values:

[^top]

#### maximumPhysicalAttendeeCapacity

The maximum physical attendee capacity of an Event whose eventAttendanceMode is OfflineEventAttendanceMode (or the offline aspects, in the case of a MixedEventAttendanceMode).

Relevant types:

- Event

Values:

[^top]

#### maximumVirtualAttendeeCapacity

The maximum physical attendee capacity of an Event whose eventAttendanceMode is OnlineEventAttendanceMode (or the online aspects, in the case of a MixedEventAttendanceMode).

Relevant types:

- Event

Values:

[^top]

#### mealService

Description of the meals that will be provided or available for purchase.

Relevant types:

- Flight

Values:

[^top]

#### measuredProperty

The measuredProperty of an Observation, either a schema.org property, a property from other RDF-compatible systems e.g. W3C RDF Data Cube, or schema.org extensions such as GS1's.

Relevant types:

- Observation

Values:

[^top]

#### measuredValue

The measuredValue of an Observation.

Relevant types:

- Observation

Values:

[^top]

#### measurementTechnique

A technique or technology used in a Dataset (or DataDownload, DataCatalog), corresponding to the method used for measuring the corresponding variable(s) (described using variableMeasured). This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but rather as a high level summary for dataset discovery.
For example, if variableMeasured is: molecule concentration, measurementTechnique could be: "mass spectrometry" or "nmr spectroscopy" or "colorimetry" or "immunofluorescence".
If the variableMeasured is "depression rating", the measurementTechnique could be "Zung Scale" or "HAM-D" or "Beck Depression Inventory".
If there are several variableMeasured properties recorded for some given data object, use a PropertyValue for each variableMeasured and attach the corresponding measurementTechnique.

Relevant types:

- DataCatalog
Relevant types:

- DataDownload
Relevant types:

- Dataset
Relevant types:

- PropertyValue

Values:

[^top]

#### mechanismOfAction

The specific biochemical interaction through which this drug or supplement produces its pharmacological effect.

Relevant types:

- DietarySupplement
Relevant types:

- Drug

Values:

[^top]

#### mediaAuthenticityCategory

Indicates a MediaManipulationRatingEnumeration classification of a media object (in the context of how it was published or shared).

Relevant types:

- MediaReview

Values:

[^top]

#### median

The median value.

Relevant types:

- QuantitativeValueDistribution

Values:

[^top]

#### medicalAudience

Medical audience for page.

Relevant types:

- MedicalWebPage

Values:

[^top]

#### medicalSpecialty

A medical specialty of the provider.

Relevant types:

- Hospital
Relevant types:

- MedicalClinic
Relevant types:

- MedicalOrganization
Relevant types:

- Physician

Values:

[^top]

#### medicineSystem

The system of medicine that includes this MedicalEntity, for example 'evidence-based', 'homeopathic', 'chiropractic', etc.

Relevant types:

- MedicalEntity

Values:

[^top]

#### meetsEmissionStandard

Indicates that the vehicle meets the respective emission standard.

Relevant types:

- Vehicle

Values:

[^top]

#### member

A member of an Organization or a ProgramMembership. Organizations can be members of organizations; ProgramMembership is typically for individuals.

Relevant types:

- Organization
Relevant types:

- ProgramMembership

Values:

[^top]

#### memberOf

An Organization (or ProgramMembership) to which this Person or Organization belongs.

Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### members

A member of this organization.

Relevant types:

- Organization
Relevant types:

- ProgramMembership

Values:

[^top]

#### membershipNumber

A unique identifier for the membership.

Relevant types:

- ProgramMembership

Values:

[^top]

#### membershipPointsEarned

The number of membership points earned by the member. If necessary, the unitText can be used to express the units the points are issued in. (e.g. stars, miles, etc.)

Relevant types:

- ProgramMembership

Values:

[^top]

#### memoryRequirements

Minimum memory requirements.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### mentions

Indicates that the CreativeWork contains a reference to, but is not necessarily about a concept.

Relevant types:

- CreativeWork

Values:

[^top]

#### menu

Either the actual menu as a structured representation, as text, or a URL of the menu.

Relevant types:

- FoodEstablishment

Values:

[^top]

#### menuAddOn

Additional menu item(s) such as a side dish of salad or side order of fries that can be added to this menu item. Additionally it can be a menu section containing allowed add-on menu items for this menu item.

Relevant types:

- MenuItem

Values:

[^top]

#### merchant

'merchant' is an out-dated term for 'seller'.

Relevant types:

- Order

Values:

[^top]

#### merchantReturnDays

The merchantReturnDays property indicates the number of days (from purchase) within which relevant merchant return policy is applicable.

Relevant types:

- MerchantReturnPolicy

Values:

[^top]

#### merchantReturnLink

Indicates a Web page or service by URL, for product return.

Relevant types:

- MerchantReturnPolicy

Values:

[^top]

#### messageAttachment

A CreativeWork attached to the message.

Relevant types:

- Message

Values:

[^top]

#### mileageFromOdometer

The total distance travelled by the particular vehicle since its initial production, as read from its odometer.
Typical unit code(s): KMT for kilometers, SMI for statute miles

Relevant types:

- Vehicle

Values:

[^top]

#### minPrice

The lowest price if the price is a range.

Relevant types:

- PriceSpecification

Values:

[^top]

#### minValue

The lower value of some characteristic or property.

Relevant types:

- MonetaryAmount
Relevant types:

- PropertyValue
Relevant types:

- PropertyValueSpecification
Relevant types:

- QuantitativeValue

Values:

[^top]

#### minimumPaymentDue

The minimum payment required at this time.

Relevant types:

- Invoice

Values:

[^top]

#### missionCoveragePrioritiesPolicy

For a NewsMediaOrganization, a statement on coverage priorities, including any public agenda or stance on issues.

Relevant types:

- NewsMediaOrganization

Values:

[^top]

#### model

The model of the product. Use with the URL of a ProductModel or a textual representation of the model identifier. The URL of the ProductModel can be from an external source. It is recommended to additionally provide strong product identifiers via the gtin8/gtin13/gtin14 and mpn properties.

Relevant types:

- Product

Values:

[^top]

#### modelDate

The release date of a vehicle model (often used to differentiate versions of the same make and model).

Relevant types:

- Vehicle

Values:

[^top]

#### modifiedTime

The date and time the reservation was modified.

Relevant types:

- Reservation

Values:

[^top]

#### monthlyMinimumRepaymentAmount

The minimum payment is the lowest amount of money that one is required to pay on a credit card statement each month.

Relevant types:

- PaymentCard

Values:

[^top]

#### monthsOfExperience

Indicates the minimal number of months of experience required for a position.

Relevant types:

- OccupationalExperienceRequirements

Values:

[^top]

#### mpn

The Manufacturer Part Number (MPN) of the product, or the product to which the offer refers.

Relevant types:

- Demand
Relevant types:

- Offer
Relevant types:

- Product

Values:

[^top]

#### multipleValues

Whether multiple values are allowed for the property. Default is false.

Relevant types:

- PropertyValueSpecification

Values:

[^top]

#### muscleAction

The movement the muscle generates.

Relevant types:

- Muscle

Values:

[^top]

#### musicArrangement

An arrangement derived from the composition.

Relevant types:

- MusicComposition

Values:

[^top]

#### musicBy

The composer of the soundtrack.

Relevant types:

- Clip
Relevant types:

- Episode
Relevant types:

- Movie
Relevant types:

- MovieSeries
Relevant types:

- RadioSeries
Relevant types:

- TVSeries
Relevant types:

- VideoGame
Relevant types:

- VideoGameSeries
Relevant types:

- VideoObject

Values:

[^top]

#### musicCompositionForm

The type of composition (e.g. overture, sonata, symphony, etc.).

Relevant types:

- MusicComposition

Values:

[^top]

#### musicGroupMember

A member of a music group—for example, John, Paul, George, or Ringo.

Relevant types:

- MusicGroup

Values:

[^top]

#### musicReleaseFormat

Format of this release (the type of recording media used, ie. compact disc, digital media, LP, etc.).

Relevant types:

- MusicRelease

Values:

[^top]

#### musicalKey

The key, mode, or scale this composition uses.

Relevant types:

- MusicComposition

Values:

[^top]

#### naics

The North American Industry Classification System (NAICS) code for a particular organization or business person.

Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### name

The name of the item.

Relevant types:

- Thing

Values:

[^top]

#### namedPosition

A position played, performed or filled by a person or organization, as part of an organization. For example, an athlete in a SportsTeam might play in the position named 'Quarterback'.

Relevant types:

- Role

Values:

[^top]

#### nationality

Nationality of the person.

Relevant types:

- Person

Values:

[^top]

#### naturalProgression

The expected progression of the condition if it is not treated and allowed to progress naturally.

Relevant types:

- MedicalCondition

Values:

[^top]

#### nerve

The underlying innervation associated with the muscle.

Relevant types:

- Muscle

Values:

[^top]

#### nerveMotor

The neurological pathway extension that involves muscle control.

Relevant types:

- Nerve

Values:

[^top]

#### netWorth

The total financial value of the person as calculated by subtracting assets from liabilities.

Relevant types:

- Person

Values:

[^top]

#### newsUpdatesAndGuidelines

Indicates a page with news updates and guidelines. This could often be (but is not required to be) the main page containing SpecialAnnouncement markup on a site.

Relevant types:

- SpecialAnnouncement

Values:

[^top]

#### nextItem

A link to the ListItem that follows the current one.

Relevant types:

- ListItem

Values:

[^top]

#### noBylinesPolicy

For a NewsMediaOrganization or other news-related Organization, a statement explaining when authors of articles are not named in bylines.

Relevant types:

- NewsMediaOrganization

Values:

[^top]

#### nonEqual

This ordering relation for qualitative values indicates that the subject is not equal to the object.

Relevant types:

- QualitativeValue

Values:

[^top]

#### nonProprietaryName

The generic name of this drug or supplement.

Relevant types:

- DietarySupplement
Relevant types:

- Drug

Values:

[^top]

#### nonprofitStatus

nonprofit Status indicates the legal status of a non-profit organization in its primary place of business.

Relevant types:

- Organization

Values:

[^top]

#### normalRange

Range of acceptable values for a typical patient, when applicable.

Relevant types:

- MedicalTest

Values:

[^top]

#### nsn

Indicates the NATO stock number (nsn) of a Product.

Relevant types:

- Product

Values:

[^top]

#### numAdults

The number of adults staying in the unit.

Relevant types:

- LodgingReservation

Values:

[^top]

#### numChildren

The number of children staying in the unit.

Relevant types:

- LodgingReservation

Values:

[^top]

#### numConstraints

Indicates the number of constraints (not counting populationType) defined for a particular StatisticalPopulation. This helps applications understand if they have access to a sufficiently complete description of a StatisticalPopulation.

Relevant types:

- StatisticalPopulation

Values:

[^top]

#### numTracks

The number of tracks in this album or playlist.

Relevant types:

- MusicPlaylist

Values:

[^top]

#### numberOfAccommodationUnits

Indicates the total (available plus unavailable) number of accommodation units in an ApartmentComplex, or the number of accommodation units for a specific FloorPlan (within its specific ApartmentComplex). See also numberOfAvailableAccommodationUnits.

Relevant types:

- ApartmentComplex
Relevant types:

- FloorPlan

Values:

[^top]

#### numberOfAirbags

The number or type of airbags in the vehicle.

Relevant types:

- Vehicle

Values:

[^top]

#### numberOfAvailableAccommodationUnits

Indicates the number of available accommodation units in an ApartmentComplex, or the number of accommodation units for a specific FloorPlan (within its specific ApartmentComplex). See also numberOfAccommodationUnits.

Relevant types:

- ApartmentComplex
Relevant types:

- FloorPlan

Values:

[^top]

#### numberOfAxles

The number of axles.
Typical unit code(s): C62

Relevant types:

- Vehicle

Values:

[^top]

#### numberOfBathroomsTotal

The total integer number of bathrooms in a some Accommodation, following real estate conventions as documented in RESO: "The simple sum of the number of bathrooms. For example for a property with two Full Bathrooms and one Half Bathroom, the Bathrooms Total Integer will be 3.". See also numberOfRooms.

Relevant types:

- Accommodation
Relevant types:

- FloorPlan

Values:

[^top]

#### numberOfBedrooms

The total integer number of bedrooms in a some Accommodation, ApartmentComplex or FloorPlan.

Relevant types:

- Accommodation
Relevant types:

- ApartmentComplex
Relevant types:

- FloorPlan

Values:

[^top]

#### numberOfBeds

The quantity of the given bed type available in the HotelRoom, Suite, House, or Apartment.

Relevant types:

- BedDetails

Values:

[^top]

#### numberOfCredits

The number of credits or units awarded by a Course or required to complete an EducationalOccupationalProgram.

Relevant types:

- Course
Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### numberOfDoors

The number of doors.
Typical unit code(s): C62

Relevant types:

- Vehicle

Values:

[^top]

#### numberOfEmployees

The number of employees in an organization e.g. business.

Relevant types:

- BusinessAudience
Relevant types:

- Organization

Values:

[^top]

#### numberOfEpisodes

The number of episodes in this season or series.

Relevant types:

- CreativeWorkSeason
Relevant types:

- RadioSeries
Relevant types:

- TVSeries
Relevant types:

- VideoGameSeries

Values:

[^top]

#### numberOfForwardGears

The total number of forward gears available for the transmission system of the vehicle.
Typical unit code(s): C62

Relevant types:

- Vehicle

Values:

[^top]

#### numberOfFullBathrooms

Number of full bathrooms - The total number of full and ¾ bathrooms in an Accommodation. This corresponds to the BathroomsFull field in RESO.

Relevant types:

- Accommodation
Relevant types:

- FloorPlan

Values:

[^top]

#### numberOfItems

The number of items in an ItemList. Note that some descriptions might not fully describe all items in a list (e.g., multi-page pagination); in such cases, the numberOfItems would be for the entire list.

Relevant types:

- ItemList

Values:

[^top]

#### numberOfLoanPayments

The number of payments contractually required at origination to repay the loan. For monthly paying loans this is the number of months from the contractual first payment date to the maturity date.

Relevant types:

- RepaymentSpecification

Values:

[^top]

#### numberOfPages

The number of pages in the book.

Relevant types:

- Book

Values:

[^top]

#### numberOfPartialBathrooms

Number of partial bathrooms - The total number of half and ¼ bathrooms in an Accommodation. This corresponds to the BathroomsPartial field in RESO.

Relevant types:

- Accommodation
Relevant types:

- FloorPlan

Values:

[^top]

#### numberOfPlayers

Indicate how many people can play this game (minimum, maximum, or range).

Relevant types:

- Game
Relevant types:

- VideoGameSeries

Values:

[^top]

#### numberOfPreviousOwners

The number of owners of the vehicle, including the current one.
Typical unit code(s): C62

Relevant types:

- Vehicle

Values:

[^top]

#### numberOfRooms

The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business. Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue.

Relevant types:

- Accommodation
Relevant types:

- Apartment
Relevant types:

- FloorPlan
Relevant types:

- House
Relevant types:

- LodgingBusiness
Relevant types:

- SingleFamilyResidence
Relevant types:

- Suite

Values:

[^top]

#### numberOfSeasons

The number of seasons in this series.

Relevant types:

- RadioSeries
Relevant types:

- TVSeries
Relevant types:

- VideoGameSeries

Values:

[^top]

#### numberedPosition

A number associated with a role in an organization, for example, the number on an athlete's jersey.

Relevant types:

- OrganizationRole

Values:

[^top]

#### nutrition

Nutrition information about the recipe or menu item.

Relevant types:

- MenuItem
Relevant types:

- Recipe

Values:

[^top]

#### object

The object upon which the action is carried out, whose state is kept intact or changed. Also known as the semantic roles patient, affected or undergoer (which change their state) or theme (which doesn't). e.g. John read a book.

Relevant types:

- Action

Values:

[^top]

#### observationDate

The observationDate of an Observation.

Relevant types:

- Observation

Values:

[^top]

#### observedNode

The observedNode of an Observation, often a StatisticalPopulation.

Relevant types:

- Observation

Values:

[^top]

#### occupancy

The allowed total occupancy for the accommodation in persons (including infants etc). For individual accommodations, this is not necessarily the legal maximum but defines the permitted usage as per the contractual agreement (e.g. a double room used by a single person). Typical unit code(s): C62 for person

Relevant types:

- Apartment
Relevant types:

- HotelRoom
Relevant types:

- SingleFamilyResidence
Relevant types:

- Suite

Values:

[^top]

#### occupationLocation

The region/country for which this occupational description is appropriate. Note that educational requirements and qualifications can vary between jurisdictions.

Relevant types:

- Occupation

Values:

[^top]

#### occupationalCategory

A category describing the job, preferably using a term from a taxonomy such as BLS O*NET-SOC, ISCO-08 or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.
Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.

Relevant types:

- EducationalOccupationalProgram
Relevant types:

- JobPosting
Relevant types:

- Occupation
Relevant types:

- WorkBasedProgram

Values:

[^top]

#### occupationalCredentialAwarded

A description of the qualification, award, certificate, diploma or other occupational credential awarded as a consequence of successful completion of this course or program.

Relevant types:

- Course
Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### offerCount

The number of offers for the product.

Relevant types:

- AggregateOffer

Values:

[^top]

#### offeredBy

A pointer to the organization or person making the offer.

Relevant types:

- Offer

Values:

[^top]

#### offers

An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use businessFunction to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a Demand. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.

Relevant types:

- AggregateOffer
Relevant types:

- CreativeWork
Relevant types:

- EducationalOccupationalProgram
Relevant types:

- Event
Relevant types:

- MenuItem
Relevant types:

- Product
Relevant types:

- Service
Relevant types:

- Trip

Values:

[^top]

#### offersPrescriptionByMail

Whether prescriptions can be delivered by mail.

Relevant types:

- HealthPlanFormulary

Values:

[^top]

#### openingHours

The general opening hours for a business. Opening hours can be specified as a weekly time range, starting with days, then times per day. Multiple days can be listed with commas ',' separating each day. Day or time ranges are specified using a hyphen '-'.

- Days are specified using the following two-letter combinations: `Mo`, `Tu`, `We`, `Th`, `Fr`, `Sa`, `Su`.
- Times are specified using 24:00 format. For example, 3pm is specified as `15:00`, 10am as `10:00`.
- Here is an example: `<time itemprop="openingHours" datetime="Tu,Th 16:00-20:00">Tuesdays and Thursdays 4-8pm</time>`.
- If a business is open 7 days a week, then it can be specified as `<time itemprop="openingHours" datetime="Mo-Su">Monday through Sunday, all day</time>`.

Relevant types:

- CivicStructure
Relevant types:

- LocalBusiness

Values:

[^top]

#### openingHoursSpecification

The opening hours of a certain place.

Relevant types:

- Place

Values:

[^top]

#### opens

The opening hour of the place or service on the given day(s) of the week.

Relevant types:

- OpeningHoursSpecification

Values:

[^top]

#### operatingSystem

Operating systems supported (Windows 7, OSX 10.6, Android 1.6).

Relevant types:

- SoftwareApplication

Values:

[^top]

#### opponent

A sub property of participant. The opponent on this action.

Relevant types:

- ExerciseAction

Values:

[^top]

#### option

A sub property of object. The options subject to this action.

Relevant types:

- ChooseAction

Values:

[^top]

#### orderDate

Date order was placed.

Relevant types:

- Order

Values:

[^top]

#### orderDelivery

The delivery of the parcel related to this order or order item.

Relevant types:

- Order
Relevant types:

- OrderItem

Values:

[^top]

#### orderItemNumber

The identifier of the order item.

Relevant types:

- OrderItem

Values:

[^top]

#### orderItemStatus

The current status of the order item.

Relevant types:

- OrderItem

Values:

[^top]

#### orderNumber

The identifier of the transaction.

Relevant types:

- Order

Values:

[^top]

#### orderQuantity

The number of the item ordered. If the property is not set, assume the quantity is one.

Relevant types:

- OrderItem

Values:

[^top]

#### orderStatus

The current status of the order.

Relevant types:

- Order

Values:

[^top]

#### orderedItem

The item ordered.

Relevant types:

- Order
Relevant types:

- OrderItem

Values:

[^top]

#### organizer

An organizer of an Event.

Relevant types:

- Event

Values:

[^top]

#### originAddress

Shipper's address.

Relevant types:

- ParcelDelivery

Values:

[^top]

#### originatesFrom

The vasculature the lymphatic structure originates, or afferents, from.

Relevant types:

- LymphaticVessel

Values:

[^top]

#### overdosage

Any information related to overdose on a drug, including signs or symptoms, treatments, contact information for emergency response.

Relevant types:

- Drug

Values:

[^top]

#### ownedFrom

The date and time of obtaining the product.

Relevant types:

- OwnershipInfo

Values:

[^top]

#### ownedThrough

The date and time of giving up ownership on the product.

Relevant types:

- OwnershipInfo

Values:

[^top]

#### ownershipFundingInfo

For an Organization (often but not necessarily a NewsMediaOrganization), a description of organizational ownership structure; funding and grants. In a news/media setting, this is with particular reference to editorial independence. Note that the funder is also available and can be used to make basic funder information machine-readable.

Relevant types:

- NewsMediaOrganization
Relevant types:

- Organization

Values:

[^top]

#### owns

Products owned by the organization or person.

Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### pageEnd

The page on which the work ends; for example "138" or "xvi".

Relevant types:

- Article
Relevant types:

- Chapter
Relevant types:

- PublicationIssue
Relevant types:

- PublicationVolume

Values:

[^top]

#### pageStart

The page on which the work starts; for example "135" or "xiii".

Relevant types:

- Article
Relevant types:

- Chapter
Relevant types:

- PublicationIssue
Relevant types:

- PublicationVolume

Values:

[^top]

#### pagination

Any description of pages that is not separated into pageStart and pageEnd; for example, "1-6, 9, 55" or "10-12, 46-49".

Relevant types:

- Article
Relevant types:

- Chapter
Relevant types:

- PublicationIssue
Relevant types:

- PublicationVolume

Values:

[^top]

#### parent

A parent of this person.

Relevant types:

- Person

Values:

[^top]

#### parentItem

The parent of a question, answer or item in general.

Relevant types:

- Comment

Values:

[^top]

#### parentOrganization

The larger organization that this organization is a subOrganization of, if any.

Relevant types:

- Organization

Values:

[^top]

#### parentService

A broadcast service to which the broadcast service may belong to such as regional variations of a national channel.

Relevant types:

- BroadcastService

Values:

[^top]

#### parents

A parents of the person.

Relevant types:

- Person

Values:

[^top]

#### partOfEpisode

The episode to which this clip belongs.

Relevant types:

- Clip

Values:

[^top]

#### partOfInvoice

The order is being paid as part of the referenced Invoice.

Relevant types:

- Order

Values:

[^top]

#### partOfOrder

The overall order the items in this delivery were included in.

Relevant types:

- ParcelDelivery

Values:

[^top]

#### partOfSeason

The season to which this episode belongs.

Relevant types:

- Clip
Relevant types:

- Episode

Values:

[^top]

#### partOfSeries

The series to which this episode or season belongs.

Relevant types:

- Clip
Relevant types:

- CreativeWorkSeason
Relevant types:

- Episode

Values:

[^top]

#### partOfSystem

The anatomical or organ system that this structure is part of.

Relevant types:

- AnatomicalStructure

Values:

[^top]

#### partOfTVSeries

The TV series to which this episode or season belongs.

Relevant types:

- TVClip
Relevant types:

- TVEpisode
Relevant types:

- TVSeason

Values:

[^top]

#### partOfTrip

Identifies that this Trip is a subTrip of another Trip. For example Day 1, Day 2, etc. of a multi-day trip.

Relevant types:

- Trip

Values:

[^top]

#### participant

Other co-agents that participated in the action indirectly. e.g. John wrote a book with Steve.

Relevant types:

- Action

Values:

[^top]

#### partySize

Number of people the reservation should accommodate.

Relevant types:

- FoodEstablishmentReservation
Relevant types:

- TaxiReservation

Values:

[^top]

#### passengerPriorityStatus

The priority status assigned to a passenger for security or boarding (e.g. FastTrack or Priority).

Relevant types:

- FlightReservation

Values:

[^top]

#### passengerSequenceNumber

The passenger's sequence number as assigned by the airline.

Relevant types:

- FlightReservation

Values:

[^top]

#### pathophysiology

Changes in the normal mechanical, physical, and biochemical functions that are associated with this activity or condition.

Relevant types:

- MedicalCondition
Relevant types:

- PhysicalActivity

Values:

[^top]

#### pattern

A pattern that something has, for example 'polka dot', 'striped', 'Canadian flag'. Values are typically expressed as text, although links to controlled value schemes are also supported.

Relevant types:

- CreativeWork
Relevant types:

- Product

Values:

[^top]

#### payload

The permitted weight of passengers and cargo, EXCLUDING the weight of the empty vehicle.
Typical unit code(s): KGM for kilogram, LBR for pound

- Note 1: Many databases specify the permitted TOTAL weight instead, which is the sum of weight and payload
- Note 2: You can indicate additional information in the name of the QuantitativeValue node.
- Note 3: You may also link to a QualitativeValue node that provides additional information using valueReference.
- Note 4: Note that you can use minValue and maxValue to indicate ranges.

Relevant types:

- Vehicle

Values:

[^top]

#### paymentAccepted

Cash, Credit Card, Cryptocurrency, Local Exchange Tradings System, etc.

Relevant types:

- LocalBusiness

Values:

[^top]

#### paymentDue

The date that payment is due.

Relevant types:

- Invoice
Relevant types:

- Order

Values:

[^top]

#### paymentDueDate

The date that payment is due.

Relevant types:

- Invoice
Relevant types:

- Order

Values:

[^top]

#### paymentMethod

The name of the credit card or other method of payment for the order.

Relevant types:

- Invoice
Relevant types:

- Order

Values:

[^top]

#### paymentMethodId

An identifier for the method of payment used (e.g. the last 4 digits of the credit card).

Relevant types:

- Invoice
Relevant types:

- Order

Values:

[^top]

#### paymentStatus

The status of payment; whether the invoice has been paid or not.

Relevant types:

- Invoice

Values:

[^top]

#### paymentUrl

The URL for sending a payment.

Relevant types:

- Order

Values:

[^top]

#### penciler

The individual who draws the primary narrative artwork.

Relevant types:

- ComicIssue
Relevant types:

- ComicStory
Relevant types:

- VisualArtwork

Values:

[^top]

#### percentile10

The 10th percentile value.

Relevant types:

- QuantitativeValueDistribution

Values:

[^top]

#### percentile25

The 25th percentile value.

Relevant types:

- QuantitativeValueDistribution

Values:

[^top]

#### percentile75

The 75th percentile value.

Relevant types:

- QuantitativeValueDistribution

Values:

[^top]

#### percentile90

The 90th percentile value.

Relevant types:

- QuantitativeValueDistribution

Values:

[^top]

#### performTime

The length of time it takes to perform instructions or a direction (not including time to prepare the supplies), in ISO 8601 duration format.

Relevant types:

- HowTo
Relevant types:

- HowToDirection

Values:

[^top]

#### performer

A performer at the event—for example, a presenter, musician, musical group or actor.

Relevant types:

- Event

Values:

[^top]

#### performerIn

Event that this person is a performer or participant in.

Relevant types:

- Person

Values:

[^top]

#### performers

The main performer or performers of the event—for example, a presenter, musician, or actor.

Relevant types:

- Event

Values:

[^top]

#### permissionType

The type of permission granted the person, organization, or audience.

Relevant types:

- DigitalDocumentPermission

Values:

[^top]

#### permissions

Permission(s) required to run the app (for example, a mobile app may require full internet access or may run only on wifi).

Relevant types:

- SoftwareApplication

Values:

[^top]

#### permitAudience

The target audience for this permit.

Relevant types:

- Permit

Values:

[^top]

#### permittedUsage

Indications regarding the permitted usage of the accommodation.

Relevant types:

- Accommodation

Values:

[^top]

#### petsAllowed

Indicates whether pets are allowed to enter the accommodation or lodging business. More detailed information can be put in a text value.

Relevant types:

- Accommodation
Relevant types:

- ApartmentComplex
Relevant types:

- FloorPlan
Relevant types:

- LodgingBusiness

Values:

[^top]

#### phoneticText

Representation of a text textValue using the specified speechToTextMarkup. For example the city name of Houston in IPA: /ˈhjuːstən/.

Relevant types:

- PronounceableText

Values:

[^top]

#### photo

A photograph of this place.

Relevant types:

- Place

Values:

[^top]

#### photos

Photographs of this place.

Relevant types:

- Place

Values:

[^top]

#### physicalRequirement

A description of the types of physical activity associated with the job. Defined terms such as those in O*net may be used, but note that there is no way to specify the level of ability as well as its nature when using a defined term.

Relevant types:

- JobPosting

Values:

[^top]

#### physiologicalBenefits

Specific physiologic benefits associated to the plan.

Relevant types:

- Diet

Values:

[^top]

#### pickupLocation

Where a taxi will pick up a passenger or a rental car can be picked up.

Relevant types:

- RentalCarReservation
Relevant types:

- TaxiReservation

Values:

[^top]

#### pickupTime

When a taxi will pickup a passenger or a rental car can be picked up.

Relevant types:

- RentalCarReservation
Relevant types:

- TaxiReservation

Values:

[^top]

#### playMode

Indicates whether this game is multi-player, co-op or single-player. The game can be marked as multi-player, co-op and single-player at the same time.

Relevant types:

- VideoGame
Relevant types:

- VideoGameSeries

Values:

[^top]

#### playerType

Player type required—for example, Flash or Silverlight.

Relevant types:

- MediaObject

Values:

[^top]

#### playersOnline

Number of players on the server.

Relevant types:

- GameServer

Values:

[^top]

#### polygon

A polygon is the area enclosed by a point-to-point path for which the starting and ending points are the same. A polygon is expressed as a series of four or more space delimited points where the first and final points are identical.

Relevant types:

- GeoShape

Values:

[^top]

#### populationType

Indicates the populationType common to all members of a StatisticalPopulation.

Relevant types:

- StatisticalPopulation

Values:

[^top]

#### position

The position of an item in a series or sequence of items.

Relevant types:

- CreativeWork
Relevant types:

- ListItem

Values:

[^top]

#### possibleComplication

A possible unexpected and unfavorable evolution of a medical condition. Complications may include worsening of the signs or symptoms of the disease, extension of the condition to other organ systems, etc.

Relevant types:

- MedicalCondition

Values:

[^top]

#### possibleTreatment

A possible treatment to address this condition, sign or symptom.

Relevant types:

- MedicalCondition
Relevant types:

- MedicalSignOrSymptom

Values:

[^top]

#### postOfficeBoxNumber

The post office box number for PO box addresses.

Relevant types:

- PostalAddress

Values:

[^top]

#### postOp

A description of the postoperative procedures, care, and/or followups for this device.

Relevant types:

- MedicalDevice

Values:

[^top]

#### postalCode

The postal code. For example, 94043.

Relevant types:

- DefinedRegion
Relevant types:

- GeoCoordinates
Relevant types:

- GeoShape
Relevant types:

- PostalAddress

Values:

[^top]

#### postalCodeBegin

First postal code in a range (included).

Relevant types:

- PostalCodeRangeSpecification

Values:

[^top]

#### postalCodeEnd

Last postal code in the range (included). Needs to be after postalCodeBegin.

Relevant types:

- PostalCodeRangeSpecification

Values:

[^top]

#### postalCodePrefix

A defined range of postal codes indicated by a common textual prefix. Used for non-numeric systems such as UK.

Relevant types:

- DefinedRegion

Values:

[^top]

#### postalCodeRange

A defined range of postal codes.

Relevant types:

- DefinedRegion

Values:

[^top]

#### potentialAction

Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.

Relevant types:

- Thing

Values:

[^top]

#### preOp

A description of the workup, testing, and other preparations required before implanting this device.

Relevant types:

- MedicalDevice

Values:

[^top]

#### predecessorOf

A pointer from a previous, often discontinued variant of the product to its newer variant.

Relevant types:

- ProductModel

Values:

[^top]

#### pregnancyCategory

Pregnancy category of this drug.

Relevant types:

- Drug

Values:

[^top]

#### pregnancyWarning

Any precaution, guidance, contraindication, etc. related to this drug's use during pregnancy.

Relevant types:

- Drug

Values:

[^top]

#### prepTime

The length of time it takes to prepare the items to be used in instructions or a direction, in ISO 8601 duration format.

Relevant types:

- HowTo
Relevant types:

- HowToDirection

Values:

[^top]

#### preparation

Typical preparation that a patient must undergo before having the procedure performed.

Relevant types:

- MedicalProcedure

Values:

[^top]

#### prescribingInfo

Link to prescribing information for the drug.

Relevant types:

- Drug

Values:

[^top]

#### prescriptionStatus

Indicates the status of drug prescription eg. local catalogs classifications or whether the drug is available by prescription or over-the-counter, etc.

Relevant types:

- Drug

Values:

[^top]

#### previousItem

A link to the ListItem that preceeds the current one.

Relevant types:

- ListItem

Values:

[^top]

#### previousStartDate

Used in conjunction with eventStatus for rescheduled or cancelled events. This property contains the previously scheduled start date. For rescheduled events, the startDate property should be used for the newly scheduled start date. In the (rare) case of an event that has been postponed and rescheduled multiple times, this field may be repeated.

Relevant types:

- Event

Values:

[^top]

#### price

The offer price of a product, or of a price component when attached to PriceSpecification and its subtypes.
Usage guidelines:

- Use the priceCurrency property (with standard formats: ISO 4217 currency format e.g. "USD"; Ticker symbol for cryptocurrencies e.g. "BTC"; well known names for Local Exchange Tradings Systems (LETS) and other currency types e.g. "Ithaca HOUR") instead of including ambiguous symbols such as '$' in the value.
- Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.
- Note that both RDFa and Microdata syntax allow the use of a "content=" attribute for publishing simple machine-readable values alongside more human-friendly formatting.
- Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similiar Unicode symbols.

Relevant types:

- Offer
Relevant types:

- PriceSpecification
Relevant types:

- TradeAction

Values:

[^top]

#### priceComponent

This property links to all UnitPriceSpecification nodes that apply in parallel for the CompoundPriceSpecification node.

Relevant types:

- CompoundPriceSpecification

Values:

[^top]

#### priceComponentType

Identifies a price component (for example, a line item on an invoice), part of the total price for an offer.

Relevant types:

- UnitPriceSpecification

Values:

[^top]

#### priceCurrency

The currency of the price, or a price component when attached to PriceSpecification and its subtypes.
Use standard formats: ISO 4217 currency format e.g. "USD"; Ticker symbol for cryptocurrencies e.g. "BTC"; well known names for Local Exchange Tradings Systems (LETS) and other currency types e.g. "Ithaca HOUR".

Relevant types:

- Offer
Relevant types:

- PriceSpecification
Relevant types:

- Reservation
Relevant types:

- Ticket
Relevant types:

- TradeAction

Values:

[^top]

#### priceRange

The price range of the business, for example `$$$`.

Relevant types:

- LocalBusiness

Values:

[^top]

#### priceSpecification

One or more detailed price specifications, indicating the unit price and delivery or payment charges.

Relevant types:

- Demand
Relevant types:

- Offer
Relevant types:

- TradeAction

Values:

[^top]

#### priceType

Defines the type of a price specified for an offered product, for example a list price, a (temporary) sale price or a manufacturer suggested retail price. If multiple prices are specified for an offer the priceType property can be used to identify the type of each such specified price. The value of priceType can be specified as a value from enumeration PriceTypeEnumeration or as a free form text string for price types that are not already predefined in PriceTypeEnumeration.

Relevant types:

- CompoundPriceSpecification
Relevant types:

- UnitPriceSpecification

Values:

[^top]

#### priceValidUntil

The date after which the price is no longer available.

Relevant types:

- Offer

Values:

[^top]

#### primaryImageOfPage

Indicates the main image on the page.

Relevant types:

- WebPage

Values:

[^top]

#### primaryPrevention

A preventative therapy used to prevent an initial occurrence of the medical condition, such as vaccination.

Relevant types:

- MedicalCondition

Values:

[^top]

#### printColumn

The number of the column in which the NewsArticle appears in the print edition.

Relevant types:

- NewsArticle

Values:

[^top]

#### printEdition

The edition of the print product in which the NewsArticle appears.

Relevant types:

- NewsArticle

Values:

[^top]

#### printPage

If this NewsArticle appears in print, this field indicates the name of the page on which the article is found. Please note that this field is intended for the exact page name (e.g. A5, B18).

Relevant types:

- NewsArticle

Values:

[^top]

#### printSection

If this NewsArticle appears in print, this field indicates the print section in which the article appeared.

Relevant types:

- NewsArticle

Values:

[^top]

#### procedure

A description of the procedure involved in setting up, using, and/or installing the device.

Relevant types:

- MedicalDevice

Values:

[^top]

#### procedureType

The type of procedure, for example Surgical, Noninvasive, or Percutaneous.

Relevant types:

- MedicalProcedure

Values:

[^top]

#### processingTime

Estimated processing time for the service using this channel.

Relevant types:

- ServiceChannel

Values:

[^top]

#### processorRequirements

Processor architecture required to run the application (e.g. IA64).

Relevant types:

- SoftwareApplication

Values:

[^top]

#### producer

The person or organization who produced the work (e.g. music album, movie, tv/radio series etc.).

Relevant types:

- CreativeWork

Values:

[^top]

#### produces

The tangible thing generated by the service, e.g. a passport, permit, etc.

Relevant types:

- Service

Values:

[^top]

#### productGroupID

Indicates a textual identifier for a ProductGroup.

Relevant types:

- ProductGroup

Values:

[^top]

#### productID

The product identifier, such as ISBN. For example: `meta itemprop="productID" content="isbn:123-456-789"`.

Relevant types:

- Product

Values:

[^top]

#### productReturnDays

The productReturnDays property indicates the number of days (from purchase) within which relevant product return policy is applicable.

Relevant types:

- ProductReturnPolicy

Values:

[^top]

#### productReturnLink

Indicates a Web page or service by URL, for product return.

Relevant types:

- ProductReturnPolicy

Values:

[^top]

#### productSupported

The product or service this support contact point is related to (such as product support for a particular product line). This can be a specific product or product line (e.g. "iPhone") or a general category of products or services (e.g. "smartphones").

Relevant types:

- ContactPoint

Values:

[^top]

#### productionCompany

The production company or studio responsible for the item e.g. series, video game, episode etc.

Relevant types:

- CreativeWorkSeason
Relevant types:

- Episode
Relevant types:

- MediaObject
Relevant types:

- Movie
Relevant types:

- MovieSeries
Relevant types:

- RadioSeries
Relevant types:

- TVSeries
Relevant types:

- VideoGameSeries

Values:

[^top]

#### productionDate

The date of production of the item, e.g. vehicle.

Relevant types:

- Product
Relevant types:

- Vehicle

Values:

[^top]

#### proficiencyLevel

Proficiency needed for this content; expected values: 'Beginner', 'Expert'.

Relevant types:

- TechArticle

Values:

[^top]

#### programMembershipUsed

Any membership in a frequent flyer, hotel loyalty program, etc. being applied to the reservation.

Relevant types:

- Reservation

Values:

[^top]

#### programName

The program providing the membership.

Relevant types:

- ProgramMembership

Values:

[^top]

#### programPrerequisites

Prerequisites for enrolling in the program.

Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### programType

The type of educational or occupational program. For example, classroom, internship, alternance, etc..

Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### programmingLanguage

The computer programming language.

Relevant types:

- SoftwareSourceCode

Values:

[^top]

#### programmingModel

Indicates whether API is managed or unmanaged.

Relevant types:

- APIReference

Values:

[^top]

#### propertyID

A commonly used identifier for the characteristic represented by the property, e.g. a manufacturer or a standard code for a property. propertyID can be (1) a prefixed string, mainly meant to be used with standards for product properties; (2) a site-specific, non-prefixed string (e.g. the primary key of the property or the vendor-specific id of the property), or (3) a URL indicating the type of the property, either pointing to an external vocabulary, or a Web resource that describes the property (e.g. a glossary entry). Standards bodies should promote a standard prefix for the identifiers of properties from their standards.

Relevant types:

- PropertyValue

Values:

[^top]

#### proprietaryName

Proprietary name given to the diet plan, typically by its originator or creator.

Relevant types:

- DietarySupplement
Relevant types:

- Drug

Values:

[^top]

#### proteinContent

The number of grams of protein.

Relevant types:

- NutritionInformation

Values:

[^top]

#### provider

The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.

Relevant types:

- CreativeWork
Relevant types:

- EducationalOccupationalProgram
Relevant types:

- Invoice
Relevant types:

- ParcelDelivery
Relevant types:

- Reservation
Relevant types:

- Service
Relevant types:

- Trip

Values:

[^top]

#### providerMobility

Indicates the mobility of a provided service (e.g. 'static', 'dynamic').

Relevant types:

- Service

Values:

[^top]

#### providesBroadcastService

The BroadcastService offered on this channel.

Relevant types:

- BroadcastChannel

Values:

[^top]

#### providesService

The service provided by this channel.

Relevant types:

- ServiceChannel

Values:

[^top]

#### publicAccess

A flag to signal that the Place is open to public visitors. If this property is omitted there is no assumed default boolean value

Relevant types:

- Place

Values:

[^top]

#### publicTransportClosuresInfo

Information about public transport closures.

Relevant types:

- SpecialAnnouncement

Values:

[^top]

#### publication

A publication event associated with the item.

Relevant types:

- CreativeWork

Values:

[^top]

#### publicationType

The type of the medical article, taken from the US NLM MeSH publication type catalog. See also MeSH documentation.

Relevant types:

- MedicalScholarlyArticle

Values:

[^top]

#### publishedBy

An agent associated with the publication event.

Relevant types:

- PublicationEvent

Values:

[^top]

#### publishedOn

A broadcast service associated with the publication event.

Relevant types:

- PublicationEvent

Values:

[^top]

#### publisher

The publisher of the creative work.

Relevant types:

- CreativeWork

Values:

[^top]

#### publisherImprint

The publishing division which published the comic.

Relevant types:

- CreativeWork

Values:

[^top]

#### publishingPrinciples

The publishingPrinciples property indicates (typically via URL) a document describing the editorial principles of an Organization (or individual e.g. a Person writing a blog) that relate to their activities as a publisher, e.g. ethics or diversity policies. When applied to a CreativeWork (e.g. NewsArticle) the principles are those of the party primarily responsible for the creation of the CreativeWork.
While such policies are most typically expressed in natural language, sometimes related information (e.g. indicating a funder) can be expressed using schema.org terminology.

Relevant types:

- CreativeWork
Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### purchaseDate

The date the item e.g. vehicle was purchased by the current owner.

Relevant types:

- Product
Relevant types:

- Vehicle

Values:

[^top]

#### qualifications

Specific qualifications required for this role or Occupation.

Relevant types:

- JobPosting
Relevant types:

- Occupation

Values:

[^top]

#### quarantineGuidelines

Guidelines about quarantine rules, e.g. in the context of a pandemic.

Relevant types:

- SpecialAnnouncement

Values:

[^top]

#### query

A sub property of instrument. The query used on this action.

Relevant types:

- SearchAction

Values:

[^top]

#### quest

The task that a player-controlled character, or group of characters may complete in order to gain a reward.

Relevant types:

- Game
Relevant types:

- VideoGameSeries

Values:

[^top]

#### question

A sub property of object. A question.

Relevant types:

- AskAction

Values:

[^top]

#### rangeIncludes

Relates a property to a class that constitutes (one of) the expected type(s) for values of the property.

Relevant types:

- Property

Values:

[^top]

#### ratingCount

The count of total number of ratings.

Relevant types:

- AggregateRating

Values:

[^top]

#### ratingExplanation

A short explanation (e.g. one to two sentences) providing background context and other information that led to the conclusion expressed in the rating. This is particularly applicable to ratings associated with "fact check" markup using ClaimReview.

Relevant types:

- Rating

Values:

[^top]

#### ratingValue

The rating for the content.
Usage guidelines:

- Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similiar Unicode symbols.
- Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.

Relevant types:

- Rating

Values:

[^top]

#### readBy

A person who reads (performs) the audiobook.

Relevant types:

- Audiobook

Values:

[^top]

#### readonlyValue

Whether or not a property is mutable. Default is false. Specifying this for a property that also has a value makes it act similar to a "hidden" input in an HTML form.

Relevant types:

- PropertyValueSpecification

Values:

[^top]

#### realEstateAgent

A sub property of participant. The real estate agent involved in the action.

Relevant types:

- RentAction

Values:

[^top]

#### recipe

A sub property of instrument. The recipe/instructions used to perform the action.

Relevant types:

- CookAction

Values:

[^top]

#### recipeCategory

The category of the recipe—for example, appetizer, entree, etc.

Relevant types:

- Recipe

Values:

[^top]

#### recipeCuisine

The cuisine of the recipe (for example, French or Ethiopian).

Relevant types:

- Recipe

Values:

[^top]

#### recipeIngredient

A single ingredient used in the recipe, e.g. sugar, flour or garlic.

Relevant types:

- Recipe

Values:

[^top]

#### recipeInstructions

A step in making the recipe, in the form of a single item (document, video, etc.) or an ordered list with HowToStep and/or HowToSection items.

Relevant types:

- Recipe

Values:

[^top]

#### recipeYield

The quantity produced by the recipe (for example, number of people served, number of servings, etc).

Relevant types:

- Recipe

Values:

[^top]

#### recipient

A sub property of participant. The participant who is at the receiving end of the action.

Relevant types:

- AuthorizeAction
Relevant types:

- CommunicateAction
Relevant types:

- DonateAction
Relevant types:

- GiveAction
Relevant types:

- Message
Relevant types:

- PayAction
Relevant types:

- ReturnAction
Relevant types:

- SendAction
Relevant types:

- TipAction

Values:

[^top]

#### recognizedBy

An organization that acknowledges the validity, value or utility of a credential. Note: recognition may include a process of quality assurance or accreditation.

Relevant types:

- EducationalOccupationalCredential

Values:

[^top]

#### recognizingAuthority

If applicable, the organization that officially recognizes this entity as part of its endorsed system of medicine.

Relevant types:

- MedicalEntity

Values:

[^top]

#### recommendationStrength

Strength of the guideline's recommendation (e.g. 'class I').

Relevant types:

- MedicalGuidelineRecommendation

Values:

[^top]

#### recommendedIntake

Recommended intake of this supplement for a given population as defined by a specific recommending authority.

Relevant types:

- DietarySupplement

Values:

[^top]

#### recordLabel

The label that issued the release.

Relevant types:

- MusicRelease

Values:

[^top]

#### recordedAs

An audio recording of the work.

Relevant types:

- MusicComposition

Values:

[^top]

#### recordedAt

The Event where the CreativeWork was recorded. The CreativeWork may capture all or part of the event.

Relevant types:

- CreativeWork

Values:

[^top]

#### recordedIn

The CreativeWork that captured all or part of this Event.

Relevant types:

- Event

Values:

[^top]

#### recordingOf

The composition this track is a recording of.

Relevant types:

- MusicRecording

Values:

[^top]

#### recourseLoan

The only way you get the money back in the event of default is the security. Recourse is where you still have the opportunity to go back to the borrower for the rest of the money.

Relevant types:

- LoanOrCredit

Values:

[^top]

#### referenceQuantity

The reference quantity for which a certain price applies, e.g. 1 EUR per 4 kWh of electricity. This property is a replacement for unitOfMeasurement for the advanced cases where the price does not relate to a standard unit.

Relevant types:

- UnitPriceSpecification

Values:

[^top]

#### referencesOrder

The Order(s) related to this Invoice. One or more Orders may be combined into a single Invoice.

Relevant types:

- Invoice

Values:

[^top]

#### refundType

A refundType, from an enumerated list.

Relevant types:

- MerchantReturnPolicy

Values:

[^top]

#### regionDrained

The anatomical or organ system drained by this vessel; generally refers to a specific part of an organ.

Relevant types:

- LymphaticVessel
Relevant types:

- Vein

Values:

[^top]

#### regionsAllowed

The regions where the media is allowed. If not specified, then it's assumed to be allowed everywhere. Specify the countries in ISO 3166 format.

Relevant types:

- MediaObject

Values:

[^top]

#### relatedAnatomy

Anatomical systems or structures that relate to the superficial anatomy.

Relevant types:

- SuperficialAnatomy

Values:

[^top]

#### relatedCondition

A medical condition associated with this anatomy.

Relevant types:

- AnatomicalStructure
Relevant types:

- AnatomicalSystem
Relevant types:

- SuperficialAnatomy

Values:

[^top]

#### relatedDrug

Any other drug related to this one, for example commonly-prescribed alternatives.

Relevant types:

- Drug

Values:

[^top]

#### relatedLink

A link related to this web page, for example to other related web pages.

Relevant types:

- WebPage

Values:

[^top]

#### relatedStructure

Related anatomical structure(s) that are not part of the system but relate or connect to it, such as vascular bundles associated with an organ system.

Relevant types:

- AnatomicalSystem

Values:

[^top]

#### relatedTherapy

A medical therapy related to this anatomy.

Relevant types:

- AnatomicalStructure
Relevant types:

- AnatomicalSystem
Relevant types:

- SuperficialAnatomy

Values:

[^top]

#### relatedTo

The most generic familial relation.

Relevant types:

- Person

Values:

[^top]

#### releaseDate

The release date of a product or product model. This can be used to distinguish the exact variant of a product.

Relevant types:

- Product

Values:

[^top]

#### releaseNotes

Description of what changed in this version.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### releaseOf

The album this is a release of.

Relevant types:

- MusicRelease

Values:

[^top]

#### releasedEvent

The place and time the release was issued, expressed as a PublicationEvent.

Relevant types:

- CreativeWork

Values:

[^top]

#### relevantOccupation

The Occupation for the JobPosting.

Relevant types:

- JobPosting

Values:

[^top]

#### relevantSpecialty

If applicable, a medical specialty in which this entity is relevant.

Relevant types:

- MedicalEntity

Values:

[^top]

#### remainingAttendeeCapacity

The number of attendee places for an event that remain unallocated.

Relevant types:

- Event

Values:

[^top]

#### renegotiableLoan

Whether the terms for payment of interest can be renegotiated during the life of the loan.

Relevant types:

- LoanOrCredit

Values:

[^top]

#### repeatCount

Defines the number of times a recurring Event will take place

Relevant types:

- Schedule

Values:

[^top]

#### repeatFrequency

Defines the frequency at which Events will occur according to a schedule Schedule. The intervals between events should be defined as a Duration of time.

Relevant types:

- Schedule

Values:

[^top]

#### repetitions

Number of times one should repeat the activity.

Relevant types:

- ExercisePlan

Values:

[^top]

#### replacee

A sub property of object. The object that is being replaced.

Relevant types:

- ReplaceAction

Values:

[^top]

#### replacer

A sub property of object. The object that replaces.

Relevant types:

- ReplaceAction

Values:

[^top]

#### replyToUrl

The URL at which a reply may be posted to the specified UserComment.

Relevant types:

- UserComments

Values:

[^top]

#### reportNumber

The number or other unique designator assigned to a Report by the publishing organization.

Relevant types:

- Report

Values:

[^top]

#### representativeOfPage

Indicates whether this image is representative of the content of the page.

Relevant types:

- ImageObject

Values:

[^top]

#### requiredCollateral

Assets required to secure loan or credit repayments. It may take form of third party pledge, goods, financial instruments (cash, securities, etc.)

Relevant types:

- LoanOrCredit

Values:

[^top]

#### requiredGender

Audiences defined by a person's gender.

Relevant types:

- PeopleAudience

Values:

[^top]

#### requiredMaxAge

Audiences defined by a person's maximum age.

Relevant types:

- PeopleAudience

Values:

[^top]

#### requiredMinAge

Audiences defined by a person's minimum age.

Relevant types:

- PeopleAudience

Values:

[^top]

#### requiredQuantity

The required quantity of the item(s).

Relevant types:

- HowToItem

Values:

[^top]

#### requirements

Component dependency requirements for application. This includes runtime environments and shared libraries that are not included in the application distribution package, but required to run the application (Examples: DirectX, Java or .NET runtime).

Relevant types:

- SoftwareApplication

Values:

[^top]

#### requiresSubscription

Indicates if use of the media require a subscription (either paid or free). Allowed values are `true` or `false` (note that an earlier version had 'yes', 'no').

Relevant types:

- ActionAccessSpecification
Relevant types:

- MediaObject

Values:

[^top]

#### reservationFor

The thing -- flight, event, restaurant,etc. being reserved.

Relevant types:

- Reservation

Values:

[^top]

#### reservationId

A unique identifier for the reservation.

Relevant types:

- Reservation

Values:

[^top]

#### reservationStatus

The current status of the reservation.

Relevant types:

- Reservation

Values:

[^top]

#### reservedTicket

A ticket associated with the reservation.

Relevant types:

- Reservation

Values:

[^top]

#### responsibilities

Responsibilities associated with this role or Occupation.

Relevant types:

- JobPosting
Relevant types:

- Occupation

Values:

[^top]

#### restPeriods

How often one should break from the activity.

Relevant types:

- ExercisePlan

Values:

[^top]

#### result

The result produced in the action. e.g. John wrote a book.

Relevant types:

- Action

Values:

[^top]

#### resultComment

A sub property of result. The Comment created or sent as a result of this action.

Relevant types:

- CommentAction
Relevant types:

- ReplyAction

Values:

[^top]

#### resultReview

A sub property of result. The review that resulted in the performing of the action.

Relevant types:

- ReviewAction

Values:

[^top]

#### returnFees

Indicates (via enumerated options) the return fees policy for a MerchantReturnPolicy

Relevant types:

- MerchantReturnPolicy

Values:

[^top]

#### returnPolicyCategory

A returnPolicyCategory expresses at most one of several enumerated kinds of return.

Relevant types:

- MerchantReturnPolicy

Values:

[^top]

#### review

A review of the item.

Relevant types:

- Brand
Relevant types:

- CreativeWork
Relevant types:

- Event
Relevant types:

- Offer
Relevant types:

- Organization
Relevant types:

- Place
Relevant types:

- Product
Relevant types:

- Service

Values:

[^top]

#### reviewAspect

This Review or Rating is relevant to this part or facet of the itemReviewed.

Relevant types:

- Guide
Relevant types:

- Rating
Relevant types:

- Review

Values:

[^top]

#### reviewBody

The actual body of the review.

Relevant types:

- Review

Values:

[^top]

#### reviewCount

The count of total number of reviews.

Relevant types:

- AggregateRating

Values:

[^top]

#### reviewRating

The rating given in this review. Note that reviews can themselves be rated. The `reviewRating` applies to rating given by the review. The aggregateRating property applies to the review itself, as a creative work.

Relevant types:

- Review

Values:

[^top]

#### reviewedBy

People or organizations that have reviewed the content on this web page for accuracy and/or completeness.

Relevant types:

- WebPage

Values:

[^top]

#### reviews

Review of the item.

Relevant types:

- CreativeWork
Relevant types:

- Offer
Relevant types:

- Organization
Relevant types:

- Place
Relevant types:

- Product

Values:

[^top]

#### riskFactor

A modifiable or non-modifiable factor that increases the risk of a patient contracting this condition, e.g. age, coexisting condition.

Relevant types:

- MedicalCondition

Values:

[^top]

#### risks

Specific physiologic risks associated to the diet plan.

Relevant types:

- Diet

Values:

[^top]

#### roleName

A role played, performed or filled by a person or organization. For example, the team of creators for a comic book might fill the roles named 'inker', 'penciller', and 'letterer'; or an athlete in a SportsTeam might play in the position named 'Quarterback'.

Relevant types:

- Role

Values:

[^top]

#### roofLoad

The permitted total weight of cargo and installations (e.g. a roof rack) on top of the vehicle.
Typical unit code(s): KGM for kilogram, LBR for pound

- Note 1: You can indicate additional information in the name of the QuantitativeValue node.
- Note 2: You may also link to a QualitativeValue node that provides additional information using valueReference
- Note 3: Note that you can use minValue and maxValue to indicate ranges.

Relevant types:

- BusOrCoach
Relevant types:

- Car

Values:

[^top]

#### rsvpResponse

The response (yes, no, maybe) to the RSVP.

Relevant types:

- RsvpAction

Values:

[^top]

#### runsTo

The vasculature the lymphatic structure runs, or efferents, to.

Relevant types:

- LymphaticVessel

Values:

[^top]

#### runtime

Runtime platform or script interpreter dependencies (Example - Java v1, Python2.3, .Net Framework 3.0).

Relevant types:

- SoftwareSourceCode

Values:

[^top]

#### runtimePlatform

Runtime platform or script interpreter dependencies (Example - Java v1, Python2.3, .Net Framework 3.0).

Relevant types:

- SoftwareSourceCode

Values:

[^top]

#### rxcui

The RxCUI drug identifier from RXNORM.

Relevant types:

- Drug

Values:

[^top]

#### safetyConsideration

Any potential safety concern associated with the supplement. May include interactions with other drugs and foods, pregnancy, breastfeeding, known adverse reactions, and documented efficacy of the supplement.

Relevant types:

- DietarySupplement

Values:

[^top]

#### salaryCurrency

The currency (coded using ISO 4217 ) used for the main salary information in this job posting or for this employee.

Relevant types:

- EmployeeRole
Relevant types:

- JobPosting

Values:

[^top]

#### salaryUponCompletion

The expected salary upon completing the training.

Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### sameAs

URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.

Relevant types:

- Thing

Values:

[^top]

#### sampleType

What type of code sample: full (compile ready) solution, code snippet, inline code, scripts, template.

Relevant types:

- SoftwareSourceCode

Values:

[^top]

#### saturatedFatContent

The number of grams of saturated fat.

Relevant types:

- NutritionInformation

Values:

[^top]

#### scheduleTimezone

Indicates the timezone for which the time(s) indicated in the Schedule are given. The value provided should be among those listed in the IANA Time Zone Database.

Relevant types:

- Schedule

Values:

[^top]

#### scheduledPaymentDate

The date the invoice is scheduled to be paid.

Relevant types:

- Invoice

Values:

[^top]

#### scheduledTime

The time the object is scheduled to.

Relevant types:

- PlanAction

Values:

[^top]

#### schemaVersion

Indicates (by URL or string) a particular version of a schema used in some CreativeWork. This property was created primarily to indicate the use of a specific schema.org release, e.g. `10.0` as a simple string, or more explicitly via URL, `https://schema.org/docs/releases.html#v10.0`. There may be situations in which other schemas might usefully be referenced this way, e.g. `http://dublincore.org/specifications/dublin-core/dces/1999-07-02/` but this has not been carefully explored in the community.

Relevant types:

- CreativeWork

Values:

[^top]

#### schoolClosuresInfo

Information about school closures.

Relevant types:

- SpecialAnnouncement

Values:

[^top]

#### screenCount

The number of screens in the movie theater.

Relevant types:

- MovieTheater

Values:

[^top]

#### screenshot

A link to a screenshot image of the app.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### sdDatePublished

Indicates the date on which the current structured data was generated / published. Typically used alongside sdPublisher

Relevant types:

- CreativeWork

Values:

[^top]

#### sdLicense

A license document that applies to this structured data, typically indicated by URL.

Relevant types:

- CreativeWork

Values:

[^top]

#### sdPublisher

Indicates the party responsible for generating and publishing the current structured data markup, typically in cases where the structured data is derived automatically from existing published content but published on a different site. For example, student projects and open data initiatives often re-publish existing content with more explicitly structured metadata. The sdPublisher property helps make such practices more explicit.

Relevant types:

- CreativeWork

Values:

[^top]

#### season

A season in a media series.

Relevant types:

- RadioSeries
Relevant types:

- TVSeries
Relevant types:

- VideoGameSeries

Values:

[^top]

#### seasonNumber

Position of the season within an ordered group of seasons.

Relevant types:

- CreativeWorkSeason

Values:

[^top]

#### seasons

A season in a media series.

Relevant types:

- RadioSeries
Relevant types:

- TVSeries
Relevant types:

- VideoGameSeries

Values:

[^top]

#### seatNumber

The location of the reserved seat (e.g., 27).

Relevant types:

- Seat

Values:

[^top]

#### seatRow

The row location of the reserved seat (e.g., B).

Relevant types:

- Seat

Values:

[^top]

#### seatSection

The section location of the reserved seat (e.g. Orchestra).

Relevant types:

- Seat

Values:

[^top]

#### seatingCapacity

The number of persons that can be seated (e.g. in a vehicle), both in terms of the physical space available, and in terms of limitations set by law.
Typical unit code(s): C62 for persons

Relevant types:

- Vehicle

Values:

[^top]

#### seatingType

The type/class of the seat.

Relevant types:

- Seat

Values:

[^top]

#### secondaryPrevention

A preventative therapy used to prevent reoccurrence of the medical condition after an initial episode of the condition.

Relevant types:

- MedicalCondition

Values:

[^top]

#### securityClearanceRequirement

A description of any security clearance requirements of the job.

Relevant types:

- JobPosting

Values:

[^top]

#### securityScreening

The type of security screening the passenger is subject to.

Relevant types:

- FlightReservation

Values:

[^top]

#### seeks

A pointer to products or services sought by the organization or person (demand).

Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### seller

An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider.

Relevant types:

- BuyAction
Relevant types:

- Demand
Relevant types:

- Flight
Relevant types:

- Offer
Relevant types:

- Order

Values:

[^top]

#### sender

A sub property of participant. The participant who is at the sending end of the action.

Relevant types:

- Message
Relevant types:

- ReceiveAction

Values:

[^top]

#### sensoryRequirement

A description of any sensory requirements and levels necessary to function on the job, including hearing and vision. Defined terms such as those in O*net may be used, but note that there is no way to specify the level of ability as well as its nature when using a defined term.

Relevant types:

- JobPosting

Values:

[^top]

#### sensoryUnit

The neurological pathway extension that inputs and sends information to the brain or spinal cord.

Relevant types:

- Nerve

Values:

[^top]

#### serialNumber

The serial number or any alphanumeric identifier of a particular product. When attached to an offer, it is a shortcut for the serial number of the product included in the offer.

Relevant types:

- Demand
Relevant types:

- IndividualProduct
Relevant types:

- Offer

Values:

[^top]

#### seriousAdverseOutcome

A possible serious complication and/or serious side effect of this therapy. Serious adverse outcomes include those that are life-threatening; result in death, disability, or permanent damage; require hospitalization or prolong existing hospitalization; cause congenital anomalies or birth defects; or jeopardize the patient and may require medical or surgical intervention to prevent one of the outcomes in this definition.

Relevant types:

- MedicalDevice
Relevant types:

- MedicalTherapy

Values:

[^top]

#### serverStatus

Status of a game server.

Relevant types:

- GameServer

Values:

[^top]

#### servesCuisine

The cuisine of the restaurant.

Relevant types:

- FoodEstablishment

Values:

[^top]

#### serviceArea

The geographic area where the service is provided.

Relevant types:

- ContactPoint
Relevant types:

- Organization
Relevant types:

- Service

Values:

[^top]

#### serviceAudience

The audience eligible for this service.

Relevant types:

- Service

Values:

[^top]

#### serviceLocation

The location (e.g. civic structure, local business, etc.) where a person can go to access the service.

Relevant types:

- ServiceChannel

Values:

[^top]

#### serviceOperator

The operating organization, if different from the provider. This enables the representation of services that are provided by an organization, but operated by another organization like a subcontractor.

Relevant types:

- GovernmentService

Values:

[^top]

#### serviceOutput

The tangible thing generated by the service, e.g. a passport, permit, etc.

Relevant types:

- Service

Values:

[^top]

#### servicePhone

The phone number to use to access the service.

Relevant types:

- ServiceChannel

Values:

[^top]

#### servicePostalAddress

The address for accessing the service by mail.

Relevant types:

- ServiceChannel

Values:

[^top]

#### serviceSmsNumber

The number to access the service by text message.

Relevant types:

- ServiceChannel

Values:

[^top]

#### serviceType

The type of service being offered, e.g. veterans' benefits, emergency relief, etc.

Relevant types:

- Service

Values:

[^top]

#### serviceUrl

The website to access the service.

Relevant types:

- ServiceChannel

Values:

[^top]

#### servingSize

The serving size, in terms of the number of volume or mass.

Relevant types:

- NutritionInformation

Values:

[^top]

#### sharedContent

A CreativeWork such as an image, video, or audio clip shared as part of this posting.

Relevant types:

- SocialMediaPosting

Values:

[^top]

#### shippingDestination

indicates (possibly multiple) shipping destinations. These can be defined in several ways e.g. postalCode ranges.

Relevant types:

- DeliveryTimeSettings
Relevant types:

- OfferShippingDetails
Relevant types:

- ShippingRateSettings

Values:

[^top]

#### shippingDetails

Indicates information about the shipping policies and options associated with an Offer.

Relevant types:

- Offer

Values:

[^top]

#### shippingLabel

Label to match an OfferShippingDetails with a ShippingRateSettings (within the context of a shippingSettingsLink cross-reference).

Relevant types:

- OfferShippingDetails
Relevant types:

- ShippingRateSettings

Values:

[^top]

#### shippingRate

The shipping rate is the cost of shipping to the specified destination. Typically, the maxValue and currency values (of the MonetaryAmount) are most appropriate.

Relevant types:

- OfferShippingDetails
Relevant types:

- ShippingRateSettings

Values:

[^top]

#### shippingSettingsLink

Link to a page containing ShippingRateSettings and DeliveryTimeSettings details.

Relevant types:

- OfferShippingDetails

Values:

[^top]

#### sibling

A sibling of the person.

Relevant types:

- Person

Values:

[^top]

#### siblings

A sibling of the person.

Relevant types:

- Person

Values:

[^top]

#### signDetected

A sign detected by the test.

Relevant types:

- MedicalTest

Values:

[^top]

#### signOrSymptom

A sign or symptom of this condition. Signs are objective or physically observable manifestations of the medical condition while symptoms are the subjective experience of the medical condition.

Relevant types:

- MedicalCondition

Values:

[^top]

#### significance

The significance associated with the superficial anatomy; as an example, how characteristics of the superficial anatomy can suggest underlying medical conditions or courses of treatment.

Relevant types:

- SuperficialAnatomy

Values:

[^top]

#### significantLink

One of the more significant URLs on the page. Typically, these are the non-navigation links that are clicked on the most.

Relevant types:

- WebPage

Values:

[^top]

#### significantLinks

The most significant URLs on the page. Typically, these are the non-navigation links that are clicked on the most.

Relevant types:

- WebPage

Values:

[^top]

#### size

A standardized size of a product or creative work, specified either through a simple textual string (for example 'XL', '32Wx34L'), a QuantitativeValue with a unitCode, or a comprehensive and structured SizeSpecification; in other cases, the width, height, depth and weight properties may be more applicable.

Relevant types:

- CreativeWork
Relevant types:

- Product

Values:

[^top]

#### sizeGroup

The size group (also known as "size type") for a product's size. Size groups are common in the fashion industry to define size segments and suggested audiences for wearable products. Multiple values can be combined, for example "men's big and tall", "petite maternity" or "regular"

Relevant types:

- SizeSpecification

Values:

[^top]

#### sizeSystem

The size system used to identify a product's size. Typically either a standard (for example, "GS1" or "ISO-EN13402"), country code (for example "US" or "JP"), or a measuring system (for example "Metric" or "Imperial").

Relevant types:

- SizeSpecification

Values:

[^top]

#### skills

A statement of knowledge, skill, ability, task or any other assertion expressing a competency that is desired or required to fulfill this role or to work in this occupation.

Relevant types:

- JobPosting
Relevant types:

- Occupation

Values:

[^top]

#### sku

The Stock Keeping Unit (SKU), i.e. a merchant-specific identifier for a product or service, or the product to which the offer refers.

Relevant types:

- Demand
Relevant types:

- Offer
Relevant types:

- Product

Values:

[^top]

#### slogan

A slogan or motto associated with the item.

Relevant types:

- Brand
Relevant types:

- Organization
Relevant types:

- Place
Relevant types:

- Product
Relevant types:

- Service

Values:

[^top]

#### smokingAllowed

Indicates whether it is allowed to smoke in the place, e.g. in the restaurant, hotel or hotel room.

Relevant types:

- Place

Values:

[^top]

#### sodiumContent

The number of milligrams of sodium.

Relevant types:

- NutritionInformation

Values:

[^top]

#### softwareAddOn

Additional content for a software application.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### softwareHelp

Software application help.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### softwareRequirements

Component dependency requirements for application. This includes runtime environments and shared libraries that are not included in the application distribution package, but required to run the application (Examples: DirectX, Java or .NET runtime).

Relevant types:

- SoftwareApplication

Values:

[^top]

#### softwareVersion

Version of the software instance.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### sourceOrganization

The Organization on whose behalf the creator was working.

Relevant types:

- CreativeWork

Values:

[^top]

#### sourcedFrom

The neurological pathway that originates the neurons.

Relevant types:

- Nerve

Values:

[^top]

#### spatial

The "spatial" property can be used in cases when more specific properties (e.g. locationCreated, spatialCoverage, contentLocation) are not known to be appropriate.

Relevant types:

- CreativeWork

Values:

[^top]

#### spatialCoverage

The spatialCoverage of a CreativeWork indicates the place(s) which are the focus of the content. It is a subproperty of contentLocation intended primarily for more technical and detailed materials. For example with a Dataset, it indicates areas that the dataset describes: a dataset of New York weather would have spatialCoverage which was the place: the state of New York.

Relevant types:

- CreativeWork

Values:

[^top]

#### speakable

Indicates sections of a Web page that are particularly 'speakable' in the sense of being highlighted as being especially appropriate for text-to-speech conversion. Other sections of a page may also be usefully spoken in particular circumstances; the 'speakable' property serves to indicate the parts most likely to be generally useful for speech.
The speakable property can be repeated an arbitrary number of times, with three kinds of possible 'content-locator' values:
1.) id-value URL references - uses id-value of an element in the page being annotated. The simplest use of speakable has (potentially relative) URL values, referencing identified sections of the document concerned.
2.) CSS Selectors - addresses content in the annotated page, eg. via class attribute. Use the cssSelector property.
3.) XPaths - addresses content via XPaths (assuming an XML view of the content). Use the xpath property.
For more sophisticated markup of speakable sections beyond simple ID references, either CSS selectors or XPath expressions to pick out document section(s) as speakable. For this we define a supporting type, SpeakableSpecification which is defined to be a possible value of the speakable property.

Relevant types:

- Article
Relevant types:

- WebPage

Values:

[^top]

#### specialCommitments

Any special commitments associated with this job posting. Valid entries include VeteranCommit, MilitarySpouseCommit, etc.

Relevant types:

- JobPosting

Values:

[^top]

#### specialOpeningHoursSpecification

The special opening hours of a certain place.
Use this to explicitly override general opening hours brought in scope by openingHoursSpecification or openingHours.

Relevant types:

- Place

Values:

[^top]

#### specialty

One of the domain specialities to which this web page's content applies.

Relevant types:

- WebPage

Values:

[^top]

#### speechToTextMarkup

Form of markup used. eg. SSML or IPA.

Relevant types:

- PronounceableText

Values:

[^top]

#### speed

The speed range of the vehicle. If the vehicle is powered by an engine, the upper limit of the speed range (indicated by maxValue should be the maximum speed achievable under regular conditions.
Typical unit code(s): KMH for km/h, HM for mile per hour (0.447 04 m/s), KNT for knot
*Note 1: Use minValue and maxValue to indicate the range. Typically, the minimal value is zero. * Note 2: There are many different ways of measuring the speed range. You can link to information about how the given value has been determined using the valueReference property.

Relevant types:

- Vehicle

Values:

[^top]

#### spokenByCharacter

The (e.g. fictional) character, Person or Organization to whom the quotation is attributed within the containing CreativeWork.

Relevant types:

- Quotation

Values:

[^top]

#### sponsor

A person or organization that supports a thing through a pledge, promise, or financial contribution. e.g. a sponsor of a Medical Study or a corporate sponsor of an event.

Relevant types:

- CreativeWork
Relevant types:

- Event
Relevant types:

- Grant
Relevant types:

- MedicalStudy
Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### sport

A type of sport (e.g. Baseball).

Relevant types:

- SportsEvent
Relevant types:

- SportsOrganization

Values:

[^top]

#### sportsActivityLocation

A sub property of location. The sports activity location where this action occurred.

Relevant types:

- ExerciseAction

Values:

[^top]

#### sportsEvent

A sub property of location. The sports event where this action occurred.

Relevant types:

- ExerciseAction

Values:

[^top]

#### sportsTeam

A sub property of participant. The sports team that participated on this action.

Relevant types:

- ExerciseAction

Values:

[^top]

#### spouse

The person's spouse.

Relevant types:

- Person

Values:

[^top]

#### stage

The stage of the condition, if applicable.

Relevant types:

- MedicalCondition

Values:

[^top]

#### stageAsNumber

The stage represented as a number, e.g. 3.

Relevant types:

- MedicalConditionStage

Values:

[^top]

#### starRating

An official rating for a lodging business or food establishment, e.g. from national associations or standards bodies. Use the author property to indicate the rating organization, e.g. as an Organization with name such as (e.g. HOTREC, DEHOGA, WHR, or Hotelstars).

Relevant types:

- FoodEstablishment
Relevant types:

- LodgingBusiness

Values:

[^top]

#### startDate

The start date and time of the item (in ISO 8601 date format).

Relevant types:

- CreativeWorkSeason
Relevant types:

- CreativeWorkSeries
Relevant types:

- DatedMoneySpecification
Relevant types:

- EducationalOccupationalProgram
Relevant types:

- Event
Relevant types:

- Role
Relevant types:

- Schedule

Values:

[^top]

#### startOffset

The start time of the clip expressed as the number of seconds from the beginning of the work.

Relevant types:

- Clip

Values:

[^top]

#### startTime

The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. e.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.
Note that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.

Relevant types:

- Action
Relevant types:

- FoodEstablishmentReservation
Relevant types:

- MediaObject
Relevant types:

- Schedule

Values:

[^top]

#### status

The status of the study (enumerated).

Relevant types:

- MedicalCondition
Relevant types:

- MedicalProcedure
Relevant types:

- MedicalStudy

Values:

[^top]

#### steeringPosition

The position of the steering wheel or similar device (mostly for cars).

Relevant types:

- Vehicle

Values:

[^top]

#### step

A single step item (as HowToStep, text, document, video, etc.) or a HowToSection.

Relevant types:

- HowTo

Values:

[^top]

#### stepValue

The stepValue attribute indicates the granularity that is expected (and required) of the value in a PropertyValueSpecification.

Relevant types:

- PropertyValueSpecification

Values:

[^top]

#### steps

A single step item (as HowToStep, text, document, video, etc.) or a HowToSection (originally misnamed 'steps'; 'step' is preferred).

Relevant types:

- HowTo
Relevant types:

- HowToSection

Values:

[^top]

#### storageRequirements

Storage requirements (free space required).

Relevant types:

- SoftwareApplication

Values:

[^top]

#### streetAddress

The street address. For example, 1600 Amphitheatre Pkwy.

Relevant types:

- PostalAddress

Values:

[^top]

#### strengthUnit

The units of an active ingredient's strength, e.g. mg.

Relevant types:

- DrugStrength

Values:

[^top]

#### strengthValue

The value of an active ingredient's strength, e.g. 325.

Relevant types:

- DrugStrength

Values:

[^top]

#### structuralClass

The name given to how bone physically connects to each other.

Relevant types:

- Joint

Values:

[^top]

#### study

A medical study or trial related to this entity.

Relevant types:

- MedicalEntity

Values:

[^top]

#### studyDesign

Specifics about the observational study design (enumerated).

Relevant types:

- MedicalObservationalStudy

Values:

[^top]

#### studyLocation

The location in which the study is taking/took place.

Relevant types:

- MedicalStudy

Values:

[^top]

#### studySubject

A subject of the study, i.e. one of the medical conditions, therapies, devices, drugs, etc. investigated by the study.

Relevant types:

- MedicalStudy

Values:

[^top]

#### stupidProperty

This is a StupidProperty! - for testing only

Relevant types:

- StupidType
Relevant types:

- Vehicle

Values:

[^top]

#### subEvent

An Event that is part of this event. For example, a conference event includes many presentations, each of which is a subEvent of the conference.

Relevant types:

- Event

Values:

[^top]

#### subEvents

Events that are a part of this event. For example, a conference event includes many presentations, each subEvents of the conference.

Relevant types:

- Event

Values:

[^top]

#### subOrganization

A relationship between two organizations where the first includes the second, e.g., as a subsidiary. See also: the more specific 'department' property.

Relevant types:

- Organization

Values:

[^top]

#### subReservation

The individual reservations included in the package. Typically a repeated property.

Relevant types:

- ReservationPackage

Values:

[^top]

#### subStageSuffix

The substage, e.g. 'a' for Stage IIIa.

Relevant types:

- MedicalConditionStage

Values:

[^top]

#### subStructure

Component (sub-)structure(s) that comprise this anatomical structure.

Relevant types:

- AnatomicalStructure

Values:

[^top]

#### subTest

A component test of the panel.

Relevant types:

- MedicalTestPanel

Values:

[^top]

#### subTrip

Identifies a Trip that is a subTrip of this Trip. For example Day 1, Day 2, etc. of a multi-day trip.

Relevant types:

- Trip

Values:

[^top]

#### subjectOf

A CreativeWork or Event about this Thing.

Relevant types:

- Thing

Values:

[^top]

#### subtitleLanguage

Languages in which subtitles/captions are available, in IETF BCP 47 standard format.

Relevant types:

- BroadcastEvent
Relevant types:

- Movie
Relevant types:

- ScreeningEvent
Relevant types:

- TVEpisode

Values:

[^top]

#### successorOf

A pointer from a newer variant of a product to its previous, often discontinued predecessor.

Relevant types:

- ProductModel

Values:

[^top]

#### sugarContent

The number of grams of sugar.

Relevant types:

- NutritionInformation

Values:

[^top]

#### suggestedAge

The age or age range for the intended audience or person, for example 3-12 months for infants, 1-5 years for toddlers.

Relevant types:

- PeopleAudience
Relevant types:

- SizeSpecification

Values:

[^top]

#### suggestedAnswer

An answer (possibly one of several, possibly incorrect) to a Question, e.g. on a Question/Answer site.

Relevant types:

- Question

Values:

[^top]

#### suggestedGender

The suggested gender of the intended person or audience, for example "male", "female", or "unisex".

Relevant types:

- PeopleAudience
Relevant types:

- SizeSpecification

Values:

[^top]

#### suggestedMaxAge

Maximum recommended age in years for the audience or user.

Relevant types:

- PeopleAudience

Values:

[^top]

#### suggestedMeasurement

A suggested range of body measurements for the intended audience or person, for example inseam between 32 and 34 inches or height between 170 and 190 cm. Typically found on a size chart for wearable products.

Relevant types:

- PeopleAudience
Relevant types:

- SizeSpecification

Values:

[^top]

#### suggestedMinAge

Minimum recommended age in years for the audience or user.

Relevant types:

- PeopleAudience

Values:

[^top]

#### suitableForDiet

Indicates a dietary restriction or guideline for which this recipe or menu item is suitable, e.g. diabetic, halal etc.

Relevant types:

- MenuItem
Relevant types:

- Recipe

Values:

[^top]

#### superEvent

An event that this event is a part of. For example, a collection of individual music performances might each have a music festival as their superEvent.

Relevant types:

- Event

Values:

[^top]

#### supersededBy

Relates a term (i.e. a property, class or enumeration) to one that supersedes it.

Relevant types:

- Class
Relevant types:

- Enumeration
Relevant types:

- Property

Values:

[^top]

#### supply

A sub-property of instrument. A supply consumed when performing instructions or a direction.

Relevant types:

- HowTo
Relevant types:

- HowToDirection

Values:

[^top]

#### supplyTo

The area to which the artery supplies blood.

Relevant types:

- Artery

Values:

[^top]

#### supportingData

Supporting data for a SoftwareApplication.

Relevant types:

- SoftwareApplication

Values:

[^top]

#### surface

A material used as a surface in some artwork, e.g. Canvas, Paper, Wood, Board, etc.

Relevant types:

- VisualArtwork

Values:

[^top]

#### target

Indicates a target EntryPoint for an Action.

Relevant types:

- Action

Values:

[^top]

#### targetCollection

A sub property of object. The collection target of the action.

Relevant types:

- UpdateAction

Values:

[^top]

#### targetDescription

The description of a node in an established educational framework.

Relevant types:

- AlignmentObject

Values:

[^top]

#### targetName

The name of a node in an established educational framework.

Relevant types:

- AlignmentObject

Values:

[^top]

#### targetPlatform

Type of app development: phone, Metro style, desktop, XBox, etc.

Relevant types:

- APIReference

Values:

[^top]

#### targetPopulation

Characteristics of the population for which this is intended, or which typically uses it, e.g. 'adults'.

Relevant types:

- DietarySupplement
Relevant types:

- DoseSchedule

Values:

[^top]

#### targetProduct

Target Operating System / Product to which the code applies. If applies to several versions, just the product name can be used.

Relevant types:

- SoftwareSourceCode

Values:

[^top]

#### targetUrl

The URL of a node in an established educational framework.

Relevant types:

- AlignmentObject

Values:

[^top]

#### taxID

The Tax / Fiscal ID of the organization or person, e.g. the TIN in the US or the CIF/NIF in Spain.

Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### teaches

The item being described is intended to help a person learn the competency or learning outcome defined by the referenced term.

Relevant types:

- CreativeWork
Relevant types:

- EducationEvent
Relevant types:

- LearningResource

Values:

[^top]

#### telephone

The telephone number.

Relevant types:

- ContactPoint
Relevant types:

- Organization
Relevant types:

- Person
Relevant types:

- Place

Values:

[^top]

#### temporal

The "temporal" property can be used in cases where more specific properties (e.g. temporalCoverage, dateCreated, dateModified, datePublished) are not known to be appropriate.

Relevant types:

- CreativeWork

Values:

[^top]

#### temporalCoverage

The temporalCoverage of a CreativeWork indicates the period that the content applies to, i.e. that it describes, either as a DateTime or as a textual string indicating a time period in ISO 8601 time interval format. In the case of a Dataset it will typically indicate the relevant time period in a precise notation (e.g. for a 2011 census dataset, the year 2011 would be written "2011/2012"). Other forms of content e.g. ScholarlyArticle, Book, TVSeries or TVEpisode may indicate their temporalCoverage in broader terms - textually or via well-known URL. Written works such as books may sometimes have precise temporal coverage too, e.g. a work set in 1939 - 1945 can be indicated in ISO 8601 interval format format via "1939/1945".
Open-ended date ranges can be written with ".." in place of the end date. For example, "2015-11/.." indicates a range beginning in November 2015 and with no specified final date. This is tentative and might be updated in future when ISO 8601 is officially updated.

Relevant types:

- CreativeWork

Values:

[^top]

#### termCode

A code that identifies this DefinedTerm within a DefinedTermSet

Relevant types:

- DefinedTerm

Values:

[^top]

#### termDuration

The amount of time in a term as defined by the institution. A term is a length of time where students take one or more classes. Semesters and quarters are common units for term.

Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### termsOfService

Human-readable terms of service documentation.

Relevant types:

- Service

Values:

[^top]

#### termsPerYear

The number of times terms of study are offered per year. Semesters and quarters are common units for term. For example, if the student can only take 2 semesters for the program in one year, then termsPerYear should be 2.

Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### text

The textual content of this CreativeWork.

Relevant types:

- CreativeWork

Values:

[^top]

#### textValue

Text value being annotated.

Relevant types:

- PronounceableText

Values:

[^top]

#### thumbnail

Thumbnail image for an image or video.

Relevant types:

- ImageObject
Relevant types:

- VideoObject

Values:

[^top]

#### thumbnailUrl

A thumbnail image relevant to the Thing.

Relevant types:

- CreativeWork

Values:

[^top]

#### tickerSymbol

The exchange traded instrument associated with a Corporation object. The tickerSymbol is expressed as an exchange and an instrument name separated by a space character. For the exchange component of the tickerSymbol attribute, we recommend using the controlled vocabulary of Market Identifier Codes (MIC) specified in ISO15022.

Relevant types:

- Corporation

Values:

[^top]

#### ticketNumber

The unique identifier for the ticket.

Relevant types:

- Ticket

Values:

[^top]

#### ticketToken

Reference to an asset (e.g., Barcode, QR code image or PDF) usable for entrance.

Relevant types:

- Ticket

Values:

[^top]

#### ticketedSeat

The seat associated with the ticket.

Relevant types:

- Ticket

Values:

[^top]

#### timeOfDay

The time of day the program normally runs. For example, "evenings".

Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### timeRequired

Approximate or typical time it takes to work with or through this learning resource for the typical intended target audience, e.g. 'PT30M', 'PT1H25M'.

Relevant types:

- CreativeWork

Values:

[^top]

#### timeToComplete

The expected length of time to complete the program if attending full-time.

Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### tissueSample

The type of tissue sample required for the test.

Relevant types:

- PathologyTest

Values:

[^top]

#### title

The title of the job.

Relevant types:

- JobPosting

Values:

[^top]

#### titleEIDR

An EIDR (Entertainment Identifier Registry) identifier representing at the most general/abstract level, a work of film or television.
For example, the motion picture known as "Ghostbusters" has a titleEIDR of "10.5240/7EC7-228A-510A-053E-CBB8-J". This title (or work) may have several variants, which EIDR calls "edits". See editEIDR.
Since schema.org types like Movie and TVEpisode can be used for both works and their multiple expressions, it is possible to use titleEIDR alone (for a general description), or alongside editEIDR for a more edit-specific description.

Relevant types:

- Movie
Relevant types:

- TVEpisode

Values:

[^top]

#### toLocation

A sub property of location. The final location of the object or the agent after the action.

Relevant types:

- ExerciseAction
Relevant types:

- InsertAction
Relevant types:

- MoveAction
Relevant types:

- TransferAction

Values:

[^top]

#### toRecipient

A sub property of recipient. The recipient who was directly sent the message.

Relevant types:

- Message

Values:

[^top]

#### tocContinuation

A HyperTocEntry can have a tocContinuation indicated, which is another HyperTocEntry that would be the default next item to play or render.

Relevant types:

- HyperTocEntry

Values:

[^top]

#### tocEntry

Indicates a HyperTocEntry in a HyperToc.

Relevant types:

- HyperToc

Values:

[^top]

#### tongueWeight

The permitted vertical load (TWR) of a trailer attached to the vehicle. Also referred to as Tongue Load Rating (TLR) or Vertical Load Rating (VLR)
Typical unit code(s): KGM for kilogram, LBR for pound

- Note 1: You can indicate additional information in the name of the QuantitativeValue node.
- Note 2: You may also link to a QualitativeValue node that provides additional information using valueReference.
- Note 3: Note that you can use minValue and maxValue to indicate ranges.

Relevant types:

- Vehicle

Values:

[^top]

#### tool

A sub property of instrument. An object used (but not consumed) when performing instructions or a direction.

Relevant types:

- HowTo
Relevant types:

- HowToDirection

Values:

[^top]

#### torque

The torque (turning force) of the vehicle's engine.
Typical unit code(s): NU for newton metre (N m), F17 for pound-force per foot, or F48 for pound-force per inch

- Note 1: You can link to information about how the given value has been determined (e.g. reference RPM) using the valueReference property.
- Note 2: You can use minValue and maxValue to indicate ranges.

Relevant types:

- EngineSpecification

Values:

[^top]

#### totalJobOpenings

The number of positions open for this job posting. Use a positive integer. Do not use if the number of positions is unclear or not known.

Relevant types:

- JobPosting

Values:

[^top]

#### totalPaymentDue

The total amount due.

Relevant types:

- Invoice

Values:

[^top]

#### totalPrice

The total price for the reservation or ticket, including applicable taxes, shipping, etc.
Usage guidelines:

- Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similiar Unicode symbols.
- Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.

Relevant types:

- Reservation
Relevant types:

- Ticket

Values:

[^top]

#### totalTime

The total time required to perform instructions or a direction (including time to prepare the supplies), in ISO 8601 duration format.

Relevant types:

- HowTo
Relevant types:

- HowToDirection

Values:

[^top]

#### tourBookingPage

A page providing information on how to book a tour of some Place, such as an Accommodation or ApartmentComplex in a real estate setting, as well as other kinds of tours as appropriate.

Relevant types:

- Accommodation
Relevant types:

- ApartmentComplex
Relevant types:

- Place

Values:

[^top]

#### touristType

Attraction suitable for type(s) of tourist. eg. Children, visitors from a particular country, etc.

Relevant types:

- TouristAttraction
Relevant types:

- TouristDestination
Relevant types:

- TouristTrip

Values:

[^top]

#### track

A music recording (track)—usually a single song. If an ItemList is given, the list should contain items of type MusicRecording.

Relevant types:

- MusicGroup
Relevant types:

- MusicPlaylist

Values:

[^top]

#### trackingNumber

Shipper tracking number.

Relevant types:

- ParcelDelivery

Values:

[^top]

#### trackingUrl

Tracking url for the parcel delivery.

Relevant types:

- ParcelDelivery

Values:

[^top]

#### tracks

A music recording (track)—usually a single song.

Relevant types:

- MusicGroup
Relevant types:

- MusicPlaylist

Values:

[^top]

#### trailer

The trailer of a movie or tv/radio series, season, episode, etc.

Relevant types:

- CreativeWorkSeason
Relevant types:

- Episode
Relevant types:

- Movie
Relevant types:

- MovieSeries
Relevant types:

- RadioSeries
Relevant types:

- TVSeries
Relevant types:

- VideoGame
Relevant types:

- VideoGameSeries

Values:

[^top]

#### trailerWeight

The permitted weight of a trailer attached to the vehicle.
Typical unit code(s): KGM for kilogram, LBR for pound * Note 1: You can indicate additional information in the name of the QuantitativeValue node. * Note 2: You may also link to a QualitativeValue node that provides additional information using valueReference. * Note 3: Note that you can use minValue and maxValue to indicate ranges.

Relevant types:

- Vehicle

Values:

[^top]

#### trainName

The name of the train (e.g. The Orient Express).

Relevant types:

- TrainTrip

Values:

[^top]

#### trainNumber

The unique identifier for the train.

Relevant types:

- TrainTrip

Values:

[^top]

#### trainingSalary

The estimated salary earned while in the program.

Relevant types:

- EducationalOccupationalProgram
Relevant types:

- WorkBasedProgram

Values:

[^top]

#### transFatContent

The number of grams of trans fat.

Relevant types:

- NutritionInformation

Values:

[^top]

#### transcript

If this MediaObject is an AudioObject or VideoObject, the transcript of that object.

Relevant types:

- AudioObject
Relevant types:

- VideoObject

Values:

[^top]

#### transitTime

The typical delay the order has been sent for delivery and the goods reach the final customer. Typical properties: minValue, maxValue, unitCode (d for DAY).

Relevant types:

- ShippingDeliveryTime

Values:

[^top]

#### transitTimeLabel

Label to match an OfferShippingDetails with a DeliveryTimeSettings (within the context of a shippingSettingsLink cross-reference).

Relevant types:

- DeliveryTimeSettings
Relevant types:

- OfferShippingDetails

Values:

[^top]

#### translationOfWork

The work that this work has been translated from. e.g. 物种起源 is a translationOf “On the Origin of Species”

Relevant types:

- CreativeWork

Values:

[^top]

#### translator

Organization or person who adapts a creative work to different languages, regional differences and technical requirements of a target market, or that translates during some event.

Relevant types:

- CreativeWork
Relevant types:

- Event

Values:

[^top]

#### transmissionMethod

How the disease spreads, either as a route or vector, for example 'direct contact', 'Aedes aegypti', etc.

Relevant types:

- InfectiousDisease

Values:

[^top]

#### travelBans

Information about travel bans, e.g. in the context of a pandemic.

Relevant types:

- SpecialAnnouncement

Values:

[^top]

#### trialDesign

Specifics about the trial design (enumerated).

Relevant types:

- MedicalTrial

Values:

[^top]

#### tributary

The anatomical or organ system that the vein flows into; a larger structure that the vein connects to.

Relevant types:

- Vein

Values:

[^top]

#### typeOfBed

The type of bed to which the BedDetail refers, i.e. the type of bed available in the quantity indicated by quantity.

Relevant types:

- BedDetails

Values:

[^top]

#### typeOfGood

The product that this structured value is referring to.

Relevant types:

- OwnershipInfo
Relevant types:

- TypeAndQuantityNode

Values:

[^top]

#### typicalAgeRange

The typical expected age range, e.g. '7-9', '11-'.

Relevant types:

- CreativeWork
Relevant types:

- Event

Values:

[^top]

#### typicalCreditsPerTerm

The number of credits or units a full-time student would be expected to take in 1 term however 'term' is defined by the institution.

Relevant types:

- EducationalOccupationalProgram

Values:

[^top]

#### typicalTest

A medical test typically performed given this condition.

Relevant types:

- MedicalCondition

Values:

[^top]

#### underName

The person or organization the reservation or ticket is for.

Relevant types:

- Reservation
Relevant types:

- Ticket

Values:

[^top]

#### unitCode

The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon.

Relevant types:

- PropertyValue
Relevant types:

- QuantitativeValue
Relevant types:

- TypeAndQuantityNode
Relevant types:

- UnitPriceSpecification

Values:

[^top]

#### unitText

A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for unitCode.

Relevant types:

- PropertyValue
Relevant types:

- QuantitativeValue
Relevant types:

- TypeAndQuantityNode
Relevant types:

- UnitPriceSpecification

Values:

[^top]

#### unnamedSourcesPolicy

For an Organization (typically a NewsMediaOrganization), a statement about policy on use of unnamed sources and the decision process required.

Relevant types:

- NewsMediaOrganization
Relevant types:

- Organization

Values:

[^top]

#### unsaturatedFatContent

The number of grams of unsaturated fat.

Relevant types:

- NutritionInformation

Values:

[^top]

#### uploadDate

Date when this media object was uploaded to this site.

Relevant types:

- MediaObject

Values:

[^top]

#### upvoteCount

The number of upvotes this question, answer or comment has received from the community.

Relevant types:

- Comment

Values:

[^top]

#### url

URL of the item.

Relevant types:

- Thing

Values:

[^top]

#### urlTemplate

An url template (RFC6570) that will be used to construct the target of the execution of the action.

Relevant types:

- EntryPoint

Values:

[^top]

#### usageInfo

The schema.org usageInfo property indicates further information about a CreativeWork. This property is applicable both to works that are freely available and to those that require payment or other transactions. It can reference additional information e.g. community expectations on preferred linking and citation conventions, as well as purchasing details. For something that can be commercially licensed, usageInfo can provide detailed, resource-specific information about licensing options.
This property can be used alongside the license property which indicates license(s) applicable to some piece of content. The usageInfo property can provide information about other licensing options, e.g. acquiring commercial usage rights for an image that is also available under non-commercial creative commons licenses.

Relevant types:

- CreativeWork

Values:

[^top]

#### usedToDiagnose

A condition the test is used to diagnose.

Relevant types:

- MedicalTest

Values:

[^top]

#### userInteractionCount

The number of interactions for the CreativeWork using the WebSite or SoftwareApplication.

Relevant types:

- InteractionCounter

Values:

[^top]

#### usesDevice

Device used to perform the test.

Relevant types:

- MedicalTest

Values:

[^top]

#### usesHealthPlanIdStandard

The standard for interpreting thePlan ID. The preferred is "HIOS". See the Centers for Medicare & Medicaid Services for more details.

Relevant types:

- HealthInsurancePlan

Values:

[^top]

#### utterances

Text of an utterances (spoken words, lyrics etc.) that occurs at a certain section of a media object, represented as a HyperTocEntry.

Relevant types:

- HyperTocEntry

Values:

[^top]

#### validFor

The duration of validity of a permit or similar thing.

Relevant types:

- EducationalOccupationalCredential
Relevant types:

- Permit

Values:

[^top]

#### validFrom

The date when the item becomes valid.

Relevant types:

- Demand
Relevant types:

- LocationFeatureSpecification
Relevant types:

- MonetaryAmount
Relevant types:

- Offer
Relevant types:

- OpeningHoursSpecification
Relevant types:

- Permit
Relevant types:

- PriceSpecification

Values:

[^top]

#### validIn

The geographic area where a permit or similar thing is valid.

Relevant types:

- EducationalOccupationalCredential
Relevant types:

- Permit

Values:

[^top]

#### validThrough

The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.

Relevant types:

- Demand
Relevant types:

- JobPosting
Relevant types:

- LocationFeatureSpecification
Relevant types:

- MonetaryAmount
Relevant types:

- Offer
Relevant types:

- OpeningHoursSpecification
Relevant types:

- PriceSpecification

Values:

[^top]

#### validUntil

The date when the item is no longer valid.

Relevant types:

- Permit

Values:

[^top]

#### value

The value of the quantitative value or property value node.

- For QuantitativeValue and MonetaryAmount, the recommended type for values is 'Number'.
- For PropertyValue, it can be 'Text;', 'Number', 'Boolean', or 'StructuredValue'.
- Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similiar Unicode symbols.
- Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.

Relevant types:

- MonetaryAmount
Relevant types:

- PropertyValue
Relevant types:

- QuantitativeValue

Values:

[^top]

#### valueAddedTaxIncluded

Specifies whether the applicable value-added tax (VAT) is included in the price specification or not.

Relevant types:

- PriceSpecification

Values:

[^top]

#### valueMaxLength

Specifies the allowed range for number of characters in a literal value.

Relevant types:

- PropertyValueSpecification

Values:

[^top]

#### valueMinLength

Specifies the minimum allowed range for number of characters in a literal value.

Relevant types:

- PropertyValueSpecification

Values:

[^top]

#### valueName

Indicates the name of the PropertyValueSpecification to be used in URL templates and form encoding in a manner analogous to HTML's input@name.

Relevant types:

- PropertyValueSpecification

Values:

[^top]

#### valuePattern

Specifies a regular expression for testing literal values according to the HTML spec.

Relevant types:

- PropertyValueSpecification

Values:

[^top]

#### valueReference

A secondary value that provides additional information on the original value, e.g. a reference temperature or a type of measurement.

Relevant types:

- PropertyValue
Relevant types:

- QualitativeValue
Relevant types:

- QuantitativeValue

Values:

[^top]

#### valueRequired

Whether the property must be filled in to complete the action. Default is false.

Relevant types:

- PropertyValueSpecification

Values:

[^top]

#### variableMeasured

The variableMeasured property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue.

Relevant types:

- Dataset

Values:

[^top]

#### variablesMeasured

Originally named variablesMeasured, The variableMeasured property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue.

Relevant types:

- Dataset

Values:

[^top]

#### variantCover

A description of the variant cover for the issue, if the issue is a variant printing. For example, "Bryan Hitch Variant Cover" or "2nd Printing Variant".

Relevant types:

- ComicIssue

Values:

[^top]

#### variesBy

Indicates the property or properties by which the variants in a ProductGroup vary, e.g. their size, color etc. Schema.org properties can be referenced by their short name e.g. "color"; terms defined elsewhere can be referenced with their URIs.

Relevant types:

- ProductGroup

Values:

[^top]

#### vatID

The Value-added Tax ID of the organization or person.

Relevant types:

- Organization
Relevant types:

- Person

Values:

[^top]

#### vehicleConfiguration

A short text indicating the configuration of the vehicle, e.g. '5dr hatchback ST 2.5 MT 225 hp' or 'limited edition'.

Relevant types:

- Vehicle

Values:

[^top]

#### vehicleEngine

Information about the engine or engines of the vehicle.

Relevant types:

- Vehicle

Values:

[^top]

#### vehicleIdentificationNumber

The Vehicle Identification Number (VIN) is a unique serial number used by the automotive industry to identify individual motor vehicles.

Relevant types:

- Vehicle

Values:

[^top]

#### vehicleInteriorColor

The color or color combination of the interior of the vehicle.

Relevant types:

- Vehicle

Values:

[^top]

#### vehicleInteriorType

The type or material of the interior of the vehicle (e.g. synthetic fabric, leather, wood, etc.). While most interior types are characterized by the material used, an interior type can also be based on vehicle usage or target audience.

Relevant types:

- Vehicle

Values:

[^top]

#### vehicleModelDate

The release date of a vehicle model (often used to differentiate versions of the same make and model).

Relevant types:

- Vehicle

Values:

[^top]

#### vehicleSeatingCapacity

The number of passengers that can be seated in the vehicle, both in terms of the physical space available, and in terms of limitations set by law.
Typical unit code(s): C62 for persons.

Relevant types:

- Vehicle

Values:

[^top]

#### vehicleSpecialUsage

Indicates whether the vehicle has been used for special purposes, like commercial rental, driving school, or as a taxi. The legislation in many countries requires this information to be revealed when offering a car for sale.

Relevant types:

- Vehicle

Values:

[^top]

#### vehicleTransmission

The type of component used for transmitting the power from a rotating power source to the wheels or other relevant component(s) ("gearbox" for cars).

Relevant types:

- Vehicle

Values:

[^top]

#### vendor

'vendor' is an earlier term for 'seller'.

Relevant types:

- BuyAction

Values:

[^top]

#### verificationFactCheckingPolicy

Disclosure about verification and fact-checking processes for a NewsMediaOrganization or other fact-checking Organization.

Relevant types:

- NewsMediaOrganization

Values:

[^top]

#### version

The version of the CreativeWork embodied by a specified resource.

Relevant types:

- CreativeWork

Values:

[^top]

#### video

An embedded video object.

Relevant types:

- CreativeWork

Values:

[^top]

#### videoFormat

The type of screening or video broadcast used (e.g. IMAX, 3D, SD, HD, etc.).

Relevant types:

- BroadcastEvent
Relevant types:

- BroadcastService
Relevant types:

- ScreeningEvent

Values:

[^top]

#### videoFrameSize

The frame size of the video.

Relevant types:

- VideoObject

Values:

[^top]

#### videoQuality

The quality of the video.

Relevant types:

- VideoObject

Values:

[^top]

#### volumeNumber

Identifies the volume of publication or multi-part work; for example, "iii" or "2".

Relevant types:

- PublicationVolume

Values:

[^top]

#### warning

Any FDA or other warnings about the drug (text or URL).

Relevant types:

- Drug

Values:

[^top]

#### warranty

The warranty promise(s) included in the offer.

Relevant types:

- Demand
Relevant types:

- Offer

Values:

[^top]

#### warrantyPromise

The warranty promise(s) included in the offer.

Relevant types:

- BuyAction
Relevant types:

- SellAction

Values:

[^top]

#### warrantyScope

The scope of the warranty promise.

Relevant types:

- WarrantyPromise

Values:

[^top]

#### webCheckinTime

The time when a passenger can check into the flight online.

Relevant types:

- Flight

Values:

[^top]

#### webFeed

The URL for a feed, e.g. associated with a podcast series, blog, or series of date-stamped updates. This is usually RSS or Atom.

Relevant types:

- PodcastSeries
Relevant types:

- SpecialAnnouncement

Values:

[^top]

#### weight

The weight of the product or person.

Relevant types:

- Person
Relevant types:

- Product

Values:

[^top]

#### weightTotal

The permitted total weight of the loaded vehicle, including passengers and cargo and the weight of the empty vehicle.
Typical unit code(s): KGM for kilogram, LBR for pound

- Note 1: You can indicate additional information in the name of the QuantitativeValue node.
- Note 2: You may also link to a QualitativeValue node that provides additional information using valueReference.
- Note 3: Note that you can use minValue and maxValue to indicate ranges.

Relevant types:

- Vehicle

Values:

[^top]

#### wheelbase

The distance between the centers of the front and rear wheels.
Typical unit code(s): CMT for centimeters, MTR for meters, INH for inches, FOT for foot/feet

Relevant types:

- Vehicle

Values:

[^top]

#### width

The width of the item.

Relevant types:

- MediaObject
Relevant types:

- Product
Relevant types:

- VisualArtwork

Values:

[^top]

#### winner

A sub property of participant. The winner of the action.

Relevant types:

- LoseAction

Values:

[^top]

#### wordCount

The number of words in the text of the Article.

Relevant types:

- Article

Values:

[^top]

#### workExample

Example/instance/realization/derivation of the concept of this creative work. eg. The paperback edition, first edition, or eBook.

Relevant types:

- CreativeWork

Values:

[^top]

#### workFeatured

A work featured in some event, e.g. exhibited in an ExhibitionEvent. Specific subproperties are available for workPerformed (e.g. a play), or a workPresented (a Movie at a ScreeningEvent).

Relevant types:

- Event

Values:

[^top]

#### workHours

The typical working hours for this job (e.g. 1st shift, night shift, 8am-5pm).

Relevant types:

- JobPosting

Values:

[^top]

#### workLocation

A contact location for a person's place of work.

Relevant types:

- Person

Values:

[^top]

#### workPerformed

A work performed in some event, for example a play performed in a TheaterEvent.

Relevant types:

- Event

Values:

[^top]

#### workPresented

The movie presented during this event.

Relevant types:

- ScreeningEvent

Values:

[^top]

#### workTranslation

A work that is a translation of the content of this work. e.g. 西遊記 has an English workTranslation “Journey to the West”,a German workTranslation “Monkeys Pilgerfahrt” and a Vietnamese translation Tây du ký bình khảo.

Relevant types:

- CreativeWork

Values:

[^top]

#### workload

Quantitative measure of the physiologic output of the exercise; also referred to as energy expenditure.

Relevant types:

- ExercisePlan

Values:

[^top]

#### worksFor

Organizations that the person works for.

Relevant types:

- Person

Values:

[^top]

#### worstRating

The lowest value allowed in this rating system. If worstRating is omitted, 1 is assumed.

Relevant types:

- Rating

Values:

[^top]

#### xpath

An XPath, e.g. of a SpeakableSpecification or WebPageElement. In the latter case, multiple matches within a page can constitute a single conceptual "Web page element".

Relevant types:

- SpeakableSpecification
Relevant types:

- WebPageElement

Values:

[^top]

#### yearBuilt

The year an Accommodation was constructed. This corresponds to the YearBuilt field in RESO.

Relevant types:

- Accommodation

Values:

[^top]

#### yearlyRevenue

The size of the business in annual revenue.

Relevant types:

- BusinessAudience

Values:

[^top]

#### yearsInOperation

The age of the business.

Relevant types:

- BusinessAudience

Values:

[^top]

#### yield

The quantity that results by performing instructions. For example, a paper airplane, 10 personalized candles.

Relevant types:

- HowTo

Values:

[^top]